import * as pulumi from "@pulumi/pulumi";
/**
 * Directory is a component representing a collection of resources described by a kustomize directory (kustomization).
 *
 * ## Example Usage
 * ### Local Kustomize Directory
 * ```typescript
 * import * as k8s from "@pulumi/kubernetes";
 *
 * const helloWorld = new k8s.kustomize.v2.Directory("helloWorldLocal", {
 *     directory: "./helloWorld",
 * });
 * ```
 * ### Kustomize Directory from a Git Repo
 * ```typescript
 * import * as k8s from "@pulumi/kubernetes";
 *
 * const helloWorld = new k8s.kustomize.v2.Directory("helloWorldRemote", {
 *     directory: "https://github.com/kubernetes-sigs/kustomize/tree/v3.3.1/examples/helloWorld",
 * });
 * ```
 */
export declare class Directory extends pulumi.ComponentResource {
    /**
     * Returns true if the given object is an instance of Directory.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Directory;
    /**
     * Resources created by the Directory resource.
     */
    readonly resources: pulumi.Output<string>;
    /**
     * Create a Directory resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DirectoryArgs, opts?: pulumi.ComponentResourceOptions);
}
/**
 * The set of arguments for constructing a Directory resource.
 */
export interface DirectoryArgs {
    /**
     * The directory containing the kustomization to apply. The value can be a local directory or a folder in a
     * git repository.
     * Example: ./helloWorld
     * Example: https://github.com/kubernetes-sigs/kustomize/tree/master/examples/helloWorld
     */
    directory: pulumi.Input<string>;
    /**
     * The default namespace to apply to the resources. Defaults to the provider's namespace.
     */
    namespace?: pulumi.Input<string>;
    /**
     * A prefix for the auto-generated resource names. Defaults to the name of the Directory resource. Example: A resource created with resourcePrefix="foo" would produce a resource named "foo:resourceName".
     */
    resourcePrefix?: pulumi.Input<string>;
    /**
     * Indicates that child resources should skip the await logic.
     */
    skipAwait?: pulumi.Input<boolean>;
}
