import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../../types/input";
import * as outputs from "../../types/output";
/**
 * PodDisruptionBudget is an object to define the max disruption that can be caused to a collection of pods
 */
export declare class PodDisruptionBudget extends pulumi.CustomResource {
    /**
     * Get an existing PodDisruptionBudget resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): PodDisruptionBudget;
    /**
     * Returns true if the given object is an instance of PodDisruptionBudget.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PodDisruptionBudget;
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    readonly apiVersion: pulumi.Output<"policy/v1beta1">;
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    readonly kind: pulumi.Output<"PodDisruptionBudget">;
    readonly metadata: pulumi.Output<outputs.meta.v1.ObjectMeta>;
    /**
     * Specification of the desired behavior of the PodDisruptionBudget.
     */
    readonly spec: pulumi.Output<outputs.policy.v1beta1.PodDisruptionBudgetSpec>;
    /**
     * Most recently observed status of the PodDisruptionBudget.
     */
    readonly status: pulumi.Output<outputs.policy.v1beta1.PodDisruptionBudgetStatus>;
    /**
     * Create a PodDisruptionBudget resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: PodDisruptionBudgetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a PodDisruptionBudget resource.
 */
export interface PodDisruptionBudgetArgs {
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    apiVersion?: pulumi.Input<"policy/v1beta1">;
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    kind?: pulumi.Input<"PodDisruptionBudget">;
    metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
    /**
     * Specification of the desired behavior of the PodDisruptionBudget.
     */
    spec?: pulumi.Input<inputs.policy.v1beta1.PodDisruptionBudgetSpec>;
}
