import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as enums from "../types/enums";
/**
 * Options to configure the Helm Release resource.
 */
export interface HelmReleaseSettings {
    /**
     * The backend storage driver for Helm. Values are: configmap, secret, memory, sql.
     */
    driver?: pulumi.Input<string>;
    /**
     * The path to the helm plugins directory.
     */
    pluginsPath?: pulumi.Input<string>;
    /**
     * The path to the registry config file.
     */
    registryConfigPath?: pulumi.Input<string>;
    /**
     * The path to the directory containing cached repository indexes.
     */
    repositoryCache?: pulumi.Input<string>;
    /**
     * The path to the file containing repository names and URLs.
     */
    repositoryConfigPath?: pulumi.Input<string>;
}
/**
 * helmReleaseSettingsProvideDefaults sets the appropriate defaults for HelmReleaseSettings
 */
export declare function helmReleaseSettingsProvideDefaults(val: HelmReleaseSettings): HelmReleaseSettings;
/**
 * Options for tuning the Kubernetes client used by a Provider.
 */
export interface KubeClientSettings {
    /**
     * Maximum burst for throttle. Default value is 120.
     */
    burst?: pulumi.Input<number>;
    /**
     * Maximum queries per second (QPS) to the API server from this client. Default value is 50.
     */
    qps?: pulumi.Input<number>;
    /**
     * Maximum time in seconds to wait before cancelling a HTTP request to the Kubernetes server. Default value is 32.
     */
    timeout?: pulumi.Input<number>;
}
/**
 * kubeClientSettingsProvideDefaults sets the appropriate defaults for KubeClientSettings
 */
export declare function kubeClientSettingsProvideDefaults(val: KubeClientSettings): KubeClientSettings;
export declare namespace admissionregistration {
    namespace v1 {
        /**
         * AuditAnnotation describes how to produce an audit annotation for an API request.
         */
        interface AuditAnnotation {
            /**
             * key specifies the audit annotation key. The audit annotation keys of a ValidatingAdmissionPolicy must be unique. The key must be a qualified name ([A-Za-z0-9][-A-Za-z0-9_.]*) no more than 63 bytes in length.
             *
             * The key is combined with the resource name of the ValidatingAdmissionPolicy to construct an audit annotation key: "{ValidatingAdmissionPolicy name}/{key}".
             *
             * If an admission webhook uses the same resource name as this ValidatingAdmissionPolicy and the same audit annotation key, the annotation key will be identical. In this case, the first annotation written with the key will be included in the audit event and all subsequent annotations with the same key will be discarded.
             *
             * Required.
             */
            key: pulumi.Input<string>;
            /**
             * valueExpression represents the expression which is evaluated by CEL to produce an audit annotation value. The expression must evaluate to either a string or null value. If the expression evaluates to a string, the audit annotation is included with the string value. If the expression evaluates to null or empty string the audit annotation will be omitted. The valueExpression may be no longer than 5kb in length. If the result of the valueExpression is more than 10kb in length, it will be truncated to 10kb.
             *
             * If multiple ValidatingAdmissionPolicyBinding resources match an API request, then the valueExpression will be evaluated for each binding. All unique values produced by the valueExpressions will be joined together in a comma-separated list.
             *
             * Required.
             */
            valueExpression: pulumi.Input<string>;
        }
        /**
         * AuditAnnotation describes how to produce an audit annotation for an API request.
         */
        interface AuditAnnotationPatch {
            /**
             * key specifies the audit annotation key. The audit annotation keys of a ValidatingAdmissionPolicy must be unique. The key must be a qualified name ([A-Za-z0-9][-A-Za-z0-9_.]*) no more than 63 bytes in length.
             *
             * The key is combined with the resource name of the ValidatingAdmissionPolicy to construct an audit annotation key: "{ValidatingAdmissionPolicy name}/{key}".
             *
             * If an admission webhook uses the same resource name as this ValidatingAdmissionPolicy and the same audit annotation key, the annotation key will be identical. In this case, the first annotation written with the key will be included in the audit event and all subsequent annotations with the same key will be discarded.
             *
             * Required.
             */
            key?: pulumi.Input<string>;
            /**
             * valueExpression represents the expression which is evaluated by CEL to produce an audit annotation value. The expression must evaluate to either a string or null value. If the expression evaluates to a string, the audit annotation is included with the string value. If the expression evaluates to null or empty string the audit annotation will be omitted. The valueExpression may be no longer than 5kb in length. If the result of the valueExpression is more than 10kb in length, it will be truncated to 10kb.
             *
             * If multiple ValidatingAdmissionPolicyBinding resources match an API request, then the valueExpression will be evaluated for each binding. All unique values produced by the valueExpressions will be joined together in a comma-separated list.
             *
             * Required.
             */
            valueExpression?: pulumi.Input<string>;
        }
        /**
         * ExpressionWarning is a warning information that targets a specific expression.
         */
        interface ExpressionWarning {
            /**
             * The path to the field that refers the expression. For example, the reference to the expression of the first item of validations is "spec.validations[0].expression"
             */
            fieldRef: pulumi.Input<string>;
            /**
             * The content of type checking information in a human-readable form. Each line of the warning contains the type that the expression is checked against, followed by the type check error from the compiler.
             */
            warning: pulumi.Input<string>;
        }
        /**
         * MatchCondition represents a condition which must by fulfilled for a request to be sent to a webhook.
         */
        interface MatchCondition {
            /**
             * Expression represents the expression which will be evaluated by CEL. Must evaluate to bool. CEL expressions have access to the contents of the AdmissionRequest and Authorizer, organized into CEL variables:
             *
             * 'object' - The object from the incoming request. The value is null for DELETE requests. 'oldObject' - The existing object. The value is null for CREATE requests. 'request' - Attributes of the admission request(/pkg/apis/admission/types.go#AdmissionRequest). 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
             *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
             * 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
             *   request resource.
             * Documentation on CEL: https://kubernetes.io/docs/reference/using-api/cel/
             *
             * Required.
             */
            expression: pulumi.Input<string>;
            /**
             * Name is an identifier for this match condition, used for strategic merging of MatchConditions, as well as providing an identifier for logging purposes. A good name should be descriptive of the associated expression. Name must be a qualified name consisting of alphanumeric characters, '-', '_' or '.', and must start and end with an alphanumeric character (e.g. 'MyName',  or 'my.name',  or '123-abc', regex used for validation is '([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9]') with an optional DNS subdomain prefix and '/' (e.g. 'example.com/MyName')
             *
             * Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * MatchCondition represents a condition which must by fulfilled for a request to be sent to a webhook.
         */
        interface MatchConditionPatch {
            /**
             * Expression represents the expression which will be evaluated by CEL. Must evaluate to bool. CEL expressions have access to the contents of the AdmissionRequest and Authorizer, organized into CEL variables:
             *
             * 'object' - The object from the incoming request. The value is null for DELETE requests. 'oldObject' - The existing object. The value is null for CREATE requests. 'request' - Attributes of the admission request(/pkg/apis/admission/types.go#AdmissionRequest). 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
             *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
             * 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
             *   request resource.
             * Documentation on CEL: https://kubernetes.io/docs/reference/using-api/cel/
             *
             * Required.
             */
            expression?: pulumi.Input<string>;
            /**
             * Name is an identifier for this match condition, used for strategic merging of MatchConditions, as well as providing an identifier for logging purposes. A good name should be descriptive of the associated expression. Name must be a qualified name consisting of alphanumeric characters, '-', '_' or '.', and must start and end with an alphanumeric character (e.g. 'MyName',  or 'my.name',  or '123-abc', regex used for validation is '([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9]') with an optional DNS subdomain prefix and '/' (e.g. 'example.com/MyName')
             *
             * Required.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * MatchResources decides whether to run the admission control policy on an object based on whether it meets the match criteria. The exclude rules take precedence over include rules (if a resource matches both, it is excluded)
         */
        interface MatchResources {
            /**
             * ExcludeResourceRules describes what operations on what resources/subresources the ValidatingAdmissionPolicy should not care about. The exclude rules take precedence over include rules (if a resource matches both, it is excluded)
             */
            excludeResourceRules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.NamedRuleWithOperations>[]>;
            /**
             * matchPolicy defines how the "MatchResources" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
             *
             * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the ValidatingAdmissionPolicy.
             *
             * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the ValidatingAdmissionPolicy.
             *
             * Defaults to "Equivalent"
             */
            matchPolicy?: pulumi.Input<string>;
            /**
             * NamespaceSelector decides whether to run the admission control policy on an object based on whether the namespace for that object matches the selector. If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the policy.
             *
             * For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "runlevel",
             *       "operator": "NotIn",
             *       "values": [
             *         "0",
             *         "1"
             *       ]
             *     }
             *   ]
             * }
             *
             * If instead you want to only run the policy on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "environment",
             *       "operator": "In",
             *       "values": [
             *         "prod",
             *         "staging"
             *       ]
             *     }
             *   ]
             * }
             *
             * See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/ for more examples of label selectors.
             *
             * Default to the empty LabelSelector, which matches everything.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * ObjectSelector decides whether to run the validation based on if the object has matching labels. objectSelector is evaluated against both the oldObject and newObject that would be sent to the cel validation, and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.
             */
            objectSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * ResourceRules describes what operations on what resources/subresources the ValidatingAdmissionPolicy matches. The policy cares about an operation if it matches _any_ Rule.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.NamedRuleWithOperations>[]>;
        }
        /**
         * MatchResources decides whether to run the admission control policy on an object based on whether it meets the match criteria. The exclude rules take precedence over include rules (if a resource matches both, it is excluded)
         */
        interface MatchResourcesPatch {
            /**
             * ExcludeResourceRules describes what operations on what resources/subresources the ValidatingAdmissionPolicy should not care about. The exclude rules take precedence over include rules (if a resource matches both, it is excluded)
             */
            excludeResourceRules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.NamedRuleWithOperationsPatch>[]>;
            /**
             * matchPolicy defines how the "MatchResources" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
             *
             * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the ValidatingAdmissionPolicy.
             *
             * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the ValidatingAdmissionPolicy.
             *
             * Defaults to "Equivalent"
             */
            matchPolicy?: pulumi.Input<string>;
            /**
             * NamespaceSelector decides whether to run the admission control policy on an object based on whether the namespace for that object matches the selector. If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the policy.
             *
             * For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "runlevel",
             *       "operator": "NotIn",
             *       "values": [
             *         "0",
             *         "1"
             *       ]
             *     }
             *   ]
             * }
             *
             * If instead you want to only run the policy on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "environment",
             *       "operator": "In",
             *       "values": [
             *         "prod",
             *         "staging"
             *       ]
             *     }
             *   ]
             * }
             *
             * See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/ for more examples of label selectors.
             *
             * Default to the empty LabelSelector, which matches everything.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * ObjectSelector decides whether to run the validation based on if the object has matching labels. objectSelector is evaluated against both the oldObject and newObject that would be sent to the cel validation, and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.
             */
            objectSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * ResourceRules describes what operations on what resources/subresources the ValidatingAdmissionPolicy matches. The policy cares about an operation if it matches _any_ Rule.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.NamedRuleWithOperationsPatch>[]>;
        }
        /**
         * MutatingWebhook describes an admission webhook and the resources and operations it applies to.
         */
        interface MutatingWebhook {
            /**
             * AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy.
             */
            admissionReviewVersions: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ClientConfig defines how to communicate with the hook. Required
             */
            clientConfig: pulumi.Input<inputs.admissionregistration.v1.WebhookClientConfig>;
            /**
             * FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Fail.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * MatchConditions is a list of conditions that must be met for a request to be sent to this webhook. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
             *
             * The exact matching logic is (in order):
             *   1. If ANY matchCondition evaluates to FALSE, the webhook is skipped.
             *   2. If ALL matchConditions evaluate to TRUE, the webhook is called.
             *   3. If any matchCondition evaluates to an error (but none are FALSE):
             *      - If failurePolicy=Fail, reject the request
             *      - If failurePolicy=Ignore, the error is ignored and the webhook is skipped
             */
            matchConditions?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.MatchCondition>[]>;
            /**
             * matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
             *
             * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.
             *
             * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.
             *
             * Defaults to "Equivalent"
             */
            matchPolicy?: pulumi.Input<string>;
            /**
             * The name of the admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required.
             */
            name: pulumi.Input<string>;
            /**
             * NamespaceSelector decides whether to run the webhook on an object based on whether the namespace for that object matches the selector. If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the webhook.
             *
             * For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "runlevel",
             *       "operator": "NotIn",
             *       "values": [
             *         "0",
             *         "1"
             *       ]
             *     }
             *   ]
             * }
             *
             * If instead you want to only run the webhook on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "environment",
             *       "operator": "In",
             *       "values": [
             *         "prod",
             *         "staging"
             *       ]
             *     }
             *   ]
             * }
             *
             * See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/ for more examples of label selectors.
             *
             * Default to the empty LabelSelector, which matches everything.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * ObjectSelector decides whether to run the webhook based on if the object has matching labels. objectSelector is evaluated against both the oldObject and newObject that would be sent to the webhook, and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.
             */
            objectSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * reinvocationPolicy indicates whether this webhook should be called multiple times as part of a single admission evaluation. Allowed values are "Never" and "IfNeeded".
             *
             * Never: the webhook will not be called more than once in a single admission evaluation.
             *
             * IfNeeded: the webhook will be called at least one additional time as part of the admission evaluation if the object being admitted is modified by other admission plugins after the initial webhook call. Webhooks that specify this option *must* be idempotent, able to process objects they previously admitted. Note: * the number of additional invocations is not guaranteed to be exactly one. * if additional invocations result in further modifications to the object, webhooks are not guaranteed to be invoked again. * webhooks that use this option may be reordered to minimize the number of additional invocations. * to validate an object after all mutations are guaranteed complete, use a validating admission webhook instead.
             *
             * Defaults to "Never".
             */
            reinvocationPolicy?: pulumi.Input<string>;
            /**
             * Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches _any_ Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.RuleWithOperations>[]>;
            /**
             * SideEffects states whether this webhook has side effects. Acceptable values are: None, NoneOnDryRun (webhooks created via v1beta1 may also specify Some or Unknown). Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission chain and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some.
             */
            sideEffects: pulumi.Input<string>;
            /**
             * TimeoutSeconds specifies the timeout for this webhook. After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 10 seconds.
             */
            timeoutSeconds?: pulumi.Input<number>;
        }
        /**
         * MutatingWebhookConfiguration describes the configuration of and admission webhook that accept or reject and may change the object.
         */
        interface MutatingWebhookConfiguration {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"admissionregistration.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"MutatingWebhookConfiguration">;
            /**
             * Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Webhooks is a list of webhooks and the affected resources and operations.
             */
            webhooks?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.MutatingWebhook>[]>;
        }
        /**
         * MutatingWebhook describes an admission webhook and the resources and operations it applies to.
         */
        interface MutatingWebhookPatch {
            /**
             * AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy.
             */
            admissionReviewVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ClientConfig defines how to communicate with the hook. Required
             */
            clientConfig?: pulumi.Input<inputs.admissionregistration.v1.WebhookClientConfigPatch>;
            /**
             * FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Fail.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * MatchConditions is a list of conditions that must be met for a request to be sent to this webhook. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
             *
             * The exact matching logic is (in order):
             *   1. If ANY matchCondition evaluates to FALSE, the webhook is skipped.
             *   2. If ALL matchConditions evaluate to TRUE, the webhook is called.
             *   3. If any matchCondition evaluates to an error (but none are FALSE):
             *      - If failurePolicy=Fail, reject the request
             *      - If failurePolicy=Ignore, the error is ignored and the webhook is skipped
             */
            matchConditions?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.MatchConditionPatch>[]>;
            /**
             * matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
             *
             * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.
             *
             * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.
             *
             * Defaults to "Equivalent"
             */
            matchPolicy?: pulumi.Input<string>;
            /**
             * The name of the admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required.
             */
            name?: pulumi.Input<string>;
            /**
             * NamespaceSelector decides whether to run the webhook on an object based on whether the namespace for that object matches the selector. If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the webhook.
             *
             * For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "runlevel",
             *       "operator": "NotIn",
             *       "values": [
             *         "0",
             *         "1"
             *       ]
             *     }
             *   ]
             * }
             *
             * If instead you want to only run the webhook on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "environment",
             *       "operator": "In",
             *       "values": [
             *         "prod",
             *         "staging"
             *       ]
             *     }
             *   ]
             * }
             *
             * See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/ for more examples of label selectors.
             *
             * Default to the empty LabelSelector, which matches everything.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * ObjectSelector decides whether to run the webhook based on if the object has matching labels. objectSelector is evaluated against both the oldObject and newObject that would be sent to the webhook, and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.
             */
            objectSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * reinvocationPolicy indicates whether this webhook should be called multiple times as part of a single admission evaluation. Allowed values are "Never" and "IfNeeded".
             *
             * Never: the webhook will not be called more than once in a single admission evaluation.
             *
             * IfNeeded: the webhook will be called at least one additional time as part of the admission evaluation if the object being admitted is modified by other admission plugins after the initial webhook call. Webhooks that specify this option *must* be idempotent, able to process objects they previously admitted. Note: * the number of additional invocations is not guaranteed to be exactly one. * if additional invocations result in further modifications to the object, webhooks are not guaranteed to be invoked again. * webhooks that use this option may be reordered to minimize the number of additional invocations. * to validate an object after all mutations are guaranteed complete, use a validating admission webhook instead.
             *
             * Defaults to "Never".
             */
            reinvocationPolicy?: pulumi.Input<string>;
            /**
             * Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches _any_ Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.RuleWithOperationsPatch>[]>;
            /**
             * SideEffects states whether this webhook has side effects. Acceptable values are: None, NoneOnDryRun (webhooks created via v1beta1 may also specify Some or Unknown). Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission chain and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some.
             */
            sideEffects?: pulumi.Input<string>;
            /**
             * TimeoutSeconds specifies the timeout for this webhook. After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 10 seconds.
             */
            timeoutSeconds?: pulumi.Input<number>;
        }
        /**
         * NamedRuleWithOperations is a tuple of Operations and Resources with ResourceNames.
         */
        interface NamedRuleWithOperations {
            /**
             * APIGroups is the API groups the resources belong to. '*' is all groups. If '*' is present, the length of the slice must be one. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * APIVersions is the API versions the resources belong to. '*' is all versions. If '*' is present, the length of the slice must be one. Required.
             */
            apiVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added. If '*' is present, the length of the slice must be one. Required.
             */
            operations?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.
             */
            resourceNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to.
             *
             * For example: 'pods' means pods. 'pods/log' means the log subresource of pods. '*' means all resources, but not subresources. 'pods/*' means all subresources of pods. '*&#47;scale' means all scale subresources. '*&#47;*' means all resources and their subresources.
             *
             * If wildcard is present, the validation rule will ensure resources do not overlap with each other.
             *
             * Depending on the enclosing object, subresources might not be allowed. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * scope specifies the scope of this rule. Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*".
             */
            scope?: pulumi.Input<string>;
        }
        /**
         * NamedRuleWithOperations is a tuple of Operations and Resources with ResourceNames.
         */
        interface NamedRuleWithOperationsPatch {
            /**
             * APIGroups is the API groups the resources belong to. '*' is all groups. If '*' is present, the length of the slice must be one. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * APIVersions is the API versions the resources belong to. '*' is all versions. If '*' is present, the length of the slice must be one. Required.
             */
            apiVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added. If '*' is present, the length of the slice must be one. Required.
             */
            operations?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.
             */
            resourceNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to.
             *
             * For example: 'pods' means pods. 'pods/log' means the log subresource of pods. '*' means all resources, but not subresources. 'pods/*' means all subresources of pods. '*&#47;scale' means all scale subresources. '*&#47;*' means all resources and their subresources.
             *
             * If wildcard is present, the validation rule will ensure resources do not overlap with each other.
             *
             * Depending on the enclosing object, subresources might not be allowed. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * scope specifies the scope of this rule. Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*".
             */
            scope?: pulumi.Input<string>;
        }
        /**
         * ParamKind is a tuple of Group Kind and Version.
         */
        interface ParamKind {
            /**
             * APIVersion is the API group version the resources belong to. In format of "group/version". Required.
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * Kind is the API kind the resources belong to. Required.
             */
            kind?: pulumi.Input<string>;
        }
        /**
         * ParamKind is a tuple of Group Kind and Version.
         */
        interface ParamKindPatch {
            /**
             * APIVersion is the API group version the resources belong to. In format of "group/version". Required.
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * Kind is the API kind the resources belong to. Required.
             */
            kind?: pulumi.Input<string>;
        }
        /**
         * ParamRef describes how to locate the params to be used as input to expressions of rules applied by a policy binding.
         */
        interface ParamRef {
            /**
             * name is the name of the resource being referenced.
             *
             * One of `name` or `selector` must be set, but `name` and `selector` are mutually exclusive properties. If one is set, the other must be unset.
             *
             * A single parameter used for all admission requests can be configured by setting the `name` field, leaving `selector` blank, and setting namespace if `paramKind` is namespace-scoped.
             */
            name?: pulumi.Input<string>;
            /**
             * namespace is the namespace of the referenced resource. Allows limiting the search for params to a specific namespace. Applies to both `name` and `selector` fields.
             *
             * A per-namespace parameter may be used by specifying a namespace-scoped `paramKind` in the policy and leaving this field empty.
             *
             * - If `paramKind` is cluster-scoped, this field MUST be unset. Setting this field results in a configuration error.
             *
             * - If `paramKind` is namespace-scoped, the namespace of the object being evaluated for admission will be used when this field is left unset. Take care that if this is left empty the binding must not match any cluster-scoped resources, which will result in an error.
             */
            namespace?: pulumi.Input<string>;
            /**
             * `parameterNotFoundAction` controls the behavior of the binding when the resource exists, and name or selector is valid, but there are no parameters matched by the binding. If the value is set to `Allow`, then no matched parameters will be treated as successful validation by the binding. If set to `Deny`, then no matched parameters will be subject to the `failurePolicy` of the policy.
             *
             * Allowed values are `Allow` or `Deny`
             *
             * Required
             */
            parameterNotFoundAction?: pulumi.Input<string>;
            /**
             * selector can be used to match multiple param objects based on their labels. Supply selector: {} to match all resources of the ParamKind.
             *
             * If multiple params are found, they are all evaluated with the policy expressions and the results are ANDed together.
             *
             * One of `name` or `selector` must be set, but `name` and `selector` are mutually exclusive properties. If one is set, the other must be unset.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
        }
        /**
         * ParamRef describes how to locate the params to be used as input to expressions of rules applied by a policy binding.
         */
        interface ParamRefPatch {
            /**
             * name is the name of the resource being referenced.
             *
             * One of `name` or `selector` must be set, but `name` and `selector` are mutually exclusive properties. If one is set, the other must be unset.
             *
             * A single parameter used for all admission requests can be configured by setting the `name` field, leaving `selector` blank, and setting namespace if `paramKind` is namespace-scoped.
             */
            name?: pulumi.Input<string>;
            /**
             * namespace is the namespace of the referenced resource. Allows limiting the search for params to a specific namespace. Applies to both `name` and `selector` fields.
             *
             * A per-namespace parameter may be used by specifying a namespace-scoped `paramKind` in the policy and leaving this field empty.
             *
             * - If `paramKind` is cluster-scoped, this field MUST be unset. Setting this field results in a configuration error.
             *
             * - If `paramKind` is namespace-scoped, the namespace of the object being evaluated for admission will be used when this field is left unset. Take care that if this is left empty the binding must not match any cluster-scoped resources, which will result in an error.
             */
            namespace?: pulumi.Input<string>;
            /**
             * `parameterNotFoundAction` controls the behavior of the binding when the resource exists, and name or selector is valid, but there are no parameters matched by the binding. If the value is set to `Allow`, then no matched parameters will be treated as successful validation by the binding. If set to `Deny`, then no matched parameters will be subject to the `failurePolicy` of the policy.
             *
             * Allowed values are `Allow` or `Deny`
             *
             * Required
             */
            parameterNotFoundAction?: pulumi.Input<string>;
            /**
             * selector can be used to match multiple param objects based on their labels. Supply selector: {} to match all resources of the ParamKind.
             *
             * If multiple params are found, they are all evaluated with the policy expressions and the results are ANDed together.
             *
             * One of `name` or `selector` must be set, but `name` and `selector` are mutually exclusive properties. If one is set, the other must be unset.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
        }
        /**
         * RuleWithOperations is a tuple of Operations and Resources. It is recommended to make sure that all the tuple expansions are valid.
         */
        interface RuleWithOperations {
            /**
             * APIGroups is the API groups the resources belong to. '*' is all groups. If '*' is present, the length of the slice must be one. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * APIVersions is the API versions the resources belong to. '*' is all versions. If '*' is present, the length of the slice must be one. Required.
             */
            apiVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added. If '*' is present, the length of the slice must be one. Required.
             */
            operations?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to.
             *
             * For example: 'pods' means pods. 'pods/log' means the log subresource of pods. '*' means all resources, but not subresources. 'pods/*' means all subresources of pods. '*&#47;scale' means all scale subresources. '*&#47;*' means all resources and their subresources.
             *
             * If wildcard is present, the validation rule will ensure resources do not overlap with each other.
             *
             * Depending on the enclosing object, subresources might not be allowed. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * scope specifies the scope of this rule. Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*".
             */
            scope?: pulumi.Input<string>;
        }
        /**
         * RuleWithOperations is a tuple of Operations and Resources. It is recommended to make sure that all the tuple expansions are valid.
         */
        interface RuleWithOperationsPatch {
            /**
             * APIGroups is the API groups the resources belong to. '*' is all groups. If '*' is present, the length of the slice must be one. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * APIVersions is the API versions the resources belong to. '*' is all versions. If '*' is present, the length of the slice must be one. Required.
             */
            apiVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added. If '*' is present, the length of the slice must be one. Required.
             */
            operations?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to.
             *
             * For example: 'pods' means pods. 'pods/log' means the log subresource of pods. '*' means all resources, but not subresources. 'pods/*' means all subresources of pods. '*&#47;scale' means all scale subresources. '*&#47;*' means all resources and their subresources.
             *
             * If wildcard is present, the validation rule will ensure resources do not overlap with each other.
             *
             * Depending on the enclosing object, subresources might not be allowed. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * scope specifies the scope of this rule. Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*".
             */
            scope?: pulumi.Input<string>;
        }
        /**
         * ServiceReference holds a reference to Service.legacy.k8s.io
         */
        interface ServiceReference {
            /**
             * `name` is the name of the service. Required
             */
            name: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of the service. Required
             */
            namespace: pulumi.Input<string>;
            /**
             * `path` is an optional URL path which will be sent in any request to this service.
             */
            path?: pulumi.Input<string>;
            /**
             * If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive).
             */
            port?: pulumi.Input<number>;
        }
        /**
         * ServiceReference holds a reference to Service.legacy.k8s.io
         */
        interface ServiceReferencePatch {
            /**
             * `name` is the name of the service. Required
             */
            name?: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of the service. Required
             */
            namespace?: pulumi.Input<string>;
            /**
             * `path` is an optional URL path which will be sent in any request to this service.
             */
            path?: pulumi.Input<string>;
            /**
             * If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive).
             */
            port?: pulumi.Input<number>;
        }
        /**
         * TypeChecking contains results of type checking the expressions in the ValidatingAdmissionPolicy
         */
        interface TypeChecking {
            /**
             * The type checking warnings for each expression.
             */
            expressionWarnings?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.ExpressionWarning>[]>;
        }
        /**
         * ValidatingAdmissionPolicy describes the definition of an admission validation policy that accepts or rejects an object without changing it.
         */
        interface ValidatingAdmissionPolicy {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"admissionregistration.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ValidatingAdmissionPolicy">;
            /**
             * Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the ValidatingAdmissionPolicy.
             */
            spec?: pulumi.Input<inputs.admissionregistration.v1.ValidatingAdmissionPolicySpec>;
            /**
             * The status of the ValidatingAdmissionPolicy, including warnings that are useful to determine if the policy behaves in the expected way. Populated by the system. Read-only.
             */
            status?: pulumi.Input<inputs.admissionregistration.v1.ValidatingAdmissionPolicyStatus>;
        }
        /**
         * ValidatingAdmissionPolicyBinding binds the ValidatingAdmissionPolicy with paramerized resources. ValidatingAdmissionPolicyBinding and parameter CRDs together define how cluster administrators configure policies for clusters.
         *
         * For a given admission request, each binding will cause its policy to be evaluated N times, where N is 1 for policies/bindings that don't use params, otherwise N is the number of parameters selected by the binding.
         *
         * The CEL expressions of a policy must have a computed CEL cost below the maximum CEL budget. Each evaluation of the policy is given an independent CEL cost budget. Adding/removing policies, bindings, or params can not affect whether a given (policy, binding, param) combination is within its own CEL budget.
         */
        interface ValidatingAdmissionPolicyBinding {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"admissionregistration.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ValidatingAdmissionPolicyBinding">;
            /**
             * Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the ValidatingAdmissionPolicyBinding.
             */
            spec?: pulumi.Input<inputs.admissionregistration.v1.ValidatingAdmissionPolicyBindingSpec>;
        }
        /**
         * ValidatingAdmissionPolicyBindingSpec is the specification of the ValidatingAdmissionPolicyBinding.
         */
        interface ValidatingAdmissionPolicyBindingSpec {
            /**
             * MatchResources declares what resources match this binding and will be validated by it. Note that this is intersected with the policy's matchConstraints, so only requests that are matched by the policy can be selected by this. If this is unset, all resources matched by the policy are validated by this binding When resourceRules is unset, it does not constrain resource matching. If a resource is matched by the other fields of this object, it will be validated. Note that this is differs from ValidatingAdmissionPolicy matchConstraints, where resourceRules are required.
             */
            matchResources?: pulumi.Input<inputs.admissionregistration.v1.MatchResources>;
            /**
             * paramRef specifies the parameter resource used to configure the admission control policy. It should point to a resource of the type specified in ParamKind of the bound ValidatingAdmissionPolicy. If the policy specifies a ParamKind and the resource referred to by ParamRef does not exist, this binding is considered mis-configured and the FailurePolicy of the ValidatingAdmissionPolicy applied. If the policy does not specify a ParamKind then this field is ignored, and the rules are evaluated without a param.
             */
            paramRef?: pulumi.Input<inputs.admissionregistration.v1.ParamRef>;
            /**
             * PolicyName references a ValidatingAdmissionPolicy name which the ValidatingAdmissionPolicyBinding binds to. If the referenced resource does not exist, this binding is considered invalid and will be ignored Required.
             */
            policyName?: pulumi.Input<string>;
            /**
             * validationActions declares how Validations of the referenced ValidatingAdmissionPolicy are enforced. If a validation evaluates to false it is always enforced according to these actions.
             *
             * Failures defined by the ValidatingAdmissionPolicy's FailurePolicy are enforced according to these actions only if the FailurePolicy is set to Fail, otherwise the failures are ignored. This includes compilation errors, runtime errors and misconfigurations of the policy.
             *
             * validationActions is declared as a set of action values. Order does not matter. validationActions may not contain duplicates of the same action.
             *
             * The supported actions values are:
             *
             * "Deny" specifies that a validation failure results in a denied request.
             *
             * "Warn" specifies that a validation failure is reported to the request client in HTTP Warning headers, with a warning code of 299. Warnings can be sent both for allowed or denied admission responses.
             *
             * "Audit" specifies that a validation failure is included in the published audit event for the request. The audit event will contain a `validation.policy.admission.k8s.io/validation_failure` audit annotation with a value containing the details of the validation failures, formatted as a JSON list of objects, each with the following fields: - message: The validation failure message string - policy: The resource name of the ValidatingAdmissionPolicy - binding: The resource name of the ValidatingAdmissionPolicyBinding - expressionIndex: The index of the failed validations in the ValidatingAdmissionPolicy - validationActions: The enforcement actions enacted for the validation failure Example audit annotation: `"validation.policy.admission.k8s.io/validation_failure": "[{\"message\": \"Invalid value\", {\"policy\": \"policy.example.com\", {\"binding\": \"policybinding.example.com\", {\"expressionIndex\": \"1\", {\"validationActions\": [\"Audit\"]}]"`
             *
             * Clients should expect to handle additional values by ignoring any values not recognized.
             *
             * "Deny" and "Warn" may not be used together since this combination needlessly duplicates the validation failure both in the API response body and the HTTP warning headers.
             *
             * Required.
             */
            validationActions?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ValidatingAdmissionPolicyBindingSpec is the specification of the ValidatingAdmissionPolicyBinding.
         */
        interface ValidatingAdmissionPolicyBindingSpecPatch {
            /**
             * MatchResources declares what resources match this binding and will be validated by it. Note that this is intersected with the policy's matchConstraints, so only requests that are matched by the policy can be selected by this. If this is unset, all resources matched by the policy are validated by this binding When resourceRules is unset, it does not constrain resource matching. If a resource is matched by the other fields of this object, it will be validated. Note that this is differs from ValidatingAdmissionPolicy matchConstraints, where resourceRules are required.
             */
            matchResources?: pulumi.Input<inputs.admissionregistration.v1.MatchResourcesPatch>;
            /**
             * paramRef specifies the parameter resource used to configure the admission control policy. It should point to a resource of the type specified in ParamKind of the bound ValidatingAdmissionPolicy. If the policy specifies a ParamKind and the resource referred to by ParamRef does not exist, this binding is considered mis-configured and the FailurePolicy of the ValidatingAdmissionPolicy applied. If the policy does not specify a ParamKind then this field is ignored, and the rules are evaluated without a param.
             */
            paramRef?: pulumi.Input<inputs.admissionregistration.v1.ParamRefPatch>;
            /**
             * PolicyName references a ValidatingAdmissionPolicy name which the ValidatingAdmissionPolicyBinding binds to. If the referenced resource does not exist, this binding is considered invalid and will be ignored Required.
             */
            policyName?: pulumi.Input<string>;
            /**
             * validationActions declares how Validations of the referenced ValidatingAdmissionPolicy are enforced. If a validation evaluates to false it is always enforced according to these actions.
             *
             * Failures defined by the ValidatingAdmissionPolicy's FailurePolicy are enforced according to these actions only if the FailurePolicy is set to Fail, otherwise the failures are ignored. This includes compilation errors, runtime errors and misconfigurations of the policy.
             *
             * validationActions is declared as a set of action values. Order does not matter. validationActions may not contain duplicates of the same action.
             *
             * The supported actions values are:
             *
             * "Deny" specifies that a validation failure results in a denied request.
             *
             * "Warn" specifies that a validation failure is reported to the request client in HTTP Warning headers, with a warning code of 299. Warnings can be sent both for allowed or denied admission responses.
             *
             * "Audit" specifies that a validation failure is included in the published audit event for the request. The audit event will contain a `validation.policy.admission.k8s.io/validation_failure` audit annotation with a value containing the details of the validation failures, formatted as a JSON list of objects, each with the following fields: - message: The validation failure message string - policy: The resource name of the ValidatingAdmissionPolicy - binding: The resource name of the ValidatingAdmissionPolicyBinding - expressionIndex: The index of the failed validations in the ValidatingAdmissionPolicy - validationActions: The enforcement actions enacted for the validation failure Example audit annotation: `"validation.policy.admission.k8s.io/validation_failure": "[{\"message\": \"Invalid value\", {\"policy\": \"policy.example.com\", {\"binding\": \"policybinding.example.com\", {\"expressionIndex\": \"1\", {\"validationActions\": [\"Audit\"]}]"`
             *
             * Clients should expect to handle additional values by ignoring any values not recognized.
             *
             * "Deny" and "Warn" may not be used together since this combination needlessly duplicates the validation failure both in the API response body and the HTTP warning headers.
             *
             * Required.
             */
            validationActions?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ValidatingAdmissionPolicySpec is the specification of the desired behavior of the AdmissionPolicy.
         */
        interface ValidatingAdmissionPolicySpec {
            /**
             * auditAnnotations contains CEL expressions which are used to produce audit annotations for the audit event of the API request. validations and auditAnnotations may not both be empty; a least one of validations or auditAnnotations is required.
             */
            auditAnnotations?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.AuditAnnotation>[]>;
            /**
             * failurePolicy defines how to handle failures for the admission policy. Failures can occur from CEL expression parse errors, type check errors, runtime errors and invalid or mis-configured policy definitions or bindings.
             *
             * A policy is invalid if spec.paramKind refers to a non-existent Kind. A binding is invalid if spec.paramRef.name refers to a non-existent resource.
             *
             * failurePolicy does not define how validations that evaluate to false are handled.
             *
             * When failurePolicy is set to Fail, ValidatingAdmissionPolicyBinding validationActions define how failures are enforced.
             *
             * Allowed values are Ignore or Fail. Defaults to Fail.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * MatchConditions is a list of conditions that must be met for a request to be validated. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
             *
             * If a parameter object is provided, it can be accessed via the `params` handle in the same manner as validation expressions.
             *
             * The exact matching logic is (in order):
             *   1. If ANY matchCondition evaluates to FALSE, the policy is skipped.
             *   2. If ALL matchConditions evaluate to TRUE, the policy is evaluated.
             *   3. If any matchCondition evaluates to an error (but none are FALSE):
             *      - If failurePolicy=Fail, reject the request
             *      - If failurePolicy=Ignore, the policy is skipped
             */
            matchConditions?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.MatchCondition>[]>;
            /**
             * MatchConstraints specifies what resources this policy is designed to validate. The AdmissionPolicy cares about a request if it matches _all_ Constraints. However, in order to prevent clusters from being put into an unstable state that cannot be recovered from via the API ValidatingAdmissionPolicy cannot match ValidatingAdmissionPolicy and ValidatingAdmissionPolicyBinding. Required.
             */
            matchConstraints?: pulumi.Input<inputs.admissionregistration.v1.MatchResources>;
            /**
             * ParamKind specifies the kind of resources used to parameterize this policy. If absent, there are no parameters for this policy and the param CEL variable will not be provided to validation expressions. If ParamKind refers to a non-existent kind, this policy definition is mis-configured and the FailurePolicy is applied. If paramKind is specified but paramRef is unset in ValidatingAdmissionPolicyBinding, the params variable will be null.
             */
            paramKind?: pulumi.Input<inputs.admissionregistration.v1.ParamKind>;
            /**
             * Validations contain CEL expressions which is used to apply the validation. Validations and AuditAnnotations may not both be empty; a minimum of one Validations or AuditAnnotations is required.
             */
            validations?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.Validation>[]>;
            /**
             * Variables contain definitions of variables that can be used in composition of other expressions. Each variable is defined as a named CEL expression. The variables defined here will be available under `variables` in other expressions of the policy except MatchConditions because MatchConditions are evaluated before the rest of the policy.
             *
             * The expression of a variable can refer to other variables defined earlier in the list but not those after. Thus, Variables must be sorted by the order of first appearance and acyclic.
             */
            variables?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.Variable>[]>;
        }
        /**
         * ValidatingAdmissionPolicySpec is the specification of the desired behavior of the AdmissionPolicy.
         */
        interface ValidatingAdmissionPolicySpecPatch {
            /**
             * auditAnnotations contains CEL expressions which are used to produce audit annotations for the audit event of the API request. validations and auditAnnotations may not both be empty; a least one of validations or auditAnnotations is required.
             */
            auditAnnotations?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.AuditAnnotationPatch>[]>;
            /**
             * failurePolicy defines how to handle failures for the admission policy. Failures can occur from CEL expression parse errors, type check errors, runtime errors and invalid or mis-configured policy definitions or bindings.
             *
             * A policy is invalid if spec.paramKind refers to a non-existent Kind. A binding is invalid if spec.paramRef.name refers to a non-existent resource.
             *
             * failurePolicy does not define how validations that evaluate to false are handled.
             *
             * When failurePolicy is set to Fail, ValidatingAdmissionPolicyBinding validationActions define how failures are enforced.
             *
             * Allowed values are Ignore or Fail. Defaults to Fail.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * MatchConditions is a list of conditions that must be met for a request to be validated. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
             *
             * If a parameter object is provided, it can be accessed via the `params` handle in the same manner as validation expressions.
             *
             * The exact matching logic is (in order):
             *   1. If ANY matchCondition evaluates to FALSE, the policy is skipped.
             *   2. If ALL matchConditions evaluate to TRUE, the policy is evaluated.
             *   3. If any matchCondition evaluates to an error (but none are FALSE):
             *      - If failurePolicy=Fail, reject the request
             *      - If failurePolicy=Ignore, the policy is skipped
             */
            matchConditions?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.MatchConditionPatch>[]>;
            /**
             * MatchConstraints specifies what resources this policy is designed to validate. The AdmissionPolicy cares about a request if it matches _all_ Constraints. However, in order to prevent clusters from being put into an unstable state that cannot be recovered from via the API ValidatingAdmissionPolicy cannot match ValidatingAdmissionPolicy and ValidatingAdmissionPolicyBinding. Required.
             */
            matchConstraints?: pulumi.Input<inputs.admissionregistration.v1.MatchResourcesPatch>;
            /**
             * ParamKind specifies the kind of resources used to parameterize this policy. If absent, there are no parameters for this policy and the param CEL variable will not be provided to validation expressions. If ParamKind refers to a non-existent kind, this policy definition is mis-configured and the FailurePolicy is applied. If paramKind is specified but paramRef is unset in ValidatingAdmissionPolicyBinding, the params variable will be null.
             */
            paramKind?: pulumi.Input<inputs.admissionregistration.v1.ParamKindPatch>;
            /**
             * Validations contain CEL expressions which is used to apply the validation. Validations and AuditAnnotations may not both be empty; a minimum of one Validations or AuditAnnotations is required.
             */
            validations?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.ValidationPatch>[]>;
            /**
             * Variables contain definitions of variables that can be used in composition of other expressions. Each variable is defined as a named CEL expression. The variables defined here will be available under `variables` in other expressions of the policy except MatchConditions because MatchConditions are evaluated before the rest of the policy.
             *
             * The expression of a variable can refer to other variables defined earlier in the list but not those after. Thus, Variables must be sorted by the order of first appearance and acyclic.
             */
            variables?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.VariablePatch>[]>;
        }
        /**
         * ValidatingAdmissionPolicyStatus represents the status of an admission validation policy.
         */
        interface ValidatingAdmissionPolicyStatus {
            /**
             * The conditions represent the latest available observations of a policy's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.meta.v1.Condition>[]>;
            /**
             * The generation observed by the controller.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * The results of type checking for each expression. Presence of this field indicates the completion of the type checking.
             */
            typeChecking?: pulumi.Input<inputs.admissionregistration.v1.TypeChecking>;
        }
        /**
         * ValidatingWebhook describes an admission webhook and the resources and operations it applies to.
         */
        interface ValidatingWebhook {
            /**
             * AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy.
             */
            admissionReviewVersions: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ClientConfig defines how to communicate with the hook. Required
             */
            clientConfig: pulumi.Input<inputs.admissionregistration.v1.WebhookClientConfig>;
            /**
             * FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Fail.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * MatchConditions is a list of conditions that must be met for a request to be sent to this webhook. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
             *
             * The exact matching logic is (in order):
             *   1. If ANY matchCondition evaluates to FALSE, the webhook is skipped.
             *   2. If ALL matchConditions evaluate to TRUE, the webhook is called.
             *   3. If any matchCondition evaluates to an error (but none are FALSE):
             *      - If failurePolicy=Fail, reject the request
             *      - If failurePolicy=Ignore, the error is ignored and the webhook is skipped
             */
            matchConditions?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.MatchCondition>[]>;
            /**
             * matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
             *
             * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.
             *
             * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.
             *
             * Defaults to "Equivalent"
             */
            matchPolicy?: pulumi.Input<string>;
            /**
             * The name of the admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required.
             */
            name: pulumi.Input<string>;
            /**
             * NamespaceSelector decides whether to run the webhook on an object based on whether the namespace for that object matches the selector. If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the webhook.
             *
             * For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "runlevel",
             *       "operator": "NotIn",
             *       "values": [
             *         "0",
             *         "1"
             *       ]
             *     }
             *   ]
             * }
             *
             * If instead you want to only run the webhook on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "environment",
             *       "operator": "In",
             *       "values": [
             *         "prod",
             *         "staging"
             *       ]
             *     }
             *   ]
             * }
             *
             * See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels for more examples of label selectors.
             *
             * Default to the empty LabelSelector, which matches everything.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * ObjectSelector decides whether to run the webhook based on if the object has matching labels. objectSelector is evaluated against both the oldObject and newObject that would be sent to the webhook, and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.
             */
            objectSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches _any_ Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.RuleWithOperations>[]>;
            /**
             * SideEffects states whether this webhook has side effects. Acceptable values are: None, NoneOnDryRun (webhooks created via v1beta1 may also specify Some or Unknown). Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission chain and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some.
             */
            sideEffects: pulumi.Input<string>;
            /**
             * TimeoutSeconds specifies the timeout for this webhook. After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 10 seconds.
             */
            timeoutSeconds?: pulumi.Input<number>;
        }
        /**
         * ValidatingWebhookConfiguration describes the configuration of and admission webhook that accept or reject and object without changing it.
         */
        interface ValidatingWebhookConfiguration {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"admissionregistration.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ValidatingWebhookConfiguration">;
            /**
             * Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Webhooks is a list of webhooks and the affected resources and operations.
             */
            webhooks?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.ValidatingWebhook>[]>;
        }
        /**
         * ValidatingWebhook describes an admission webhook and the resources and operations it applies to.
         */
        interface ValidatingWebhookPatch {
            /**
             * AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy.
             */
            admissionReviewVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ClientConfig defines how to communicate with the hook. Required
             */
            clientConfig?: pulumi.Input<inputs.admissionregistration.v1.WebhookClientConfigPatch>;
            /**
             * FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Fail.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * MatchConditions is a list of conditions that must be met for a request to be sent to this webhook. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
             *
             * The exact matching logic is (in order):
             *   1. If ANY matchCondition evaluates to FALSE, the webhook is skipped.
             *   2. If ALL matchConditions evaluate to TRUE, the webhook is called.
             *   3. If any matchCondition evaluates to an error (but none are FALSE):
             *      - If failurePolicy=Fail, reject the request
             *      - If failurePolicy=Ignore, the error is ignored and the webhook is skipped
             */
            matchConditions?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.MatchConditionPatch>[]>;
            /**
             * matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
             *
             * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.
             *
             * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.
             *
             * Defaults to "Equivalent"
             */
            matchPolicy?: pulumi.Input<string>;
            /**
             * The name of the admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required.
             */
            name?: pulumi.Input<string>;
            /**
             * NamespaceSelector decides whether to run the webhook on an object based on whether the namespace for that object matches the selector. If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the webhook.
             *
             * For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "runlevel",
             *       "operator": "NotIn",
             *       "values": [
             *         "0",
             *         "1"
             *       ]
             *     }
             *   ]
             * }
             *
             * If instead you want to only run the webhook on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "environment",
             *       "operator": "In",
             *       "values": [
             *         "prod",
             *         "staging"
             *       ]
             *     }
             *   ]
             * }
             *
             * See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels for more examples of label selectors.
             *
             * Default to the empty LabelSelector, which matches everything.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * ObjectSelector decides whether to run the webhook based on if the object has matching labels. objectSelector is evaluated against both the oldObject and newObject that would be sent to the webhook, and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.
             */
            objectSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches _any_ Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1.RuleWithOperationsPatch>[]>;
            /**
             * SideEffects states whether this webhook has side effects. Acceptable values are: None, NoneOnDryRun (webhooks created via v1beta1 may also specify Some or Unknown). Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission chain and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some.
             */
            sideEffects?: pulumi.Input<string>;
            /**
             * TimeoutSeconds specifies the timeout for this webhook. After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 10 seconds.
             */
            timeoutSeconds?: pulumi.Input<number>;
        }
        /**
         * Validation specifies the CEL expression which is used to apply the validation.
         */
        interface Validation {
            /**
             * Expression represents the expression which will be evaluated by CEL. ref: https://github.com/google/cel-spec CEL expressions have access to the contents of the API request/response, organized into CEL variables as well as some other useful variables:
             *
             * - 'object' - The object from the incoming request. The value is null for DELETE requests. - 'oldObject' - The existing object. The value is null for CREATE requests. - 'request' - Attributes of the API request([ref](/pkg/apis/admission/types.go#AdmissionRequest)). - 'params' - Parameter resource referred to by the policy binding being evaluated. Only populated if the policy has a ParamKind. - 'namespaceObject' - The namespace object that the incoming object belongs to. The value is null for cluster-scoped resources. - 'variables' - Map of composited variables, from its name to its lazily evaluated value.
             *   For example, a variable named 'foo' can be accessed as 'variables.foo'.
             * - 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
             *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
             * - 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
             *   request resource.
             *
             * The `apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object. No other metadata properties are accessible.
             *
             * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Accessible property names are escaped according to the following rules when accessed in the expression: - '__' escapes to '__underscores__' - '.' escapes to '__dot__' - '-' escapes to '__dash__' - '/' escapes to '__slash__' - Property names that exactly match a CEL RESERVED keyword escape to '__{keyword}__'. The keywords are:
             * 	  "true", "false", "null", "in", "as", "break", "const", "continue", "else", "for", "function", "if",
             * 	  "import", "let", "loop", "package", "namespace", "return".
             * Examples:
             *   - Expression accessing a property named "namespace": {"Expression": "object.__namespace__ > 0"}
             *   - Expression accessing a property named "x-prop": {"Expression": "object.x__dash__prop > 0"}
             *   - Expression accessing a property named "redact__d": {"Expression": "object.redact__underscores__d > 0"}
             *
             * Equality on arrays with list type of 'set' or 'map' ignores element order, i.e. [1, 2] == [2, 1]. Concatenation on arrays with x-kubernetes-list-type use the semantics of the list type:
             *   - 'set': `X + Y` performs a union where the array positions of all elements in `X` are preserved and
             *     non-intersecting elements in `Y` are appended, retaining their partial order.
             *   - 'map': `X + Y` performs a merge where the array positions of all keys in `X` are preserved but the values
             *     are overwritten by values in `Y` when the key sets of `X` and `Y` intersect. Elements in `Y` with
             *     non-intersecting keys are appended, retaining their partial order.
             * Required.
             */
            expression: pulumi.Input<string>;
            /**
             * Message represents the message displayed when validation fails. The message is required if the Expression contains line breaks. The message must not contain line breaks. If unset, the message is "failed rule: {Rule}". e.g. "must be a URL with the host matching spec.host" If the Expression contains line breaks. Message is required. The message must not contain line breaks. If unset, the message is "failed Expression: {Expression}".
             */
            message?: pulumi.Input<string>;
            /**
             * messageExpression declares a CEL expression that evaluates to the validation failure message that is returned when this rule fails. Since messageExpression is used as a failure message, it must evaluate to a string. If both message and messageExpression are present on a validation, then messageExpression will be used if validation fails. If messageExpression results in a runtime error, the runtime error is logged, and the validation failure message is produced as if the messageExpression field were unset. If messageExpression evaluates to an empty string, a string with only spaces, or a string that contains line breaks, then the validation failure message will also be produced as if the messageExpression field were unset, and the fact that messageExpression produced an empty string/string with only spaces/string with line breaks will be logged. messageExpression has access to all the same variables as the `expression` except for 'authorizer' and 'authorizer.requestResource'. Example: "object.x must be less than max ("+string(params.max)+")"
             */
            messageExpression?: pulumi.Input<string>;
            /**
             * Reason represents a machine-readable description of why this validation failed. If this is the first validation in the list to fail, this reason, as well as the corresponding HTTP response code, are used in the HTTP response to the client. The currently supported reasons are: "Unauthorized", "Forbidden", "Invalid", "RequestEntityTooLarge". If not set, StatusReasonInvalid is used in the response to the client.
             */
            reason?: pulumi.Input<string>;
        }
        /**
         * Validation specifies the CEL expression which is used to apply the validation.
         */
        interface ValidationPatch {
            /**
             * Expression represents the expression which will be evaluated by CEL. ref: https://github.com/google/cel-spec CEL expressions have access to the contents of the API request/response, organized into CEL variables as well as some other useful variables:
             *
             * - 'object' - The object from the incoming request. The value is null for DELETE requests. - 'oldObject' - The existing object. The value is null for CREATE requests. - 'request' - Attributes of the API request([ref](/pkg/apis/admission/types.go#AdmissionRequest)). - 'params' - Parameter resource referred to by the policy binding being evaluated. Only populated if the policy has a ParamKind. - 'namespaceObject' - The namespace object that the incoming object belongs to. The value is null for cluster-scoped resources. - 'variables' - Map of composited variables, from its name to its lazily evaluated value.
             *   For example, a variable named 'foo' can be accessed as 'variables.foo'.
             * - 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
             *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
             * - 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
             *   request resource.
             *
             * The `apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object. No other metadata properties are accessible.
             *
             * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Accessible property names are escaped according to the following rules when accessed in the expression: - '__' escapes to '__underscores__' - '.' escapes to '__dot__' - '-' escapes to '__dash__' - '/' escapes to '__slash__' - Property names that exactly match a CEL RESERVED keyword escape to '__{keyword}__'. The keywords are:
             * 	  "true", "false", "null", "in", "as", "break", "const", "continue", "else", "for", "function", "if",
             * 	  "import", "let", "loop", "package", "namespace", "return".
             * Examples:
             *   - Expression accessing a property named "namespace": {"Expression": "object.__namespace__ > 0"}
             *   - Expression accessing a property named "x-prop": {"Expression": "object.x__dash__prop > 0"}
             *   - Expression accessing a property named "redact__d": {"Expression": "object.redact__underscores__d > 0"}
             *
             * Equality on arrays with list type of 'set' or 'map' ignores element order, i.e. [1, 2] == [2, 1]. Concatenation on arrays with x-kubernetes-list-type use the semantics of the list type:
             *   - 'set': `X + Y` performs a union where the array positions of all elements in `X` are preserved and
             *     non-intersecting elements in `Y` are appended, retaining their partial order.
             *   - 'map': `X + Y` performs a merge where the array positions of all keys in `X` are preserved but the values
             *     are overwritten by values in `Y` when the key sets of `X` and `Y` intersect. Elements in `Y` with
             *     non-intersecting keys are appended, retaining their partial order.
             * Required.
             */
            expression?: pulumi.Input<string>;
            /**
             * Message represents the message displayed when validation fails. The message is required if the Expression contains line breaks. The message must not contain line breaks. If unset, the message is "failed rule: {Rule}". e.g. "must be a URL with the host matching spec.host" If the Expression contains line breaks. Message is required. The message must not contain line breaks. If unset, the message is "failed Expression: {Expression}".
             */
            message?: pulumi.Input<string>;
            /**
             * messageExpression declares a CEL expression that evaluates to the validation failure message that is returned when this rule fails. Since messageExpression is used as a failure message, it must evaluate to a string. If both message and messageExpression are present on a validation, then messageExpression will be used if validation fails. If messageExpression results in a runtime error, the runtime error is logged, and the validation failure message is produced as if the messageExpression field were unset. If messageExpression evaluates to an empty string, a string with only spaces, or a string that contains line breaks, then the validation failure message will also be produced as if the messageExpression field were unset, and the fact that messageExpression produced an empty string/string with only spaces/string with line breaks will be logged. messageExpression has access to all the same variables as the `expression` except for 'authorizer' and 'authorizer.requestResource'. Example: "object.x must be less than max ("+string(params.max)+")"
             */
            messageExpression?: pulumi.Input<string>;
            /**
             * Reason represents a machine-readable description of why this validation failed. If this is the first validation in the list to fail, this reason, as well as the corresponding HTTP response code, are used in the HTTP response to the client. The currently supported reasons are: "Unauthorized", "Forbidden", "Invalid", "RequestEntityTooLarge". If not set, StatusReasonInvalid is used in the response to the client.
             */
            reason?: pulumi.Input<string>;
        }
        /**
         * Variable is the definition of a variable that is used for composition. A variable is defined as a named expression.
         */
        interface Variable {
            /**
             * Expression is the expression that will be evaluated as the value of the variable. The CEL expression has access to the same identifiers as the CEL expressions in Validation.
             */
            expression: pulumi.Input<string>;
            /**
             * Name is the name of the variable. The name must be a valid CEL identifier and unique among all variables. The variable can be accessed in other expressions through `variables` For example, if name is "foo", the variable will be available as `variables.foo`
             */
            name: pulumi.Input<string>;
        }
        /**
         * Variable is the definition of a variable that is used for composition. A variable is defined as a named expression.
         */
        interface VariablePatch {
            /**
             * Expression is the expression that will be evaluated as the value of the variable. The CEL expression has access to the same identifiers as the CEL expressions in Validation.
             */
            expression?: pulumi.Input<string>;
            /**
             * Name is the name of the variable. The name must be a valid CEL identifier and unique among all variables. The variable can be accessed in other expressions through `variables` For example, if name is "foo", the variable will be available as `variables.foo`
             */
            name?: pulumi.Input<string>;
        }
        /**
         * WebhookClientConfig contains the information to make a TLS connection with the webhook
         */
        interface WebhookClientConfig {
            /**
             * `caBundle` is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used.
             */
            caBundle?: pulumi.Input<string>;
            /**
             * `service` is a reference to the service for this webhook. Either `service` or `url` must be specified.
             *
             * If the webhook is running within the cluster, then you should use `service`.
             */
            service?: pulumi.Input<inputs.admissionregistration.v1.ServiceReference>;
            /**
             * `url` gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
             *
             * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
             *
             * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
             *
             * The scheme must be "https"; the URL must begin with "https://".
             *
             * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
             *
             * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
             */
            url?: pulumi.Input<string>;
        }
        /**
         * WebhookClientConfig contains the information to make a TLS connection with the webhook
         */
        interface WebhookClientConfigPatch {
            /**
             * `caBundle` is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used.
             */
            caBundle?: pulumi.Input<string>;
            /**
             * `service` is a reference to the service for this webhook. Either `service` or `url` must be specified.
             *
             * If the webhook is running within the cluster, then you should use `service`.
             */
            service?: pulumi.Input<inputs.admissionregistration.v1.ServiceReferencePatch>;
            /**
             * `url` gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
             *
             * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
             *
             * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
             *
             * The scheme must be "https"; the URL must begin with "https://".
             *
             * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
             *
             * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
             */
            url?: pulumi.Input<string>;
        }
    }
    namespace v1alpha1 {
        /**
         * ApplyConfiguration defines the desired configuration values of an object.
         */
        interface ApplyConfiguration {
            /**
             * expression will be evaluated by CEL to create an apply configuration. ref: https://github.com/google/cel-spec
             *
             * Apply configurations are declared in CEL using object initialization. For example, this CEL expression returns an apply configuration to set a single field:
             *
             * 	Object{
             * 	  spec: Object.spec{
             * 	    serviceAccountName: "example"
             * 	  }
             * 	}
             *
             * Apply configurations may not modify atomic structs, maps or arrays due to the risk of accidental deletion of values not included in the apply configuration.
             *
             * CEL expressions have access to the object types needed to create apply configurations:
             *
             * - 'Object' - CEL type of the resource object. - 'Object.<fieldName>' - CEL type of object field (such as 'Object.spec') - 'Object.<fieldName1>.<fieldName2>...<fieldNameN>` - CEL type of nested field (such as 'Object.spec.containers')
             *
             * CEL expressions have access to the contents of the API request, organized into CEL variables as well as some other useful variables:
             *
             * - 'object' - The object from the incoming request. The value is null for DELETE requests. - 'oldObject' - The existing object. The value is null for CREATE requests. - 'request' - Attributes of the API request([ref](/pkg/apis/admission/types.go#AdmissionRequest)). - 'params' - Parameter resource referred to by the policy binding being evaluated. Only populated if the policy has a ParamKind. - 'namespaceObject' - The namespace object that the incoming object belongs to. The value is null for cluster-scoped resources. - 'variables' - Map of composited variables, from its name to its lazily evaluated value.
             *   For example, a variable named 'foo' can be accessed as 'variables.foo'.
             * - 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
             *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
             * - 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
             *   request resource.
             *
             * The `apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object. No other metadata properties are accessible.
             *
             * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Required.
             */
            expression?: pulumi.Input<string>;
        }
        /**
         * ApplyConfiguration defines the desired configuration values of an object.
         */
        interface ApplyConfigurationPatch {
            /**
             * expression will be evaluated by CEL to create an apply configuration. ref: https://github.com/google/cel-spec
             *
             * Apply configurations are declared in CEL using object initialization. For example, this CEL expression returns an apply configuration to set a single field:
             *
             * 	Object{
             * 	  spec: Object.spec{
             * 	    serviceAccountName: "example"
             * 	  }
             * 	}
             *
             * Apply configurations may not modify atomic structs, maps or arrays due to the risk of accidental deletion of values not included in the apply configuration.
             *
             * CEL expressions have access to the object types needed to create apply configurations:
             *
             * - 'Object' - CEL type of the resource object. - 'Object.<fieldName>' - CEL type of object field (such as 'Object.spec') - 'Object.<fieldName1>.<fieldName2>...<fieldNameN>` - CEL type of nested field (such as 'Object.spec.containers')
             *
             * CEL expressions have access to the contents of the API request, organized into CEL variables as well as some other useful variables:
             *
             * - 'object' - The object from the incoming request. The value is null for DELETE requests. - 'oldObject' - The existing object. The value is null for CREATE requests. - 'request' - Attributes of the API request([ref](/pkg/apis/admission/types.go#AdmissionRequest)). - 'params' - Parameter resource referred to by the policy binding being evaluated. Only populated if the policy has a ParamKind. - 'namespaceObject' - The namespace object that the incoming object belongs to. The value is null for cluster-scoped resources. - 'variables' - Map of composited variables, from its name to its lazily evaluated value.
             *   For example, a variable named 'foo' can be accessed as 'variables.foo'.
             * - 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
             *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
             * - 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
             *   request resource.
             *
             * The `apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object. No other metadata properties are accessible.
             *
             * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Required.
             */
            expression?: pulumi.Input<string>;
        }
        /**
         * AuditAnnotation describes how to produce an audit annotation for an API request.
         */
        interface AuditAnnotation {
            /**
             * key specifies the audit annotation key. The audit annotation keys of a ValidatingAdmissionPolicy must be unique. The key must be a qualified name ([A-Za-z0-9][-A-Za-z0-9_.]*) no more than 63 bytes in length.
             *
             * The key is combined with the resource name of the ValidatingAdmissionPolicy to construct an audit annotation key: "{ValidatingAdmissionPolicy name}/{key}".
             *
             * If an admission webhook uses the same resource name as this ValidatingAdmissionPolicy and the same audit annotation key, the annotation key will be identical. In this case, the first annotation written with the key will be included in the audit event and all subsequent annotations with the same key will be discarded.
             *
             * Required.
             */
            key: pulumi.Input<string>;
            /**
             * valueExpression represents the expression which is evaluated by CEL to produce an audit annotation value. The expression must evaluate to either a string or null value. If the expression evaluates to a string, the audit annotation is included with the string value. If the expression evaluates to null or empty string the audit annotation will be omitted. The valueExpression may be no longer than 5kb in length. If the result of the valueExpression is more than 10kb in length, it will be truncated to 10kb.
             *
             * If multiple ValidatingAdmissionPolicyBinding resources match an API request, then the valueExpression will be evaluated for each binding. All unique values produced by the valueExpressions will be joined together in a comma-separated list.
             *
             * Required.
             */
            valueExpression: pulumi.Input<string>;
        }
        /**
         * AuditAnnotation describes how to produce an audit annotation for an API request.
         */
        interface AuditAnnotationPatch {
            /**
             * key specifies the audit annotation key. The audit annotation keys of a ValidatingAdmissionPolicy must be unique. The key must be a qualified name ([A-Za-z0-9][-A-Za-z0-9_.]*) no more than 63 bytes in length.
             *
             * The key is combined with the resource name of the ValidatingAdmissionPolicy to construct an audit annotation key: "{ValidatingAdmissionPolicy name}/{key}".
             *
             * If an admission webhook uses the same resource name as this ValidatingAdmissionPolicy and the same audit annotation key, the annotation key will be identical. In this case, the first annotation written with the key will be included in the audit event and all subsequent annotations with the same key will be discarded.
             *
             * Required.
             */
            key?: pulumi.Input<string>;
            /**
             * valueExpression represents the expression which is evaluated by CEL to produce an audit annotation value. The expression must evaluate to either a string or null value. If the expression evaluates to a string, the audit annotation is included with the string value. If the expression evaluates to null or empty string the audit annotation will be omitted. The valueExpression may be no longer than 5kb in length. If the result of the valueExpression is more than 10kb in length, it will be truncated to 10kb.
             *
             * If multiple ValidatingAdmissionPolicyBinding resources match an API request, then the valueExpression will be evaluated for each binding. All unique values produced by the valueExpressions will be joined together in a comma-separated list.
             *
             * Required.
             */
            valueExpression?: pulumi.Input<string>;
        }
        /**
         * ExpressionWarning is a warning information that targets a specific expression.
         */
        interface ExpressionWarning {
            /**
             * The path to the field that refers the expression. For example, the reference to the expression of the first item of validations is "spec.validations[0].expression"
             */
            fieldRef: pulumi.Input<string>;
            /**
             * The content of type checking information in a human-readable form. Each line of the warning contains the type that the expression is checked against, followed by the type check error from the compiler.
             */
            warning: pulumi.Input<string>;
        }
        /**
         * JSONPatch defines a JSON Patch.
         */
        interface JSONPatch {
            /**
             * expression will be evaluated by CEL to create a [JSON patch](https://jsonpatch.com/). ref: https://github.com/google/cel-spec
             *
             * expression must return an array of JSONPatch values.
             *
             * For example, this CEL expression returns a JSON patch to conditionally modify a value:
             *
             * 	  [
             * 	    JSONPatch{op: "test", path: "/spec/example", value: "Red"},
             * 	    JSONPatch{op: "replace", path: "/spec/example", value: "Green"}
             * 	  ]
             *
             * To define an object for the patch value, use Object types. For example:
             *
             * 	  [
             * 	    JSONPatch{
             * 	      op: "add",
             * 	      path: "/spec/selector",
             * 	      value: Object.spec.selector{matchLabels: {"environment": "test"}}
             * 	    }
             * 	  ]
             *
             * To use strings containing '/' and '~' as JSONPatch path keys, use "jsonpatch.escapeKey". For example:
             *
             * 	  [
             * 	    JSONPatch{
             * 	      op: "add",
             * 	      path: "/metadata/labels/" + jsonpatch.escapeKey("example.com/environment"),
             * 	      value: "test"
             * 	    },
             * 	  ]
             *
             * CEL expressions have access to the types needed to create JSON patches and objects:
             *
             * - 'JSONPatch' - CEL type of JSON Patch operations. JSONPatch has the fields 'op', 'from', 'path' and 'value'.
             *   See [JSON patch](https://jsonpatch.com/) for more details. The 'value' field may be set to any of: string,
             *   integer, array, map or object.  If set, the 'path' and 'from' fields must be set to a
             *   [JSON pointer](https://datatracker.ietf.org/doc/html/rfc6901/) string, where the 'jsonpatch.escapeKey()' CEL
             *   function may be used to escape path keys containing '/' and '~'.
             * - 'Object' - CEL type of the resource object. - 'Object.<fieldName>' - CEL type of object field (such as 'Object.spec') - 'Object.<fieldName1>.<fieldName2>...<fieldNameN>` - CEL type of nested field (such as 'Object.spec.containers')
             *
             * CEL expressions have access to the contents of the API request, organized into CEL variables as well as some other useful variables:
             *
             * - 'object' - The object from the incoming request. The value is null for DELETE requests. - 'oldObject' - The existing object. The value is null for CREATE requests. - 'request' - Attributes of the API request([ref](/pkg/apis/admission/types.go#AdmissionRequest)). - 'params' - Parameter resource referred to by the policy binding being evaluated. Only populated if the policy has a ParamKind. - 'namespaceObject' - The namespace object that the incoming object belongs to. The value is null for cluster-scoped resources. - 'variables' - Map of composited variables, from its name to its lazily evaluated value.
             *   For example, a variable named 'foo' can be accessed as 'variables.foo'.
             * - 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
             *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
             * - 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
             *   request resource.
             *
             * CEL expressions have access to [Kubernetes CEL function libraries](https://kubernetes.io/docs/reference/using-api/cel/#cel-options-language-features-and-libraries) as well as:
             *
             * - 'jsonpatch.escapeKey' - Performs JSONPatch key escaping. '~' and  '/' are escaped as '~0' and `~1' respectively).
             *
             * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Required.
             */
            expression?: pulumi.Input<string>;
        }
        /**
         * JSONPatch defines a JSON Patch.
         */
        interface JSONPatchPatch {
            /**
             * expression will be evaluated by CEL to create a [JSON patch](https://jsonpatch.com/). ref: https://github.com/google/cel-spec
             *
             * expression must return an array of JSONPatch values.
             *
             * For example, this CEL expression returns a JSON patch to conditionally modify a value:
             *
             * 	  [
             * 	    JSONPatch{op: "test", path: "/spec/example", value: "Red"},
             * 	    JSONPatch{op: "replace", path: "/spec/example", value: "Green"}
             * 	  ]
             *
             * To define an object for the patch value, use Object types. For example:
             *
             * 	  [
             * 	    JSONPatch{
             * 	      op: "add",
             * 	      path: "/spec/selector",
             * 	      value: Object.spec.selector{matchLabels: {"environment": "test"}}
             * 	    }
             * 	  ]
             *
             * To use strings containing '/' and '~' as JSONPatch path keys, use "jsonpatch.escapeKey". For example:
             *
             * 	  [
             * 	    JSONPatch{
             * 	      op: "add",
             * 	      path: "/metadata/labels/" + jsonpatch.escapeKey("example.com/environment"),
             * 	      value: "test"
             * 	    },
             * 	  ]
             *
             * CEL expressions have access to the types needed to create JSON patches and objects:
             *
             * - 'JSONPatch' - CEL type of JSON Patch operations. JSONPatch has the fields 'op', 'from', 'path' and 'value'.
             *   See [JSON patch](https://jsonpatch.com/) for more details. The 'value' field may be set to any of: string,
             *   integer, array, map or object.  If set, the 'path' and 'from' fields must be set to a
             *   [JSON pointer](https://datatracker.ietf.org/doc/html/rfc6901/) string, where the 'jsonpatch.escapeKey()' CEL
             *   function may be used to escape path keys containing '/' and '~'.
             * - 'Object' - CEL type of the resource object. - 'Object.<fieldName>' - CEL type of object field (such as 'Object.spec') - 'Object.<fieldName1>.<fieldName2>...<fieldNameN>` - CEL type of nested field (such as 'Object.spec.containers')
             *
             * CEL expressions have access to the contents of the API request, organized into CEL variables as well as some other useful variables:
             *
             * - 'object' - The object from the incoming request. The value is null for DELETE requests. - 'oldObject' - The existing object. The value is null for CREATE requests. - 'request' - Attributes of the API request([ref](/pkg/apis/admission/types.go#AdmissionRequest)). - 'params' - Parameter resource referred to by the policy binding being evaluated. Only populated if the policy has a ParamKind. - 'namespaceObject' - The namespace object that the incoming object belongs to. The value is null for cluster-scoped resources. - 'variables' - Map of composited variables, from its name to its lazily evaluated value.
             *   For example, a variable named 'foo' can be accessed as 'variables.foo'.
             * - 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
             *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
             * - 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
             *   request resource.
             *
             * CEL expressions have access to [Kubernetes CEL function libraries](https://kubernetes.io/docs/reference/using-api/cel/#cel-options-language-features-and-libraries) as well as:
             *
             * - 'jsonpatch.escapeKey' - Performs JSONPatch key escaping. '~' and  '/' are escaped as '~0' and `~1' respectively).
             *
             * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Required.
             */
            expression?: pulumi.Input<string>;
        }
        interface MatchCondition {
            /**
             * Expression represents the expression which will be evaluated by CEL. Must evaluate to bool. CEL expressions have access to the contents of the AdmissionRequest and Authorizer, organized into CEL variables:
             *
             * 'object' - The object from the incoming request. The value is null for DELETE requests. 'oldObject' - The existing object. The value is null for CREATE requests. 'request' - Attributes of the admission request(/pkg/apis/admission/types.go#AdmissionRequest). 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
             *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
             * 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
             *   request resource.
             * Documentation on CEL: https://kubernetes.io/docs/reference/using-api/cel/
             *
             * Required.
             */
            expression: pulumi.Input<string>;
            /**
             * Name is an identifier for this match condition, used for strategic merging of MatchConditions, as well as providing an identifier for logging purposes. A good name should be descriptive of the associated expression. Name must be a qualified name consisting of alphanumeric characters, '-', '_' or '.', and must start and end with an alphanumeric character (e.g. 'MyName',  or 'my.name',  or '123-abc', regex used for validation is '([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9]') with an optional DNS subdomain prefix and '/' (e.g. 'example.com/MyName')
             *
             * Required.
             */
            name: pulumi.Input<string>;
        }
        interface MatchConditionPatch {
            /**
             * Expression represents the expression which will be evaluated by CEL. Must evaluate to bool. CEL expressions have access to the contents of the AdmissionRequest and Authorizer, organized into CEL variables:
             *
             * 'object' - The object from the incoming request. The value is null for DELETE requests. 'oldObject' - The existing object. The value is null for CREATE requests. 'request' - Attributes of the admission request(/pkg/apis/admission/types.go#AdmissionRequest). 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
             *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
             * 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
             *   request resource.
             * Documentation on CEL: https://kubernetes.io/docs/reference/using-api/cel/
             *
             * Required.
             */
            expression?: pulumi.Input<string>;
            /**
             * Name is an identifier for this match condition, used for strategic merging of MatchConditions, as well as providing an identifier for logging purposes. A good name should be descriptive of the associated expression. Name must be a qualified name consisting of alphanumeric characters, '-', '_' or '.', and must start and end with an alphanumeric character (e.g. 'MyName',  or 'my.name',  or '123-abc', regex used for validation is '([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9]') with an optional DNS subdomain prefix and '/' (e.g. 'example.com/MyName')
             *
             * Required.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * MatchResources decides whether to run the admission control policy on an object based on whether it meets the match criteria. The exclude rules take precedence over include rules (if a resource matches both, it is excluded)
         */
        interface MatchResources {
            /**
             * ExcludeResourceRules describes what operations on what resources/subresources the policy should not care about. The exclude rules take precedence over include rules (if a resource matches both, it is excluded)
             */
            excludeResourceRules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.NamedRuleWithOperations>[]>;
            /**
             * matchPolicy defines how the "MatchResources" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
             *
             * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, the admission policy does not consider requests to apps/v1beta1 or extensions/v1beta1 API groups.
             *
             * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, the admission policy **does** consider requests made to apps/v1beta1 or extensions/v1beta1 API groups. The API server translates the request to a matched resource API if necessary.
             *
             * Defaults to "Equivalent"
             */
            matchPolicy?: pulumi.Input<string>;
            /**
             * NamespaceSelector decides whether to run the admission control policy on an object based on whether the namespace for that object matches the selector. If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the policy.
             *
             * For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "runlevel",
             *       "operator": "NotIn",
             *       "values": [
             *         "0",
             *         "1"
             *       ]
             *     }
             *   ]
             * }
             *
             * If instead you want to only run the policy on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "environment",
             *       "operator": "In",
             *       "values": [
             *         "prod",
             *         "staging"
             *       ]
             *     }
             *   ]
             * }
             *
             * See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/ for more examples of label selectors.
             *
             * Default to the empty LabelSelector, which matches everything.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * ObjectSelector decides whether to run the policy based on if the object has matching labels. objectSelector is evaluated against both the oldObject and newObject that would be sent to the policy's expression (CEL), and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.
             */
            objectSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * ResourceRules describes what operations on what resources/subresources the admission policy matches. The policy cares about an operation if it matches _any_ Rule.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.NamedRuleWithOperations>[]>;
        }
        /**
         * MatchResources decides whether to run the admission control policy on an object based on whether it meets the match criteria. The exclude rules take precedence over include rules (if a resource matches both, it is excluded)
         */
        interface MatchResourcesPatch {
            /**
             * ExcludeResourceRules describes what operations on what resources/subresources the policy should not care about. The exclude rules take precedence over include rules (if a resource matches both, it is excluded)
             */
            excludeResourceRules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.NamedRuleWithOperationsPatch>[]>;
            /**
             * matchPolicy defines how the "MatchResources" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
             *
             * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, the admission policy does not consider requests to apps/v1beta1 or extensions/v1beta1 API groups.
             *
             * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, the admission policy **does** consider requests made to apps/v1beta1 or extensions/v1beta1 API groups. The API server translates the request to a matched resource API if necessary.
             *
             * Defaults to "Equivalent"
             */
            matchPolicy?: pulumi.Input<string>;
            /**
             * NamespaceSelector decides whether to run the admission control policy on an object based on whether the namespace for that object matches the selector. If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the policy.
             *
             * For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "runlevel",
             *       "operator": "NotIn",
             *       "values": [
             *         "0",
             *         "1"
             *       ]
             *     }
             *   ]
             * }
             *
             * If instead you want to only run the policy on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "environment",
             *       "operator": "In",
             *       "values": [
             *         "prod",
             *         "staging"
             *       ]
             *     }
             *   ]
             * }
             *
             * See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/ for more examples of label selectors.
             *
             * Default to the empty LabelSelector, which matches everything.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * ObjectSelector decides whether to run the policy based on if the object has matching labels. objectSelector is evaluated against both the oldObject and newObject that would be sent to the policy's expression (CEL), and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.
             */
            objectSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * ResourceRules describes what operations on what resources/subresources the admission policy matches. The policy cares about an operation if it matches _any_ Rule.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.NamedRuleWithOperationsPatch>[]>;
        }
        /**
         * MutatingAdmissionPolicy describes the definition of an admission mutation policy that mutates the object coming into admission chain.
         */
        interface MutatingAdmissionPolicy {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"admissionregistration.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"MutatingAdmissionPolicy">;
            /**
             * Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the MutatingAdmissionPolicy.
             */
            spec?: pulumi.Input<inputs.admissionregistration.v1alpha1.MutatingAdmissionPolicySpec>;
        }
        /**
         * MutatingAdmissionPolicyBinding binds the MutatingAdmissionPolicy with parametrized resources. MutatingAdmissionPolicyBinding and the optional parameter resource together define how cluster administrators configure policies for clusters.
         *
         * For a given admission request, each binding will cause its policy to be evaluated N times, where N is 1 for policies/bindings that don't use params, otherwise N is the number of parameters selected by the binding. Each evaluation is constrained by a [runtime cost budget](https://kubernetes.io/docs/reference/using-api/cel/#runtime-cost-budget).
         *
         * Adding/removing policies, bindings, or params can not affect whether a given (policy, binding, param) combination is within its own CEL budget.
         */
        interface MutatingAdmissionPolicyBinding {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"admissionregistration.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"MutatingAdmissionPolicyBinding">;
            /**
             * Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the MutatingAdmissionPolicyBinding.
             */
            spec?: pulumi.Input<inputs.admissionregistration.v1alpha1.MutatingAdmissionPolicyBindingSpec>;
        }
        /**
         * MutatingAdmissionPolicyBindingSpec is the specification of the MutatingAdmissionPolicyBinding.
         */
        interface MutatingAdmissionPolicyBindingSpec {
            /**
             * matchResources limits what resources match this binding and may be mutated by it. Note that if matchResources matches a resource, the resource must also match a policy's matchConstraints and matchConditions before the resource may be mutated. When matchResources is unset, it does not constrain resource matching, and only the policy's matchConstraints and matchConditions must match for the resource to be mutated. Additionally, matchResources.resourceRules are optional and do not constraint matching when unset. Note that this is differs from MutatingAdmissionPolicy matchConstraints, where resourceRules are required. The CREATE, UPDATE and CONNECT operations are allowed.  The DELETE operation may not be matched. '*' matches CREATE, UPDATE and CONNECT.
             */
            matchResources?: pulumi.Input<inputs.admissionregistration.v1alpha1.MatchResources>;
            /**
             * paramRef specifies the parameter resource used to configure the admission control policy. It should point to a resource of the type specified in spec.ParamKind of the bound MutatingAdmissionPolicy. If the policy specifies a ParamKind and the resource referred to by ParamRef does not exist, this binding is considered mis-configured and the FailurePolicy of the MutatingAdmissionPolicy applied. If the policy does not specify a ParamKind then this field is ignored, and the rules are evaluated without a param.
             */
            paramRef?: pulumi.Input<inputs.admissionregistration.v1alpha1.ParamRef>;
            /**
             * policyName references a MutatingAdmissionPolicy name which the MutatingAdmissionPolicyBinding binds to. If the referenced resource does not exist, this binding is considered invalid and will be ignored Required.
             */
            policyName?: pulumi.Input<string>;
        }
        /**
         * MutatingAdmissionPolicyBindingSpec is the specification of the MutatingAdmissionPolicyBinding.
         */
        interface MutatingAdmissionPolicyBindingSpecPatch {
            /**
             * matchResources limits what resources match this binding and may be mutated by it. Note that if matchResources matches a resource, the resource must also match a policy's matchConstraints and matchConditions before the resource may be mutated. When matchResources is unset, it does not constrain resource matching, and only the policy's matchConstraints and matchConditions must match for the resource to be mutated. Additionally, matchResources.resourceRules are optional and do not constraint matching when unset. Note that this is differs from MutatingAdmissionPolicy matchConstraints, where resourceRules are required. The CREATE, UPDATE and CONNECT operations are allowed.  The DELETE operation may not be matched. '*' matches CREATE, UPDATE and CONNECT.
             */
            matchResources?: pulumi.Input<inputs.admissionregistration.v1alpha1.MatchResourcesPatch>;
            /**
             * paramRef specifies the parameter resource used to configure the admission control policy. It should point to a resource of the type specified in spec.ParamKind of the bound MutatingAdmissionPolicy. If the policy specifies a ParamKind and the resource referred to by ParamRef does not exist, this binding is considered mis-configured and the FailurePolicy of the MutatingAdmissionPolicy applied. If the policy does not specify a ParamKind then this field is ignored, and the rules are evaluated without a param.
             */
            paramRef?: pulumi.Input<inputs.admissionregistration.v1alpha1.ParamRefPatch>;
            /**
             * policyName references a MutatingAdmissionPolicy name which the MutatingAdmissionPolicyBinding binds to. If the referenced resource does not exist, this binding is considered invalid and will be ignored Required.
             */
            policyName?: pulumi.Input<string>;
        }
        /**
         * MutatingAdmissionPolicySpec is the specification of the desired behavior of the admission policy.
         */
        interface MutatingAdmissionPolicySpec {
            /**
             * failurePolicy defines how to handle failures for the admission policy. Failures can occur from CEL expression parse errors, type check errors, runtime errors and invalid or mis-configured policy definitions or bindings.
             *
             * A policy is invalid if paramKind refers to a non-existent Kind. A binding is invalid if paramRef.name refers to a non-existent resource.
             *
             * failurePolicy does not define how validations that evaluate to false are handled.
             *
             * Allowed values are Ignore or Fail. Defaults to Fail.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * matchConditions is a list of conditions that must be met for a request to be validated. Match conditions filter requests that have already been matched by the matchConstraints. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
             *
             * If a parameter object is provided, it can be accessed via the `params` handle in the same manner as validation expressions.
             *
             * The exact matching logic is (in order):
             *   1. If ANY matchCondition evaluates to FALSE, the policy is skipped.
             *   2. If ALL matchConditions evaluate to TRUE, the policy is evaluated.
             *   3. If any matchCondition evaluates to an error (but none are FALSE):
             *      - If failurePolicy=Fail, reject the request
             *      - If failurePolicy=Ignore, the policy is skipped
             */
            matchConditions?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.MatchCondition>[]>;
            /**
             * matchConstraints specifies what resources this policy is designed to validate. The MutatingAdmissionPolicy cares about a request if it matches _all_ Constraints. However, in order to prevent clusters from being put into an unstable state that cannot be recovered from via the API MutatingAdmissionPolicy cannot match MutatingAdmissionPolicy and MutatingAdmissionPolicyBinding. The CREATE, UPDATE and CONNECT operations are allowed.  The DELETE operation may not be matched. '*' matches CREATE, UPDATE and CONNECT. Required.
             */
            matchConstraints?: pulumi.Input<inputs.admissionregistration.v1alpha1.MatchResources>;
            /**
             * mutations contain operations to perform on matching objects. mutations may not be empty; a minimum of one mutation is required. mutations are evaluated in order, and are reinvoked according to the reinvocationPolicy. The mutations of a policy are invoked for each binding of this policy and reinvocation of mutations occurs on a per binding basis.
             */
            mutations?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.Mutation>[]>;
            /**
             * paramKind specifies the kind of resources used to parameterize this policy. If absent, there are no parameters for this policy and the param CEL variable will not be provided to validation expressions. If paramKind refers to a non-existent kind, this policy definition is mis-configured and the FailurePolicy is applied. If paramKind is specified but paramRef is unset in MutatingAdmissionPolicyBinding, the params variable will be null.
             */
            paramKind?: pulumi.Input<inputs.admissionregistration.v1alpha1.ParamKind>;
            /**
             * reinvocationPolicy indicates whether mutations may be called multiple times per MutatingAdmissionPolicyBinding as part of a single admission evaluation. Allowed values are "Never" and "IfNeeded".
             *
             * Never: These mutations will not be called more than once per binding in a single admission evaluation.
             *
             * IfNeeded: These mutations may be invoked more than once per binding for a single admission request and there is no guarantee of order with respect to other admission plugins, admission webhooks, bindings of this policy and admission policies.  Mutations are only reinvoked when mutations change the object after this mutation is invoked. Required.
             */
            reinvocationPolicy?: pulumi.Input<string>;
            /**
             * variables contain definitions of variables that can be used in composition of other expressions. Each variable is defined as a named CEL expression. The variables defined here will be available under `variables` in other expressions of the policy except matchConditions because matchConditions are evaluated before the rest of the policy.
             *
             * The expression of a variable can refer to other variables defined earlier in the list but not those after. Thus, variables must be sorted by the order of first appearance and acyclic.
             */
            variables?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.Variable>[]>;
        }
        /**
         * MutatingAdmissionPolicySpec is the specification of the desired behavior of the admission policy.
         */
        interface MutatingAdmissionPolicySpecPatch {
            /**
             * failurePolicy defines how to handle failures for the admission policy. Failures can occur from CEL expression parse errors, type check errors, runtime errors and invalid or mis-configured policy definitions or bindings.
             *
             * A policy is invalid if paramKind refers to a non-existent Kind. A binding is invalid if paramRef.name refers to a non-existent resource.
             *
             * failurePolicy does not define how validations that evaluate to false are handled.
             *
             * Allowed values are Ignore or Fail. Defaults to Fail.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * matchConditions is a list of conditions that must be met for a request to be validated. Match conditions filter requests that have already been matched by the matchConstraints. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
             *
             * If a parameter object is provided, it can be accessed via the `params` handle in the same manner as validation expressions.
             *
             * The exact matching logic is (in order):
             *   1. If ANY matchCondition evaluates to FALSE, the policy is skipped.
             *   2. If ALL matchConditions evaluate to TRUE, the policy is evaluated.
             *   3. If any matchCondition evaluates to an error (but none are FALSE):
             *      - If failurePolicy=Fail, reject the request
             *      - If failurePolicy=Ignore, the policy is skipped
             */
            matchConditions?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.MatchConditionPatch>[]>;
            /**
             * matchConstraints specifies what resources this policy is designed to validate. The MutatingAdmissionPolicy cares about a request if it matches _all_ Constraints. However, in order to prevent clusters from being put into an unstable state that cannot be recovered from via the API MutatingAdmissionPolicy cannot match MutatingAdmissionPolicy and MutatingAdmissionPolicyBinding. The CREATE, UPDATE and CONNECT operations are allowed.  The DELETE operation may not be matched. '*' matches CREATE, UPDATE and CONNECT. Required.
             */
            matchConstraints?: pulumi.Input<inputs.admissionregistration.v1alpha1.MatchResourcesPatch>;
            /**
             * mutations contain operations to perform on matching objects. mutations may not be empty; a minimum of one mutation is required. mutations are evaluated in order, and are reinvoked according to the reinvocationPolicy. The mutations of a policy are invoked for each binding of this policy and reinvocation of mutations occurs on a per binding basis.
             */
            mutations?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.MutationPatch>[]>;
            /**
             * paramKind specifies the kind of resources used to parameterize this policy. If absent, there are no parameters for this policy and the param CEL variable will not be provided to validation expressions. If paramKind refers to a non-existent kind, this policy definition is mis-configured and the FailurePolicy is applied. If paramKind is specified but paramRef is unset in MutatingAdmissionPolicyBinding, the params variable will be null.
             */
            paramKind?: pulumi.Input<inputs.admissionregistration.v1alpha1.ParamKindPatch>;
            /**
             * reinvocationPolicy indicates whether mutations may be called multiple times per MutatingAdmissionPolicyBinding as part of a single admission evaluation. Allowed values are "Never" and "IfNeeded".
             *
             * Never: These mutations will not be called more than once per binding in a single admission evaluation.
             *
             * IfNeeded: These mutations may be invoked more than once per binding for a single admission request and there is no guarantee of order with respect to other admission plugins, admission webhooks, bindings of this policy and admission policies.  Mutations are only reinvoked when mutations change the object after this mutation is invoked. Required.
             */
            reinvocationPolicy?: pulumi.Input<string>;
            /**
             * variables contain definitions of variables that can be used in composition of other expressions. Each variable is defined as a named CEL expression. The variables defined here will be available under `variables` in other expressions of the policy except matchConditions because matchConditions are evaluated before the rest of the policy.
             *
             * The expression of a variable can refer to other variables defined earlier in the list but not those after. Thus, variables must be sorted by the order of first appearance and acyclic.
             */
            variables?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.VariablePatch>[]>;
        }
        /**
         * Mutation specifies the CEL expression which is used to apply the Mutation.
         */
        interface Mutation {
            /**
             * applyConfiguration defines the desired configuration values of an object. The configuration is applied to the admission object using [structured merge diff](https://github.com/kubernetes-sigs/structured-merge-diff). A CEL expression is used to create apply configuration.
             */
            applyConfiguration?: pulumi.Input<inputs.admissionregistration.v1alpha1.ApplyConfiguration>;
            /**
             * jsonPatch defines a [JSON patch](https://jsonpatch.com/) operation to perform a mutation to the object. A CEL expression is used to create the JSON patch.
             */
            jsonPatch?: pulumi.Input<inputs.admissionregistration.v1alpha1.JSONPatch>;
            /**
             * patchType indicates the patch strategy used. Allowed values are "ApplyConfiguration" and "JSONPatch". Required.
             */
            patchType: pulumi.Input<string>;
        }
        /**
         * Mutation specifies the CEL expression which is used to apply the Mutation.
         */
        interface MutationPatch {
            /**
             * applyConfiguration defines the desired configuration values of an object. The configuration is applied to the admission object using [structured merge diff](https://github.com/kubernetes-sigs/structured-merge-diff). A CEL expression is used to create apply configuration.
             */
            applyConfiguration?: pulumi.Input<inputs.admissionregistration.v1alpha1.ApplyConfigurationPatch>;
            /**
             * jsonPatch defines a [JSON patch](https://jsonpatch.com/) operation to perform a mutation to the object. A CEL expression is used to create the JSON patch.
             */
            jsonPatch?: pulumi.Input<inputs.admissionregistration.v1alpha1.JSONPatchPatch>;
            /**
             * patchType indicates the patch strategy used. Allowed values are "ApplyConfiguration" and "JSONPatch". Required.
             */
            patchType?: pulumi.Input<string>;
        }
        /**
         * NamedRuleWithOperations is a tuple of Operations and Resources with ResourceNames.
         */
        interface NamedRuleWithOperations {
            /**
             * APIGroups is the API groups the resources belong to. '*' is all groups. If '*' is present, the length of the slice must be one. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * APIVersions is the API versions the resources belong to. '*' is all versions. If '*' is present, the length of the slice must be one. Required.
             */
            apiVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added. If '*' is present, the length of the slice must be one. Required.
             */
            operations?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.
             */
            resourceNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to.
             *
             * For example: 'pods' means pods. 'pods/log' means the log subresource of pods. '*' means all resources, but not subresources. 'pods/*' means all subresources of pods. '*&#47;scale' means all scale subresources. '*&#47;*' means all resources and their subresources.
             *
             * If wildcard is present, the validation rule will ensure resources do not overlap with each other.
             *
             * Depending on the enclosing object, subresources might not be allowed. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * scope specifies the scope of this rule. Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*".
             */
            scope?: pulumi.Input<string>;
        }
        /**
         * NamedRuleWithOperations is a tuple of Operations and Resources with ResourceNames.
         */
        interface NamedRuleWithOperationsPatch {
            /**
             * APIGroups is the API groups the resources belong to. '*' is all groups. If '*' is present, the length of the slice must be one. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * APIVersions is the API versions the resources belong to. '*' is all versions. If '*' is present, the length of the slice must be one. Required.
             */
            apiVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added. If '*' is present, the length of the slice must be one. Required.
             */
            operations?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.
             */
            resourceNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to.
             *
             * For example: 'pods' means pods. 'pods/log' means the log subresource of pods. '*' means all resources, but not subresources. 'pods/*' means all subresources of pods. '*&#47;scale' means all scale subresources. '*&#47;*' means all resources and their subresources.
             *
             * If wildcard is present, the validation rule will ensure resources do not overlap with each other.
             *
             * Depending on the enclosing object, subresources might not be allowed. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * scope specifies the scope of this rule. Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*".
             */
            scope?: pulumi.Input<string>;
        }
        /**
         * ParamKind is a tuple of Group Kind and Version.
         */
        interface ParamKind {
            /**
             * APIVersion is the API group version the resources belong to. In format of "group/version". Required.
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * Kind is the API kind the resources belong to. Required.
             */
            kind?: pulumi.Input<string>;
        }
        /**
         * ParamKind is a tuple of Group Kind and Version.
         */
        interface ParamKindPatch {
            /**
             * APIVersion is the API group version the resources belong to. In format of "group/version". Required.
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * Kind is the API kind the resources belong to. Required.
             */
            kind?: pulumi.Input<string>;
        }
        /**
         * ParamRef describes how to locate the params to be used as input to expressions of rules applied by a policy binding.
         */
        interface ParamRef {
            /**
             * `name` is the name of the resource being referenced.
             *
             * `name` and `selector` are mutually exclusive properties. If one is set, the other must be unset.
             */
            name?: pulumi.Input<string>;
            /**
             * namespace is the namespace of the referenced resource. Allows limiting the search for params to a specific namespace. Applies to both `name` and `selector` fields.
             *
             * A per-namespace parameter may be used by specifying a namespace-scoped `paramKind` in the policy and leaving this field empty.
             *
             * - If `paramKind` is cluster-scoped, this field MUST be unset. Setting this field results in a configuration error.
             *
             * - If `paramKind` is namespace-scoped, the namespace of the object being evaluated for admission will be used when this field is left unset. Take care that if this is left empty the binding must not match any cluster-scoped resources, which will result in an error.
             */
            namespace?: pulumi.Input<string>;
            /**
             * `parameterNotFoundAction` controls the behavior of the binding when the resource exists, and name or selector is valid, but there are no parameters matched by the binding. If the value is set to `Allow`, then no matched parameters will be treated as successful validation by the binding. If set to `Deny`, then no matched parameters will be subject to the `failurePolicy` of the policy.
             *
             * Allowed values are `Allow` or `Deny` Default to `Deny`
             */
            parameterNotFoundAction?: pulumi.Input<string>;
            /**
             * selector can be used to match multiple param objects based on their labels. Supply selector: {} to match all resources of the ParamKind.
             *
             * If multiple params are found, they are all evaluated with the policy expressions and the results are ANDed together.
             *
             * One of `name` or `selector` must be set, but `name` and `selector` are mutually exclusive properties. If one is set, the other must be unset.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
        }
        /**
         * ParamRef describes how to locate the params to be used as input to expressions of rules applied by a policy binding.
         */
        interface ParamRefPatch {
            /**
             * `name` is the name of the resource being referenced.
             *
             * `name` and `selector` are mutually exclusive properties. If one is set, the other must be unset.
             */
            name?: pulumi.Input<string>;
            /**
             * namespace is the namespace of the referenced resource. Allows limiting the search for params to a specific namespace. Applies to both `name` and `selector` fields.
             *
             * A per-namespace parameter may be used by specifying a namespace-scoped `paramKind` in the policy and leaving this field empty.
             *
             * - If `paramKind` is cluster-scoped, this field MUST be unset. Setting this field results in a configuration error.
             *
             * - If `paramKind` is namespace-scoped, the namespace of the object being evaluated for admission will be used when this field is left unset. Take care that if this is left empty the binding must not match any cluster-scoped resources, which will result in an error.
             */
            namespace?: pulumi.Input<string>;
            /**
             * `parameterNotFoundAction` controls the behavior of the binding when the resource exists, and name or selector is valid, but there are no parameters matched by the binding. If the value is set to `Allow`, then no matched parameters will be treated as successful validation by the binding. If set to `Deny`, then no matched parameters will be subject to the `failurePolicy` of the policy.
             *
             * Allowed values are `Allow` or `Deny` Default to `Deny`
             */
            parameterNotFoundAction?: pulumi.Input<string>;
            /**
             * selector can be used to match multiple param objects based on their labels. Supply selector: {} to match all resources of the ParamKind.
             *
             * If multiple params are found, they are all evaluated with the policy expressions and the results are ANDed together.
             *
             * One of `name` or `selector` must be set, but `name` and `selector` are mutually exclusive properties. If one is set, the other must be unset.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
        }
        /**
         * TypeChecking contains results of type checking the expressions in the ValidatingAdmissionPolicy
         */
        interface TypeChecking {
            /**
             * The type checking warnings for each expression.
             */
            expressionWarnings?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.ExpressionWarning>[]>;
        }
        /**
         * ValidatingAdmissionPolicy describes the definition of an admission validation policy that accepts or rejects an object without changing it.
         */
        interface ValidatingAdmissionPolicy {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"admissionregistration.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ValidatingAdmissionPolicy">;
            /**
             * Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the ValidatingAdmissionPolicy.
             */
            spec?: pulumi.Input<inputs.admissionregistration.v1alpha1.ValidatingAdmissionPolicySpec>;
            /**
             * The status of the ValidatingAdmissionPolicy, including warnings that are useful to determine if the policy behaves in the expected way. Populated by the system. Read-only.
             */
            status?: pulumi.Input<inputs.admissionregistration.v1alpha1.ValidatingAdmissionPolicyStatus>;
        }
        /**
         * ValidatingAdmissionPolicyBinding binds the ValidatingAdmissionPolicy with paramerized resources. ValidatingAdmissionPolicyBinding and parameter CRDs together define how cluster administrators configure policies for clusters.
         */
        interface ValidatingAdmissionPolicyBinding {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"admissionregistration.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ValidatingAdmissionPolicyBinding">;
            /**
             * Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the ValidatingAdmissionPolicyBinding.
             */
            spec?: pulumi.Input<inputs.admissionregistration.v1alpha1.ValidatingAdmissionPolicyBindingSpec>;
        }
        /**
         * ValidatingAdmissionPolicyBindingSpec is the specification of the ValidatingAdmissionPolicyBinding.
         */
        interface ValidatingAdmissionPolicyBindingSpec {
            /**
             * MatchResources declares what resources match this binding and will be validated by it. Note that this is intersected with the policy's matchConstraints, so only requests that are matched by the policy can be selected by this. If this is unset, all resources matched by the policy are validated by this binding When resourceRules is unset, it does not constrain resource matching. If a resource is matched by the other fields of this object, it will be validated. Note that this is differs from ValidatingAdmissionPolicy matchConstraints, where resourceRules are required.
             */
            matchResources?: pulumi.Input<inputs.admissionregistration.v1alpha1.MatchResources>;
            /**
             * ParamRef specifies the parameter resource used to configure the admission control policy. It should point to a resource of the type specified in ParamKind of the bound ValidatingAdmissionPolicy. If the policy specifies a ParamKind and the resource referred to by ParamRef does not exist, this binding is considered mis-configured and the FailurePolicy of the ValidatingAdmissionPolicy applied.
             */
            paramRef?: pulumi.Input<inputs.admissionregistration.v1alpha1.ParamRef>;
            /**
             * PolicyName references a ValidatingAdmissionPolicy name which the ValidatingAdmissionPolicyBinding binds to. If the referenced resource does not exist, this binding is considered invalid and will be ignored Required.
             */
            policyName?: pulumi.Input<string>;
            /**
             * validationActions declares how Validations of the referenced ValidatingAdmissionPolicy are enforced. If a validation evaluates to false it is always enforced according to these actions.
             *
             * Failures defined by the ValidatingAdmissionPolicy's FailurePolicy are enforced according to these actions only if the FailurePolicy is set to Fail, otherwise the failures are ignored. This includes compilation errors, runtime errors and misconfigurations of the policy.
             *
             * validationActions is declared as a set of action values. Order does not matter. validationActions may not contain duplicates of the same action.
             *
             * The supported actions values are:
             *
             * "Deny" specifies that a validation failure results in a denied request.
             *
             * "Warn" specifies that a validation failure is reported to the request client in HTTP Warning headers, with a warning code of 299. Warnings can be sent both for allowed or denied admission responses.
             *
             * "Audit" specifies that a validation failure is included in the published audit event for the request. The audit event will contain a `validation.policy.admission.k8s.io/validation_failure` audit annotation with a value containing the details of the validation failures, formatted as a JSON list of objects, each with the following fields: - message: The validation failure message string - policy: The resource name of the ValidatingAdmissionPolicy - binding: The resource name of the ValidatingAdmissionPolicyBinding - expressionIndex: The index of the failed validations in the ValidatingAdmissionPolicy - validationActions: The enforcement actions enacted for the validation failure Example audit annotation: `"validation.policy.admission.k8s.io/validation_failure": "[{"message": "Invalid value", {"policy": "policy.example.com", {"binding": "policybinding.example.com", {"expressionIndex": "1", {"validationActions": ["Audit"]}]"`
             *
             * Clients should expect to handle additional values by ignoring any values not recognized.
             *
             * "Deny" and "Warn" may not be used together since this combination needlessly duplicates the validation failure both in the API response body and the HTTP warning headers.
             *
             * Required.
             */
            validationActions?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ValidatingAdmissionPolicyBindingSpec is the specification of the ValidatingAdmissionPolicyBinding.
         */
        interface ValidatingAdmissionPolicyBindingSpecPatch {
            /**
             * MatchResources declares what resources match this binding and will be validated by it. Note that this is intersected with the policy's matchConstraints, so only requests that are matched by the policy can be selected by this. If this is unset, all resources matched by the policy are validated by this binding When resourceRules is unset, it does not constrain resource matching. If a resource is matched by the other fields of this object, it will be validated. Note that this is differs from ValidatingAdmissionPolicy matchConstraints, where resourceRules are required.
             */
            matchResources?: pulumi.Input<inputs.admissionregistration.v1alpha1.MatchResourcesPatch>;
            /**
             * ParamRef specifies the parameter resource used to configure the admission control policy. It should point to a resource of the type specified in ParamKind of the bound ValidatingAdmissionPolicy. If the policy specifies a ParamKind and the resource referred to by ParamRef does not exist, this binding is considered mis-configured and the FailurePolicy of the ValidatingAdmissionPolicy applied.
             */
            paramRef?: pulumi.Input<inputs.admissionregistration.v1alpha1.ParamRefPatch>;
            /**
             * PolicyName references a ValidatingAdmissionPolicy name which the ValidatingAdmissionPolicyBinding binds to. If the referenced resource does not exist, this binding is considered invalid and will be ignored Required.
             */
            policyName?: pulumi.Input<string>;
            /**
             * validationActions declares how Validations of the referenced ValidatingAdmissionPolicy are enforced. If a validation evaluates to false it is always enforced according to these actions.
             *
             * Failures defined by the ValidatingAdmissionPolicy's FailurePolicy are enforced according to these actions only if the FailurePolicy is set to Fail, otherwise the failures are ignored. This includes compilation errors, runtime errors and misconfigurations of the policy.
             *
             * validationActions is declared as a set of action values. Order does not matter. validationActions may not contain duplicates of the same action.
             *
             * The supported actions values are:
             *
             * "Deny" specifies that a validation failure results in a denied request.
             *
             * "Warn" specifies that a validation failure is reported to the request client in HTTP Warning headers, with a warning code of 299. Warnings can be sent both for allowed or denied admission responses.
             *
             * "Audit" specifies that a validation failure is included in the published audit event for the request. The audit event will contain a `validation.policy.admission.k8s.io/validation_failure` audit annotation with a value containing the details of the validation failures, formatted as a JSON list of objects, each with the following fields: - message: The validation failure message string - policy: The resource name of the ValidatingAdmissionPolicy - binding: The resource name of the ValidatingAdmissionPolicyBinding - expressionIndex: The index of the failed validations in the ValidatingAdmissionPolicy - validationActions: The enforcement actions enacted for the validation failure Example audit annotation: `"validation.policy.admission.k8s.io/validation_failure": "[{"message": "Invalid value", {"policy": "policy.example.com", {"binding": "policybinding.example.com", {"expressionIndex": "1", {"validationActions": ["Audit"]}]"`
             *
             * Clients should expect to handle additional values by ignoring any values not recognized.
             *
             * "Deny" and "Warn" may not be used together since this combination needlessly duplicates the validation failure both in the API response body and the HTTP warning headers.
             *
             * Required.
             */
            validationActions?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ValidatingAdmissionPolicySpec is the specification of the desired behavior of the AdmissionPolicy.
         */
        interface ValidatingAdmissionPolicySpec {
            /**
             * auditAnnotations contains CEL expressions which are used to produce audit annotations for the audit event of the API request. validations and auditAnnotations may not both be empty; a least one of validations or auditAnnotations is required.
             */
            auditAnnotations?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.AuditAnnotation>[]>;
            /**
             * FailurePolicy defines how to handle failures for the admission policy. Failures can occur from invalid or mis-configured policy definitions or bindings. A policy is invalid if spec.paramKind refers to a non-existent Kind. A binding is invalid if spec.paramRef.name refers to a non-existent resource. Allowed values are Ignore or Fail. Defaults to Fail.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * MatchConditions is a list of conditions that must be met for a request to be validated. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
             *
             * If a parameter object is provided, it can be accessed via the `params` handle in the same manner as validation expressions.
             *
             * The exact matching logic is (in order):
             *   1. If ANY matchCondition evaluates to FALSE, the policy is skipped.
             *   2. If ALL matchConditions evaluate to TRUE, the policy is evaluated.
             *   3. If any matchCondition evaluates to an error (but none are FALSE):
             *      - If failurePolicy=Fail, reject the request
             *      - If failurePolicy=Ignore, the policy is skipped
             */
            matchConditions?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.MatchCondition>[]>;
            /**
             * MatchConstraints specifies what resources this policy is designed to validate. The AdmissionPolicy cares about a request if it matches _all_ Constraints. However, in order to prevent clusters from being put into an unstable state that cannot be recovered from via the API ValidatingAdmissionPolicy cannot match ValidatingAdmissionPolicy and ValidatingAdmissionPolicyBinding. Required.
             */
            matchConstraints?: pulumi.Input<inputs.admissionregistration.v1alpha1.MatchResources>;
            /**
             * ParamKind specifies the kind of resources used to parameterize this policy. If absent, there are no parameters for this policy and the param CEL variable will not be provided to validation expressions. If ParamKind refers to a non-existent kind, this policy definition is mis-configured and the FailurePolicy is applied. If paramKind is specified but paramRef is unset in ValidatingAdmissionPolicyBinding, the params variable will be null.
             */
            paramKind?: pulumi.Input<inputs.admissionregistration.v1alpha1.ParamKind>;
            /**
             * Validations contain CEL expressions which is used to apply the validation. A minimum of one validation is required for a policy definition. Required.
             */
            validations: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.Validation>[]>;
            /**
             * Variables contain definitions of variables that can be used in composition of other expressions. Each variable is defined as a named CEL expression. The variables defined here will be available under `variables` in other expressions of the policy except MatchConditions because MatchConditions are evaluated before the rest of the policy.
             *
             * The expression of a variable can refer to other variables defined earlier in the list but not those after. Thus, Variables must be sorted by the order of first appearance and acyclic.
             */
            variables?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.Variable>[]>;
        }
        /**
         * ValidatingAdmissionPolicySpec is the specification of the desired behavior of the AdmissionPolicy.
         */
        interface ValidatingAdmissionPolicySpecPatch {
            /**
             * auditAnnotations contains CEL expressions which are used to produce audit annotations for the audit event of the API request. validations and auditAnnotations may not both be empty; a least one of validations or auditAnnotations is required.
             */
            auditAnnotations?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.AuditAnnotationPatch>[]>;
            /**
             * FailurePolicy defines how to handle failures for the admission policy. Failures can occur from invalid or mis-configured policy definitions or bindings. A policy is invalid if spec.paramKind refers to a non-existent Kind. A binding is invalid if spec.paramRef.name refers to a non-existent resource. Allowed values are Ignore or Fail. Defaults to Fail.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * MatchConditions is a list of conditions that must be met for a request to be validated. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
             *
             * If a parameter object is provided, it can be accessed via the `params` handle in the same manner as validation expressions.
             *
             * The exact matching logic is (in order):
             *   1. If ANY matchCondition evaluates to FALSE, the policy is skipped.
             *   2. If ALL matchConditions evaluate to TRUE, the policy is evaluated.
             *   3. If any matchCondition evaluates to an error (but none are FALSE):
             *      - If failurePolicy=Fail, reject the request
             *      - If failurePolicy=Ignore, the policy is skipped
             */
            matchConditions?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.MatchConditionPatch>[]>;
            /**
             * MatchConstraints specifies what resources this policy is designed to validate. The AdmissionPolicy cares about a request if it matches _all_ Constraints. However, in order to prevent clusters from being put into an unstable state that cannot be recovered from via the API ValidatingAdmissionPolicy cannot match ValidatingAdmissionPolicy and ValidatingAdmissionPolicyBinding. Required.
             */
            matchConstraints?: pulumi.Input<inputs.admissionregistration.v1alpha1.MatchResourcesPatch>;
            /**
             * ParamKind specifies the kind of resources used to parameterize this policy. If absent, there are no parameters for this policy and the param CEL variable will not be provided to validation expressions. If ParamKind refers to a non-existent kind, this policy definition is mis-configured and the FailurePolicy is applied. If paramKind is specified but paramRef is unset in ValidatingAdmissionPolicyBinding, the params variable will be null.
             */
            paramKind?: pulumi.Input<inputs.admissionregistration.v1alpha1.ParamKindPatch>;
            /**
             * Validations contain CEL expressions which is used to apply the validation. A minimum of one validation is required for a policy definition. Required.
             */
            validations?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.ValidationPatch>[]>;
            /**
             * Variables contain definitions of variables that can be used in composition of other expressions. Each variable is defined as a named CEL expression. The variables defined here will be available under `variables` in other expressions of the policy except MatchConditions because MatchConditions are evaluated before the rest of the policy.
             *
             * The expression of a variable can refer to other variables defined earlier in the list but not those after. Thus, Variables must be sorted by the order of first appearance and acyclic.
             */
            variables?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1alpha1.VariablePatch>[]>;
        }
        /**
         * ValidatingAdmissionPolicyStatus represents the status of a ValidatingAdmissionPolicy.
         */
        interface ValidatingAdmissionPolicyStatus {
            /**
             * The conditions represent the latest available observations of a policy's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.meta.v1.Condition>[]>;
            /**
             * The generation observed by the controller.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * The results of type checking for each expression. Presence of this field indicates the completion of the type checking.
             */
            typeChecking?: pulumi.Input<inputs.admissionregistration.v1alpha1.TypeChecking>;
        }
        /**
         * Validation specifies the CEL expression which is used to apply the validation.
         */
        interface Validation {
            /**
             * Expression represents the expression which will be evaluated by CEL. ref: https://github.com/google/cel-spec CEL expressions have access to the contents of the Admission request/response, organized into CEL variables as well as some other useful variables:
             *
             * 'object' - The object from the incoming request. The value is null for DELETE requests. 'oldObject' - The existing object. The value is null for CREATE requests. 'request' - Attributes of the admission request([ref](/pkg/apis/admission/types.go#AdmissionRequest)). 'params' - Parameter resource referred to by the policy binding being evaluated. Only populated if the policy has a ParamKind.
             *
             * The `apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object. No other metadata properties are accessible.
             *
             * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Accessible property names are escaped according to the following rules when accessed in the expression: - '__' escapes to '__underscores__' - '.' escapes to '__dot__' - '-' escapes to '__dash__' - '/' escapes to '__slash__' - Property names that exactly match a CEL RESERVED keyword escape to '__{keyword}__'. The keywords are:
             * 	  "true", "false", "null", "in", "as", "break", "const", "continue", "else", "for", "function", "if",
             * 	  "import", "let", "loop", "package", "namespace", "return".
             * Examples:
             *   - Expression accessing a property named "namespace": {"Expression": "object.__namespace__ > 0"}
             *   - Expression accessing a property named "x-prop": {"Expression": "object.x__dash__prop > 0"}
             *   - Expression accessing a property named "redact__d": {"Expression": "object.redact__underscores__d > 0"}
             *
             * Equality on arrays with list type of 'set' or 'map' ignores element order, i.e. [1, 2] == [2, 1]. Concatenation on arrays with x-kubernetes-list-type use the semantics of the list type:
             *   - 'set': `X + Y` performs a union where the array positions of all elements in `X` are preserved and
             *     non-intersecting elements in `Y` are appended, retaining their partial order.
             *   - 'map': `X + Y` performs a merge where the array positions of all keys in `X` are preserved but the values
             *     are overwritten by values in `Y` when the key sets of `X` and `Y` intersect. Elements in `Y` with
             *     non-intersecting keys are appended, retaining their partial order.
             * Required.
             */
            expression: pulumi.Input<string>;
            /**
             * Message represents the message displayed when validation fails. The message is required if the Expression contains line breaks. The message must not contain line breaks. If unset, the message is "failed rule: {Rule}". e.g. "must be a URL with the host matching spec.host" If the Expression contains line breaks. Message is required. The message must not contain line breaks. If unset, the message is "failed Expression: {Expression}".
             */
            message?: pulumi.Input<string>;
            /**
             * messageExpression declares a CEL expression that evaluates to the validation failure message that is returned when this rule fails. Since messageExpression is used as a failure message, it must evaluate to a string. If both message and messageExpression are present on a validation, then messageExpression will be used if validation fails. If messageExpression results in a runtime error, the runtime error is logged, and the validation failure message is produced as if the messageExpression field were unset. If messageExpression evaluates to an empty string, a string with only spaces, or a string that contains line breaks, then the validation failure message will also be produced as if the messageExpression field were unset, and the fact that messageExpression produced an empty string/string with only spaces/string with line breaks will be logged. messageExpression has access to all the same variables as the `expression` except for 'authorizer' and 'authorizer.requestResource'. Example: "object.x must be less than max ("+string(params.max)+")"
             */
            messageExpression?: pulumi.Input<string>;
            /**
             * Reason represents a machine-readable description of why this validation failed. If this is the first validation in the list to fail, this reason, as well as the corresponding HTTP response code, are used in the HTTP response to the client. The currently supported reasons are: "Unauthorized", "Forbidden", "Invalid", "RequestEntityTooLarge". If not set, StatusReasonInvalid is used in the response to the client.
             */
            reason?: pulumi.Input<string>;
        }
        /**
         * Validation specifies the CEL expression which is used to apply the validation.
         */
        interface ValidationPatch {
            /**
             * Expression represents the expression which will be evaluated by CEL. ref: https://github.com/google/cel-spec CEL expressions have access to the contents of the Admission request/response, organized into CEL variables as well as some other useful variables:
             *
             * 'object' - The object from the incoming request. The value is null for DELETE requests. 'oldObject' - The existing object. The value is null for CREATE requests. 'request' - Attributes of the admission request([ref](/pkg/apis/admission/types.go#AdmissionRequest)). 'params' - Parameter resource referred to by the policy binding being evaluated. Only populated if the policy has a ParamKind.
             *
             * The `apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object. No other metadata properties are accessible.
             *
             * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Accessible property names are escaped according to the following rules when accessed in the expression: - '__' escapes to '__underscores__' - '.' escapes to '__dot__' - '-' escapes to '__dash__' - '/' escapes to '__slash__' - Property names that exactly match a CEL RESERVED keyword escape to '__{keyword}__'. The keywords are:
             * 	  "true", "false", "null", "in", "as", "break", "const", "continue", "else", "for", "function", "if",
             * 	  "import", "let", "loop", "package", "namespace", "return".
             * Examples:
             *   - Expression accessing a property named "namespace": {"Expression": "object.__namespace__ > 0"}
             *   - Expression accessing a property named "x-prop": {"Expression": "object.x__dash__prop > 0"}
             *   - Expression accessing a property named "redact__d": {"Expression": "object.redact__underscores__d > 0"}
             *
             * Equality on arrays with list type of 'set' or 'map' ignores element order, i.e. [1, 2] == [2, 1]. Concatenation on arrays with x-kubernetes-list-type use the semantics of the list type:
             *   - 'set': `X + Y` performs a union where the array positions of all elements in `X` are preserved and
             *     non-intersecting elements in `Y` are appended, retaining their partial order.
             *   - 'map': `X + Y` performs a merge where the array positions of all keys in `X` are preserved but the values
             *     are overwritten by values in `Y` when the key sets of `X` and `Y` intersect. Elements in `Y` with
             *     non-intersecting keys are appended, retaining their partial order.
             * Required.
             */
            expression?: pulumi.Input<string>;
            /**
             * Message represents the message displayed when validation fails. The message is required if the Expression contains line breaks. The message must not contain line breaks. If unset, the message is "failed rule: {Rule}". e.g. "must be a URL with the host matching spec.host" If the Expression contains line breaks. Message is required. The message must not contain line breaks. If unset, the message is "failed Expression: {Expression}".
             */
            message?: pulumi.Input<string>;
            /**
             * messageExpression declares a CEL expression that evaluates to the validation failure message that is returned when this rule fails. Since messageExpression is used as a failure message, it must evaluate to a string. If both message and messageExpression are present on a validation, then messageExpression will be used if validation fails. If messageExpression results in a runtime error, the runtime error is logged, and the validation failure message is produced as if the messageExpression field were unset. If messageExpression evaluates to an empty string, a string with only spaces, or a string that contains line breaks, then the validation failure message will also be produced as if the messageExpression field were unset, and the fact that messageExpression produced an empty string/string with only spaces/string with line breaks will be logged. messageExpression has access to all the same variables as the `expression` except for 'authorizer' and 'authorizer.requestResource'. Example: "object.x must be less than max ("+string(params.max)+")"
             */
            messageExpression?: pulumi.Input<string>;
            /**
             * Reason represents a machine-readable description of why this validation failed. If this is the first validation in the list to fail, this reason, as well as the corresponding HTTP response code, are used in the HTTP response to the client. The currently supported reasons are: "Unauthorized", "Forbidden", "Invalid", "RequestEntityTooLarge". If not set, StatusReasonInvalid is used in the response to the client.
             */
            reason?: pulumi.Input<string>;
        }
        /**
         * Variable is the definition of a variable that is used for composition.
         */
        interface Variable {
            /**
             * Expression is the expression that will be evaluated as the value of the variable. The CEL expression has access to the same identifiers as the CEL expressions in Validation.
             */
            expression: pulumi.Input<string>;
            /**
             * Name is the name of the variable. The name must be a valid CEL identifier and unique among all variables. The variable can be accessed in other expressions through `variables` For example, if name is "foo", the variable will be available as `variables.foo`
             */
            name: pulumi.Input<string>;
        }
        /**
         * Variable is the definition of a variable that is used for composition.
         */
        interface VariablePatch {
            /**
             * Expression is the expression that will be evaluated as the value of the variable. The CEL expression has access to the same identifiers as the CEL expressions in Validation.
             */
            expression?: pulumi.Input<string>;
            /**
             * Name is the name of the variable. The name must be a valid CEL identifier and unique among all variables. The variable can be accessed in other expressions through `variables` For example, if name is "foo", the variable will be available as `variables.foo`
             */
            name?: pulumi.Input<string>;
        }
    }
    namespace v1beta1 {
        /**
         * AuditAnnotation describes how to produce an audit annotation for an API request.
         */
        interface AuditAnnotation {
            /**
             * key specifies the audit annotation key. The audit annotation keys of a ValidatingAdmissionPolicy must be unique. The key must be a qualified name ([A-Za-z0-9][-A-Za-z0-9_.]*) no more than 63 bytes in length.
             *
             * The key is combined with the resource name of the ValidatingAdmissionPolicy to construct an audit annotation key: "{ValidatingAdmissionPolicy name}/{key}".
             *
             * If an admission webhook uses the same resource name as this ValidatingAdmissionPolicy and the same audit annotation key, the annotation key will be identical. In this case, the first annotation written with the key will be included in the audit event and all subsequent annotations with the same key will be discarded.
             *
             * Required.
             */
            key: pulumi.Input<string>;
            /**
             * valueExpression represents the expression which is evaluated by CEL to produce an audit annotation value. The expression must evaluate to either a string or null value. If the expression evaluates to a string, the audit annotation is included with the string value. If the expression evaluates to null or empty string the audit annotation will be omitted. The valueExpression may be no longer than 5kb in length. If the result of the valueExpression is more than 10kb in length, it will be truncated to 10kb.
             *
             * If multiple ValidatingAdmissionPolicyBinding resources match an API request, then the valueExpression will be evaluated for each binding. All unique values produced by the valueExpressions will be joined together in a comma-separated list.
             *
             * Required.
             */
            valueExpression: pulumi.Input<string>;
        }
        /**
         * AuditAnnotation describes how to produce an audit annotation for an API request.
         */
        interface AuditAnnotationPatch {
            /**
             * key specifies the audit annotation key. The audit annotation keys of a ValidatingAdmissionPolicy must be unique. The key must be a qualified name ([A-Za-z0-9][-A-Za-z0-9_.]*) no more than 63 bytes in length.
             *
             * The key is combined with the resource name of the ValidatingAdmissionPolicy to construct an audit annotation key: "{ValidatingAdmissionPolicy name}/{key}".
             *
             * If an admission webhook uses the same resource name as this ValidatingAdmissionPolicy and the same audit annotation key, the annotation key will be identical. In this case, the first annotation written with the key will be included in the audit event and all subsequent annotations with the same key will be discarded.
             *
             * Required.
             */
            key?: pulumi.Input<string>;
            /**
             * valueExpression represents the expression which is evaluated by CEL to produce an audit annotation value. The expression must evaluate to either a string or null value. If the expression evaluates to a string, the audit annotation is included with the string value. If the expression evaluates to null or empty string the audit annotation will be omitted. The valueExpression may be no longer than 5kb in length. If the result of the valueExpression is more than 10kb in length, it will be truncated to 10kb.
             *
             * If multiple ValidatingAdmissionPolicyBinding resources match an API request, then the valueExpression will be evaluated for each binding. All unique values produced by the valueExpressions will be joined together in a comma-separated list.
             *
             * Required.
             */
            valueExpression?: pulumi.Input<string>;
        }
        /**
         * ExpressionWarning is a warning information that targets a specific expression.
         */
        interface ExpressionWarning {
            /**
             * The path to the field that refers the expression. For example, the reference to the expression of the first item of validations is "spec.validations[0].expression"
             */
            fieldRef: pulumi.Input<string>;
            /**
             * The content of type checking information in a human-readable form. Each line of the warning contains the type that the expression is checked against, followed by the type check error from the compiler.
             */
            warning: pulumi.Input<string>;
        }
        /**
         * MatchCondition represents a condition which must be fulfilled for a request to be sent to a webhook.
         */
        interface MatchCondition {
            /**
             * Expression represents the expression which will be evaluated by CEL. Must evaluate to bool. CEL expressions have access to the contents of the AdmissionRequest and Authorizer, organized into CEL variables:
             *
             * 'object' - The object from the incoming request. The value is null for DELETE requests. 'oldObject' - The existing object. The value is null for CREATE requests. 'request' - Attributes of the admission request(/pkg/apis/admission/types.go#AdmissionRequest). 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
             *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
             * 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
             *   request resource.
             * Documentation on CEL: https://kubernetes.io/docs/reference/using-api/cel/
             *
             * Required.
             */
            expression: pulumi.Input<string>;
            /**
             * Name is an identifier for this match condition, used for strategic merging of MatchConditions, as well as providing an identifier for logging purposes. A good name should be descriptive of the associated expression. Name must be a qualified name consisting of alphanumeric characters, '-', '_' or '.', and must start and end with an alphanumeric character (e.g. 'MyName',  or 'my.name',  or '123-abc', regex used for validation is '([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9]') with an optional DNS subdomain prefix and '/' (e.g. 'example.com/MyName')
             *
             * Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * MatchCondition represents a condition which must be fulfilled for a request to be sent to a webhook.
         */
        interface MatchConditionPatch {
            /**
             * Expression represents the expression which will be evaluated by CEL. Must evaluate to bool. CEL expressions have access to the contents of the AdmissionRequest and Authorizer, organized into CEL variables:
             *
             * 'object' - The object from the incoming request. The value is null for DELETE requests. 'oldObject' - The existing object. The value is null for CREATE requests. 'request' - Attributes of the admission request(/pkg/apis/admission/types.go#AdmissionRequest). 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
             *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
             * 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
             *   request resource.
             * Documentation on CEL: https://kubernetes.io/docs/reference/using-api/cel/
             *
             * Required.
             */
            expression?: pulumi.Input<string>;
            /**
             * Name is an identifier for this match condition, used for strategic merging of MatchConditions, as well as providing an identifier for logging purposes. A good name should be descriptive of the associated expression. Name must be a qualified name consisting of alphanumeric characters, '-', '_' or '.', and must start and end with an alphanumeric character (e.g. 'MyName',  or 'my.name',  or '123-abc', regex used for validation is '([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9]') with an optional DNS subdomain prefix and '/' (e.g. 'example.com/MyName')
             *
             * Required.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * MatchResources decides whether to run the admission control policy on an object based on whether it meets the match criteria. The exclude rules take precedence over include rules (if a resource matches both, it is excluded)
         */
        interface MatchResources {
            /**
             * ExcludeResourceRules describes what operations on what resources/subresources the ValidatingAdmissionPolicy should not care about. The exclude rules take precedence over include rules (if a resource matches both, it is excluded)
             */
            excludeResourceRules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.NamedRuleWithOperations>[]>;
            /**
             * matchPolicy defines how the "MatchResources" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
             *
             * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the ValidatingAdmissionPolicy.
             *
             * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the ValidatingAdmissionPolicy.
             *
             * Defaults to "Equivalent"
             */
            matchPolicy?: pulumi.Input<string>;
            /**
             * NamespaceSelector decides whether to run the admission control policy on an object based on whether the namespace for that object matches the selector. If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the policy.
             *
             * For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "runlevel",
             *       "operator": "NotIn",
             *       "values": [
             *         "0",
             *         "1"
             *       ]
             *     }
             *   ]
             * }
             *
             * If instead you want to only run the policy on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "environment",
             *       "operator": "In",
             *       "values": [
             *         "prod",
             *         "staging"
             *       ]
             *     }
             *   ]
             * }
             *
             * See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/ for more examples of label selectors.
             *
             * Default to the empty LabelSelector, which matches everything.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * ObjectSelector decides whether to run the validation based on if the object has matching labels. objectSelector is evaluated against both the oldObject and newObject that would be sent to the cel validation, and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.
             */
            objectSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * ResourceRules describes what operations on what resources/subresources the ValidatingAdmissionPolicy matches. The policy cares about an operation if it matches _any_ Rule.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.NamedRuleWithOperations>[]>;
        }
        /**
         * MatchResources decides whether to run the admission control policy on an object based on whether it meets the match criteria. The exclude rules take precedence over include rules (if a resource matches both, it is excluded)
         */
        interface MatchResourcesPatch {
            /**
             * ExcludeResourceRules describes what operations on what resources/subresources the ValidatingAdmissionPolicy should not care about. The exclude rules take precedence over include rules (if a resource matches both, it is excluded)
             */
            excludeResourceRules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.NamedRuleWithOperationsPatch>[]>;
            /**
             * matchPolicy defines how the "MatchResources" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
             *
             * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the ValidatingAdmissionPolicy.
             *
             * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the ValidatingAdmissionPolicy.
             *
             * Defaults to "Equivalent"
             */
            matchPolicy?: pulumi.Input<string>;
            /**
             * NamespaceSelector decides whether to run the admission control policy on an object based on whether the namespace for that object matches the selector. If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the policy.
             *
             * For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "runlevel",
             *       "operator": "NotIn",
             *       "values": [
             *         "0",
             *         "1"
             *       ]
             *     }
             *   ]
             * }
             *
             * If instead you want to only run the policy on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "environment",
             *       "operator": "In",
             *       "values": [
             *         "prod",
             *         "staging"
             *       ]
             *     }
             *   ]
             * }
             *
             * See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/ for more examples of label selectors.
             *
             * Default to the empty LabelSelector, which matches everything.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * ObjectSelector decides whether to run the validation based on if the object has matching labels. objectSelector is evaluated against both the oldObject and newObject that would be sent to the cel validation, and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.
             */
            objectSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * ResourceRules describes what operations on what resources/subresources the ValidatingAdmissionPolicy matches. The policy cares about an operation if it matches _any_ Rule.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.NamedRuleWithOperationsPatch>[]>;
        }
        /**
         * MutatingWebhook describes an admission webhook and the resources and operations it applies to.
         */
        interface MutatingWebhook {
            /**
             * AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy. Default to `['v1beta1']`.
             */
            admissionReviewVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ClientConfig defines how to communicate with the hook. Required
             */
            clientConfig: pulumi.Input<inputs.admissionregistration.v1beta1.WebhookClientConfig>;
            /**
             * FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Ignore.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
             *
             * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.
             *
             * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.
             *
             * Defaults to "Exact"
             */
            matchPolicy?: pulumi.Input<string>;
            /**
             * The name of the admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required.
             */
            name: pulumi.Input<string>;
            /**
             * NamespaceSelector decides whether to run the webhook on an object based on whether the namespace for that object matches the selector. If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the webhook.
             *
             * For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "runlevel",
             *       "operator": "NotIn",
             *       "values": [
             *         "0",
             *         "1"
             *       ]
             *     }
             *   ]
             * }
             *
             * If instead you want to only run the webhook on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "environment",
             *       "operator": "In",
             *       "values": [
             *         "prod",
             *         "staging"
             *       ]
             *     }
             *   ]
             * }
             *
             * See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/ for more examples of label selectors.
             *
             * Default to the empty LabelSelector, which matches everything.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * ObjectSelector decides whether to run the webhook based on if the object has matching labels. objectSelector is evaluated against both the oldObject and newObject that would be sent to the webhook, and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.
             */
            objectSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * reinvocationPolicy indicates whether this webhook should be called multiple times as part of a single admission evaluation. Allowed values are "Never" and "IfNeeded".
             *
             * Never: the webhook will not be called more than once in a single admission evaluation.
             *
             * IfNeeded: the webhook will be called at least one additional time as part of the admission evaluation if the object being admitted is modified by other admission plugins after the initial webhook call. Webhooks that specify this option *must* be idempotent, able to process objects they previously admitted. Note: * the number of additional invocations is not guaranteed to be exactly one. * if additional invocations result in further modifications to the object, webhooks are not guaranteed to be invoked again. * webhooks that use this option may be reordered to minimize the number of additional invocations. * to validate an object after all mutations are guaranteed complete, use a validating admission webhook instead.
             *
             * Defaults to "Never".
             */
            reinvocationPolicy?: pulumi.Input<string>;
            /**
             * Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches _any_ Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.RuleWithOperations>[]>;
            /**
             * SideEffects states whether this webhook has side effects. Acceptable values are: Unknown, None, Some, NoneOnDryRun Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission change and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some. Defaults to Unknown.
             */
            sideEffects?: pulumi.Input<string>;
            /**
             * TimeoutSeconds specifies the timeout for this webhook. After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 30 seconds.
             */
            timeoutSeconds?: pulumi.Input<number>;
        }
        /**
         * MutatingWebhookConfiguration describes the configuration of and admission webhook that accept or reject and may change the object. Deprecated in v1.16, planned for removal in v1.19. Use admissionregistration.k8s.io/v1 MutatingWebhookConfiguration instead.
         */
        interface MutatingWebhookConfiguration {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"admissionregistration.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"MutatingWebhookConfiguration">;
            /**
             * Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Webhooks is a list of webhooks and the affected resources and operations.
             */
            webhooks?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.MutatingWebhook>[]>;
        }
        /**
         * MutatingWebhook describes an admission webhook and the resources and operations it applies to.
         */
        interface MutatingWebhookPatch {
            /**
             * AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy. Default to `['v1beta1']`.
             */
            admissionReviewVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ClientConfig defines how to communicate with the hook. Required
             */
            clientConfig?: pulumi.Input<inputs.admissionregistration.v1beta1.WebhookClientConfigPatch>;
            /**
             * FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Ignore.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
             *
             * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.
             *
             * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.
             *
             * Defaults to "Exact"
             */
            matchPolicy?: pulumi.Input<string>;
            /**
             * The name of the admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required.
             */
            name?: pulumi.Input<string>;
            /**
             * NamespaceSelector decides whether to run the webhook on an object based on whether the namespace for that object matches the selector. If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the webhook.
             *
             * For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "runlevel",
             *       "operator": "NotIn",
             *       "values": [
             *         "0",
             *         "1"
             *       ]
             *     }
             *   ]
             * }
             *
             * If instead you want to only run the webhook on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "environment",
             *       "operator": "In",
             *       "values": [
             *         "prod",
             *         "staging"
             *       ]
             *     }
             *   ]
             * }
             *
             * See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/ for more examples of label selectors.
             *
             * Default to the empty LabelSelector, which matches everything.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * ObjectSelector decides whether to run the webhook based on if the object has matching labels. objectSelector is evaluated against both the oldObject and newObject that would be sent to the webhook, and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.
             */
            objectSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * reinvocationPolicy indicates whether this webhook should be called multiple times as part of a single admission evaluation. Allowed values are "Never" and "IfNeeded".
             *
             * Never: the webhook will not be called more than once in a single admission evaluation.
             *
             * IfNeeded: the webhook will be called at least one additional time as part of the admission evaluation if the object being admitted is modified by other admission plugins after the initial webhook call. Webhooks that specify this option *must* be idempotent, able to process objects they previously admitted. Note: * the number of additional invocations is not guaranteed to be exactly one. * if additional invocations result in further modifications to the object, webhooks are not guaranteed to be invoked again. * webhooks that use this option may be reordered to minimize the number of additional invocations. * to validate an object after all mutations are guaranteed complete, use a validating admission webhook instead.
             *
             * Defaults to "Never".
             */
            reinvocationPolicy?: pulumi.Input<string>;
            /**
             * Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches _any_ Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.RuleWithOperationsPatch>[]>;
            /**
             * SideEffects states whether this webhook has side effects. Acceptable values are: Unknown, None, Some, NoneOnDryRun Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission change and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some. Defaults to Unknown.
             */
            sideEffects?: pulumi.Input<string>;
            /**
             * TimeoutSeconds specifies the timeout for this webhook. After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 30 seconds.
             */
            timeoutSeconds?: pulumi.Input<number>;
        }
        /**
         * NamedRuleWithOperations is a tuple of Operations and Resources with ResourceNames.
         */
        interface NamedRuleWithOperations {
            /**
             * APIGroups is the API groups the resources belong to. '*' is all groups. If '*' is present, the length of the slice must be one. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * APIVersions is the API versions the resources belong to. '*' is all versions. If '*' is present, the length of the slice must be one. Required.
             */
            apiVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added. If '*' is present, the length of the slice must be one. Required.
             */
            operations?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.
             */
            resourceNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to.
             *
             * For example: 'pods' means pods. 'pods/log' means the log subresource of pods. '*' means all resources, but not subresources. 'pods/*' means all subresources of pods. '*&#47;scale' means all scale subresources. '*&#47;*' means all resources and their subresources.
             *
             * If wildcard is present, the validation rule will ensure resources do not overlap with each other.
             *
             * Depending on the enclosing object, subresources might not be allowed. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * scope specifies the scope of this rule. Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*".
             */
            scope?: pulumi.Input<string>;
        }
        /**
         * NamedRuleWithOperations is a tuple of Operations and Resources with ResourceNames.
         */
        interface NamedRuleWithOperationsPatch {
            /**
             * APIGroups is the API groups the resources belong to. '*' is all groups. If '*' is present, the length of the slice must be one. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * APIVersions is the API versions the resources belong to. '*' is all versions. If '*' is present, the length of the slice must be one. Required.
             */
            apiVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added. If '*' is present, the length of the slice must be one. Required.
             */
            operations?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.
             */
            resourceNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to.
             *
             * For example: 'pods' means pods. 'pods/log' means the log subresource of pods. '*' means all resources, but not subresources. 'pods/*' means all subresources of pods. '*&#47;scale' means all scale subresources. '*&#47;*' means all resources and their subresources.
             *
             * If wildcard is present, the validation rule will ensure resources do not overlap with each other.
             *
             * Depending on the enclosing object, subresources might not be allowed. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * scope specifies the scope of this rule. Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*".
             */
            scope?: pulumi.Input<string>;
        }
        /**
         * ParamKind is a tuple of Group Kind and Version.
         */
        interface ParamKind {
            /**
             * APIVersion is the API group version the resources belong to. In format of "group/version". Required.
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * Kind is the API kind the resources belong to. Required.
             */
            kind?: pulumi.Input<string>;
        }
        /**
         * ParamKind is a tuple of Group Kind and Version.
         */
        interface ParamKindPatch {
            /**
             * APIVersion is the API group version the resources belong to. In format of "group/version". Required.
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * Kind is the API kind the resources belong to. Required.
             */
            kind?: pulumi.Input<string>;
        }
        /**
         * ParamRef describes how to locate the params to be used as input to expressions of rules applied by a policy binding.
         */
        interface ParamRef {
            /**
             * name is the name of the resource being referenced.
             *
             * One of `name` or `selector` must be set, but `name` and `selector` are mutually exclusive properties. If one is set, the other must be unset.
             *
             * A single parameter used for all admission requests can be configured by setting the `name` field, leaving `selector` blank, and setting namespace if `paramKind` is namespace-scoped.
             */
            name?: pulumi.Input<string>;
            /**
             * namespace is the namespace of the referenced resource. Allows limiting the search for params to a specific namespace. Applies to both `name` and `selector` fields.
             *
             * A per-namespace parameter may be used by specifying a namespace-scoped `paramKind` in the policy and leaving this field empty.
             *
             * - If `paramKind` is cluster-scoped, this field MUST be unset. Setting this field results in a configuration error.
             *
             * - If `paramKind` is namespace-scoped, the namespace of the object being evaluated for admission will be used when this field is left unset. Take care that if this is left empty the binding must not match any cluster-scoped resources, which will result in an error.
             */
            namespace?: pulumi.Input<string>;
            /**
             * `parameterNotFoundAction` controls the behavior of the binding when the resource exists, and name or selector is valid, but there are no parameters matched by the binding. If the value is set to `Allow`, then no matched parameters will be treated as successful validation by the binding. If set to `Deny`, then no matched parameters will be subject to the `failurePolicy` of the policy.
             *
             * Allowed values are `Allow` or `Deny`
             *
             * Required
             */
            parameterNotFoundAction?: pulumi.Input<string>;
            /**
             * selector can be used to match multiple param objects based on their labels. Supply selector: {} to match all resources of the ParamKind.
             *
             * If multiple params are found, they are all evaluated with the policy expressions and the results are ANDed together.
             *
             * One of `name` or `selector` must be set, but `name` and `selector` are mutually exclusive properties. If one is set, the other must be unset.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
        }
        /**
         * ParamRef describes how to locate the params to be used as input to expressions of rules applied by a policy binding.
         */
        interface ParamRefPatch {
            /**
             * name is the name of the resource being referenced.
             *
             * One of `name` or `selector` must be set, but `name` and `selector` are mutually exclusive properties. If one is set, the other must be unset.
             *
             * A single parameter used for all admission requests can be configured by setting the `name` field, leaving `selector` blank, and setting namespace if `paramKind` is namespace-scoped.
             */
            name?: pulumi.Input<string>;
            /**
             * namespace is the namespace of the referenced resource. Allows limiting the search for params to a specific namespace. Applies to both `name` and `selector` fields.
             *
             * A per-namespace parameter may be used by specifying a namespace-scoped `paramKind` in the policy and leaving this field empty.
             *
             * - If `paramKind` is cluster-scoped, this field MUST be unset. Setting this field results in a configuration error.
             *
             * - If `paramKind` is namespace-scoped, the namespace of the object being evaluated for admission will be used when this field is left unset. Take care that if this is left empty the binding must not match any cluster-scoped resources, which will result in an error.
             */
            namespace?: pulumi.Input<string>;
            /**
             * `parameterNotFoundAction` controls the behavior of the binding when the resource exists, and name or selector is valid, but there are no parameters matched by the binding. If the value is set to `Allow`, then no matched parameters will be treated as successful validation by the binding. If set to `Deny`, then no matched parameters will be subject to the `failurePolicy` of the policy.
             *
             * Allowed values are `Allow` or `Deny`
             *
             * Required
             */
            parameterNotFoundAction?: pulumi.Input<string>;
            /**
             * selector can be used to match multiple param objects based on their labels. Supply selector: {} to match all resources of the ParamKind.
             *
             * If multiple params are found, they are all evaluated with the policy expressions and the results are ANDed together.
             *
             * One of `name` or `selector` must be set, but `name` and `selector` are mutually exclusive properties. If one is set, the other must be unset.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
        }
        /**
         * RuleWithOperations is a tuple of Operations and Resources. It is recommended to make sure that all the tuple expansions are valid.
         */
        interface RuleWithOperations {
            /**
             * APIGroups is the API groups the resources belong to. '*' is all groups. If '*' is present, the length of the slice must be one. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * APIVersions is the API versions the resources belong to. '*' is all versions. If '*' is present, the length of the slice must be one. Required.
             */
            apiVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Operations is the operations the admission hook cares about - CREATE, UPDATE, or * for all operations. If '*' is present, the length of the slice must be one. Required.
             */
            operations?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to.
             *
             * For example: 'pods' means pods. 'pods/log' means the log subresource of pods. '*' means all resources, but not subresources. 'pods/*' means all subresources of pods. '*&#47;scale' means all scale subresources. '*&#47;*' means all resources and their subresources.
             *
             * If wildcard is present, the validation rule will ensure resources do not overlap with each other.
             *
             * Depending on the enclosing object, subresources might not be allowed. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * scope specifies the scope of this rule. Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*".
             */
            scope?: pulumi.Input<string>;
        }
        /**
         * RuleWithOperations is a tuple of Operations and Resources. It is recommended to make sure that all the tuple expansions are valid.
         */
        interface RuleWithOperationsPatch {
            /**
             * APIGroups is the API groups the resources belong to. '*' is all groups. If '*' is present, the length of the slice must be one. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * APIVersions is the API versions the resources belong to. '*' is all versions. If '*' is present, the length of the slice must be one. Required.
             */
            apiVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Operations is the operations the admission hook cares about - CREATE, UPDATE, or * for all operations. If '*' is present, the length of the slice must be one. Required.
             */
            operations?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to.
             *
             * For example: 'pods' means pods. 'pods/log' means the log subresource of pods. '*' means all resources, but not subresources. 'pods/*' means all subresources of pods. '*&#47;scale' means all scale subresources. '*&#47;*' means all resources and their subresources.
             *
             * If wildcard is present, the validation rule will ensure resources do not overlap with each other.
             *
             * Depending on the enclosing object, subresources might not be allowed. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * scope specifies the scope of this rule. Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*".
             */
            scope?: pulumi.Input<string>;
        }
        /**
         * ServiceReference holds a reference to Service.legacy.k8s.io
         */
        interface ServiceReference {
            /**
             * `name` is the name of the service. Required
             */
            name: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of the service. Required
             */
            namespace: pulumi.Input<string>;
            /**
             * `path` is an optional URL path which will be sent in any request to this service.
             */
            path?: pulumi.Input<string>;
            /**
             * If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive).
             */
            port?: pulumi.Input<number>;
        }
        /**
         * ServiceReference holds a reference to Service.legacy.k8s.io
         */
        interface ServiceReferencePatch {
            /**
             * `name` is the name of the service. Required
             */
            name?: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of the service. Required
             */
            namespace?: pulumi.Input<string>;
            /**
             * `path` is an optional URL path which will be sent in any request to this service.
             */
            path?: pulumi.Input<string>;
            /**
             * If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive).
             */
            port?: pulumi.Input<number>;
        }
        /**
         * TypeChecking contains results of type checking the expressions in the ValidatingAdmissionPolicy
         */
        interface TypeChecking {
            /**
             * The type checking warnings for each expression.
             */
            expressionWarnings?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.ExpressionWarning>[]>;
        }
        /**
         * ValidatingAdmissionPolicy describes the definition of an admission validation policy that accepts or rejects an object without changing it.
         */
        interface ValidatingAdmissionPolicy {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"admissionregistration.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ValidatingAdmissionPolicy">;
            /**
             * Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the ValidatingAdmissionPolicy.
             */
            spec?: pulumi.Input<inputs.admissionregistration.v1beta1.ValidatingAdmissionPolicySpec>;
            /**
             * The status of the ValidatingAdmissionPolicy, including warnings that are useful to determine if the policy behaves in the expected way. Populated by the system. Read-only.
             */
            status?: pulumi.Input<inputs.admissionregistration.v1beta1.ValidatingAdmissionPolicyStatus>;
        }
        /**
         * ValidatingAdmissionPolicyBinding binds the ValidatingAdmissionPolicy with paramerized resources. ValidatingAdmissionPolicyBinding and parameter CRDs together define how cluster administrators configure policies for clusters.
         *
         * For a given admission request, each binding will cause its policy to be evaluated N times, where N is 1 for policies/bindings that don't use params, otherwise N is the number of parameters selected by the binding.
         *
         * The CEL expressions of a policy must have a computed CEL cost below the maximum CEL budget. Each evaluation of the policy is given an independent CEL cost budget. Adding/removing policies, bindings, or params can not affect whether a given (policy, binding, param) combination is within its own CEL budget.
         */
        interface ValidatingAdmissionPolicyBinding {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"admissionregistration.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ValidatingAdmissionPolicyBinding">;
            /**
             * Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the ValidatingAdmissionPolicyBinding.
             */
            spec?: pulumi.Input<inputs.admissionregistration.v1beta1.ValidatingAdmissionPolicyBindingSpec>;
        }
        /**
         * ValidatingAdmissionPolicyBindingSpec is the specification of the ValidatingAdmissionPolicyBinding.
         */
        interface ValidatingAdmissionPolicyBindingSpec {
            /**
             * MatchResources declares what resources match this binding and will be validated by it. Note that this is intersected with the policy's matchConstraints, so only requests that are matched by the policy can be selected by this. If this is unset, all resources matched by the policy are validated by this binding When resourceRules is unset, it does not constrain resource matching. If a resource is matched by the other fields of this object, it will be validated. Note that this is differs from ValidatingAdmissionPolicy matchConstraints, where resourceRules are required.
             */
            matchResources?: pulumi.Input<inputs.admissionregistration.v1beta1.MatchResources>;
            /**
             * paramRef specifies the parameter resource used to configure the admission control policy. It should point to a resource of the type specified in ParamKind of the bound ValidatingAdmissionPolicy. If the policy specifies a ParamKind and the resource referred to by ParamRef does not exist, this binding is considered mis-configured and the FailurePolicy of the ValidatingAdmissionPolicy applied. If the policy does not specify a ParamKind then this field is ignored, and the rules are evaluated without a param.
             */
            paramRef?: pulumi.Input<inputs.admissionregistration.v1beta1.ParamRef>;
            /**
             * PolicyName references a ValidatingAdmissionPolicy name which the ValidatingAdmissionPolicyBinding binds to. If the referenced resource does not exist, this binding is considered invalid and will be ignored Required.
             */
            policyName?: pulumi.Input<string>;
            /**
             * validationActions declares how Validations of the referenced ValidatingAdmissionPolicy are enforced. If a validation evaluates to false it is always enforced according to these actions.
             *
             * Failures defined by the ValidatingAdmissionPolicy's FailurePolicy are enforced according to these actions only if the FailurePolicy is set to Fail, otherwise the failures are ignored. This includes compilation errors, runtime errors and misconfigurations of the policy.
             *
             * validationActions is declared as a set of action values. Order does not matter. validationActions may not contain duplicates of the same action.
             *
             * The supported actions values are:
             *
             * "Deny" specifies that a validation failure results in a denied request.
             *
             * "Warn" specifies that a validation failure is reported to the request client in HTTP Warning headers, with a warning code of 299. Warnings can be sent both for allowed or denied admission responses.
             *
             * "Audit" specifies that a validation failure is included in the published audit event for the request. The audit event will contain a `validation.policy.admission.k8s.io/validation_failure` audit annotation with a value containing the details of the validation failures, formatted as a JSON list of objects, each with the following fields: - message: The validation failure message string - policy: The resource name of the ValidatingAdmissionPolicy - binding: The resource name of the ValidatingAdmissionPolicyBinding - expressionIndex: The index of the failed validations in the ValidatingAdmissionPolicy - validationActions: The enforcement actions enacted for the validation failure Example audit annotation: `"validation.policy.admission.k8s.io/validation_failure": "[{\"message\": \"Invalid value\", {\"policy\": \"policy.example.com\", {\"binding\": \"policybinding.example.com\", {\"expressionIndex\": \"1\", {\"validationActions\": [\"Audit\"]}]"`
             *
             * Clients should expect to handle additional values by ignoring any values not recognized.
             *
             * "Deny" and "Warn" may not be used together since this combination needlessly duplicates the validation failure both in the API response body and the HTTP warning headers.
             *
             * Required.
             */
            validationActions?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ValidatingAdmissionPolicyBindingSpec is the specification of the ValidatingAdmissionPolicyBinding.
         */
        interface ValidatingAdmissionPolicyBindingSpecPatch {
            /**
             * MatchResources declares what resources match this binding and will be validated by it. Note that this is intersected with the policy's matchConstraints, so only requests that are matched by the policy can be selected by this. If this is unset, all resources matched by the policy are validated by this binding When resourceRules is unset, it does not constrain resource matching. If a resource is matched by the other fields of this object, it will be validated. Note that this is differs from ValidatingAdmissionPolicy matchConstraints, where resourceRules are required.
             */
            matchResources?: pulumi.Input<inputs.admissionregistration.v1beta1.MatchResourcesPatch>;
            /**
             * paramRef specifies the parameter resource used to configure the admission control policy. It should point to a resource of the type specified in ParamKind of the bound ValidatingAdmissionPolicy. If the policy specifies a ParamKind and the resource referred to by ParamRef does not exist, this binding is considered mis-configured and the FailurePolicy of the ValidatingAdmissionPolicy applied. If the policy does not specify a ParamKind then this field is ignored, and the rules are evaluated without a param.
             */
            paramRef?: pulumi.Input<inputs.admissionregistration.v1beta1.ParamRefPatch>;
            /**
             * PolicyName references a ValidatingAdmissionPolicy name which the ValidatingAdmissionPolicyBinding binds to. If the referenced resource does not exist, this binding is considered invalid and will be ignored Required.
             */
            policyName?: pulumi.Input<string>;
            /**
             * validationActions declares how Validations of the referenced ValidatingAdmissionPolicy are enforced. If a validation evaluates to false it is always enforced according to these actions.
             *
             * Failures defined by the ValidatingAdmissionPolicy's FailurePolicy are enforced according to these actions only if the FailurePolicy is set to Fail, otherwise the failures are ignored. This includes compilation errors, runtime errors and misconfigurations of the policy.
             *
             * validationActions is declared as a set of action values. Order does not matter. validationActions may not contain duplicates of the same action.
             *
             * The supported actions values are:
             *
             * "Deny" specifies that a validation failure results in a denied request.
             *
             * "Warn" specifies that a validation failure is reported to the request client in HTTP Warning headers, with a warning code of 299. Warnings can be sent both for allowed or denied admission responses.
             *
             * "Audit" specifies that a validation failure is included in the published audit event for the request. The audit event will contain a `validation.policy.admission.k8s.io/validation_failure` audit annotation with a value containing the details of the validation failures, formatted as a JSON list of objects, each with the following fields: - message: The validation failure message string - policy: The resource name of the ValidatingAdmissionPolicy - binding: The resource name of the ValidatingAdmissionPolicyBinding - expressionIndex: The index of the failed validations in the ValidatingAdmissionPolicy - validationActions: The enforcement actions enacted for the validation failure Example audit annotation: `"validation.policy.admission.k8s.io/validation_failure": "[{\"message\": \"Invalid value\", {\"policy\": \"policy.example.com\", {\"binding\": \"policybinding.example.com\", {\"expressionIndex\": \"1\", {\"validationActions\": [\"Audit\"]}]"`
             *
             * Clients should expect to handle additional values by ignoring any values not recognized.
             *
             * "Deny" and "Warn" may not be used together since this combination needlessly duplicates the validation failure both in the API response body and the HTTP warning headers.
             *
             * Required.
             */
            validationActions?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ValidatingAdmissionPolicySpec is the specification of the desired behavior of the AdmissionPolicy.
         */
        interface ValidatingAdmissionPolicySpec {
            /**
             * auditAnnotations contains CEL expressions which are used to produce audit annotations for the audit event of the API request. validations and auditAnnotations may not both be empty; a least one of validations or auditAnnotations is required.
             */
            auditAnnotations?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.AuditAnnotation>[]>;
            /**
             * failurePolicy defines how to handle failures for the admission policy. Failures can occur from CEL expression parse errors, type check errors, runtime errors and invalid or mis-configured policy definitions or bindings.
             *
             * A policy is invalid if spec.paramKind refers to a non-existent Kind. A binding is invalid if spec.paramRef.name refers to a non-existent resource.
             *
             * failurePolicy does not define how validations that evaluate to false are handled.
             *
             * When failurePolicy is set to Fail, ValidatingAdmissionPolicyBinding validationActions define how failures are enforced.
             *
             * Allowed values are Ignore or Fail. Defaults to Fail.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * MatchConditions is a list of conditions that must be met for a request to be validated. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
             *
             * If a parameter object is provided, it can be accessed via the `params` handle in the same manner as validation expressions.
             *
             * The exact matching logic is (in order):
             *   1. If ANY matchCondition evaluates to FALSE, the policy is skipped.
             *   2. If ALL matchConditions evaluate to TRUE, the policy is evaluated.
             *   3. If any matchCondition evaluates to an error (but none are FALSE):
             *      - If failurePolicy=Fail, reject the request
             *      - If failurePolicy=Ignore, the policy is skipped
             */
            matchConditions?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.MatchCondition>[]>;
            /**
             * MatchConstraints specifies what resources this policy is designed to validate. The AdmissionPolicy cares about a request if it matches _all_ Constraints. However, in order to prevent clusters from being put into an unstable state that cannot be recovered from via the API ValidatingAdmissionPolicy cannot match ValidatingAdmissionPolicy and ValidatingAdmissionPolicyBinding. Required.
             */
            matchConstraints?: pulumi.Input<inputs.admissionregistration.v1beta1.MatchResources>;
            /**
             * ParamKind specifies the kind of resources used to parameterize this policy. If absent, there are no parameters for this policy and the param CEL variable will not be provided to validation expressions. If ParamKind refers to a non-existent kind, this policy definition is mis-configured and the FailurePolicy is applied. If paramKind is specified but paramRef is unset in ValidatingAdmissionPolicyBinding, the params variable will be null.
             */
            paramKind?: pulumi.Input<inputs.admissionregistration.v1beta1.ParamKind>;
            /**
             * Validations contain CEL expressions which is used to apply the validation. Validations and AuditAnnotations may not both be empty; a minimum of one Validations or AuditAnnotations is required.
             */
            validations?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.Validation>[]>;
            /**
             * Variables contain definitions of variables that can be used in composition of other expressions. Each variable is defined as a named CEL expression. The variables defined here will be available under `variables` in other expressions of the policy except MatchConditions because MatchConditions are evaluated before the rest of the policy.
             *
             * The expression of a variable can refer to other variables defined earlier in the list but not those after. Thus, Variables must be sorted by the order of first appearance and acyclic.
             */
            variables?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.Variable>[]>;
        }
        /**
         * ValidatingAdmissionPolicySpec is the specification of the desired behavior of the AdmissionPolicy.
         */
        interface ValidatingAdmissionPolicySpecPatch {
            /**
             * auditAnnotations contains CEL expressions which are used to produce audit annotations for the audit event of the API request. validations and auditAnnotations may not both be empty; a least one of validations or auditAnnotations is required.
             */
            auditAnnotations?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.AuditAnnotationPatch>[]>;
            /**
             * failurePolicy defines how to handle failures for the admission policy. Failures can occur from CEL expression parse errors, type check errors, runtime errors and invalid or mis-configured policy definitions or bindings.
             *
             * A policy is invalid if spec.paramKind refers to a non-existent Kind. A binding is invalid if spec.paramRef.name refers to a non-existent resource.
             *
             * failurePolicy does not define how validations that evaluate to false are handled.
             *
             * When failurePolicy is set to Fail, ValidatingAdmissionPolicyBinding validationActions define how failures are enforced.
             *
             * Allowed values are Ignore or Fail. Defaults to Fail.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * MatchConditions is a list of conditions that must be met for a request to be validated. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
             *
             * If a parameter object is provided, it can be accessed via the `params` handle in the same manner as validation expressions.
             *
             * The exact matching logic is (in order):
             *   1. If ANY matchCondition evaluates to FALSE, the policy is skipped.
             *   2. If ALL matchConditions evaluate to TRUE, the policy is evaluated.
             *   3. If any matchCondition evaluates to an error (but none are FALSE):
             *      - If failurePolicy=Fail, reject the request
             *      - If failurePolicy=Ignore, the policy is skipped
             */
            matchConditions?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.MatchConditionPatch>[]>;
            /**
             * MatchConstraints specifies what resources this policy is designed to validate. The AdmissionPolicy cares about a request if it matches _all_ Constraints. However, in order to prevent clusters from being put into an unstable state that cannot be recovered from via the API ValidatingAdmissionPolicy cannot match ValidatingAdmissionPolicy and ValidatingAdmissionPolicyBinding. Required.
             */
            matchConstraints?: pulumi.Input<inputs.admissionregistration.v1beta1.MatchResourcesPatch>;
            /**
             * ParamKind specifies the kind of resources used to parameterize this policy. If absent, there are no parameters for this policy and the param CEL variable will not be provided to validation expressions. If ParamKind refers to a non-existent kind, this policy definition is mis-configured and the FailurePolicy is applied. If paramKind is specified but paramRef is unset in ValidatingAdmissionPolicyBinding, the params variable will be null.
             */
            paramKind?: pulumi.Input<inputs.admissionregistration.v1beta1.ParamKindPatch>;
            /**
             * Validations contain CEL expressions which is used to apply the validation. Validations and AuditAnnotations may not both be empty; a minimum of one Validations or AuditAnnotations is required.
             */
            validations?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.ValidationPatch>[]>;
            /**
             * Variables contain definitions of variables that can be used in composition of other expressions. Each variable is defined as a named CEL expression. The variables defined here will be available under `variables` in other expressions of the policy except MatchConditions because MatchConditions are evaluated before the rest of the policy.
             *
             * The expression of a variable can refer to other variables defined earlier in the list but not those after. Thus, Variables must be sorted by the order of first appearance and acyclic.
             */
            variables?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.VariablePatch>[]>;
        }
        /**
         * ValidatingAdmissionPolicyStatus represents the status of an admission validation policy.
         */
        interface ValidatingAdmissionPolicyStatus {
            /**
             * The conditions represent the latest available observations of a policy's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.meta.v1.Condition>[]>;
            /**
             * The generation observed by the controller.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * The results of type checking for each expression. Presence of this field indicates the completion of the type checking.
             */
            typeChecking?: pulumi.Input<inputs.admissionregistration.v1beta1.TypeChecking>;
        }
        /**
         * ValidatingWebhook describes an admission webhook and the resources and operations it applies to.
         */
        interface ValidatingWebhook {
            /**
             * AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy. Default to `['v1beta1']`.
             */
            admissionReviewVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ClientConfig defines how to communicate with the hook. Required
             */
            clientConfig: pulumi.Input<inputs.admissionregistration.v1beta1.WebhookClientConfig>;
            /**
             * FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Ignore.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
             *
             * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.
             *
             * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.
             *
             * Defaults to "Exact"
             */
            matchPolicy?: pulumi.Input<string>;
            /**
             * The name of the admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required.
             */
            name: pulumi.Input<string>;
            /**
             * NamespaceSelector decides whether to run the webhook on an object based on whether the namespace for that object matches the selector. If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the webhook.
             *
             * For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "runlevel",
             *       "operator": "NotIn",
             *       "values": [
             *         "0",
             *         "1"
             *       ]
             *     }
             *   ]
             * }
             *
             * If instead you want to only run the webhook on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "environment",
             *       "operator": "In",
             *       "values": [
             *         "prod",
             *         "staging"
             *       ]
             *     }
             *   ]
             * }
             *
             * See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels for more examples of label selectors.
             *
             * Default to the empty LabelSelector, which matches everything.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * ObjectSelector decides whether to run the webhook based on if the object has matching labels. objectSelector is evaluated against both the oldObject and newObject that would be sent to the webhook, and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.
             */
            objectSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches _any_ Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.RuleWithOperations>[]>;
            /**
             * SideEffects states whether this webhook has side effects. Acceptable values are: Unknown, None, Some, NoneOnDryRun Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission change and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some. Defaults to Unknown.
             */
            sideEffects?: pulumi.Input<string>;
            /**
             * TimeoutSeconds specifies the timeout for this webhook. After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 30 seconds.
             */
            timeoutSeconds?: pulumi.Input<number>;
        }
        /**
         * ValidatingWebhookConfiguration describes the configuration of and admission webhook that accept or reject and object without changing it. Deprecated in v1.16, planned for removal in v1.19. Use admissionregistration.k8s.io/v1 ValidatingWebhookConfiguration instead.
         */
        interface ValidatingWebhookConfiguration {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"admissionregistration.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ValidatingWebhookConfiguration">;
            /**
             * Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Webhooks is a list of webhooks and the affected resources and operations.
             */
            webhooks?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.ValidatingWebhook>[]>;
        }
        /**
         * ValidatingWebhook describes an admission webhook and the resources and operations it applies to.
         */
        interface ValidatingWebhookPatch {
            /**
             * AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy. Default to `['v1beta1']`.
             */
            admissionReviewVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ClientConfig defines how to communicate with the hook. Required
             */
            clientConfig?: pulumi.Input<inputs.admissionregistration.v1beta1.WebhookClientConfigPatch>;
            /**
             * FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Ignore.
             */
            failurePolicy?: pulumi.Input<string>;
            /**
             * matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
             *
             * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.
             *
             * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.
             *
             * Defaults to "Exact"
             */
            matchPolicy?: pulumi.Input<string>;
            /**
             * The name of the admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required.
             */
            name?: pulumi.Input<string>;
            /**
             * NamespaceSelector decides whether to run the webhook on an object based on whether the namespace for that object matches the selector. If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the webhook.
             *
             * For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "runlevel",
             *       "operator": "NotIn",
             *       "values": [
             *         "0",
             *         "1"
             *       ]
             *     }
             *   ]
             * }
             *
             * If instead you want to only run the webhook on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
             *   "matchExpressions": [
             *     {
             *       "key": "environment",
             *       "operator": "In",
             *       "values": [
             *         "prod",
             *         "staging"
             *       ]
             *     }
             *   ]
             * }
             *
             * See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels for more examples of label selectors.
             *
             * Default to the empty LabelSelector, which matches everything.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * ObjectSelector decides whether to run the webhook based on if the object has matching labels. objectSelector is evaluated against both the oldObject and newObject that would be sent to the webhook, and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.
             */
            objectSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches _any_ Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.admissionregistration.v1beta1.RuleWithOperationsPatch>[]>;
            /**
             * SideEffects states whether this webhook has side effects. Acceptable values are: Unknown, None, Some, NoneOnDryRun Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission change and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some. Defaults to Unknown.
             */
            sideEffects?: pulumi.Input<string>;
            /**
             * TimeoutSeconds specifies the timeout for this webhook. After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 30 seconds.
             */
            timeoutSeconds?: pulumi.Input<number>;
        }
        /**
         * Validation specifies the CEL expression which is used to apply the validation.
         */
        interface Validation {
            /**
             * Expression represents the expression which will be evaluated by CEL. ref: https://github.com/google/cel-spec CEL expressions have access to the contents of the API request/response, organized into CEL variables as well as some other useful variables:
             *
             * - 'object' - The object from the incoming request. The value is null for DELETE requests. - 'oldObject' - The existing object. The value is null for CREATE requests. - 'request' - Attributes of the API request([ref](/pkg/apis/admission/types.go#AdmissionRequest)). - 'params' - Parameter resource referred to by the policy binding being evaluated. Only populated if the policy has a ParamKind. - 'namespaceObject' - The namespace object that the incoming object belongs to. The value is null for cluster-scoped resources. - 'variables' - Map of composited variables, from its name to its lazily evaluated value.
             *   For example, a variable named 'foo' can be accessed as 'variables.foo'.
             * - 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
             *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
             * - 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
             *   request resource.
             *
             * The `apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object. No other metadata properties are accessible.
             *
             * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Accessible property names are escaped according to the following rules when accessed in the expression: - '__' escapes to '__underscores__' - '.' escapes to '__dot__' - '-' escapes to '__dash__' - '/' escapes to '__slash__' - Property names that exactly match a CEL RESERVED keyword escape to '__{keyword}__'. The keywords are:
             * 	  "true", "false", "null", "in", "as", "break", "const", "continue", "else", "for", "function", "if",
             * 	  "import", "let", "loop", "package", "namespace", "return".
             * Examples:
             *   - Expression accessing a property named "namespace": {"Expression": "object.__namespace__ > 0"}
             *   - Expression accessing a property named "x-prop": {"Expression": "object.x__dash__prop > 0"}
             *   - Expression accessing a property named "redact__d": {"Expression": "object.redact__underscores__d > 0"}
             *
             * Equality on arrays with list type of 'set' or 'map' ignores element order, i.e. [1, 2] == [2, 1]. Concatenation on arrays with x-kubernetes-list-type use the semantics of the list type:
             *   - 'set': `X + Y` performs a union where the array positions of all elements in `X` are preserved and
             *     non-intersecting elements in `Y` are appended, retaining their partial order.
             *   - 'map': `X + Y` performs a merge where the array positions of all keys in `X` are preserved but the values
             *     are overwritten by values in `Y` when the key sets of `X` and `Y` intersect. Elements in `Y` with
             *     non-intersecting keys are appended, retaining their partial order.
             * Required.
             */
            expression: pulumi.Input<string>;
            /**
             * Message represents the message displayed when validation fails. The message is required if the Expression contains line breaks. The message must not contain line breaks. If unset, the message is "failed rule: {Rule}". e.g. "must be a URL with the host matching spec.host" If the Expression contains line breaks. Message is required. The message must not contain line breaks. If unset, the message is "failed Expression: {Expression}".
             */
            message?: pulumi.Input<string>;
            /**
             * messageExpression declares a CEL expression that evaluates to the validation failure message that is returned when this rule fails. Since messageExpression is used as a failure message, it must evaluate to a string. If both message and messageExpression are present on a validation, then messageExpression will be used if validation fails. If messageExpression results in a runtime error, the runtime error is logged, and the validation failure message is produced as if the messageExpression field were unset. If messageExpression evaluates to an empty string, a string with only spaces, or a string that contains line breaks, then the validation failure message will also be produced as if the messageExpression field were unset, and the fact that messageExpression produced an empty string/string with only spaces/string with line breaks will be logged. messageExpression has access to all the same variables as the `expression` except for 'authorizer' and 'authorizer.requestResource'. Example: "object.x must be less than max ("+string(params.max)+")"
             */
            messageExpression?: pulumi.Input<string>;
            /**
             * Reason represents a machine-readable description of why this validation failed. If this is the first validation in the list to fail, this reason, as well as the corresponding HTTP response code, are used in the HTTP response to the client. The currently supported reasons are: "Unauthorized", "Forbidden", "Invalid", "RequestEntityTooLarge". If not set, StatusReasonInvalid is used in the response to the client.
             */
            reason?: pulumi.Input<string>;
        }
        /**
         * Validation specifies the CEL expression which is used to apply the validation.
         */
        interface ValidationPatch {
            /**
             * Expression represents the expression which will be evaluated by CEL. ref: https://github.com/google/cel-spec CEL expressions have access to the contents of the API request/response, organized into CEL variables as well as some other useful variables:
             *
             * - 'object' - The object from the incoming request. The value is null for DELETE requests. - 'oldObject' - The existing object. The value is null for CREATE requests. - 'request' - Attributes of the API request([ref](/pkg/apis/admission/types.go#AdmissionRequest)). - 'params' - Parameter resource referred to by the policy binding being evaluated. Only populated if the policy has a ParamKind. - 'namespaceObject' - The namespace object that the incoming object belongs to. The value is null for cluster-scoped resources. - 'variables' - Map of composited variables, from its name to its lazily evaluated value.
             *   For example, a variable named 'foo' can be accessed as 'variables.foo'.
             * - 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
             *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
             * - 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
             *   request resource.
             *
             * The `apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object. No other metadata properties are accessible.
             *
             * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Accessible property names are escaped according to the following rules when accessed in the expression: - '__' escapes to '__underscores__' - '.' escapes to '__dot__' - '-' escapes to '__dash__' - '/' escapes to '__slash__' - Property names that exactly match a CEL RESERVED keyword escape to '__{keyword}__'. The keywords are:
             * 	  "true", "false", "null", "in", "as", "break", "const", "continue", "else", "for", "function", "if",
             * 	  "import", "let", "loop", "package", "namespace", "return".
             * Examples:
             *   - Expression accessing a property named "namespace": {"Expression": "object.__namespace__ > 0"}
             *   - Expression accessing a property named "x-prop": {"Expression": "object.x__dash__prop > 0"}
             *   - Expression accessing a property named "redact__d": {"Expression": "object.redact__underscores__d > 0"}
             *
             * Equality on arrays with list type of 'set' or 'map' ignores element order, i.e. [1, 2] == [2, 1]. Concatenation on arrays with x-kubernetes-list-type use the semantics of the list type:
             *   - 'set': `X + Y` performs a union where the array positions of all elements in `X` are preserved and
             *     non-intersecting elements in `Y` are appended, retaining their partial order.
             *   - 'map': `X + Y` performs a merge where the array positions of all keys in `X` are preserved but the values
             *     are overwritten by values in `Y` when the key sets of `X` and `Y` intersect. Elements in `Y` with
             *     non-intersecting keys are appended, retaining their partial order.
             * Required.
             */
            expression?: pulumi.Input<string>;
            /**
             * Message represents the message displayed when validation fails. The message is required if the Expression contains line breaks. The message must not contain line breaks. If unset, the message is "failed rule: {Rule}". e.g. "must be a URL with the host matching spec.host" If the Expression contains line breaks. Message is required. The message must not contain line breaks. If unset, the message is "failed Expression: {Expression}".
             */
            message?: pulumi.Input<string>;
            /**
             * messageExpression declares a CEL expression that evaluates to the validation failure message that is returned when this rule fails. Since messageExpression is used as a failure message, it must evaluate to a string. If both message and messageExpression are present on a validation, then messageExpression will be used if validation fails. If messageExpression results in a runtime error, the runtime error is logged, and the validation failure message is produced as if the messageExpression field were unset. If messageExpression evaluates to an empty string, a string with only spaces, or a string that contains line breaks, then the validation failure message will also be produced as if the messageExpression field were unset, and the fact that messageExpression produced an empty string/string with only spaces/string with line breaks will be logged. messageExpression has access to all the same variables as the `expression` except for 'authorizer' and 'authorizer.requestResource'. Example: "object.x must be less than max ("+string(params.max)+")"
             */
            messageExpression?: pulumi.Input<string>;
            /**
             * Reason represents a machine-readable description of why this validation failed. If this is the first validation in the list to fail, this reason, as well as the corresponding HTTP response code, are used in the HTTP response to the client. The currently supported reasons are: "Unauthorized", "Forbidden", "Invalid", "RequestEntityTooLarge". If not set, StatusReasonInvalid is used in the response to the client.
             */
            reason?: pulumi.Input<string>;
        }
        /**
         * Variable is the definition of a variable that is used for composition. A variable is defined as a named expression.
         */
        interface Variable {
            /**
             * Expression is the expression that will be evaluated as the value of the variable. The CEL expression has access to the same identifiers as the CEL expressions in Validation.
             */
            expression: pulumi.Input<string>;
            /**
             * Name is the name of the variable. The name must be a valid CEL identifier and unique among all variables. The variable can be accessed in other expressions through `variables` For example, if name is "foo", the variable will be available as `variables.foo`
             */
            name: pulumi.Input<string>;
        }
        /**
         * Variable is the definition of a variable that is used for composition. A variable is defined as a named expression.
         */
        interface VariablePatch {
            /**
             * Expression is the expression that will be evaluated as the value of the variable. The CEL expression has access to the same identifiers as the CEL expressions in Validation.
             */
            expression?: pulumi.Input<string>;
            /**
             * Name is the name of the variable. The name must be a valid CEL identifier and unique among all variables. The variable can be accessed in other expressions through `variables` For example, if name is "foo", the variable will be available as `variables.foo`
             */
            name?: pulumi.Input<string>;
        }
        /**
         * WebhookClientConfig contains the information to make a TLS connection with the webhook
         */
        interface WebhookClientConfig {
            /**
             * `caBundle` is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used.
             */
            caBundle?: pulumi.Input<string>;
            /**
             * `service` is a reference to the service for this webhook. Either `service` or `url` must be specified.
             *
             * If the webhook is running within the cluster, then you should use `service`.
             */
            service?: pulumi.Input<inputs.admissionregistration.v1beta1.ServiceReference>;
            /**
             * `url` gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
             *
             * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
             *
             * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
             *
             * The scheme must be "https"; the URL must begin with "https://".
             *
             * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
             *
             * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
             */
            url?: pulumi.Input<string>;
        }
        /**
         * WebhookClientConfig contains the information to make a TLS connection with the webhook
         */
        interface WebhookClientConfigPatch {
            /**
             * `caBundle` is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used.
             */
            caBundle?: pulumi.Input<string>;
            /**
             * `service` is a reference to the service for this webhook. Either `service` or `url` must be specified.
             *
             * If the webhook is running within the cluster, then you should use `service`.
             */
            service?: pulumi.Input<inputs.admissionregistration.v1beta1.ServiceReferencePatch>;
            /**
             * `url` gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
             *
             * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
             *
             * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
             *
             * The scheme must be "https"; the URL must begin with "https://".
             *
             * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
             *
             * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
             */
            url?: pulumi.Input<string>;
        }
    }
}
export declare namespace apiextensions {
    namespace v1 {
        /**
         * CustomResourceColumnDefinition specifies a column for server side printing.
         */
        interface CustomResourceColumnDefinition {
            /**
             * description is a human readable description of this column.
             */
            description?: pulumi.Input<string>;
            /**
             * format is an optional OpenAPI type definition for this column. The 'name' format is applied to the primary identifier column to assist in clients identifying column is the resource name. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details.
             */
            format?: pulumi.Input<string>;
            /**
             * jsonPath is a simple JSON path (i.e. with array notation) which is evaluated against each custom resource to produce the value for this column.
             */
            jsonPath: pulumi.Input<string>;
            /**
             * name is a human readable name for the column.
             */
            name: pulumi.Input<string>;
            /**
             * priority is an integer defining the relative importance of this column compared to others. Lower numbers are considered higher priority. Columns that may be omitted in limited space scenarios should be given a priority greater than 0.
             */
            priority?: pulumi.Input<number>;
            /**
             * type is an OpenAPI type definition for this column. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details.
             */
            type: pulumi.Input<string>;
        }
        /**
         * CustomResourceColumnDefinition specifies a column for server side printing.
         */
        interface CustomResourceColumnDefinitionPatch {
            /**
             * description is a human readable description of this column.
             */
            description?: pulumi.Input<string>;
            /**
             * format is an optional OpenAPI type definition for this column. The 'name' format is applied to the primary identifier column to assist in clients identifying column is the resource name. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details.
             */
            format?: pulumi.Input<string>;
            /**
             * jsonPath is a simple JSON path (i.e. with array notation) which is evaluated against each custom resource to produce the value for this column.
             */
            jsonPath?: pulumi.Input<string>;
            /**
             * name is a human readable name for the column.
             */
            name?: pulumi.Input<string>;
            /**
             * priority is an integer defining the relative importance of this column compared to others. Lower numbers are considered higher priority. Columns that may be omitted in limited space scenarios should be given a priority greater than 0.
             */
            priority?: pulumi.Input<number>;
            /**
             * type is an OpenAPI type definition for this column. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * CustomResourceConversion describes how to convert different versions of a CR.
         */
        interface CustomResourceConversion {
            /**
             * strategy specifies how custom resources are converted between versions. Allowed values are: - `"None"`: The converter only change the apiVersion and would not touch any other field in the custom resource. - `"Webhook"`: API Server will call to an external webhook to do the conversion. Additional information
             *   is needed for this option. This requires spec.preserveUnknownFields to be false, and spec.conversion.webhook to be set.
             */
            strategy: pulumi.Input<string>;
            /**
             * webhook describes how to call the conversion webhook. Required when `strategy` is set to `"Webhook"`.
             */
            webhook?: pulumi.Input<inputs.apiextensions.v1.WebhookConversion>;
        }
        /**
         * CustomResourceConversion describes how to convert different versions of a CR.
         */
        interface CustomResourceConversionPatch {
            /**
             * strategy specifies how custom resources are converted between versions. Allowed values are: - `"None"`: The converter only change the apiVersion and would not touch any other field in the custom resource. - `"Webhook"`: API Server will call to an external webhook to do the conversion. Additional information
             *   is needed for this option. This requires spec.preserveUnknownFields to be false, and spec.conversion.webhook to be set.
             */
            strategy?: pulumi.Input<string>;
            /**
             * webhook describes how to call the conversion webhook. Required when `strategy` is set to `"Webhook"`.
             */
            webhook?: pulumi.Input<inputs.apiextensions.v1.WebhookConversionPatch>;
        }
        /**
         * CustomResourceDefinition represents a resource that should be exposed on the API server.  Its name MUST be in the format <.spec.name>.<.spec.group>.
         */
        interface CustomResourceDefinition {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apiextensions.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"CustomResourceDefinition">;
            /**
             * Standard object's metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec describes how the user wants the resources to appear
             */
            spec: pulumi.Input<inputs.apiextensions.v1.CustomResourceDefinitionSpec>;
            /**
             * status indicates the actual state of the CustomResourceDefinition
             */
            status?: pulumi.Input<inputs.apiextensions.v1.CustomResourceDefinitionStatus>;
        }
        /**
         * CustomResourceDefinitionCondition contains details for the current condition of this pod.
         */
        interface CustomResourceDefinitionCondition {
            /**
             * lastTransitionTime last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * message is a human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * reason is a unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * status is the status of the condition. Can be True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * type is the type of the condition. Types include Established, NamesAccepted and Terminating.
             */
            type: pulumi.Input<string>;
        }
        /**
         * CustomResourceDefinitionNames indicates the names to serve this CustomResourceDefinition
         */
        interface CustomResourceDefinitionNames {
            /**
             * categories is a list of grouped resources this custom resource belongs to (e.g. 'all'). This is published in API discovery documents, and used by clients to support invocations like `kubectl get all`.
             */
            categories?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * kind is the serialized kind of the resource. It is normally CamelCase and singular. Custom resource instances will use this value as the `kind` attribute in API calls.
             */
            kind: pulumi.Input<string>;
            /**
             * listKind is the serialized kind of the list for this resource. Defaults to "`kind`List".
             */
            listKind?: pulumi.Input<string>;
            /**
             * plural is the plural name of the resource to serve. The custom resources are served under `/apis/<group>/<version>/.../<plural>`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`). Must be all lowercase.
             */
            plural: pulumi.Input<string>;
            /**
             * shortNames are short names for the resource, exposed in API discovery documents, and used by clients to support invocations like `kubectl get <shortname>`. It must be all lowercase.
             */
            shortNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * singular is the singular name of the resource. It must be all lowercase. Defaults to lowercased `kind`.
             */
            singular?: pulumi.Input<string>;
        }
        /**
         * CustomResourceDefinitionNames indicates the names to serve this CustomResourceDefinition
         */
        interface CustomResourceDefinitionNamesPatch {
            /**
             * categories is a list of grouped resources this custom resource belongs to (e.g. 'all'). This is published in API discovery documents, and used by clients to support invocations like `kubectl get all`.
             */
            categories?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * kind is the serialized kind of the resource. It is normally CamelCase and singular. Custom resource instances will use this value as the `kind` attribute in API calls.
             */
            kind?: pulumi.Input<string>;
            /**
             * listKind is the serialized kind of the list for this resource. Defaults to "`kind`List".
             */
            listKind?: pulumi.Input<string>;
            /**
             * plural is the plural name of the resource to serve. The custom resources are served under `/apis/<group>/<version>/.../<plural>`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`). Must be all lowercase.
             */
            plural?: pulumi.Input<string>;
            /**
             * shortNames are short names for the resource, exposed in API discovery documents, and used by clients to support invocations like `kubectl get <shortname>`. It must be all lowercase.
             */
            shortNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * singular is the singular name of the resource. It must be all lowercase. Defaults to lowercased `kind`.
             */
            singular?: pulumi.Input<string>;
        }
        /**
         * CustomResourceDefinitionSpec describes how a user wants their resource to appear
         */
        interface CustomResourceDefinitionSpec {
            /**
             * conversion defines conversion settings for the CRD.
             */
            conversion?: pulumi.Input<inputs.apiextensions.v1.CustomResourceConversion>;
            /**
             * group is the API group of the defined custom resource. The custom resources are served under `/apis/<group>/...`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`).
             */
            group: pulumi.Input<string>;
            /**
             * names specify the resource and kind names for the custom resource.
             */
            names: pulumi.Input<inputs.apiextensions.v1.CustomResourceDefinitionNames>;
            /**
             * preserveUnknownFields indicates that object fields which are not specified in the OpenAPI schema should be preserved when persisting to storage. apiVersion, kind, metadata and known fields inside metadata are always preserved. This field is deprecated in favor of setting `x-preserve-unknown-fields` to true in `spec.versions[*].schema.openAPIV3Schema`. See https://kubernetes.io/docs/tasks/extend-kubernetes/custom-resources/custom-resource-definitions/#field-pruning for details.
             */
            preserveUnknownFields?: pulumi.Input<boolean>;
            /**
             * scope indicates whether the defined custom resource is cluster- or namespace-scoped. Allowed values are `Cluster` and `Namespaced`.
             */
            scope: pulumi.Input<string>;
            /**
             * versions is the list of all API versions of the defined custom resource. Version names are used to compute the order in which served versions are listed in API discovery. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10.
             */
            versions: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.CustomResourceDefinitionVersion>[]>;
        }
        /**
         * CustomResourceDefinitionSpec describes how a user wants their resource to appear
         */
        interface CustomResourceDefinitionSpecPatch {
            /**
             * conversion defines conversion settings for the CRD.
             */
            conversion?: pulumi.Input<inputs.apiextensions.v1.CustomResourceConversionPatch>;
            /**
             * group is the API group of the defined custom resource. The custom resources are served under `/apis/<group>/...`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`).
             */
            group?: pulumi.Input<string>;
            /**
             * names specify the resource and kind names for the custom resource.
             */
            names?: pulumi.Input<inputs.apiextensions.v1.CustomResourceDefinitionNamesPatch>;
            /**
             * preserveUnknownFields indicates that object fields which are not specified in the OpenAPI schema should be preserved when persisting to storage. apiVersion, kind, metadata and known fields inside metadata are always preserved. This field is deprecated in favor of setting `x-preserve-unknown-fields` to true in `spec.versions[*].schema.openAPIV3Schema`. See https://kubernetes.io/docs/tasks/extend-kubernetes/custom-resources/custom-resource-definitions/#field-pruning for details.
             */
            preserveUnknownFields?: pulumi.Input<boolean>;
            /**
             * scope indicates whether the defined custom resource is cluster- or namespace-scoped. Allowed values are `Cluster` and `Namespaced`.
             */
            scope?: pulumi.Input<string>;
            /**
             * versions is the list of all API versions of the defined custom resource. Version names are used to compute the order in which served versions are listed in API discovery. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10.
             */
            versions?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.CustomResourceDefinitionVersionPatch>[]>;
        }
        /**
         * CustomResourceDefinitionStatus indicates the state of the CustomResourceDefinition
         */
        interface CustomResourceDefinitionStatus {
            /**
             * acceptedNames are the names that are actually being used to serve discovery. They may be different than the names in spec.
             */
            acceptedNames: pulumi.Input<inputs.apiextensions.v1.CustomResourceDefinitionNames>;
            /**
             * conditions indicate state for particular aspects of a CustomResourceDefinition
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.CustomResourceDefinitionCondition>[]>;
            /**
             * storedVersions lists all versions of CustomResources that were ever persisted. Tracking these versions allows a migration path for stored versions in etcd. The field is mutable so a migration controller can finish a migration to another version (ensuring no old objects are left in storage), and then remove the rest of the versions from this list. Versions may not be removed from `spec.versions` while they exist in this list.
             */
            storedVersions: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * CustomResourceDefinitionVersion describes a version for CRD.
         */
        interface CustomResourceDefinitionVersion {
            /**
             * additionalPrinterColumns specifies additional columns returned in Table output. See https://kubernetes.io/docs/reference/using-api/api-concepts/#receiving-resources-as-tables for details. If no columns are specified, a single column displaying the age of the custom resource is used.
             */
            additionalPrinterColumns?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.CustomResourceColumnDefinition>[]>;
            /**
             * deprecated indicates this version of the custom resource API is deprecated. When set to true, API requests to this version receive a warning header in the server response. Defaults to false.
             */
            deprecated?: pulumi.Input<boolean>;
            /**
             * deprecationWarning overrides the default warning returned to API clients. May only be set when `deprecated` is true. The default warning indicates this version is deprecated and recommends use of the newest served version of equal or greater stability, if one exists.
             */
            deprecationWarning?: pulumi.Input<string>;
            /**
             * name is the version name, e.g. “v1”, “v2beta1”, etc. The custom resources are served under this version at `/apis/<group>/<version>/...` if `served` is true.
             */
            name: pulumi.Input<string>;
            /**
             * schema describes the schema used for validation, pruning, and defaulting of this version of the custom resource.
             */
            schema?: pulumi.Input<inputs.apiextensions.v1.CustomResourceValidation>;
            /**
             * selectableFields specifies paths to fields that may be used as field selectors. A maximum of 8 selectable fields are allowed. See https://kubernetes.io/docs/concepts/overview/working-with-objects/field-selectors
             */
            selectableFields?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.SelectableField>[]>;
            /**
             * served is a flag enabling/disabling this version from being served via REST APIs
             */
            served: pulumi.Input<boolean>;
            /**
             * storage indicates this version should be used when persisting custom resources to storage. There must be exactly one version with storage=true.
             */
            storage: pulumi.Input<boolean>;
            /**
             * subresources specify what subresources this version of the defined custom resource have.
             */
            subresources?: pulumi.Input<inputs.apiextensions.v1.CustomResourceSubresources>;
        }
        /**
         * CustomResourceDefinitionVersion describes a version for CRD.
         */
        interface CustomResourceDefinitionVersionPatch {
            /**
             * additionalPrinterColumns specifies additional columns returned in Table output. See https://kubernetes.io/docs/reference/using-api/api-concepts/#receiving-resources-as-tables for details. If no columns are specified, a single column displaying the age of the custom resource is used.
             */
            additionalPrinterColumns?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.CustomResourceColumnDefinitionPatch>[]>;
            /**
             * deprecated indicates this version of the custom resource API is deprecated. When set to true, API requests to this version receive a warning header in the server response. Defaults to false.
             */
            deprecated?: pulumi.Input<boolean>;
            /**
             * deprecationWarning overrides the default warning returned to API clients. May only be set when `deprecated` is true. The default warning indicates this version is deprecated and recommends use of the newest served version of equal or greater stability, if one exists.
             */
            deprecationWarning?: pulumi.Input<string>;
            /**
             * name is the version name, e.g. “v1”, “v2beta1”, etc. The custom resources are served under this version at `/apis/<group>/<version>/...` if `served` is true.
             */
            name?: pulumi.Input<string>;
            /**
             * schema describes the schema used for validation, pruning, and defaulting of this version of the custom resource.
             */
            schema?: pulumi.Input<inputs.apiextensions.v1.CustomResourceValidationPatch>;
            /**
             * selectableFields specifies paths to fields that may be used as field selectors. A maximum of 8 selectable fields are allowed. See https://kubernetes.io/docs/concepts/overview/working-with-objects/field-selectors
             */
            selectableFields?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.SelectableFieldPatch>[]>;
            /**
             * served is a flag enabling/disabling this version from being served via REST APIs
             */
            served?: pulumi.Input<boolean>;
            /**
             * storage indicates this version should be used when persisting custom resources to storage. There must be exactly one version with storage=true.
             */
            storage?: pulumi.Input<boolean>;
            /**
             * subresources specify what subresources this version of the defined custom resource have.
             */
            subresources?: pulumi.Input<inputs.apiextensions.v1.CustomResourceSubresourcesPatch>;
        }
        /**
         * CustomResourceSubresourceScale defines how to serve the scale subresource for CustomResources.
         */
        interface CustomResourceSubresourceScale {
            /**
             * labelSelectorPath defines the JSON path inside of a custom resource that corresponds to Scale `status.selector`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status` or `.spec`. Must be set to work with HorizontalPodAutoscaler. The field pointed by this JSON path must be a string field (not a complex selector struct) which contains a serialized label selector in string form. More info: https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions#scale-subresource If there is no value under the given path in the custom resource, the `status.selector` value in the `/scale` subresource will default to the empty string.
             */
            labelSelectorPath?: pulumi.Input<string>;
            /**
             * specReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `spec.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.spec`. If there is no value under the given path in the custom resource, the `/scale` subresource will return an error on GET.
             */
            specReplicasPath: pulumi.Input<string>;
            /**
             * statusReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `status.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status`. If there is no value under the given path in the custom resource, the `status.replicas` value in the `/scale` subresource will default to 0.
             */
            statusReplicasPath: pulumi.Input<string>;
        }
        /**
         * CustomResourceSubresourceScale defines how to serve the scale subresource for CustomResources.
         */
        interface CustomResourceSubresourceScalePatch {
            /**
             * labelSelectorPath defines the JSON path inside of a custom resource that corresponds to Scale `status.selector`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status` or `.spec`. Must be set to work with HorizontalPodAutoscaler. The field pointed by this JSON path must be a string field (not a complex selector struct) which contains a serialized label selector in string form. More info: https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions#scale-subresource If there is no value under the given path in the custom resource, the `status.selector` value in the `/scale` subresource will default to the empty string.
             */
            labelSelectorPath?: pulumi.Input<string>;
            /**
             * specReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `spec.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.spec`. If there is no value under the given path in the custom resource, the `/scale` subresource will return an error on GET.
             */
            specReplicasPath?: pulumi.Input<string>;
            /**
             * statusReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `status.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status`. If there is no value under the given path in the custom resource, the `status.replicas` value in the `/scale` subresource will default to 0.
             */
            statusReplicasPath?: pulumi.Input<string>;
        }
        /**
         * CustomResourceSubresources defines the status and scale subresources for CustomResources.
         */
        interface CustomResourceSubresources {
            /**
             * scale indicates the custom resource should serve a `/scale` subresource that returns an `autoscaling/v1` Scale object.
             */
            scale?: pulumi.Input<inputs.apiextensions.v1.CustomResourceSubresourceScale>;
            /**
             * status indicates the custom resource should serve a `/status` subresource. When enabled: 1. requests to the custom resource primary endpoint ignore changes to the `status` stanza of the object. 2. requests to the custom resource `/status` subresource ignore changes to anything other than the `status` stanza of the object.
             */
            status?: any;
        }
        /**
         * CustomResourceSubresources defines the status and scale subresources for CustomResources.
         */
        interface CustomResourceSubresourcesPatch {
            /**
             * scale indicates the custom resource should serve a `/scale` subresource that returns an `autoscaling/v1` Scale object.
             */
            scale?: pulumi.Input<inputs.apiextensions.v1.CustomResourceSubresourceScalePatch>;
            /**
             * status indicates the custom resource should serve a `/status` subresource. When enabled: 1. requests to the custom resource primary endpoint ignore changes to the `status` stanza of the object. 2. requests to the custom resource `/status` subresource ignore changes to anything other than the `status` stanza of the object.
             */
            status?: any;
        }
        /**
         * CustomResourceValidation is a list of validation methods for CustomResources.
         */
        interface CustomResourceValidation {
            /**
             * openAPIV3Schema is the OpenAPI v3 schema to use for validation and pruning.
             */
            openAPIV3Schema?: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps>;
        }
        /**
         * CustomResourceValidation is a list of validation methods for CustomResources.
         */
        interface CustomResourceValidationPatch {
            /**
             * openAPIV3Schema is the OpenAPI v3 schema to use for validation and pruning.
             */
            openAPIV3Schema?: pulumi.Input<inputs.apiextensions.v1.JSONSchemaPropsPatch>;
        }
        /**
         * ExternalDocumentation allows referencing an external resource for extended documentation.
         */
        interface ExternalDocumentation {
            description?: pulumi.Input<string>;
            url?: pulumi.Input<string>;
        }
        /**
         * ExternalDocumentation allows referencing an external resource for extended documentation.
         */
        interface ExternalDocumentationPatch {
            description?: pulumi.Input<string>;
            url?: pulumi.Input<string>;
        }
        /**
         * JSONSchemaProps is a JSON-Schema following Specification Draft 4 (http://json-schema.org/).
         */
        interface JSONSchemaProps {
            $ref?: pulumi.Input<string>;
            $schema?: pulumi.Input<string>;
            additionalItems?: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps | boolean>;
            additionalProperties?: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps | boolean>;
            allOf?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps>[]>;
            anyOf?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps>[]>;
            /**
             * default is a default value for undefined object fields. Defaulting is a beta feature under the CustomResourceDefaulting feature gate. Defaulting requires spec.preserveUnknownFields to be false.
             */
            default?: any;
            definitions?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps>;
            }>;
            dependencies?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps | pulumi.Input<string>[]>;
            }>;
            description?: pulumi.Input<string>;
            enum?: pulumi.Input<any[]>;
            example?: any;
            exclusiveMaximum?: pulumi.Input<boolean>;
            exclusiveMinimum?: pulumi.Input<boolean>;
            externalDocs?: pulumi.Input<inputs.apiextensions.v1.ExternalDocumentation>;
            /**
             * format is an OpenAPI v3 format string. Unknown formats are ignored. The following formats are validated:
             *
             * - bsonobjectid: a bson object ID, i.e. a 24 characters hex string - uri: an URI as parsed by Golang net/url.ParseRequestURI - email: an email address as parsed by Golang net/mail.ParseAddress - hostname: a valid representation for an Internet host name, as defined by RFC 1034, section 3.1 [RFC1034]. - ipv4: an IPv4 IP as parsed by Golang net.ParseIP - ipv6: an IPv6 IP as parsed by Golang net.ParseIP - cidr: a CIDR as parsed by Golang net.ParseCIDR - mac: a MAC address as parsed by Golang net.ParseMAC - uuid: an UUID that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid3: an UUID3 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?3[0-9a-f]{3}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid4: an UUID4 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?4[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - uuid5: an UUID5 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?5[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - isbn: an ISBN10 or ISBN13 number string like "0321751043" or "978-0321751041" - isbn10: an ISBN10 number string like "0321751043" - isbn13: an ISBN13 number string like "978-0321751041" - creditcard: a credit card number defined by the regex ^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|6(?:011|5[0-9][0-9])[0-9]{12}|3[47][0-9]{13}|3(?:0[0-5]|[68][0-9])[0-9]{11}|(?:2131|1800|35\\d{3})\\d{11})$ with any non digit characters mixed in - ssn: a U.S. social security number following the regex ^\\d{3}[- ]?\\d{2}[- ]?\\d{4}$ - hexcolor: an hexadecimal color code like "#FFFFFF: following the regex ^#?([0-9a-fA-F]{3}|[0-9a-fA-F]{6})$ - rgbcolor: an RGB color code like rgb like "rgb(255,255,2559" - byte: base64 encoded binary data - password: any kind of string - date: a date string like "2006-01-02" as defined by full-date in RFC3339 - duration: a duration string like "22 ns" as parsed by Golang time.ParseDuration or compatible with Scala duration format - datetime: a date time string like "2014-12-15T19:30:20.000Z" as defined by date-time in RFC3339.
             */
            format?: pulumi.Input<string>;
            id?: pulumi.Input<string>;
            items?: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps | any[]>;
            maxItems?: pulumi.Input<number>;
            maxLength?: pulumi.Input<number>;
            maxProperties?: pulumi.Input<number>;
            maximum?: pulumi.Input<number>;
            minItems?: pulumi.Input<number>;
            minLength?: pulumi.Input<number>;
            minProperties?: pulumi.Input<number>;
            minimum?: pulumi.Input<number>;
            multipleOf?: pulumi.Input<number>;
            not?: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps>;
            nullable?: pulumi.Input<boolean>;
            oneOf?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps>[]>;
            pattern?: pulumi.Input<string>;
            patternProperties?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps>;
            }>;
            properties?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps>;
            }>;
            required?: pulumi.Input<pulumi.Input<string>[]>;
            title?: pulumi.Input<string>;
            type?: pulumi.Input<string>;
            uniqueItems?: pulumi.Input<boolean>;
            /**
             * x-kubernetes-embedded-resource defines that the value is an embedded Kubernetes runtime.Object, with TypeMeta and ObjectMeta. The type must be object. It is allowed to further restrict the embedded object. kind, apiVersion and metadata are validated automatically. x-kubernetes-preserve-unknown-fields is allowed to be true, but does not have to be if the object is fully specified (up to kind, apiVersion, metadata).
             */
            x_kubernetes_embedded_resource?: pulumi.Input<boolean>;
            /**
             * x-kubernetes-int-or-string specifies that this value is either an integer or a string. If this is true, an empty type is allowed and type as child of anyOf is permitted if following one of the following patterns:
             *
             * 1) anyOf:
             *    - type: integer
             *    - type: string
             * 2) allOf:
             *    - anyOf:
             *      - type: integer
             *      - type: string
             *    - ... zero or more
             */
            x_kubernetes_int_or_string?: pulumi.Input<boolean>;
            /**
             * x-kubernetes-list-map-keys annotates an array with the x-kubernetes-list-type `map` by specifying the keys used as the index of the map.
             *
             * This tag MUST only be used on lists that have the "x-kubernetes-list-type" extension set to "map". Also, the values specified for this attribute must be a scalar typed field of the child structure (no nesting is supported).
             *
             * The properties specified must either be required or have a default value, to ensure those properties are present for all list items.
             */
            x_kubernetes_list_map_keys?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * x-kubernetes-list-type annotates an array to further describe its topology. This extension must only be used on lists and may have 3 possible values:
             *
             * 1) `atomic`: the list is treated as a single entity, like a scalar.
             *      Atomic lists will be entirely replaced when updated. This extension
             *      may be used on any type of list (struct, scalar, ...).
             * 2) `set`:
             *      Sets are lists that must not have multiple items with the same value. Each
             *      value must be a scalar, an object with x-kubernetes-map-type `atomic` or an
             *      array with x-kubernetes-list-type `atomic`.
             * 3) `map`:
             *      These lists are like maps in that their elements have a non-index key
             *      used to identify them. Order is preserved upon merge. The map tag
             *      must only be used on a list with elements of type object.
             * Defaults to atomic for arrays.
             */
            x_kubernetes_list_type?: pulumi.Input<string>;
            /**
             * x-kubernetes-map-type annotates an object to further describe its topology. This extension must only be used when type is object and may have 2 possible values:
             *
             * 1) `granular`:
             *      These maps are actual maps (key-value pairs) and each fields are independent
             *      from each other (they can each be manipulated by separate actors). This is
             *      the default behaviour for all maps.
             * 2) `atomic`: the list is treated as a single entity, like a scalar.
             *      Atomic maps will be entirely replaced when updated.
             */
            x_kubernetes_map_type?: pulumi.Input<string>;
            /**
             * x-kubernetes-preserve-unknown-fields stops the API server decoding step from pruning fields which are not specified in the validation schema. This affects fields recursively, but switches back to normal pruning behaviour if nested properties or additionalProperties are specified in the schema. This can either be true or undefined. False is forbidden.
             */
            x_kubernetes_preserve_unknown_fields?: pulumi.Input<boolean>;
            /**
             * x-kubernetes-validations describes a list of validation rules written in the CEL expression language.
             */
            x_kubernetes_validations?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.ValidationRule>[]>;
        }
        /**
         * JSONSchemaProps is a JSON-Schema following Specification Draft 4 (http://json-schema.org/).
         */
        interface JSONSchemaPropsPatch {
            $ref?: pulumi.Input<string>;
            $schema?: pulumi.Input<string>;
            additionalItems?: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps | boolean>;
            additionalProperties?: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps | boolean>;
            allOf?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.JSONSchemaPropsPatch>[]>;
            anyOf?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.JSONSchemaPropsPatch>[]>;
            /**
             * default is a default value for undefined object fields. Defaulting is a beta feature under the CustomResourceDefaulting feature gate. Defaulting requires spec.preserveUnknownFields to be false.
             */
            default?: any;
            definitions?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps>;
            }>;
            dependencies?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps | pulumi.Input<string>[]>;
            }>;
            description?: pulumi.Input<string>;
            enum?: pulumi.Input<any[]>;
            example?: any;
            exclusiveMaximum?: pulumi.Input<boolean>;
            exclusiveMinimum?: pulumi.Input<boolean>;
            externalDocs?: pulumi.Input<inputs.apiextensions.v1.ExternalDocumentationPatch>;
            /**
             * format is an OpenAPI v3 format string. Unknown formats are ignored. The following formats are validated:
             *
             * - bsonobjectid: a bson object ID, i.e. a 24 characters hex string - uri: an URI as parsed by Golang net/url.ParseRequestURI - email: an email address as parsed by Golang net/mail.ParseAddress - hostname: a valid representation for an Internet host name, as defined by RFC 1034, section 3.1 [RFC1034]. - ipv4: an IPv4 IP as parsed by Golang net.ParseIP - ipv6: an IPv6 IP as parsed by Golang net.ParseIP - cidr: a CIDR as parsed by Golang net.ParseCIDR - mac: a MAC address as parsed by Golang net.ParseMAC - uuid: an UUID that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid3: an UUID3 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?3[0-9a-f]{3}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid4: an UUID4 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?4[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - uuid5: an UUID5 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?5[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - isbn: an ISBN10 or ISBN13 number string like "0321751043" or "978-0321751041" - isbn10: an ISBN10 number string like "0321751043" - isbn13: an ISBN13 number string like "978-0321751041" - creditcard: a credit card number defined by the regex ^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|6(?:011|5[0-9][0-9])[0-9]{12}|3[47][0-9]{13}|3(?:0[0-5]|[68][0-9])[0-9]{11}|(?:2131|1800|35\\d{3})\\d{11})$ with any non digit characters mixed in - ssn: a U.S. social security number following the regex ^\\d{3}[- ]?\\d{2}[- ]?\\d{4}$ - hexcolor: an hexadecimal color code like "#FFFFFF: following the regex ^#?([0-9a-fA-F]{3}|[0-9a-fA-F]{6})$ - rgbcolor: an RGB color code like rgb like "rgb(255,255,2559" - byte: base64 encoded binary data - password: any kind of string - date: a date string like "2006-01-02" as defined by full-date in RFC3339 - duration: a duration string like "22 ns" as parsed by Golang time.ParseDuration or compatible with Scala duration format - datetime: a date time string like "2014-12-15T19:30:20.000Z" as defined by date-time in RFC3339.
             */
            format?: pulumi.Input<string>;
            id?: pulumi.Input<string>;
            items?: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps | any[]>;
            maxItems?: pulumi.Input<number>;
            maxLength?: pulumi.Input<number>;
            maxProperties?: pulumi.Input<number>;
            maximum?: pulumi.Input<number>;
            minItems?: pulumi.Input<number>;
            minLength?: pulumi.Input<number>;
            minProperties?: pulumi.Input<number>;
            minimum?: pulumi.Input<number>;
            multipleOf?: pulumi.Input<number>;
            not?: pulumi.Input<inputs.apiextensions.v1.JSONSchemaPropsPatch>;
            nullable?: pulumi.Input<boolean>;
            oneOf?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.JSONSchemaPropsPatch>[]>;
            pattern?: pulumi.Input<string>;
            patternProperties?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps>;
            }>;
            properties?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1.JSONSchemaProps>;
            }>;
            required?: pulumi.Input<pulumi.Input<string>[]>;
            title?: pulumi.Input<string>;
            type?: pulumi.Input<string>;
            uniqueItems?: pulumi.Input<boolean>;
            /**
             * x-kubernetes-embedded-resource defines that the value is an embedded Kubernetes runtime.Object, with TypeMeta and ObjectMeta. The type must be object. It is allowed to further restrict the embedded object. kind, apiVersion and metadata are validated automatically. x-kubernetes-preserve-unknown-fields is allowed to be true, but does not have to be if the object is fully specified (up to kind, apiVersion, metadata).
             */
            x_kubernetes_embedded_resource?: pulumi.Input<boolean>;
            /**
             * x-kubernetes-int-or-string specifies that this value is either an integer or a string. If this is true, an empty type is allowed and type as child of anyOf is permitted if following one of the following patterns:
             *
             * 1) anyOf:
             *    - type: integer
             *    - type: string
             * 2) allOf:
             *    - anyOf:
             *      - type: integer
             *      - type: string
             *    - ... zero or more
             */
            x_kubernetes_int_or_string?: pulumi.Input<boolean>;
            /**
             * x-kubernetes-list-map-keys annotates an array with the x-kubernetes-list-type `map` by specifying the keys used as the index of the map.
             *
             * This tag MUST only be used on lists that have the "x-kubernetes-list-type" extension set to "map". Also, the values specified for this attribute must be a scalar typed field of the child structure (no nesting is supported).
             *
             * The properties specified must either be required or have a default value, to ensure those properties are present for all list items.
             */
            x_kubernetes_list_map_keys?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * x-kubernetes-list-type annotates an array to further describe its topology. This extension must only be used on lists and may have 3 possible values:
             *
             * 1) `atomic`: the list is treated as a single entity, like a scalar.
             *      Atomic lists will be entirely replaced when updated. This extension
             *      may be used on any type of list (struct, scalar, ...).
             * 2) `set`:
             *      Sets are lists that must not have multiple items with the same value. Each
             *      value must be a scalar, an object with x-kubernetes-map-type `atomic` or an
             *      array with x-kubernetes-list-type `atomic`.
             * 3) `map`:
             *      These lists are like maps in that their elements have a non-index key
             *      used to identify them. Order is preserved upon merge. The map tag
             *      must only be used on a list with elements of type object.
             * Defaults to atomic for arrays.
             */
            x_kubernetes_list_type?: pulumi.Input<string>;
            /**
             * x-kubernetes-map-type annotates an object to further describe its topology. This extension must only be used when type is object and may have 2 possible values:
             *
             * 1) `granular`:
             *      These maps are actual maps (key-value pairs) and each fields are independent
             *      from each other (they can each be manipulated by separate actors). This is
             *      the default behaviour for all maps.
             * 2) `atomic`: the list is treated as a single entity, like a scalar.
             *      Atomic maps will be entirely replaced when updated.
             */
            x_kubernetes_map_type?: pulumi.Input<string>;
            /**
             * x-kubernetes-preserve-unknown-fields stops the API server decoding step from pruning fields which are not specified in the validation schema. This affects fields recursively, but switches back to normal pruning behaviour if nested properties or additionalProperties are specified in the schema. This can either be true or undefined. False is forbidden.
             */
            x_kubernetes_preserve_unknown_fields?: pulumi.Input<boolean>;
            /**
             * x-kubernetes-validations describes a list of validation rules written in the CEL expression language.
             */
            x_kubernetes_validations?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1.ValidationRulePatch>[]>;
        }
        /**
         * SelectableField specifies the JSON path of a field that may be used with field selectors.
         */
        interface SelectableField {
            /**
             * jsonPath is a simple JSON path which is evaluated against each custom resource to produce a field selector value. Only JSON paths without the array notation are allowed. Must point to a field of type string, boolean or integer. Types with enum values and strings with formats are allowed. If jsonPath refers to absent field in a resource, the jsonPath evaluates to an empty string. Must not point to metdata fields. Required.
             */
            jsonPath: pulumi.Input<string>;
        }
        /**
         * SelectableField specifies the JSON path of a field that may be used with field selectors.
         */
        interface SelectableFieldPatch {
            /**
             * jsonPath is a simple JSON path which is evaluated against each custom resource to produce a field selector value. Only JSON paths without the array notation are allowed. Must point to a field of type string, boolean or integer. Types with enum values and strings with formats are allowed. If jsonPath refers to absent field in a resource, the jsonPath evaluates to an empty string. Must not point to metdata fields. Required.
             */
            jsonPath?: pulumi.Input<string>;
        }
        /**
         * ServiceReference holds a reference to Service.legacy.k8s.io
         */
        interface ServiceReference {
            /**
             * name is the name of the service. Required
             */
            name: pulumi.Input<string>;
            /**
             * namespace is the namespace of the service. Required
             */
            namespace: pulumi.Input<string>;
            /**
             * path is an optional URL path at which the webhook will be contacted.
             */
            path?: pulumi.Input<string>;
            /**
             * port is an optional service port at which the webhook will be contacted. `port` should be a valid port number (1-65535, inclusive). Defaults to 443 for backward compatibility.
             */
            port?: pulumi.Input<number>;
        }
        /**
         * ServiceReference holds a reference to Service.legacy.k8s.io
         */
        interface ServiceReferencePatch {
            /**
             * name is the name of the service. Required
             */
            name?: pulumi.Input<string>;
            /**
             * namespace is the namespace of the service. Required
             */
            namespace?: pulumi.Input<string>;
            /**
             * path is an optional URL path at which the webhook will be contacted.
             */
            path?: pulumi.Input<string>;
            /**
             * port is an optional service port at which the webhook will be contacted. `port` should be a valid port number (1-65535, inclusive). Defaults to 443 for backward compatibility.
             */
            port?: pulumi.Input<number>;
        }
        /**
         * ValidationRule describes a validation rule written in the CEL expression language.
         */
        interface ValidationRule {
            /**
             * fieldPath represents the field path returned when the validation fails. It must be a relative JSON path (i.e. with array notation) scoped to the location of this x-kubernetes-validations extension in the schema and refer to an existing field. e.g. when validation checks if a specific attribute `foo` under a map `testMap`, the fieldPath could be set to `.testMap.foo` If the validation checks two lists must have unique attributes, the fieldPath could be set to either of the list: e.g. `.testList` It does not support list numeric index. It supports child operation to refer to an existing field currently. Refer to [JSONPath support in Kubernetes](https://kubernetes.io/docs/reference/kubectl/jsonpath/) for more info. Numeric index of array is not supported. For field name which contains special characters, use `['specialName']` to refer the field name. e.g. for attribute `foo.34$` appears in a list `testList`, the fieldPath could be set to `.testList['foo.34$']`
             */
            fieldPath?: pulumi.Input<string>;
            /**
             * Message represents the message displayed when validation fails. The message is required if the Rule contains line breaks. The message must not contain line breaks. If unset, the message is "failed rule: {Rule}". e.g. "must be a URL with the host matching spec.host"
             */
            message?: pulumi.Input<string>;
            /**
             * MessageExpression declares a CEL expression that evaluates to the validation failure message that is returned when this rule fails. Since messageExpression is used as a failure message, it must evaluate to a string. If both message and messageExpression are present on a rule, then messageExpression will be used if validation fails. If messageExpression results in a runtime error, the runtime error is logged, and the validation failure message is produced as if the messageExpression field were unset. If messageExpression evaluates to an empty string, a string with only spaces, or a string that contains line breaks, then the validation failure message will also be produced as if the messageExpression field were unset, and the fact that messageExpression produced an empty string/string with only spaces/string with line breaks will be logged. messageExpression has access to all the same variables as the rule; the only difference is the return type. Example: "x must be less than max ("+string(self.max)+")"
             */
            messageExpression?: pulumi.Input<string>;
            /**
             * optionalOldSelf is used to opt a transition rule into evaluation even when the object is first created, or if the old object is missing the value.
             *
             * When enabled `oldSelf` will be a CEL optional whose value will be `None` if there is no old value, or when the object is initially created.
             *
             * You may check for presence of oldSelf using `oldSelf.hasValue()` and unwrap it after checking using `oldSelf.value()`. Check the CEL documentation for Optional types for more information: https://pkg.go.dev/github.com/google/cel-go/cel#OptionalTypes
             *
             * May not be set unless `oldSelf` is used in `rule`.
             */
            optionalOldSelf?: pulumi.Input<boolean>;
            /**
             * reason provides a machine-readable validation failure reason that is returned to the caller when a request fails this validation rule. The HTTP status code returned to the caller will match the reason of the reason of the first failed validation rule. The currently supported reasons are: "FieldValueInvalid", "FieldValueForbidden", "FieldValueRequired", "FieldValueDuplicate". If not set, default to use "FieldValueInvalid". All future added reasons must be accepted by clients when reading this value and unknown reasons should be treated as FieldValueInvalid.
             */
            reason?: pulumi.Input<string>;
            /**
             * Rule represents the expression which will be evaluated by CEL. ref: https://github.com/google/cel-spec The Rule is scoped to the location of the x-kubernetes-validations extension in the schema. The `self` variable in the CEL expression is bound to the scoped value. Example: - Rule scoped to the root of a resource with a status subresource: {"rule": "self.status.actual <= self.spec.maxDesired"}
             *
             * If the Rule is scoped to an object with properties, the accessible properties of the object are field selectable via `self.field` and field presence can be checked via `has(self.field)`. Null valued fields are treated as absent fields in CEL expressions. If the Rule is scoped to an object with additionalProperties (i.e. a map) the value of the map are accessible via `self[mapKey]`, map containment can be checked via `mapKey in self` and all entries of the map are accessible via CEL macros and functions such as `self.all(...)`. If the Rule is scoped to an array, the elements of the array are accessible via `self[i]` and also by macros and functions. If the Rule is scoped to a scalar, `self` is bound to the scalar value. Examples: - Rule scoped to a map of objects: {"rule": "self.components['Widget'].priority < 10"} - Rule scoped to a list of integers: {"rule": "self.values.all(value, value >= 0 && value < 100)"} - Rule scoped to a string value: {"rule": "self.startsWith('kube')"}
             *
             * The `apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object and from any x-kubernetes-embedded-resource annotated objects. No other metadata properties are accessible.
             *
             * Unknown data preserved in custom resources via x-kubernetes-preserve-unknown-fields is not accessible in CEL expressions. This includes: - Unknown field values that are preserved by object schemas with x-kubernetes-preserve-unknown-fields. - Object properties where the property schema is of an "unknown type". An "unknown type" is recursively defined as:
             *   - A schema with no type and x-kubernetes-preserve-unknown-fields set to true
             *   - An array where the items schema is of an "unknown type"
             *   - An object where the additionalProperties schema is of an "unknown type"
             *
             * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Accessible property names are escaped according to the following rules when accessed in the expression: - '__' escapes to '__underscores__' - '.' escapes to '__dot__' - '-' escapes to '__dash__' - '/' escapes to '__slash__' - Property names that exactly match a CEL RESERVED keyword escape to '__{keyword}__'. The keywords are:
             * 	  "true", "false", "null", "in", "as", "break", "const", "continue", "else", "for", "function", "if",
             * 	  "import", "let", "loop", "package", "namespace", "return".
             * Examples:
             *   - Rule accessing a property named "namespace": {"rule": "self.__namespace__ > 0"}
             *   - Rule accessing a property named "x-prop": {"rule": "self.x__dash__prop > 0"}
             *   - Rule accessing a property named "redact__d": {"rule": "self.redact__underscores__d > 0"}
             *
             * Equality on arrays with x-kubernetes-list-type of 'set' or 'map' ignores element order, i.e. [1, 2] == [2, 1]. Concatenation on arrays with x-kubernetes-list-type use the semantics of the list type:
             *   - 'set': `X + Y` performs a union where the array positions of all elements in `X` are preserved and
             *     non-intersecting elements in `Y` are appended, retaining their partial order.
             *   - 'map': `X + Y` performs a merge where the array positions of all keys in `X` are preserved but the values
             *     are overwritten by values in `Y` when the key sets of `X` and `Y` intersect. Elements in `Y` with
             *     non-intersecting keys are appended, retaining their partial order.
             *
             * If `rule` makes use of the `oldSelf` variable it is implicitly a `transition rule`.
             *
             * By default, the `oldSelf` variable is the same type as `self`. When `optionalOldSelf` is true, the `oldSelf` variable is a CEL optional
             *  variable whose value() is the same type as `self`.
             * See the documentation for the `optionalOldSelf` field for details.
             *
             * Transition rules by default are applied only on UPDATE requests and are skipped if an old value could not be found. You can opt a transition rule into unconditional evaluation by setting `optionalOldSelf` to true.
             */
            rule: pulumi.Input<string>;
        }
        /**
         * ValidationRule describes a validation rule written in the CEL expression language.
         */
        interface ValidationRulePatch {
            /**
             * fieldPath represents the field path returned when the validation fails. It must be a relative JSON path (i.e. with array notation) scoped to the location of this x-kubernetes-validations extension in the schema and refer to an existing field. e.g. when validation checks if a specific attribute `foo` under a map `testMap`, the fieldPath could be set to `.testMap.foo` If the validation checks two lists must have unique attributes, the fieldPath could be set to either of the list: e.g. `.testList` It does not support list numeric index. It supports child operation to refer to an existing field currently. Refer to [JSONPath support in Kubernetes](https://kubernetes.io/docs/reference/kubectl/jsonpath/) for more info. Numeric index of array is not supported. For field name which contains special characters, use `['specialName']` to refer the field name. e.g. for attribute `foo.34$` appears in a list `testList`, the fieldPath could be set to `.testList['foo.34$']`
             */
            fieldPath?: pulumi.Input<string>;
            /**
             * Message represents the message displayed when validation fails. The message is required if the Rule contains line breaks. The message must not contain line breaks. If unset, the message is "failed rule: {Rule}". e.g. "must be a URL with the host matching spec.host"
             */
            message?: pulumi.Input<string>;
            /**
             * MessageExpression declares a CEL expression that evaluates to the validation failure message that is returned when this rule fails. Since messageExpression is used as a failure message, it must evaluate to a string. If both message and messageExpression are present on a rule, then messageExpression will be used if validation fails. If messageExpression results in a runtime error, the runtime error is logged, and the validation failure message is produced as if the messageExpression field were unset. If messageExpression evaluates to an empty string, a string with only spaces, or a string that contains line breaks, then the validation failure message will also be produced as if the messageExpression field were unset, and the fact that messageExpression produced an empty string/string with only spaces/string with line breaks will be logged. messageExpression has access to all the same variables as the rule; the only difference is the return type. Example: "x must be less than max ("+string(self.max)+")"
             */
            messageExpression?: pulumi.Input<string>;
            /**
             * optionalOldSelf is used to opt a transition rule into evaluation even when the object is first created, or if the old object is missing the value.
             *
             * When enabled `oldSelf` will be a CEL optional whose value will be `None` if there is no old value, or when the object is initially created.
             *
             * You may check for presence of oldSelf using `oldSelf.hasValue()` and unwrap it after checking using `oldSelf.value()`. Check the CEL documentation for Optional types for more information: https://pkg.go.dev/github.com/google/cel-go/cel#OptionalTypes
             *
             * May not be set unless `oldSelf` is used in `rule`.
             */
            optionalOldSelf?: pulumi.Input<boolean>;
            /**
             * reason provides a machine-readable validation failure reason that is returned to the caller when a request fails this validation rule. The HTTP status code returned to the caller will match the reason of the reason of the first failed validation rule. The currently supported reasons are: "FieldValueInvalid", "FieldValueForbidden", "FieldValueRequired", "FieldValueDuplicate". If not set, default to use "FieldValueInvalid". All future added reasons must be accepted by clients when reading this value and unknown reasons should be treated as FieldValueInvalid.
             */
            reason?: pulumi.Input<string>;
            /**
             * Rule represents the expression which will be evaluated by CEL. ref: https://github.com/google/cel-spec The Rule is scoped to the location of the x-kubernetes-validations extension in the schema. The `self` variable in the CEL expression is bound to the scoped value. Example: - Rule scoped to the root of a resource with a status subresource: {"rule": "self.status.actual <= self.spec.maxDesired"}
             *
             * If the Rule is scoped to an object with properties, the accessible properties of the object are field selectable via `self.field` and field presence can be checked via `has(self.field)`. Null valued fields are treated as absent fields in CEL expressions. If the Rule is scoped to an object with additionalProperties (i.e. a map) the value of the map are accessible via `self[mapKey]`, map containment can be checked via `mapKey in self` and all entries of the map are accessible via CEL macros and functions such as `self.all(...)`. If the Rule is scoped to an array, the elements of the array are accessible via `self[i]` and also by macros and functions. If the Rule is scoped to a scalar, `self` is bound to the scalar value. Examples: - Rule scoped to a map of objects: {"rule": "self.components['Widget'].priority < 10"} - Rule scoped to a list of integers: {"rule": "self.values.all(value, value >= 0 && value < 100)"} - Rule scoped to a string value: {"rule": "self.startsWith('kube')"}
             *
             * The `apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object and from any x-kubernetes-embedded-resource annotated objects. No other metadata properties are accessible.
             *
             * Unknown data preserved in custom resources via x-kubernetes-preserve-unknown-fields is not accessible in CEL expressions. This includes: - Unknown field values that are preserved by object schemas with x-kubernetes-preserve-unknown-fields. - Object properties where the property schema is of an "unknown type". An "unknown type" is recursively defined as:
             *   - A schema with no type and x-kubernetes-preserve-unknown-fields set to true
             *   - An array where the items schema is of an "unknown type"
             *   - An object where the additionalProperties schema is of an "unknown type"
             *
             * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Accessible property names are escaped according to the following rules when accessed in the expression: - '__' escapes to '__underscores__' - '.' escapes to '__dot__' - '-' escapes to '__dash__' - '/' escapes to '__slash__' - Property names that exactly match a CEL RESERVED keyword escape to '__{keyword}__'. The keywords are:
             * 	  "true", "false", "null", "in", "as", "break", "const", "continue", "else", "for", "function", "if",
             * 	  "import", "let", "loop", "package", "namespace", "return".
             * Examples:
             *   - Rule accessing a property named "namespace": {"rule": "self.__namespace__ > 0"}
             *   - Rule accessing a property named "x-prop": {"rule": "self.x__dash__prop > 0"}
             *   - Rule accessing a property named "redact__d": {"rule": "self.redact__underscores__d > 0"}
             *
             * Equality on arrays with x-kubernetes-list-type of 'set' or 'map' ignores element order, i.e. [1, 2] == [2, 1]. Concatenation on arrays with x-kubernetes-list-type use the semantics of the list type:
             *   - 'set': `X + Y` performs a union where the array positions of all elements in `X` are preserved and
             *     non-intersecting elements in `Y` are appended, retaining their partial order.
             *   - 'map': `X + Y` performs a merge where the array positions of all keys in `X` are preserved but the values
             *     are overwritten by values in `Y` when the key sets of `X` and `Y` intersect. Elements in `Y` with
             *     non-intersecting keys are appended, retaining their partial order.
             *
             * If `rule` makes use of the `oldSelf` variable it is implicitly a `transition rule`.
             *
             * By default, the `oldSelf` variable is the same type as `self`. When `optionalOldSelf` is true, the `oldSelf` variable is a CEL optional
             *  variable whose value() is the same type as `self`.
             * See the documentation for the `optionalOldSelf` field for details.
             *
             * Transition rules by default are applied only on UPDATE requests and are skipped if an old value could not be found. You can opt a transition rule into unconditional evaluation by setting `optionalOldSelf` to true.
             */
            rule?: pulumi.Input<string>;
        }
        /**
         * WebhookClientConfig contains the information to make a TLS connection with the webhook.
         */
        interface WebhookClientConfig {
            /**
             * caBundle is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used.
             */
            caBundle?: pulumi.Input<string>;
            /**
             * service is a reference to the service for this webhook. Either service or url must be specified.
             *
             * If the webhook is running within the cluster, then you should use `service`.
             */
            service?: pulumi.Input<inputs.apiextensions.v1.ServiceReference>;
            /**
             * url gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
             *
             * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
             *
             * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
             *
             * The scheme must be "https"; the URL must begin with "https://".
             *
             * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
             *
             * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
             */
            url?: pulumi.Input<string>;
        }
        /**
         * WebhookClientConfig contains the information to make a TLS connection with the webhook.
         */
        interface WebhookClientConfigPatch {
            /**
             * caBundle is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used.
             */
            caBundle?: pulumi.Input<string>;
            /**
             * service is a reference to the service for this webhook. Either service or url must be specified.
             *
             * If the webhook is running within the cluster, then you should use `service`.
             */
            service?: pulumi.Input<inputs.apiextensions.v1.ServiceReferencePatch>;
            /**
             * url gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
             *
             * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
             *
             * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
             *
             * The scheme must be "https"; the URL must begin with "https://".
             *
             * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
             *
             * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
             */
            url?: pulumi.Input<string>;
        }
        /**
         * WebhookConversion describes how to call a conversion webhook
         */
        interface WebhookConversion {
            /**
             * clientConfig is the instructions for how to call the webhook if strategy is `Webhook`.
             */
            clientConfig?: pulumi.Input<inputs.apiextensions.v1.WebhookClientConfig>;
            /**
             * conversionReviewVersions is an ordered list of preferred `ConversionReview` versions the Webhook expects. The API server will use the first version in the list which it supports. If none of the versions specified in this list are supported by API server, conversion will fail for the custom resource. If a persisted Webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail.
             */
            conversionReviewVersions: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * WebhookConversion describes how to call a conversion webhook
         */
        interface WebhookConversionPatch {
            /**
             * clientConfig is the instructions for how to call the webhook if strategy is `Webhook`.
             */
            clientConfig?: pulumi.Input<inputs.apiextensions.v1.WebhookClientConfigPatch>;
            /**
             * conversionReviewVersions is an ordered list of preferred `ConversionReview` versions the Webhook expects. The API server will use the first version in the list which it supports. If none of the versions specified in this list are supported by API server, conversion will fail for the custom resource. If a persisted Webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail.
             */
            conversionReviewVersions?: pulumi.Input<pulumi.Input<string>[]>;
        }
    }
    namespace v1beta1 {
        /**
         * CustomResourceColumnDefinition specifies a column for server side printing.
         */
        interface CustomResourceColumnDefinition {
            /**
             * JSONPath is a simple JSON path (i.e. with array notation) which is evaluated against each custom resource to produce the value for this column.
             */
            JSONPath: pulumi.Input<string>;
            /**
             * description is a human readable description of this column.
             */
            description?: pulumi.Input<string>;
            /**
             * format is an optional OpenAPI type definition for this column. The 'name' format is applied to the primary identifier column to assist in clients identifying column is the resource name. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details.
             */
            format?: pulumi.Input<string>;
            /**
             * name is a human readable name for the column.
             */
            name: pulumi.Input<string>;
            /**
             * priority is an integer defining the relative importance of this column compared to others. Lower numbers are considered higher priority. Columns that may be omitted in limited space scenarios should be given a priority greater than 0.
             */
            priority?: pulumi.Input<number>;
            /**
             * type is an OpenAPI type definition for this column. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details.
             */
            type: pulumi.Input<string>;
        }
        /**
         * CustomResourceColumnDefinition specifies a column for server side printing.
         */
        interface CustomResourceColumnDefinitionPatch {
            /**
             * JSONPath is a simple JSON path (i.e. with array notation) which is evaluated against each custom resource to produce the value for this column.
             */
            JSONPath?: pulumi.Input<string>;
            /**
             * description is a human readable description of this column.
             */
            description?: pulumi.Input<string>;
            /**
             * format is an optional OpenAPI type definition for this column. The 'name' format is applied to the primary identifier column to assist in clients identifying column is the resource name. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details.
             */
            format?: pulumi.Input<string>;
            /**
             * name is a human readable name for the column.
             */
            name?: pulumi.Input<string>;
            /**
             * priority is an integer defining the relative importance of this column compared to others. Lower numbers are considered higher priority. Columns that may be omitted in limited space scenarios should be given a priority greater than 0.
             */
            priority?: pulumi.Input<number>;
            /**
             * type is an OpenAPI type definition for this column. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * CustomResourceConversion describes how to convert different versions of a CR.
         */
        interface CustomResourceConversion {
            /**
             * conversionReviewVersions is an ordered list of preferred `ConversionReview` versions the Webhook expects. The API server will use the first version in the list which it supports. If none of the versions specified in this list are supported by API server, conversion will fail for the custom resource. If a persisted Webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail. Defaults to `["v1beta1"]`.
             */
            conversionReviewVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * strategy specifies how custom resources are converted between versions. Allowed values are: - `None`: The converter only change the apiVersion and would not touch any other field in the custom resource. - `Webhook`: API Server will call to an external webhook to do the conversion. Additional information
             *   is needed for this option. This requires spec.preserveUnknownFields to be false, and spec.conversion.webhookClientConfig to be set.
             */
            strategy: pulumi.Input<string>;
            /**
             * webhookClientConfig is the instructions for how to call the webhook if strategy is `Webhook`. Required when `strategy` is set to `Webhook`.
             */
            webhookClientConfig?: pulumi.Input<inputs.apiextensions.v1beta1.WebhookClientConfig>;
        }
        /**
         * CustomResourceConversion describes how to convert different versions of a CR.
         */
        interface CustomResourceConversionPatch {
            /**
             * conversionReviewVersions is an ordered list of preferred `ConversionReview` versions the Webhook expects. The API server will use the first version in the list which it supports. If none of the versions specified in this list are supported by API server, conversion will fail for the custom resource. If a persisted Webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail. Defaults to `["v1beta1"]`.
             */
            conversionReviewVersions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * strategy specifies how custom resources are converted between versions. Allowed values are: - `None`: The converter only change the apiVersion and would not touch any other field in the custom resource. - `Webhook`: API Server will call to an external webhook to do the conversion. Additional information
             *   is needed for this option. This requires spec.preserveUnknownFields to be false, and spec.conversion.webhookClientConfig to be set.
             */
            strategy?: pulumi.Input<string>;
            /**
             * webhookClientConfig is the instructions for how to call the webhook if strategy is `Webhook`. Required when `strategy` is set to `Webhook`.
             */
            webhookClientConfig?: pulumi.Input<inputs.apiextensions.v1beta1.WebhookClientConfigPatch>;
        }
        /**
         * CustomResourceDefinition represents a resource that should be exposed on the API server.  Its name MUST be in the format <.spec.name>.<.spec.group>. Deprecated in v1.16, planned for removal in v1.19. Use apiextensions.k8s.io/v1 CustomResourceDefinition instead.
         */
        interface CustomResourceDefinition {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apiextensions.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"CustomResourceDefinition">;
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec describes how the user wants the resources to appear
             */
            spec: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceDefinitionSpec>;
            /**
             * status indicates the actual state of the CustomResourceDefinition
             */
            status?: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceDefinitionStatus>;
        }
        /**
         * CustomResourceDefinitionCondition contains details for the current condition of this pod.
         */
        interface CustomResourceDefinitionCondition {
            /**
             * lastTransitionTime last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * message is a human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * reason is a unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * status is the status of the condition. Can be True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * type is the type of the condition. Types include Established, NamesAccepted and Terminating.
             */
            type: pulumi.Input<string>;
        }
        /**
         * CustomResourceDefinitionNames indicates the names to serve this CustomResourceDefinition
         */
        interface CustomResourceDefinitionNames {
            /**
             * categories is a list of grouped resources this custom resource belongs to (e.g. 'all'). This is published in API discovery documents, and used by clients to support invocations like `kubectl get all`.
             */
            categories?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * kind is the serialized kind of the resource. It is normally CamelCase and singular. Custom resource instances will use this value as the `kind` attribute in API calls.
             */
            kind: pulumi.Input<string>;
            /**
             * listKind is the serialized kind of the list for this resource. Defaults to "`kind`List".
             */
            listKind?: pulumi.Input<string>;
            /**
             * plural is the plural name of the resource to serve. The custom resources are served under `/apis/<group>/<version>/.../<plural>`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`). Must be all lowercase.
             */
            plural: pulumi.Input<string>;
            /**
             * shortNames are short names for the resource, exposed in API discovery documents, and used by clients to support invocations like `kubectl get <shortname>`. It must be all lowercase.
             */
            shortNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * singular is the singular name of the resource. It must be all lowercase. Defaults to lowercased `kind`.
             */
            singular?: pulumi.Input<string>;
        }
        /**
         * CustomResourceDefinitionNames indicates the names to serve this CustomResourceDefinition
         */
        interface CustomResourceDefinitionNamesPatch {
            /**
             * categories is a list of grouped resources this custom resource belongs to (e.g. 'all'). This is published in API discovery documents, and used by clients to support invocations like `kubectl get all`.
             */
            categories?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * kind is the serialized kind of the resource. It is normally CamelCase and singular. Custom resource instances will use this value as the `kind` attribute in API calls.
             */
            kind?: pulumi.Input<string>;
            /**
             * listKind is the serialized kind of the list for this resource. Defaults to "`kind`List".
             */
            listKind?: pulumi.Input<string>;
            /**
             * plural is the plural name of the resource to serve. The custom resources are served under `/apis/<group>/<version>/.../<plural>`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`). Must be all lowercase.
             */
            plural?: pulumi.Input<string>;
            /**
             * shortNames are short names for the resource, exposed in API discovery documents, and used by clients to support invocations like `kubectl get <shortname>`. It must be all lowercase.
             */
            shortNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * singular is the singular name of the resource. It must be all lowercase. Defaults to lowercased `kind`.
             */
            singular?: pulumi.Input<string>;
        }
        /**
         * CustomResourceDefinitionSpec describes how a user wants their resource to appear
         */
        interface CustomResourceDefinitionSpec {
            /**
             * additionalPrinterColumns specifies additional columns returned in Table output. See https://kubernetes.io/docs/reference/using-api/api-concepts/#receiving-resources-as-tables for details. If present, this field configures columns for all versions. Top-level and per-version columns are mutually exclusive. If no top-level or per-version columns are specified, a single column displaying the age of the custom resource is used.
             */
            additionalPrinterColumns?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceColumnDefinition>[]>;
            /**
             * conversion defines conversion settings for the CRD.
             */
            conversion?: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceConversion>;
            /**
             * group is the API group of the defined custom resource. The custom resources are served under `/apis/<group>/...`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`).
             */
            group: pulumi.Input<string>;
            /**
             * names specify the resource and kind names for the custom resource.
             */
            names: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceDefinitionNames>;
            /**
             * preserveUnknownFields indicates that object fields which are not specified in the OpenAPI schema should be preserved when persisting to storage. apiVersion, kind, metadata and known fields inside metadata are always preserved. If false, schemas must be defined for all versions. Defaults to true in v1beta for backwards compatibility. Deprecated: will be required to be false in v1. Preservation of unknown fields can be specified in the validation schema using the `x-kubernetes-preserve-unknown-fields: true` extension. See https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions/#pruning-versus-preserving-unknown-fields for details.
             */
            preserveUnknownFields?: pulumi.Input<boolean>;
            /**
             * scope indicates whether the defined custom resource is cluster- or namespace-scoped. Allowed values are `Cluster` and `Namespaced`. Default is `Namespaced`.
             */
            scope: pulumi.Input<string>;
            /**
             * subresources specify what subresources the defined custom resource has. If present, this field configures subresources for all versions. Top-level and per-version subresources are mutually exclusive.
             */
            subresources?: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceSubresources>;
            /**
             * validation describes the schema used for validation and pruning of the custom resource. If present, this validation schema is used to validate all versions. Top-level and per-version schemas are mutually exclusive.
             */
            validation?: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceValidation>;
            /**
             * version is the API version of the defined custom resource. The custom resources are served under `/apis/<group>/<version>/...`. Must match the name of the first item in the `versions` list if `version` and `versions` are both specified. Optional if `versions` is specified. Deprecated: use `versions` instead.
             */
            version?: pulumi.Input<string>;
            /**
             * versions is the list of all API versions of the defined custom resource. Optional if `version` is specified. The name of the first item in the `versions` list must match the `version` field if `version` and `versions` are both specified. Version names are used to compute the order in which served versions are listed in API discovery. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10.
             */
            versions?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceDefinitionVersion>[]>;
        }
        /**
         * CustomResourceDefinitionSpec describes how a user wants their resource to appear
         */
        interface CustomResourceDefinitionSpecPatch {
            /**
             * additionalPrinterColumns specifies additional columns returned in Table output. See https://kubernetes.io/docs/reference/using-api/api-concepts/#receiving-resources-as-tables for details. If present, this field configures columns for all versions. Top-level and per-version columns are mutually exclusive. If no top-level or per-version columns are specified, a single column displaying the age of the custom resource is used.
             */
            additionalPrinterColumns?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceColumnDefinitionPatch>[]>;
            /**
             * conversion defines conversion settings for the CRD.
             */
            conversion?: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceConversionPatch>;
            /**
             * group is the API group of the defined custom resource. The custom resources are served under `/apis/<group>/...`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`).
             */
            group?: pulumi.Input<string>;
            /**
             * names specify the resource and kind names for the custom resource.
             */
            names?: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceDefinitionNamesPatch>;
            /**
             * preserveUnknownFields indicates that object fields which are not specified in the OpenAPI schema should be preserved when persisting to storage. apiVersion, kind, metadata and known fields inside metadata are always preserved. If false, schemas must be defined for all versions. Defaults to true in v1beta for backwards compatibility. Deprecated: will be required to be false in v1. Preservation of unknown fields can be specified in the validation schema using the `x-kubernetes-preserve-unknown-fields: true` extension. See https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions/#pruning-versus-preserving-unknown-fields for details.
             */
            preserveUnknownFields?: pulumi.Input<boolean>;
            /**
             * scope indicates whether the defined custom resource is cluster- or namespace-scoped. Allowed values are `Cluster` and `Namespaced`. Default is `Namespaced`.
             */
            scope?: pulumi.Input<string>;
            /**
             * subresources specify what subresources the defined custom resource has. If present, this field configures subresources for all versions. Top-level and per-version subresources are mutually exclusive.
             */
            subresources?: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceSubresourcesPatch>;
            /**
             * validation describes the schema used for validation and pruning of the custom resource. If present, this validation schema is used to validate all versions. Top-level and per-version schemas are mutually exclusive.
             */
            validation?: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceValidationPatch>;
            /**
             * version is the API version of the defined custom resource. The custom resources are served under `/apis/<group>/<version>/...`. Must match the name of the first item in the `versions` list if `version` and `versions` are both specified. Optional if `versions` is specified. Deprecated: use `versions` instead.
             */
            version?: pulumi.Input<string>;
            /**
             * versions is the list of all API versions of the defined custom resource. Optional if `version` is specified. The name of the first item in the `versions` list must match the `version` field if `version` and `versions` are both specified. Version names are used to compute the order in which served versions are listed in API discovery. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10.
             */
            versions?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceDefinitionVersionPatch>[]>;
        }
        /**
         * CustomResourceDefinitionStatus indicates the state of the CustomResourceDefinition
         */
        interface CustomResourceDefinitionStatus {
            /**
             * acceptedNames are the names that are actually being used to serve discovery. They may be different than the names in spec.
             */
            acceptedNames: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceDefinitionNames>;
            /**
             * conditions indicate state for particular aspects of a CustomResourceDefinition
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceDefinitionCondition>[]>;
            /**
             * storedVersions lists all versions of CustomResources that were ever persisted. Tracking these versions allows a migration path for stored versions in etcd. The field is mutable so a migration controller can finish a migration to another version (ensuring no old objects are left in storage), and then remove the rest of the versions from this list. Versions may not be removed from `spec.versions` while they exist in this list.
             */
            storedVersions: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * CustomResourceDefinitionVersion describes a version for CRD.
         */
        interface CustomResourceDefinitionVersion {
            /**
             * additionalPrinterColumns specifies additional columns returned in Table output. See https://kubernetes.io/docs/reference/using-api/api-concepts/#receiving-resources-as-tables for details. Top-level and per-version columns are mutually exclusive. Per-version columns must not all be set to identical values (top-level columns should be used instead). If no top-level or per-version columns are specified, a single column displaying the age of the custom resource is used.
             */
            additionalPrinterColumns?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceColumnDefinition>[]>;
            /**
             * deprecated indicates this version of the custom resource API is deprecated. When set to true, API requests to this version receive a warning header in the server response. Defaults to false.
             */
            deprecated?: pulumi.Input<boolean>;
            /**
             * deprecationWarning overrides the default warning returned to API clients. May only be set when `deprecated` is true. The default warning indicates this version is deprecated and recommends use of the newest served version of equal or greater stability, if one exists.
             */
            deprecationWarning?: pulumi.Input<string>;
            /**
             * name is the version name, e.g. “v1”, “v2beta1”, etc. The custom resources are served under this version at `/apis/<group>/<version>/...` if `served` is true.
             */
            name: pulumi.Input<string>;
            /**
             * schema describes the schema used for validation and pruning of this version of the custom resource. Top-level and per-version schemas are mutually exclusive. Per-version schemas must not all be set to identical values (top-level validation schema should be used instead).
             */
            schema?: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceValidation>;
            /**
             * served is a flag enabling/disabling this version from being served via REST APIs
             */
            served: pulumi.Input<boolean>;
            /**
             * storage indicates this version should be used when persisting custom resources to storage. There must be exactly one version with storage=true.
             */
            storage: pulumi.Input<boolean>;
            /**
             * subresources specify what subresources this version of the defined custom resource have. Top-level and per-version subresources are mutually exclusive. Per-version subresources must not all be set to identical values (top-level subresources should be used instead).
             */
            subresources?: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceSubresources>;
        }
        /**
         * CustomResourceDefinitionVersion describes a version for CRD.
         */
        interface CustomResourceDefinitionVersionPatch {
            /**
             * additionalPrinterColumns specifies additional columns returned in Table output. See https://kubernetes.io/docs/reference/using-api/api-concepts/#receiving-resources-as-tables for details. Top-level and per-version columns are mutually exclusive. Per-version columns must not all be set to identical values (top-level columns should be used instead). If no top-level or per-version columns are specified, a single column displaying the age of the custom resource is used.
             */
            additionalPrinterColumns?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceColumnDefinitionPatch>[]>;
            /**
             * deprecated indicates this version of the custom resource API is deprecated. When set to true, API requests to this version receive a warning header in the server response. Defaults to false.
             */
            deprecated?: pulumi.Input<boolean>;
            /**
             * deprecationWarning overrides the default warning returned to API clients. May only be set when `deprecated` is true. The default warning indicates this version is deprecated and recommends use of the newest served version of equal or greater stability, if one exists.
             */
            deprecationWarning?: pulumi.Input<string>;
            /**
             * name is the version name, e.g. “v1”, “v2beta1”, etc. The custom resources are served under this version at `/apis/<group>/<version>/...` if `served` is true.
             */
            name?: pulumi.Input<string>;
            /**
             * schema describes the schema used for validation and pruning of this version of the custom resource. Top-level and per-version schemas are mutually exclusive. Per-version schemas must not all be set to identical values (top-level validation schema should be used instead).
             */
            schema?: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceValidationPatch>;
            /**
             * served is a flag enabling/disabling this version from being served via REST APIs
             */
            served?: pulumi.Input<boolean>;
            /**
             * storage indicates this version should be used when persisting custom resources to storage. There must be exactly one version with storage=true.
             */
            storage?: pulumi.Input<boolean>;
            /**
             * subresources specify what subresources this version of the defined custom resource have. Top-level and per-version subresources are mutually exclusive. Per-version subresources must not all be set to identical values (top-level subresources should be used instead).
             */
            subresources?: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceSubresourcesPatch>;
        }
        /**
         * CustomResourceSubresourceScale defines how to serve the scale subresource for CustomResources.
         */
        interface CustomResourceSubresourceScale {
            /**
             * labelSelectorPath defines the JSON path inside of a custom resource that corresponds to Scale `status.selector`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status` or `.spec`. Must be set to work with HorizontalPodAutoscaler. The field pointed by this JSON path must be a string field (not a complex selector struct) which contains a serialized label selector in string form. More info: https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions#scale-subresource If there is no value under the given path in the custom resource, the `status.selector` value in the `/scale` subresource will default to the empty string.
             */
            labelSelectorPath?: pulumi.Input<string>;
            /**
             * specReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `spec.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.spec`. If there is no value under the given path in the custom resource, the `/scale` subresource will return an error on GET.
             */
            specReplicasPath: pulumi.Input<string>;
            /**
             * statusReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `status.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status`. If there is no value under the given path in the custom resource, the `status.replicas` value in the `/scale` subresource will default to 0.
             */
            statusReplicasPath: pulumi.Input<string>;
        }
        /**
         * CustomResourceSubresourceScale defines how to serve the scale subresource for CustomResources.
         */
        interface CustomResourceSubresourceScalePatch {
            /**
             * labelSelectorPath defines the JSON path inside of a custom resource that corresponds to Scale `status.selector`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status` or `.spec`. Must be set to work with HorizontalPodAutoscaler. The field pointed by this JSON path must be a string field (not a complex selector struct) which contains a serialized label selector in string form. More info: https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions#scale-subresource If there is no value under the given path in the custom resource, the `status.selector` value in the `/scale` subresource will default to the empty string.
             */
            labelSelectorPath?: pulumi.Input<string>;
            /**
             * specReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `spec.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.spec`. If there is no value under the given path in the custom resource, the `/scale` subresource will return an error on GET.
             */
            specReplicasPath?: pulumi.Input<string>;
            /**
             * statusReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `status.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status`. If there is no value under the given path in the custom resource, the `status.replicas` value in the `/scale` subresource will default to 0.
             */
            statusReplicasPath?: pulumi.Input<string>;
        }
        /**
         * CustomResourceSubresources defines the status and scale subresources for CustomResources.
         */
        interface CustomResourceSubresources {
            /**
             * scale indicates the custom resource should serve a `/scale` subresource that returns an `autoscaling/v1` Scale object.
             */
            scale?: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceSubresourceScale>;
            /**
             * status indicates the custom resource should serve a `/status` subresource. When enabled: 1. requests to the custom resource primary endpoint ignore changes to the `status` stanza of the object. 2. requests to the custom resource `/status` subresource ignore changes to anything other than the `status` stanza of the object.
             */
            status?: any;
        }
        /**
         * CustomResourceSubresources defines the status and scale subresources for CustomResources.
         */
        interface CustomResourceSubresourcesPatch {
            /**
             * scale indicates the custom resource should serve a `/scale` subresource that returns an `autoscaling/v1` Scale object.
             */
            scale?: pulumi.Input<inputs.apiextensions.v1beta1.CustomResourceSubresourceScalePatch>;
            /**
             * status indicates the custom resource should serve a `/status` subresource. When enabled: 1. requests to the custom resource primary endpoint ignore changes to the `status` stanza of the object. 2. requests to the custom resource `/status` subresource ignore changes to anything other than the `status` stanza of the object.
             */
            status?: any;
        }
        /**
         * CustomResourceValidation is a list of validation methods for CustomResources.
         */
        interface CustomResourceValidation {
            /**
             * openAPIV3Schema is the OpenAPI v3 schema to use for validation and pruning.
             */
            openAPIV3Schema?: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps>;
        }
        /**
         * CustomResourceValidation is a list of validation methods for CustomResources.
         */
        interface CustomResourceValidationPatch {
            /**
             * openAPIV3Schema is the OpenAPI v3 schema to use for validation and pruning.
             */
            openAPIV3Schema?: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaPropsPatch>;
        }
        /**
         * ExternalDocumentation allows referencing an external resource for extended documentation.
         */
        interface ExternalDocumentation {
            description?: pulumi.Input<string>;
            url?: pulumi.Input<string>;
        }
        /**
         * ExternalDocumentation allows referencing an external resource for extended documentation.
         */
        interface ExternalDocumentationPatch {
            description?: pulumi.Input<string>;
            url?: pulumi.Input<string>;
        }
        /**
         * JSONSchemaProps is a JSON-Schema following Specification Draft 4 (http://json-schema.org/).
         */
        interface JSONSchemaProps {
            $ref?: pulumi.Input<string>;
            $schema?: pulumi.Input<string>;
            additionalItems?: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps | boolean>;
            additionalProperties?: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps | boolean>;
            allOf?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps>[]>;
            anyOf?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps>[]>;
            /**
             * default is a default value for undefined object fields. Defaulting is a beta feature under the CustomResourceDefaulting feature gate. CustomResourceDefinitions with defaults must be created using the v1 (or newer) CustomResourceDefinition API.
             */
            default?: any;
            definitions?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps>;
            }>;
            dependencies?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps | pulumi.Input<string>[]>;
            }>;
            description?: pulumi.Input<string>;
            enum?: pulumi.Input<any[]>;
            example?: any;
            exclusiveMaximum?: pulumi.Input<boolean>;
            exclusiveMinimum?: pulumi.Input<boolean>;
            externalDocs?: pulumi.Input<inputs.apiextensions.v1beta1.ExternalDocumentation>;
            /**
             * format is an OpenAPI v3 format string. Unknown formats are ignored. The following formats are validated:
             *
             * - bsonobjectid: a bson object ID, i.e. a 24 characters hex string - uri: an URI as parsed by Golang net/url.ParseRequestURI - email: an email address as parsed by Golang net/mail.ParseAddress - hostname: a valid representation for an Internet host name, as defined by RFC 1034, section 3.1 [RFC1034]. - ipv4: an IPv4 IP as parsed by Golang net.ParseIP - ipv6: an IPv6 IP as parsed by Golang net.ParseIP - cidr: a CIDR as parsed by Golang net.ParseCIDR - mac: a MAC address as parsed by Golang net.ParseMAC - uuid: an UUID that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid3: an UUID3 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?3[0-9a-f]{3}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid4: an UUID4 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?4[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - uuid5: an UUID5 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?5[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - isbn: an ISBN10 or ISBN13 number string like "0321751043" or "978-0321751041" - isbn10: an ISBN10 number string like "0321751043" - isbn13: an ISBN13 number string like "978-0321751041" - creditcard: a credit card number defined by the regex ^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|6(?:011|5[0-9][0-9])[0-9]{12}|3[47][0-9]{13}|3(?:0[0-5]|[68][0-9])[0-9]{11}|(?:2131|1800|35\d{3})\d{11})$ with any non digit characters mixed in - ssn: a U.S. social security number following the regex ^\d{3}[- ]?\d{2}[- ]?\d{4}$ - hexcolor: an hexadecimal color code like "#FFFFFF: following the regex ^#?([0-9a-fA-F]{3}|[0-9a-fA-F]{6})$ - rgbcolor: an RGB color code like rgb like "rgb(255,255,2559" - byte: base64 encoded binary data - password: any kind of string - date: a date string like "2006-01-02" as defined by full-date in RFC3339 - duration: a duration string like "22 ns" as parsed by Golang time.ParseDuration or compatible with Scala duration format - datetime: a date time string like "2014-12-15T19:30:20.000Z" as defined by date-time in RFC3339.
             */
            format?: pulumi.Input<string>;
            id?: pulumi.Input<string>;
            items?: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps | any[]>;
            maxItems?: pulumi.Input<number>;
            maxLength?: pulumi.Input<number>;
            maxProperties?: pulumi.Input<number>;
            maximum?: pulumi.Input<number>;
            minItems?: pulumi.Input<number>;
            minLength?: pulumi.Input<number>;
            minProperties?: pulumi.Input<number>;
            minimum?: pulumi.Input<number>;
            multipleOf?: pulumi.Input<number>;
            not?: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps>;
            nullable?: pulumi.Input<boolean>;
            oneOf?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps>[]>;
            pattern?: pulumi.Input<string>;
            patternProperties?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps>;
            }>;
            properties?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps>;
            }>;
            required?: pulumi.Input<pulumi.Input<string>[]>;
            title?: pulumi.Input<string>;
            type?: pulumi.Input<string>;
            uniqueItems?: pulumi.Input<boolean>;
            /**
             * x-kubernetes-embedded-resource defines that the value is an embedded Kubernetes runtime.Object, with TypeMeta and ObjectMeta. The type must be object. It is allowed to further restrict the embedded object. kind, apiVersion and metadata are validated automatically. x-kubernetes-preserve-unknown-fields is allowed to be true, but does not have to be if the object is fully specified (up to kind, apiVersion, metadata).
             */
            x_kubernetes_embedded_resource?: pulumi.Input<boolean>;
            /**
             * x-kubernetes-int-or-string specifies that this value is either an integer or a string. If this is true, an empty type is allowed and type as child of anyOf is permitted if following one of the following patterns:
             *
             * 1) anyOf:
             *    - type: integer
             *    - type: string
             * 2) allOf:
             *    - anyOf:
             *      - type: integer
             *      - type: string
             *    - ... zero or more
             */
            x_kubernetes_int_or_string?: pulumi.Input<boolean>;
            /**
             * x-kubernetes-list-map-keys annotates an array with the x-kubernetes-list-type `map` by specifying the keys used as the index of the map.
             *
             * This tag MUST only be used on lists that have the "x-kubernetes-list-type" extension set to "map". Also, the values specified for this attribute must be a scalar typed field of the child structure (no nesting is supported).
             */
            x_kubernetes_list_map_keys?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * x-kubernetes-list-type annotates an array to further describe its topology. This extension must only be used on lists and may have 3 possible values:
             *
             * 1) `atomic`: the list is treated as a single entity, like a scalar.
             *      Atomic lists will be entirely replaced when updated. This extension
             *      may be used on any type of list (struct, scalar, ...).
             * 2) `set`:
             *      Sets are lists that must not have multiple items with the same value. Each
             *      value must be a scalar, an object with x-kubernetes-map-type `atomic` or an
             *      array with x-kubernetes-list-type `atomic`.
             * 3) `map`:
             *      These lists are like maps in that their elements have a non-index key
             *      used to identify them. Order is preserved upon merge. The map tag
             *      must only be used on a list with elements of type object.
             * Defaults to atomic for arrays.
             */
            x_kubernetes_list_type?: pulumi.Input<string>;
            /**
             * x-kubernetes-map-type annotates an object to further describe its topology. This extension must only be used when type is object and may have 2 possible values:
             *
             * 1) `granular`:
             *      These maps are actual maps (key-value pairs) and each fields are independent
             *      from each other (they can each be manipulated by separate actors). This is
             *      the default behaviour for all maps.
             * 2) `atomic`: the list is treated as a single entity, like a scalar.
             *      Atomic maps will be entirely replaced when updated.
             */
            x_kubernetes_map_type?: pulumi.Input<string>;
            /**
             * x-kubernetes-preserve-unknown-fields stops the API server decoding step from pruning fields which are not specified in the validation schema. This affects fields recursively, but switches back to normal pruning behaviour if nested properties or additionalProperties are specified in the schema. This can either be true or undefined. False is forbidden.
             */
            x_kubernetes_preserve_unknown_fields?: pulumi.Input<boolean>;
        }
        /**
         * JSONSchemaProps is a JSON-Schema following Specification Draft 4 (http://json-schema.org/).
         */
        interface JSONSchemaPropsPatch {
            $ref?: pulumi.Input<string>;
            $schema?: pulumi.Input<string>;
            additionalItems?: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps | boolean>;
            additionalProperties?: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps | boolean>;
            allOf?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaPropsPatch>[]>;
            anyOf?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaPropsPatch>[]>;
            /**
             * default is a default value for undefined object fields. Defaulting is a beta feature under the CustomResourceDefaulting feature gate. CustomResourceDefinitions with defaults must be created using the v1 (or newer) CustomResourceDefinition API.
             */
            default?: any;
            definitions?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps>;
            }>;
            dependencies?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps | pulumi.Input<string>[]>;
            }>;
            description?: pulumi.Input<string>;
            enum?: pulumi.Input<any[]>;
            example?: any;
            exclusiveMaximum?: pulumi.Input<boolean>;
            exclusiveMinimum?: pulumi.Input<boolean>;
            externalDocs?: pulumi.Input<inputs.apiextensions.v1beta1.ExternalDocumentationPatch>;
            /**
             * format is an OpenAPI v3 format string. Unknown formats are ignored. The following formats are validated:
             *
             * - bsonobjectid: a bson object ID, i.e. a 24 characters hex string - uri: an URI as parsed by Golang net/url.ParseRequestURI - email: an email address as parsed by Golang net/mail.ParseAddress - hostname: a valid representation for an Internet host name, as defined by RFC 1034, section 3.1 [RFC1034]. - ipv4: an IPv4 IP as parsed by Golang net.ParseIP - ipv6: an IPv6 IP as parsed by Golang net.ParseIP - cidr: a CIDR as parsed by Golang net.ParseCIDR - mac: a MAC address as parsed by Golang net.ParseMAC - uuid: an UUID that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid3: an UUID3 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?3[0-9a-f]{3}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid4: an UUID4 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?4[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - uuid5: an UUID5 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?5[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - isbn: an ISBN10 or ISBN13 number string like "0321751043" or "978-0321751041" - isbn10: an ISBN10 number string like "0321751043" - isbn13: an ISBN13 number string like "978-0321751041" - creditcard: a credit card number defined by the regex ^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|6(?:011|5[0-9][0-9])[0-9]{12}|3[47][0-9]{13}|3(?:0[0-5]|[68][0-9])[0-9]{11}|(?:2131|1800|35\d{3})\d{11})$ with any non digit characters mixed in - ssn: a U.S. social security number following the regex ^\d{3}[- ]?\d{2}[- ]?\d{4}$ - hexcolor: an hexadecimal color code like "#FFFFFF: following the regex ^#?([0-9a-fA-F]{3}|[0-9a-fA-F]{6})$ - rgbcolor: an RGB color code like rgb like "rgb(255,255,2559" - byte: base64 encoded binary data - password: any kind of string - date: a date string like "2006-01-02" as defined by full-date in RFC3339 - duration: a duration string like "22 ns" as parsed by Golang time.ParseDuration or compatible with Scala duration format - datetime: a date time string like "2014-12-15T19:30:20.000Z" as defined by date-time in RFC3339.
             */
            format?: pulumi.Input<string>;
            id?: pulumi.Input<string>;
            items?: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps | any[]>;
            maxItems?: pulumi.Input<number>;
            maxLength?: pulumi.Input<number>;
            maxProperties?: pulumi.Input<number>;
            maximum?: pulumi.Input<number>;
            minItems?: pulumi.Input<number>;
            minLength?: pulumi.Input<number>;
            minProperties?: pulumi.Input<number>;
            minimum?: pulumi.Input<number>;
            multipleOf?: pulumi.Input<number>;
            not?: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaPropsPatch>;
            nullable?: pulumi.Input<boolean>;
            oneOf?: pulumi.Input<pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaPropsPatch>[]>;
            pattern?: pulumi.Input<string>;
            patternProperties?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps>;
            }>;
            properties?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.apiextensions.v1beta1.JSONSchemaProps>;
            }>;
            required?: pulumi.Input<pulumi.Input<string>[]>;
            title?: pulumi.Input<string>;
            type?: pulumi.Input<string>;
            uniqueItems?: pulumi.Input<boolean>;
            /**
             * x-kubernetes-embedded-resource defines that the value is an embedded Kubernetes runtime.Object, with TypeMeta and ObjectMeta. The type must be object. It is allowed to further restrict the embedded object. kind, apiVersion and metadata are validated automatically. x-kubernetes-preserve-unknown-fields is allowed to be true, but does not have to be if the object is fully specified (up to kind, apiVersion, metadata).
             */
            x_kubernetes_embedded_resource?: pulumi.Input<boolean>;
            /**
             * x-kubernetes-int-or-string specifies that this value is either an integer or a string. If this is true, an empty type is allowed and type as child of anyOf is permitted if following one of the following patterns:
             *
             * 1) anyOf:
             *    - type: integer
             *    - type: string
             * 2) allOf:
             *    - anyOf:
             *      - type: integer
             *      - type: string
             *    - ... zero or more
             */
            x_kubernetes_int_or_string?: pulumi.Input<boolean>;
            /**
             * x-kubernetes-list-map-keys annotates an array with the x-kubernetes-list-type `map` by specifying the keys used as the index of the map.
             *
             * This tag MUST only be used on lists that have the "x-kubernetes-list-type" extension set to "map". Also, the values specified for this attribute must be a scalar typed field of the child structure (no nesting is supported).
             */
            x_kubernetes_list_map_keys?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * x-kubernetes-list-type annotates an array to further describe its topology. This extension must only be used on lists and may have 3 possible values:
             *
             * 1) `atomic`: the list is treated as a single entity, like a scalar.
             *      Atomic lists will be entirely replaced when updated. This extension
             *      may be used on any type of list (struct, scalar, ...).
             * 2) `set`:
             *      Sets are lists that must not have multiple items with the same value. Each
             *      value must be a scalar, an object with x-kubernetes-map-type `atomic` or an
             *      array with x-kubernetes-list-type `atomic`.
             * 3) `map`:
             *      These lists are like maps in that their elements have a non-index key
             *      used to identify them. Order is preserved upon merge. The map tag
             *      must only be used on a list with elements of type object.
             * Defaults to atomic for arrays.
             */
            x_kubernetes_list_type?: pulumi.Input<string>;
            /**
             * x-kubernetes-map-type annotates an object to further describe its topology. This extension must only be used when type is object and may have 2 possible values:
             *
             * 1) `granular`:
             *      These maps are actual maps (key-value pairs) and each fields are independent
             *      from each other (they can each be manipulated by separate actors). This is
             *      the default behaviour for all maps.
             * 2) `atomic`: the list is treated as a single entity, like a scalar.
             *      Atomic maps will be entirely replaced when updated.
             */
            x_kubernetes_map_type?: pulumi.Input<string>;
            /**
             * x-kubernetes-preserve-unknown-fields stops the API server decoding step from pruning fields which are not specified in the validation schema. This affects fields recursively, but switches back to normal pruning behaviour if nested properties or additionalProperties are specified in the schema. This can either be true or undefined. False is forbidden.
             */
            x_kubernetes_preserve_unknown_fields?: pulumi.Input<boolean>;
        }
        /**
         * ServiceReference holds a reference to Service.legacy.k8s.io
         */
        interface ServiceReference {
            /**
             * name is the name of the service. Required
             */
            name: pulumi.Input<string>;
            /**
             * namespace is the namespace of the service. Required
             */
            namespace: pulumi.Input<string>;
            /**
             * path is an optional URL path at which the webhook will be contacted.
             */
            path?: pulumi.Input<string>;
            /**
             * port is an optional service port at which the webhook will be contacted. `port` should be a valid port number (1-65535, inclusive). Defaults to 443 for backward compatibility.
             */
            port?: pulumi.Input<number>;
        }
        /**
         * ServiceReference holds a reference to Service.legacy.k8s.io
         */
        interface ServiceReferencePatch {
            /**
             * name is the name of the service. Required
             */
            name?: pulumi.Input<string>;
            /**
             * namespace is the namespace of the service. Required
             */
            namespace?: pulumi.Input<string>;
            /**
             * path is an optional URL path at which the webhook will be contacted.
             */
            path?: pulumi.Input<string>;
            /**
             * port is an optional service port at which the webhook will be contacted. `port` should be a valid port number (1-65535, inclusive). Defaults to 443 for backward compatibility.
             */
            port?: pulumi.Input<number>;
        }
        /**
         * WebhookClientConfig contains the information to make a TLS connection with the webhook.
         */
        interface WebhookClientConfig {
            /**
             * caBundle is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used.
             */
            caBundle?: pulumi.Input<string>;
            /**
             * service is a reference to the service for this webhook. Either service or url must be specified.
             *
             * If the webhook is running within the cluster, then you should use `service`.
             */
            service?: pulumi.Input<inputs.apiextensions.v1beta1.ServiceReference>;
            /**
             * url gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
             *
             * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
             *
             * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
             *
             * The scheme must be "https"; the URL must begin with "https://".
             *
             * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
             *
             * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
             */
            url?: pulumi.Input<string>;
        }
        /**
         * WebhookClientConfig contains the information to make a TLS connection with the webhook.
         */
        interface WebhookClientConfigPatch {
            /**
             * caBundle is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used.
             */
            caBundle?: pulumi.Input<string>;
            /**
             * service is a reference to the service for this webhook. Either service or url must be specified.
             *
             * If the webhook is running within the cluster, then you should use `service`.
             */
            service?: pulumi.Input<inputs.apiextensions.v1beta1.ServiceReferencePatch>;
            /**
             * url gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
             *
             * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
             *
             * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
             *
             * The scheme must be "https"; the URL must begin with "https://".
             *
             * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
             *
             * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
             */
            url?: pulumi.Input<string>;
        }
    }
}
export declare namespace apiregistration {
    namespace v1 {
        /**
         * APIService represents a server for a particular GroupVersion. Name must be "version.group".
         */
        interface APIService {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apiregistration.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"APIService">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec contains information for locating and communicating with a server
             */
            spec?: pulumi.Input<inputs.apiregistration.v1.APIServiceSpec>;
            /**
             * Status contains derived information about an API server
             */
            status?: pulumi.Input<inputs.apiregistration.v1.APIServiceStatus>;
        }
        /**
         * APIServiceCondition describes the state of an APIService at a particular point
         */
        interface APIServiceCondition {
            /**
             * Last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * Human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * Unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status is the status of the condition. Can be True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type is the type of the condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * APIServiceSpec contains information for locating and communicating with a server. Only https is supported, though you are able to disable certificate verification.
         */
        interface APIServiceSpec {
            /**
             * CABundle is a PEM encoded CA bundle which will be used to validate an API server's serving certificate. If unspecified, system trust roots on the apiserver are used.
             */
            caBundle?: pulumi.Input<string>;
            /**
             * Group is the API group name this server hosts
             */
            group?: pulumi.Input<string>;
            /**
             * GroupPriorityMinimum is the priority this group should have at least. Higher priority means that the group is preferred by clients over lower priority ones. Note that other versions of this group might specify even higher GroupPriorityMinimum values such that the whole group gets a higher priority. The primary sort is based on GroupPriorityMinimum, ordered highest number to lowest (20 before 10). The secondary sort is based on the alphabetical comparison of the name of the object.  (v1.bar before v1.foo) We'd recommend something like: *.k8s.io (except extensions) at 18000 and PaaSes (OpenShift, Deis) are recommended to be in the 2000s
             */
            groupPriorityMinimum: pulumi.Input<number>;
            /**
             * InsecureSkipTLSVerify disables TLS certificate verification when communicating with this server. This is strongly discouraged.  You should use the CABundle instead.
             */
            insecureSkipTLSVerify?: pulumi.Input<boolean>;
            /**
             * Service is a reference to the service for this API server.  It must communicate on port 443. If the Service is nil, that means the handling for the API groupversion is handled locally on this server. The call will simply delegate to the normal handler chain to be fulfilled.
             */
            service?: pulumi.Input<inputs.apiregistration.v1.ServiceReference>;
            /**
             * Version is the API version this server hosts.  For example, "v1"
             */
            version?: pulumi.Input<string>;
            /**
             * VersionPriority controls the ordering of this API version inside of its group.  Must be greater than zero. The primary sort is based on VersionPriority, ordered highest to lowest (20 before 10). Since it's inside of a group, the number can be small, probably in the 10s. In case of equal version priorities, the version string will be used to compute the order inside a group. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10.
             */
            versionPriority: pulumi.Input<number>;
        }
        /**
         * APIServiceSpec contains information for locating and communicating with a server. Only https is supported, though you are able to disable certificate verification.
         */
        interface APIServiceSpecPatch {
            /**
             * CABundle is a PEM encoded CA bundle which will be used to validate an API server's serving certificate. If unspecified, system trust roots on the apiserver are used.
             */
            caBundle?: pulumi.Input<string>;
            /**
             * Group is the API group name this server hosts
             */
            group?: pulumi.Input<string>;
            /**
             * GroupPriorityMinimum is the priority this group should have at least. Higher priority means that the group is preferred by clients over lower priority ones. Note that other versions of this group might specify even higher GroupPriorityMinimum values such that the whole group gets a higher priority. The primary sort is based on GroupPriorityMinimum, ordered highest number to lowest (20 before 10). The secondary sort is based on the alphabetical comparison of the name of the object.  (v1.bar before v1.foo) We'd recommend something like: *.k8s.io (except extensions) at 18000 and PaaSes (OpenShift, Deis) are recommended to be in the 2000s
             */
            groupPriorityMinimum?: pulumi.Input<number>;
            /**
             * InsecureSkipTLSVerify disables TLS certificate verification when communicating with this server. This is strongly discouraged.  You should use the CABundle instead.
             */
            insecureSkipTLSVerify?: pulumi.Input<boolean>;
            /**
             * Service is a reference to the service for this API server.  It must communicate on port 443. If the Service is nil, that means the handling for the API groupversion is handled locally on this server. The call will simply delegate to the normal handler chain to be fulfilled.
             */
            service?: pulumi.Input<inputs.apiregistration.v1.ServiceReferencePatch>;
            /**
             * Version is the API version this server hosts.  For example, "v1"
             */
            version?: pulumi.Input<string>;
            /**
             * VersionPriority controls the ordering of this API version inside of its group.  Must be greater than zero. The primary sort is based on VersionPriority, ordered highest to lowest (20 before 10). Since it's inside of a group, the number can be small, probably in the 10s. In case of equal version priorities, the version string will be used to compute the order inside a group. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10.
             */
            versionPriority?: pulumi.Input<number>;
        }
        /**
         * APIServiceStatus contains derived information about an API server
         */
        interface APIServiceStatus {
            /**
             * Current service state of apiService.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.apiregistration.v1.APIServiceCondition>[]>;
        }
        /**
         * ServiceReference holds a reference to Service.legacy.k8s.io
         */
        interface ServiceReference {
            /**
             * Name is the name of the service
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace is the namespace of the service
             */
            namespace?: pulumi.Input<string>;
            /**
             * If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive).
             */
            port?: pulumi.Input<number>;
        }
        /**
         * ServiceReference holds a reference to Service.legacy.k8s.io
         */
        interface ServiceReferencePatch {
            /**
             * Name is the name of the service
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace is the namespace of the service
             */
            namespace?: pulumi.Input<string>;
            /**
             * If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive).
             */
            port?: pulumi.Input<number>;
        }
    }
    namespace v1beta1 {
        /**
         * APIService represents a server for a particular GroupVersion. Name must be "version.group".
         */
        interface APIService {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apiregistration.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"APIService">;
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec contains information for locating and communicating with a server
             */
            spec?: pulumi.Input<inputs.apiregistration.v1beta1.APIServiceSpec>;
            /**
             * Status contains derived information about an API server
             */
            status?: pulumi.Input<inputs.apiregistration.v1beta1.APIServiceStatus>;
        }
        /**
         * APIServiceCondition describes the state of an APIService at a particular point
         */
        interface APIServiceCondition {
            /**
             * Last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * Human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * Unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status is the status of the condition. Can be True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type is the type of the condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * APIServiceSpec contains information for locating and communicating with a server. Only https is supported, though you are able to disable certificate verification.
         */
        interface APIServiceSpec {
            /**
             * CABundle is a PEM encoded CA bundle which will be used to validate an API server's serving certificate. If unspecified, system trust roots on the apiserver are used.
             */
            caBundle?: pulumi.Input<string>;
            /**
             * Group is the API group name this server hosts
             */
            group?: pulumi.Input<string>;
            /**
             * GroupPriorityMininum is the priority this group should have at least. Higher priority means that the group is preferred by clients over lower priority ones. Note that other versions of this group might specify even higher GroupPriorityMininum values such that the whole group gets a higher priority. The primary sort is based on GroupPriorityMinimum, ordered highest number to lowest (20 before 10). The secondary sort is based on the alphabetical comparison of the name of the object.  (v1.bar before v1.foo) We'd recommend something like: *.k8s.io (except extensions) at 18000 and PaaSes (OpenShift, Deis) are recommended to be in the 2000s
             */
            groupPriorityMinimum: pulumi.Input<number>;
            /**
             * InsecureSkipTLSVerify disables TLS certificate verification when communicating with this server. This is strongly discouraged.  You should use the CABundle instead.
             */
            insecureSkipTLSVerify?: pulumi.Input<boolean>;
            /**
             * Service is a reference to the service for this API server.  It must communicate on port 443 If the Service is nil, that means the handling for the API groupversion is handled locally on this server. The call will simply delegate to the normal handler chain to be fulfilled.
             */
            service: pulumi.Input<inputs.apiregistration.v1beta1.ServiceReference>;
            /**
             * Version is the API version this server hosts.  For example, "v1"
             */
            version?: pulumi.Input<string>;
            /**
             * VersionPriority controls the ordering of this API version inside of its group.  Must be greater than zero. The primary sort is based on VersionPriority, ordered highest to lowest (20 before 10). Since it's inside of a group, the number can be small, probably in the 10s. In case of equal version priorities, the version string will be used to compute the order inside a group. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10.
             */
            versionPriority: pulumi.Input<number>;
        }
        /**
         * APIServiceSpec contains information for locating and communicating with a server. Only https is supported, though you are able to disable certificate verification.
         */
        interface APIServiceSpecPatch {
            /**
             * CABundle is a PEM encoded CA bundle which will be used to validate an API server's serving certificate. If unspecified, system trust roots on the apiserver are used.
             */
            caBundle?: pulumi.Input<string>;
            /**
             * Group is the API group name this server hosts
             */
            group?: pulumi.Input<string>;
            /**
             * GroupPriorityMininum is the priority this group should have at least. Higher priority means that the group is preferred by clients over lower priority ones. Note that other versions of this group might specify even higher GroupPriorityMininum values such that the whole group gets a higher priority. The primary sort is based on GroupPriorityMinimum, ordered highest number to lowest (20 before 10). The secondary sort is based on the alphabetical comparison of the name of the object.  (v1.bar before v1.foo) We'd recommend something like: *.k8s.io (except extensions) at 18000 and PaaSes (OpenShift, Deis) are recommended to be in the 2000s
             */
            groupPriorityMinimum?: pulumi.Input<number>;
            /**
             * InsecureSkipTLSVerify disables TLS certificate verification when communicating with this server. This is strongly discouraged.  You should use the CABundle instead.
             */
            insecureSkipTLSVerify?: pulumi.Input<boolean>;
            /**
             * Service is a reference to the service for this API server.  It must communicate on port 443 If the Service is nil, that means the handling for the API groupversion is handled locally on this server. The call will simply delegate to the normal handler chain to be fulfilled.
             */
            service?: pulumi.Input<inputs.apiregistration.v1beta1.ServiceReferencePatch>;
            /**
             * Version is the API version this server hosts.  For example, "v1"
             */
            version?: pulumi.Input<string>;
            /**
             * VersionPriority controls the ordering of this API version inside of its group.  Must be greater than zero. The primary sort is based on VersionPriority, ordered highest to lowest (20 before 10). Since it's inside of a group, the number can be small, probably in the 10s. In case of equal version priorities, the version string will be used to compute the order inside a group. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10.
             */
            versionPriority?: pulumi.Input<number>;
        }
        /**
         * APIServiceStatus contains derived information about an API server
         */
        interface APIServiceStatus {
            /**
             * Current service state of apiService.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.apiregistration.v1beta1.APIServiceCondition>[]>;
        }
        /**
         * ServiceReference holds a reference to Service.legacy.k8s.io
         */
        interface ServiceReference {
            /**
             * Name is the name of the service
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace is the namespace of the service
             */
            namespace?: pulumi.Input<string>;
            /**
             * If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive).
             */
            port?: pulumi.Input<number>;
        }
        /**
         * ServiceReference holds a reference to Service.legacy.k8s.io
         */
        interface ServiceReferencePatch {
            /**
             * Name is the name of the service
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace is the namespace of the service
             */
            namespace?: pulumi.Input<string>;
            /**
             * If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive).
             */
            port?: pulumi.Input<number>;
        }
    }
}
export declare namespace apps {
    namespace v1 {
        /**
         * ControllerRevision implements an immutable snapshot of state data. Clients are responsible for serializing and deserializing the objects that contain their internal state. Once a ControllerRevision has been successfully created, it can not be updated. The API Server will fail validation of all requests that attempt to mutate the Data field. ControllerRevisions may, however, be deleted. Note that, due to its use by both the DaemonSet and StatefulSet controllers for update and rollback, this object is beta. However, it may be subject to name and representation changes in future releases, and clients should not depend on its stability. It is primarily for internal use by controllers.
         */
        interface ControllerRevision {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apps/v1">;
            /**
             * Data is the serialized representation of the state.
             */
            data?: any;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ControllerRevision">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Revision indicates the revision of the state represented by Data.
             */
            revision: pulumi.Input<number>;
        }
        /**
         * DaemonSet represents the configuration of a daemon set.
         */
        interface DaemonSet {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apps/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"DaemonSet">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * The desired behavior of this daemon set. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.apps.v1.DaemonSetSpec>;
            /**
             * The current status of this daemon set. This data may be out of date by some window of time. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.apps.v1.DaemonSetStatus>;
        }
        /**
         * DaemonSetCondition describes the state of a DaemonSet at a certain point.
         */
        interface DaemonSetCondition {
            /**
             * Last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of DaemonSet condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * DaemonSetSpec is the specification of a daemon set.
         */
        interface DaemonSetSpec {
            /**
             * The minimum number of seconds for which a newly created DaemonSet pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready).
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * The number of old history to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * A label query over pods that are managed by the daemon set. Must match in order to be controlled. It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * An object that describes the pod that will be created. The DaemonSet will create exactly one copy of this pod on every node that matches the template's node selector (or on every node if no node selector is specified). The only allowed template.spec.restartPolicy value is "Always". More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
             */
            template: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
            /**
             * An update strategy to replace existing DaemonSet pods with new pods.
             */
            updateStrategy?: pulumi.Input<inputs.apps.v1.DaemonSetUpdateStrategy>;
        }
        /**
         * DaemonSetSpec is the specification of a daemon set.
         */
        interface DaemonSetSpecPatch {
            /**
             * The minimum number of seconds for which a newly created DaemonSet pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready).
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * The number of old history to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * A label query over pods that are managed by the daemon set. Must match in order to be controlled. It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * An object that describes the pod that will be created. The DaemonSet will create exactly one copy of this pod on every node that matches the template's node selector (or on every node if no node selector is specified). The only allowed template.spec.restartPolicy value is "Always". More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
            /**
             * An update strategy to replace existing DaemonSet pods with new pods.
             */
            updateStrategy?: pulumi.Input<inputs.apps.v1.DaemonSetUpdateStrategyPatch>;
        }
        /**
         * DaemonSetStatus represents the current status of a daemon set.
         */
        interface DaemonSetStatus {
            /**
             * Count of hash collisions for the DaemonSet. The DaemonSet controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ControllerRevision.
             */
            collisionCount?: pulumi.Input<number>;
            /**
             * Represents the latest available observations of a DaemonSet's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.apps.v1.DaemonSetCondition>[]>;
            /**
             * The number of nodes that are running at least 1 daemon pod and are supposed to run the daemon pod. More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
             */
            currentNumberScheduled: pulumi.Input<number>;
            /**
             * The total number of nodes that should be running the daemon pod (including nodes correctly running the daemon pod). More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
             */
            desiredNumberScheduled: pulumi.Input<number>;
            /**
             * The number of nodes that should be running the daemon pod and have one or more of the daemon pod running and available (ready for at least spec.minReadySeconds)
             */
            numberAvailable?: pulumi.Input<number>;
            /**
             * The number of nodes that are running the daemon pod, but are not supposed to run the daemon pod. More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
             */
            numberMisscheduled: pulumi.Input<number>;
            /**
             * numberReady is the number of nodes that should be running the daemon pod and have one or more of the daemon pod running with a Ready Condition.
             */
            numberReady: pulumi.Input<number>;
            /**
             * The number of nodes that should be running the daemon pod and have none of the daemon pod running and available (ready for at least spec.minReadySeconds)
             */
            numberUnavailable?: pulumi.Input<number>;
            /**
             * The most recent generation observed by the daemon set controller.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * The total number of nodes that are running updated daemon pod
             */
            updatedNumberScheduled?: pulumi.Input<number>;
        }
        /**
         * DaemonSetUpdateStrategy is a struct used to control the update strategy for a DaemonSet.
         */
        interface DaemonSetUpdateStrategy {
            /**
             * Rolling update config params. Present only if type = "RollingUpdate".
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1.RollingUpdateDaemonSet>;
            /**
             * Type of daemon set update. Can be "RollingUpdate" or "OnDelete". Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * DaemonSetUpdateStrategy is a struct used to control the update strategy for a DaemonSet.
         */
        interface DaemonSetUpdateStrategyPatch {
            /**
             * Rolling update config params. Present only if type = "RollingUpdate".
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1.RollingUpdateDaemonSetPatch>;
            /**
             * Type of daemon set update. Can be "RollingUpdate" or "OnDelete". Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * Deployment enables declarative updates for Pods and ReplicaSets.
         *
         * This resource waits until its status is ready before registering success
         * for create/update, and populating output properties from the current state of the resource.
         * The following conditions are used to determine whether the resource creation has
         * succeeded or failed:
         *
         * 1. The Deployment has begun to be updated by the Deployment controller. If the current
         *    generation of the Deployment is > 1, then this means that the current generation must
         *    be different from the generation reported by the last outputs.
         * 2. There exists a ReplicaSet whose revision is equal to the current revision of the
         *    Deployment.
         * 3. The Deployment's '.status.conditions' has a status of type 'Available' whose 'status'
         *    member is set to 'True'.
         * 4. If the Deployment has generation > 1, then '.status.conditions' has a status of type
         *    'Progressing', whose 'status' member is set to 'True', and whose 'reason' is
         *    'NewReplicaSetAvailable'. For generation <= 1, this status field does not exist,
         *    because it doesn't do a rollout (i.e., it simply creates the Deployment and
         *    corresponding ReplicaSet), and therefore there is no rollout to mark as 'Progressing'.
         *
         * If the Deployment has not reached a Ready state after 10 minutes, it will
         * time out and mark the resource update as Failed. You can override the default timeout value
         * by setting the 'customTimeouts' option on the resource.
         */
        interface Deployment {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apps/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Deployment">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the Deployment.
             */
            spec?: pulumi.Input<inputs.apps.v1.DeploymentSpec>;
            /**
             * Most recently observed status of the Deployment.
             */
            status?: pulumi.Input<inputs.apps.v1.DeploymentStatus>;
        }
        /**
         * DeploymentCondition describes the state of a deployment at a certain point.
         */
        interface DeploymentCondition {
            /**
             * Last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * The last time this condition was updated.
             */
            lastUpdateTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of deployment condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * DeploymentSpec is the specification of the desired behavior of the Deployment.
         */
        interface DeploymentSpec {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Indicates that the deployment is paused.
             */
            paused?: pulumi.Input<boolean>;
            /**
             * The maximum time in seconds for a deployment to make progress before it is considered to be failed. The deployment controller will continue to process failed deployments and a condition with a ProgressDeadlineExceeded reason will be surfaced in the deployment status. Note that progress will not be estimated during the time a deployment is paused. Defaults to 600s.
             */
            progressDeadlineSeconds?: pulumi.Input<number>;
            /**
             * Number of desired pods. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1.
             */
            replicas?: pulumi.Input<number>;
            /**
             * The number of old ReplicaSets to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * Label selector for pods. Existing ReplicaSets whose pods are selected by this will be the ones affected by this deployment. It must match the pod template's labels.
             */
            selector: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * The deployment strategy to use to replace existing pods with new ones.
             */
            strategy?: pulumi.Input<inputs.apps.v1.DeploymentStrategy>;
            /**
             * Template describes the pods that will be created. The only allowed template.spec.restartPolicy value is "Always".
             */
            template: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
        }
        /**
         * DeploymentSpec is the specification of the desired behavior of the Deployment.
         */
        interface DeploymentSpecPatch {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Indicates that the deployment is paused.
             */
            paused?: pulumi.Input<boolean>;
            /**
             * The maximum time in seconds for a deployment to make progress before it is considered to be failed. The deployment controller will continue to process failed deployments and a condition with a ProgressDeadlineExceeded reason will be surfaced in the deployment status. Note that progress will not be estimated during the time a deployment is paused. Defaults to 600s.
             */
            progressDeadlineSeconds?: pulumi.Input<number>;
            /**
             * Number of desired pods. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1.
             */
            replicas?: pulumi.Input<number>;
            /**
             * The number of old ReplicaSets to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * Label selector for pods. Existing ReplicaSets whose pods are selected by this will be the ones affected by this deployment. It must match the pod template's labels.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * The deployment strategy to use to replace existing pods with new ones.
             */
            strategy?: pulumi.Input<inputs.apps.v1.DeploymentStrategyPatch>;
            /**
             * Template describes the pods that will be created. The only allowed template.spec.restartPolicy value is "Always".
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
        }
        /**
         * DeploymentStatus is the most recently observed status of the Deployment.
         */
        interface DeploymentStatus {
            /**
             * Total number of available non-terminating pods (ready for at least minReadySeconds) targeted by this deployment.
             */
            availableReplicas?: pulumi.Input<number>;
            /**
             * Count of hash collisions for the Deployment. The Deployment controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ReplicaSet.
             */
            collisionCount?: pulumi.Input<number>;
            /**
             * Represents the latest available observations of a deployment's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.apps.v1.DeploymentCondition>[]>;
            /**
             * The generation observed by the deployment controller.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * Total number of non-terminating pods targeted by this Deployment with a Ready Condition.
             */
            readyReplicas?: pulumi.Input<number>;
            /**
             * Total number of non-terminating pods targeted by this deployment (their labels match the selector).
             */
            replicas?: pulumi.Input<number>;
            /**
             * Total number of terminating pods targeted by this deployment. Terminating pods have a non-null .metadata.deletionTimestamp and have not yet reached the Failed or Succeeded .status.phase.
             *
             * This is an alpha field. Enable DeploymentReplicaSetTerminatingReplicas to be able to use this field.
             */
            terminatingReplicas?: pulumi.Input<number>;
            /**
             * Total number of unavailable pods targeted by this deployment. This is the total number of pods that are still required for the deployment to have 100% available capacity. They may either be pods that are running but not yet available or pods that still have not been created.
             */
            unavailableReplicas?: pulumi.Input<number>;
            /**
             * Total number of non-terminating pods targeted by this deployment that have the desired template spec.
             */
            updatedReplicas?: pulumi.Input<number>;
        }
        /**
         * DeploymentStrategy describes how to replace existing pods with new ones.
         */
        interface DeploymentStrategy {
            /**
             * Rolling update config params. Present only if DeploymentStrategyType = RollingUpdate.
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1.RollingUpdateDeployment>;
            /**
             * Type of deployment. Can be "Recreate" or "RollingUpdate". Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * DeploymentStrategy describes how to replace existing pods with new ones.
         */
        interface DeploymentStrategyPatch {
            /**
             * Rolling update config params. Present only if DeploymentStrategyType = RollingUpdate.
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1.RollingUpdateDeploymentPatch>;
            /**
             * Type of deployment. Can be "Recreate" or "RollingUpdate". Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * ReplicaSet ensures that a specified number of pod replicas are running at any given time.
         */
        interface ReplicaSet {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apps/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ReplicaSet">;
            /**
             * If the Labels of a ReplicaSet are empty, they are defaulted to be the same as the Pod(s) that the ReplicaSet manages. Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines the specification of the desired behavior of the ReplicaSet. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.apps.v1.ReplicaSetSpec>;
            /**
             * Status is the most recently observed status of the ReplicaSet. This data may be out of date by some window of time. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.apps.v1.ReplicaSetStatus>;
        }
        /**
         * ReplicaSetCondition describes the state of a replica set at a certain point.
         */
        interface ReplicaSetCondition {
            /**
             * The last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of replica set condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * ReplicaSetSpec is the specification of a ReplicaSet.
         */
        interface ReplicaSetSpec {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Replicas is the number of desired pods. This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicaset
             */
            replicas?: pulumi.Input<number>;
            /**
             * Selector is a label query over pods that should match the replica count. Label keys and values that must match in order to be controlled by this replica set. It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * Template is the object that describes the pod that will be created if insufficient replicas are detected. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicaset/#pod-template
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
        }
        /**
         * ReplicaSetSpec is the specification of a ReplicaSet.
         */
        interface ReplicaSetSpecPatch {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Replicas is the number of desired pods. This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicaset
             */
            replicas?: pulumi.Input<number>;
            /**
             * Selector is a label query over pods that should match the replica count. Label keys and values that must match in order to be controlled by this replica set. It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * Template is the object that describes the pod that will be created if insufficient replicas are detected. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicaset/#pod-template
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
        }
        /**
         * ReplicaSetStatus represents the current status of a ReplicaSet.
         */
        interface ReplicaSetStatus {
            /**
             * The number of available non-terminating pods (ready for at least minReadySeconds) for this replica set.
             */
            availableReplicas?: pulumi.Input<number>;
            /**
             * Represents the latest available observations of a replica set's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.apps.v1.ReplicaSetCondition>[]>;
            /**
             * The number of non-terminating pods that have labels matching the labels of the pod template of the replicaset.
             */
            fullyLabeledReplicas?: pulumi.Input<number>;
            /**
             * ObservedGeneration reflects the generation of the most recently observed ReplicaSet.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * The number of non-terminating pods targeted by this ReplicaSet with a Ready Condition.
             */
            readyReplicas?: pulumi.Input<number>;
            /**
             * Replicas is the most recently observed number of non-terminating pods. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicaset
             */
            replicas: pulumi.Input<number>;
            /**
             * The number of terminating pods for this replica set. Terminating pods have a non-null .metadata.deletionTimestamp and have not yet reached the Failed or Succeeded .status.phase.
             *
             * This is an alpha field. Enable DeploymentReplicaSetTerminatingReplicas to be able to use this field.
             */
            terminatingReplicas?: pulumi.Input<number>;
        }
        /**
         * Spec to control the desired behavior of daemon set rolling update.
         */
        interface RollingUpdateDaemonSet {
            /**
             * The maximum number of nodes with an existing available DaemonSet pod that can have an updated DaemonSet pod during during an update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). This can not be 0 if MaxUnavailable is 0. Absolute number is calculated from percentage by rounding up to a minimum of 1. Default value is 0. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their a new pod created before the old pod is marked as deleted. The update starts by launching new pods on 30% of nodes. Once an updated pod is available (Ready for at least minReadySeconds) the old DaemonSet pod on that node is marked deleted. If the old pod becomes unavailable for any reason (Ready transitions to false, is evicted, or is drained) an updated pod is immediatedly created on that node without considering surge limits. Allowing surge implies the possibility that the resources consumed by the daemonset on any given node can double if the readiness check fails, and so resource intensive daemonsets should take into account that they may cause evictions during disruption.
             */
            maxSurge?: pulumi.Input<number | string>;
            /**
             * The maximum number of DaemonSet pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of total number of DaemonSet pods at the start of the update (ex: 10%). Absolute number is calculated from percentage by rounding up. This cannot be 0 if MaxSurge is 0 Default value is 1. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their pods stopped for an update at any given time. The update starts by stopping at most 30% of those DaemonSet pods and then brings up new DaemonSet pods in their place. Once the new pods are available, it then proceeds onto other DaemonSet pods, thus ensuring that at least 70% of original number of DaemonSet pods are available at all times during the update.
             */
            maxUnavailable?: pulumi.Input<number | string>;
        }
        /**
         * Spec to control the desired behavior of daemon set rolling update.
         */
        interface RollingUpdateDaemonSetPatch {
            /**
             * The maximum number of nodes with an existing available DaemonSet pod that can have an updated DaemonSet pod during during an update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). This can not be 0 if MaxUnavailable is 0. Absolute number is calculated from percentage by rounding up to a minimum of 1. Default value is 0. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their a new pod created before the old pod is marked as deleted. The update starts by launching new pods on 30% of nodes. Once an updated pod is available (Ready for at least minReadySeconds) the old DaemonSet pod on that node is marked deleted. If the old pod becomes unavailable for any reason (Ready transitions to false, is evicted, or is drained) an updated pod is immediatedly created on that node without considering surge limits. Allowing surge implies the possibility that the resources consumed by the daemonset on any given node can double if the readiness check fails, and so resource intensive daemonsets should take into account that they may cause evictions during disruption.
             */
            maxSurge?: pulumi.Input<number | string>;
            /**
             * The maximum number of DaemonSet pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of total number of DaemonSet pods at the start of the update (ex: 10%). Absolute number is calculated from percentage by rounding up. This cannot be 0 if MaxSurge is 0 Default value is 1. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their pods stopped for an update at any given time. The update starts by stopping at most 30% of those DaemonSet pods and then brings up new DaemonSet pods in their place. Once the new pods are available, it then proceeds onto other DaemonSet pods, thus ensuring that at least 70% of original number of DaemonSet pods are available at all times during the update.
             */
            maxUnavailable?: pulumi.Input<number | string>;
        }
        /**
         * Spec to control the desired behavior of rolling update.
         */
        interface RollingUpdateDeployment {
            /**
             * The maximum number of pods that can be scheduled above the desired number of pods. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). This can not be 0 if MaxUnavailable is 0. Absolute number is calculated from percentage by rounding up. Defaults to 25%. Example: when this is set to 30%, the new ReplicaSet can be scaled up immediately when the rolling update starts, such that the total number of old and new pods do not exceed 130% of desired pods. Once old pods have been killed, new ReplicaSet can be scaled up further, ensuring that total number of pods running at any time during the update is at most 130% of desired pods.
             */
            maxSurge?: pulumi.Input<number | string>;
            /**
             * The maximum number of pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). Absolute number is calculated from percentage by rounding down. This can not be 0 if MaxSurge is 0. Defaults to 25%. Example: when this is set to 30%, the old ReplicaSet can be scaled down to 70% of desired pods immediately when the rolling update starts. Once new pods are ready, old ReplicaSet can be scaled down further, followed by scaling up the new ReplicaSet, ensuring that the total number of pods available at all times during the update is at least 70% of desired pods.
             */
            maxUnavailable?: pulumi.Input<number | string>;
        }
        /**
         * Spec to control the desired behavior of rolling update.
         */
        interface RollingUpdateDeploymentPatch {
            /**
             * The maximum number of pods that can be scheduled above the desired number of pods. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). This can not be 0 if MaxUnavailable is 0. Absolute number is calculated from percentage by rounding up. Defaults to 25%. Example: when this is set to 30%, the new ReplicaSet can be scaled up immediately when the rolling update starts, such that the total number of old and new pods do not exceed 130% of desired pods. Once old pods have been killed, new ReplicaSet can be scaled up further, ensuring that total number of pods running at any time during the update is at most 130% of desired pods.
             */
            maxSurge?: pulumi.Input<number | string>;
            /**
             * The maximum number of pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). Absolute number is calculated from percentage by rounding down. This can not be 0 if MaxSurge is 0. Defaults to 25%. Example: when this is set to 30%, the old ReplicaSet can be scaled down to 70% of desired pods immediately when the rolling update starts. Once new pods are ready, old ReplicaSet can be scaled down further, followed by scaling up the new ReplicaSet, ensuring that the total number of pods available at all times during the update is at least 70% of desired pods.
             */
            maxUnavailable?: pulumi.Input<number | string>;
        }
        /**
         * RollingUpdateStatefulSetStrategy is used to communicate parameter for RollingUpdateStatefulSetStrategyType.
         */
        interface RollingUpdateStatefulSetStrategy {
            /**
             * The maximum number of pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). Absolute number is calculated from percentage by rounding up. This can not be 0. Defaults to 1. This field is alpha-level and is only honored by servers that enable the MaxUnavailableStatefulSet feature. The field applies to all pods in the range 0 to Replicas-1. That means if there is any unavailable pod in the range 0 to Replicas-1, it will be counted towards MaxUnavailable.
             */
            maxUnavailable?: pulumi.Input<number | string>;
            /**
             * Partition indicates the ordinal at which the StatefulSet should be partitioned for updates. During a rolling update, all pods from ordinal Replicas-1 to Partition are updated. All pods from ordinal Partition-1 to 0 remain untouched. This is helpful in being able to do a canary based deployment. The default value is 0.
             */
            partition?: pulumi.Input<number>;
        }
        /**
         * RollingUpdateStatefulSetStrategy is used to communicate parameter for RollingUpdateStatefulSetStrategyType.
         */
        interface RollingUpdateStatefulSetStrategyPatch {
            /**
             * The maximum number of pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). Absolute number is calculated from percentage by rounding up. This can not be 0. Defaults to 1. This field is alpha-level and is only honored by servers that enable the MaxUnavailableStatefulSet feature. The field applies to all pods in the range 0 to Replicas-1. That means if there is any unavailable pod in the range 0 to Replicas-1, it will be counted towards MaxUnavailable.
             */
            maxUnavailable?: pulumi.Input<number | string>;
            /**
             * Partition indicates the ordinal at which the StatefulSet should be partitioned for updates. During a rolling update, all pods from ordinal Replicas-1 to Partition are updated. All pods from ordinal Partition-1 to 0 remain untouched. This is helpful in being able to do a canary based deployment. The default value is 0.
             */
            partition?: pulumi.Input<number>;
        }
        /**
         * StatefulSet represents a set of pods with consistent identities. Identities are defined as:
         *   - Network: A single stable DNS and hostname.
         *   - Storage: As many VolumeClaims as requested.
         *
         * The StatefulSet guarantees that a given network identity will always map to the same storage identity.
         *
         * This resource waits until its status is ready before registering success
         * for create/update, and populating output properties from the current state of the resource.
         * The following conditions are used to determine whether the resource creation has
         * succeeded or failed:
         *
         * 1. The value of 'spec.replicas' matches '.status.replicas', '.status.currentReplicas',
         *    and '.status.readyReplicas'.
         * 2. The value of '.status.updateRevision' matches '.status.currentRevision'.
         *
         * If the StatefulSet has not reached a Ready state after 10 minutes, it will
         * time out and mark the resource update as Failed. You can override the default timeout value
         * by setting the 'customTimeouts' option on the resource.
         */
        interface StatefulSet {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apps/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"StatefulSet">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines the desired identities of pods in this set.
             */
            spec?: pulumi.Input<inputs.apps.v1.StatefulSetSpec>;
            /**
             * Status is the current status of Pods in this StatefulSet. This data may be out of date by some window of time.
             */
            status?: pulumi.Input<inputs.apps.v1.StatefulSetStatus>;
        }
        /**
         * StatefulSetCondition describes the state of a statefulset at a certain point.
         */
        interface StatefulSetCondition {
            /**
             * Last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of statefulset condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * StatefulSetOrdinals describes the policy used for replica ordinal assignment in this StatefulSet.
         */
        interface StatefulSetOrdinals {
            /**
             * start is the number representing the first replica's index. It may be used to number replicas from an alternate index (eg: 1-indexed) over the default 0-indexed names, or to orchestrate progressive movement of replicas from one StatefulSet to another. If set, replica indices will be in the range:
             *   [.spec.ordinals.start, .spec.ordinals.start + .spec.replicas).
             * If unset, defaults to 0. Replica indices will be in the range:
             *   [0, .spec.replicas).
             */
            start?: pulumi.Input<number>;
        }
        /**
         * StatefulSetOrdinals describes the policy used for replica ordinal assignment in this StatefulSet.
         */
        interface StatefulSetOrdinalsPatch {
            /**
             * start is the number representing the first replica's index. It may be used to number replicas from an alternate index (eg: 1-indexed) over the default 0-indexed names, or to orchestrate progressive movement of replicas from one StatefulSet to another. If set, replica indices will be in the range:
             *   [.spec.ordinals.start, .spec.ordinals.start + .spec.replicas).
             * If unset, defaults to 0. Replica indices will be in the range:
             *   [0, .spec.replicas).
             */
            start?: pulumi.Input<number>;
        }
        /**
         * StatefulSetPersistentVolumeClaimRetentionPolicy describes the policy used for PVCs created from the StatefulSet VolumeClaimTemplates.
         */
        interface StatefulSetPersistentVolumeClaimRetentionPolicy {
            /**
             * WhenDeleted specifies what happens to PVCs created from StatefulSet VolumeClaimTemplates when the StatefulSet is deleted. The default policy of `Retain` causes PVCs to not be affected by StatefulSet deletion. The `Delete` policy causes those PVCs to be deleted.
             */
            whenDeleted?: pulumi.Input<string>;
            /**
             * WhenScaled specifies what happens to PVCs created from StatefulSet VolumeClaimTemplates when the StatefulSet is scaled down. The default policy of `Retain` causes PVCs to not be affected by a scaledown. The `Delete` policy causes the associated PVCs for any excess pods above the replica count to be deleted.
             */
            whenScaled?: pulumi.Input<string>;
        }
        /**
         * StatefulSetPersistentVolumeClaimRetentionPolicy describes the policy used for PVCs created from the StatefulSet VolumeClaimTemplates.
         */
        interface StatefulSetPersistentVolumeClaimRetentionPolicyPatch {
            /**
             * WhenDeleted specifies what happens to PVCs created from StatefulSet VolumeClaimTemplates when the StatefulSet is deleted. The default policy of `Retain` causes PVCs to not be affected by StatefulSet deletion. The `Delete` policy causes those PVCs to be deleted.
             */
            whenDeleted?: pulumi.Input<string>;
            /**
             * WhenScaled specifies what happens to PVCs created from StatefulSet VolumeClaimTemplates when the StatefulSet is scaled down. The default policy of `Retain` causes PVCs to not be affected by a scaledown. The `Delete` policy causes the associated PVCs for any excess pods above the replica count to be deleted.
             */
            whenScaled?: pulumi.Input<string>;
        }
        /**
         * A StatefulSetSpec is the specification of a StatefulSet.
         */
        interface StatefulSetSpec {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * ordinals controls the numbering of replica indices in a StatefulSet. The default ordinals behavior assigns a "0" index to the first replica and increments the index by one for each additional replica requested.
             */
            ordinals?: pulumi.Input<inputs.apps.v1.StatefulSetOrdinals>;
            /**
             * persistentVolumeClaimRetentionPolicy describes the lifecycle of persistent volume claims created from volumeClaimTemplates. By default, all persistent volume claims are created as needed and retained until manually deleted. This policy allows the lifecycle to be altered, for example by deleting persistent volume claims when their stateful set is deleted, or when their pod is scaled down.
             */
            persistentVolumeClaimRetentionPolicy?: pulumi.Input<inputs.apps.v1.StatefulSetPersistentVolumeClaimRetentionPolicy>;
            /**
             * podManagementPolicy controls how pods are created during initial scale up, when replacing pods on nodes, or when scaling down. The default policy is `OrderedReady`, where pods are created in increasing order (pod-0, then pod-1, etc) and the controller will wait until each pod is ready before continuing. When scaling down, the pods are removed in the opposite order. The alternative policy is `Parallel` which will create pods in parallel to match the desired scale without waiting, and on scale down will delete all pods at once.
             */
            podManagementPolicy?: pulumi.Input<string>;
            /**
             * replicas is the desired number of replicas of the given Template. These are replicas in the sense that they are instantiations of the same Template, but individual replicas also have a consistent identity. If unspecified, defaults to 1.
             */
            replicas?: pulumi.Input<number>;
            /**
             * revisionHistoryLimit is the maximum number of revisions that will be maintained in the StatefulSet's revision history. The revision history consists of all revisions not represented by a currently applied StatefulSetSpec version. The default value is 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * selector is a label query over pods that should match the replica count. It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * serviceName is the name of the service that governs this StatefulSet. This service must exist before the StatefulSet, and is responsible for the network identity of the set. Pods get DNS/hostnames that follow the pattern: pod-specific-string.serviceName.default.svc.cluster.local where "pod-specific-string" is managed by the StatefulSet controller.
             */
            serviceName?: pulumi.Input<string>;
            /**
             * template is the object that describes the pod that will be created if insufficient replicas are detected. Each pod stamped out by the StatefulSet will fulfill this Template, but have a unique identity from the rest of the StatefulSet. Each pod will be named with the format <statefulsetname>-<podindex>. For example, a pod in a StatefulSet named "web" with index number "3" would be named "web-3". The only allowed template.spec.restartPolicy value is "Always".
             */
            template: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
            /**
             * updateStrategy indicates the StatefulSetUpdateStrategy that will be employed to update Pods in the StatefulSet when a revision is made to Template.
             */
            updateStrategy?: pulumi.Input<inputs.apps.v1.StatefulSetUpdateStrategy>;
            /**
             * volumeClaimTemplates is a list of claims that pods are allowed to reference. The StatefulSet controller is responsible for mapping network identities to claims in a way that maintains the identity of a pod. Every claim in this list must have at least one matching (by name) volumeMount in one container in the template. A claim in this list takes precedence over any volumes in the template, with the same name.
             */
            volumeClaimTemplates?: pulumi.Input<pulumi.Input<inputs.core.v1.PersistentVolumeClaim>[]>;
        }
        /**
         * A StatefulSetSpec is the specification of a StatefulSet.
         */
        interface StatefulSetSpecPatch {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * ordinals controls the numbering of replica indices in a StatefulSet. The default ordinals behavior assigns a "0" index to the first replica and increments the index by one for each additional replica requested.
             */
            ordinals?: pulumi.Input<inputs.apps.v1.StatefulSetOrdinalsPatch>;
            /**
             * persistentVolumeClaimRetentionPolicy describes the lifecycle of persistent volume claims created from volumeClaimTemplates. By default, all persistent volume claims are created as needed and retained until manually deleted. This policy allows the lifecycle to be altered, for example by deleting persistent volume claims when their stateful set is deleted, or when their pod is scaled down.
             */
            persistentVolumeClaimRetentionPolicy?: pulumi.Input<inputs.apps.v1.StatefulSetPersistentVolumeClaimRetentionPolicyPatch>;
            /**
             * podManagementPolicy controls how pods are created during initial scale up, when replacing pods on nodes, or when scaling down. The default policy is `OrderedReady`, where pods are created in increasing order (pod-0, then pod-1, etc) and the controller will wait until each pod is ready before continuing. When scaling down, the pods are removed in the opposite order. The alternative policy is `Parallel` which will create pods in parallel to match the desired scale without waiting, and on scale down will delete all pods at once.
             */
            podManagementPolicy?: pulumi.Input<string>;
            /**
             * replicas is the desired number of replicas of the given Template. These are replicas in the sense that they are instantiations of the same Template, but individual replicas also have a consistent identity. If unspecified, defaults to 1.
             */
            replicas?: pulumi.Input<number>;
            /**
             * revisionHistoryLimit is the maximum number of revisions that will be maintained in the StatefulSet's revision history. The revision history consists of all revisions not represented by a currently applied StatefulSetSpec version. The default value is 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * selector is a label query over pods that should match the replica count. It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * serviceName is the name of the service that governs this StatefulSet. This service must exist before the StatefulSet, and is responsible for the network identity of the set. Pods get DNS/hostnames that follow the pattern: pod-specific-string.serviceName.default.svc.cluster.local where "pod-specific-string" is managed by the StatefulSet controller.
             */
            serviceName?: pulumi.Input<string>;
            /**
             * template is the object that describes the pod that will be created if insufficient replicas are detected. Each pod stamped out by the StatefulSet will fulfill this Template, but have a unique identity from the rest of the StatefulSet. Each pod will be named with the format <statefulsetname>-<podindex>. For example, a pod in a StatefulSet named "web" with index number "3" would be named "web-3". The only allowed template.spec.restartPolicy value is "Always".
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
            /**
             * updateStrategy indicates the StatefulSetUpdateStrategy that will be employed to update Pods in the StatefulSet when a revision is made to Template.
             */
            updateStrategy?: pulumi.Input<inputs.apps.v1.StatefulSetUpdateStrategyPatch>;
            /**
             * volumeClaimTemplates is a list of claims that pods are allowed to reference. The StatefulSet controller is responsible for mapping network identities to claims in a way that maintains the identity of a pod. Every claim in this list must have at least one matching (by name) volumeMount in one container in the template. A claim in this list takes precedence over any volumes in the template, with the same name.
             */
            volumeClaimTemplates?: pulumi.Input<pulumi.Input<inputs.core.v1.PersistentVolumeClaimPatch>[]>;
        }
        /**
         * StatefulSetStatus represents the current state of a StatefulSet.
         */
        interface StatefulSetStatus {
            /**
             * Total number of available pods (ready for at least minReadySeconds) targeted by this statefulset.
             */
            availableReplicas?: pulumi.Input<number>;
            /**
             * collisionCount is the count of hash collisions for the StatefulSet. The StatefulSet controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ControllerRevision.
             */
            collisionCount?: pulumi.Input<number>;
            /**
             * Represents the latest available observations of a statefulset's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.apps.v1.StatefulSetCondition>[]>;
            /**
             * currentReplicas is the number of Pods created by the StatefulSet controller from the StatefulSet version indicated by currentRevision.
             */
            currentReplicas?: pulumi.Input<number>;
            /**
             * currentRevision, if not empty, indicates the version of the StatefulSet used to generate Pods in the sequence [0,currentReplicas).
             */
            currentRevision?: pulumi.Input<string>;
            /**
             * observedGeneration is the most recent generation observed for this StatefulSet. It corresponds to the StatefulSet's generation, which is updated on mutation by the API Server.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * readyReplicas is the number of pods created for this StatefulSet with a Ready Condition.
             */
            readyReplicas?: pulumi.Input<number>;
            /**
             * replicas is the number of Pods created by the StatefulSet controller.
             */
            replicas: pulumi.Input<number>;
            /**
             * updateRevision, if not empty, indicates the version of the StatefulSet used to generate Pods in the sequence [replicas-updatedReplicas,replicas)
             */
            updateRevision?: pulumi.Input<string>;
            /**
             * updatedReplicas is the number of Pods created by the StatefulSet controller from the StatefulSet version indicated by updateRevision.
             */
            updatedReplicas?: pulumi.Input<number>;
        }
        /**
         * StatefulSetUpdateStrategy indicates the strategy that the StatefulSet controller will use to perform updates. It includes any additional parameters necessary to perform the update for the indicated strategy.
         */
        interface StatefulSetUpdateStrategy {
            /**
             * RollingUpdate is used to communicate parameters when Type is RollingUpdateStatefulSetStrategyType.
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1.RollingUpdateStatefulSetStrategy>;
            /**
             * Type indicates the type of the StatefulSetUpdateStrategy. Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * StatefulSetUpdateStrategy indicates the strategy that the StatefulSet controller will use to perform updates. It includes any additional parameters necessary to perform the update for the indicated strategy.
         */
        interface StatefulSetUpdateStrategyPatch {
            /**
             * RollingUpdate is used to communicate parameters when Type is RollingUpdateStatefulSetStrategyType.
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1.RollingUpdateStatefulSetStrategyPatch>;
            /**
             * Type indicates the type of the StatefulSetUpdateStrategy. Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
    }
    namespace v1beta1 {
        /**
         * ControllerRevision implements an immutable snapshot of state data. Clients are responsible for serializing and deserializing the objects that contain their internal state. Once a ControllerRevision has been successfully created, it can not be updated. The API Server will fail validation of all requests that attempt to mutate the Data field. ControllerRevisions may, however, be deleted. Note that, due to its use by both the DaemonSet and StatefulSet controllers for update and rollback, this object is beta. However, it may be subject to name and representation changes in future releases, and clients should not depend on its stability. It is primarily for internal use by controllers.
         */
        interface ControllerRevision {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apps/v1beta1">;
            /**
             * Data is the serialized representation of the state.
             */
            data?: any;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ControllerRevision">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Revision indicates the revision of the state represented by Data.
             */
            revision: pulumi.Input<number>;
        }
        /**
         * Deployment enables declarative updates for Pods and ReplicaSets.
         *
         * This resource waits until its status is ready before registering success
         * for create/update, and populating output properties from the current state of the resource.
         * The following conditions are used to determine whether the resource creation has
         * succeeded or failed:
         *
         * 1. The Deployment has begun to be updated by the Deployment controller. If the current
         *    generation of the Deployment is > 1, then this means that the current generation must
         *    be different from the generation reported by the last outputs.
         * 2. There exists a ReplicaSet whose revision is equal to the current revision of the
         *    Deployment.
         * 3. The Deployment's '.status.conditions' has a status of type 'Available' whose 'status'
         *    member is set to 'True'.
         * 4. If the Deployment has generation > 1, then '.status.conditions' has a status of type
         *    'Progressing', whose 'status' member is set to 'True', and whose 'reason' is
         *    'NewReplicaSetAvailable'. For generation <= 1, this status field does not exist,
         *    because it doesn't do a rollout (i.e., it simply creates the Deployment and
         *    corresponding ReplicaSet), and therefore there is no rollout to mark as 'Progressing'.
         *
         * If the Deployment has not reached a Ready state after 10 minutes, it will
         * time out and mark the resource update as Failed. You can override the default timeout value
         * by setting the 'customTimeouts' option on the resource.
         */
        interface Deployment {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apps/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Deployment">;
            /**
             * Standard object metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the Deployment.
             */
            spec?: pulumi.Input<inputs.apps.v1beta1.DeploymentSpec>;
            /**
             * Most recently observed status of the Deployment.
             */
            status?: pulumi.Input<inputs.apps.v1beta1.DeploymentStatus>;
        }
        /**
         * DeploymentCondition describes the state of a deployment at a certain point.
         */
        interface DeploymentCondition {
            /**
             * Last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * The last time this condition was updated.
             */
            lastUpdateTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of deployment condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * DeploymentSpec is the specification of the desired behavior of the Deployment.
         */
        interface DeploymentSpec {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Indicates that the deployment is paused.
             */
            paused?: pulumi.Input<boolean>;
            /**
             * The maximum time in seconds for a deployment to make progress before it is considered to be failed. The deployment controller will continue to process failed deployments and a condition with a ProgressDeadlineExceeded reason will be surfaced in the deployment status. Note that progress will not be estimated during the time a deployment is paused. Defaults to 600s.
             */
            progressDeadlineSeconds?: pulumi.Input<number>;
            /**
             * Number of desired pods. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1.
             */
            replicas?: pulumi.Input<number>;
            /**
             * The number of old ReplicaSets to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 2.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * DEPRECATED. The config this deployment is rolling back to. Will be cleared after rollback is done.
             */
            rollbackTo?: pulumi.Input<inputs.apps.v1beta1.RollbackConfig>;
            /**
             * Label selector for pods. Existing ReplicaSets whose pods are selected by this will be the ones affected by this deployment.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * The deployment strategy to use to replace existing pods with new ones.
             */
            strategy?: pulumi.Input<inputs.apps.v1beta1.DeploymentStrategy>;
            /**
             * Template describes the pods that will be created.
             */
            template: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
        }
        /**
         * DeploymentSpec is the specification of the desired behavior of the Deployment.
         */
        interface DeploymentSpecPatch {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Indicates that the deployment is paused.
             */
            paused?: pulumi.Input<boolean>;
            /**
             * The maximum time in seconds for a deployment to make progress before it is considered to be failed. The deployment controller will continue to process failed deployments and a condition with a ProgressDeadlineExceeded reason will be surfaced in the deployment status. Note that progress will not be estimated during the time a deployment is paused. Defaults to 600s.
             */
            progressDeadlineSeconds?: pulumi.Input<number>;
            /**
             * Number of desired pods. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1.
             */
            replicas?: pulumi.Input<number>;
            /**
             * The number of old ReplicaSets to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 2.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * DEPRECATED. The config this deployment is rolling back to. Will be cleared after rollback is done.
             */
            rollbackTo?: pulumi.Input<inputs.apps.v1beta1.RollbackConfigPatch>;
            /**
             * Label selector for pods. Existing ReplicaSets whose pods are selected by this will be the ones affected by this deployment.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * The deployment strategy to use to replace existing pods with new ones.
             */
            strategy?: pulumi.Input<inputs.apps.v1beta1.DeploymentStrategyPatch>;
            /**
             * Template describes the pods that will be created.
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
        }
        /**
         * DeploymentStatus is the most recently observed status of the Deployment.
         */
        interface DeploymentStatus {
            /**
             * Total number of available pods (ready for at least minReadySeconds) targeted by this deployment.
             */
            availableReplicas?: pulumi.Input<number>;
            /**
             * Count of hash collisions for the Deployment. The Deployment controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ReplicaSet.
             */
            collisionCount?: pulumi.Input<number>;
            /**
             * Represents the latest available observations of a deployment's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.apps.v1beta1.DeploymentCondition>[]>;
            /**
             * The generation observed by the deployment controller.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * Total number of ready pods targeted by this deployment.
             */
            readyReplicas?: pulumi.Input<number>;
            /**
             * Total number of non-terminated pods targeted by this deployment (their labels match the selector).
             */
            replicas?: pulumi.Input<number>;
            /**
             * Total number of unavailable pods targeted by this deployment. This is the total number of pods that are still required for the deployment to have 100% available capacity. They may either be pods that are running but not yet available or pods that still have not been created.
             */
            unavailableReplicas?: pulumi.Input<number>;
            /**
             * Total number of non-terminated pods targeted by this deployment that have the desired template spec.
             */
            updatedReplicas?: pulumi.Input<number>;
        }
        /**
         * DeploymentStrategy describes how to replace existing pods with new ones.
         */
        interface DeploymentStrategy {
            /**
             * Rolling update config params. Present only if DeploymentStrategyType = RollingUpdate.
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1beta1.RollingUpdateDeployment>;
            /**
             * Type of deployment. Can be "Recreate" or "RollingUpdate". Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * DeploymentStrategy describes how to replace existing pods with new ones.
         */
        interface DeploymentStrategyPatch {
            /**
             * Rolling update config params. Present only if DeploymentStrategyType = RollingUpdate.
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1beta1.RollingUpdateDeploymentPatch>;
            /**
             * Type of deployment. Can be "Recreate" or "RollingUpdate". Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * DEPRECATED.
         */
        interface RollbackConfig {
            /**
             * The revision to rollback to. If set to 0, rollback to the last revision.
             */
            revision?: pulumi.Input<number>;
        }
        /**
         * DEPRECATED.
         */
        interface RollbackConfigPatch {
            /**
             * The revision to rollback to. If set to 0, rollback to the last revision.
             */
            revision?: pulumi.Input<number>;
        }
        /**
         * Spec to control the desired behavior of rolling update.
         */
        interface RollingUpdateDeployment {
            /**
             * The maximum number of pods that can be scheduled above the desired number of pods. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). This can not be 0 if MaxUnavailable is 0. Absolute number is calculated from percentage by rounding up. Defaults to 25%. Example: when this is set to 30%, the new ReplicaSet can be scaled up immediately when the rolling update starts, such that the total number of old and new pods do not exceed 130% of desired pods. Once old pods have been killed, new ReplicaSet can be scaled up further, ensuring that total number of pods running at any time during the update is at most 130% of desired pods.
             */
            maxSurge?: pulumi.Input<number | string>;
            /**
             * The maximum number of pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). Absolute number is calculated from percentage by rounding down. This can not be 0 if MaxSurge is 0. Defaults to 25%. Example: when this is set to 30%, the old ReplicaSet can be scaled down to 70% of desired pods immediately when the rolling update starts. Once new pods are ready, old ReplicaSet can be scaled down further, followed by scaling up the new ReplicaSet, ensuring that the total number of pods available at all times during the update is at least 70% of desired pods.
             */
            maxUnavailable?: pulumi.Input<number | string>;
        }
        /**
         * Spec to control the desired behavior of rolling update.
         */
        interface RollingUpdateDeploymentPatch {
            /**
             * The maximum number of pods that can be scheduled above the desired number of pods. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). This can not be 0 if MaxUnavailable is 0. Absolute number is calculated from percentage by rounding up. Defaults to 25%. Example: when this is set to 30%, the new ReplicaSet can be scaled up immediately when the rolling update starts, such that the total number of old and new pods do not exceed 130% of desired pods. Once old pods have been killed, new ReplicaSet can be scaled up further, ensuring that total number of pods running at any time during the update is at most 130% of desired pods.
             */
            maxSurge?: pulumi.Input<number | string>;
            /**
             * The maximum number of pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). Absolute number is calculated from percentage by rounding down. This can not be 0 if MaxSurge is 0. Defaults to 25%. Example: when this is set to 30%, the old ReplicaSet can be scaled down to 70% of desired pods immediately when the rolling update starts. Once new pods are ready, old ReplicaSet can be scaled down further, followed by scaling up the new ReplicaSet, ensuring that the total number of pods available at all times during the update is at least 70% of desired pods.
             */
            maxUnavailable?: pulumi.Input<number | string>;
        }
        /**
         * RollingUpdateStatefulSetStrategy is used to communicate parameter for RollingUpdateStatefulSetStrategyType.
         */
        interface RollingUpdateStatefulSetStrategy {
            /**
             * Partition indicates the ordinal at which the StatefulSet should be partitioned.
             */
            partition?: pulumi.Input<number>;
        }
        /**
         * RollingUpdateStatefulSetStrategy is used to communicate parameter for RollingUpdateStatefulSetStrategyType.
         */
        interface RollingUpdateStatefulSetStrategyPatch {
            /**
             * Partition indicates the ordinal at which the StatefulSet should be partitioned.
             */
            partition?: pulumi.Input<number>;
        }
        /**
         * StatefulSet represents a set of pods with consistent identities. Identities are defined as:
         *  - Network: A single stable DNS and hostname.
         *  - Storage: As many VolumeClaims as requested.
         * The StatefulSet guarantees that a given network identity will always map to the same storage identity.
         *
         * This resource waits until its status is ready before registering success
         * for create/update, and populating output properties from the current state of the resource.
         * The following conditions are used to determine whether the resource creation has
         * succeeded or failed:
         *
         * 1. The value of 'spec.replicas' matches '.status.replicas', '.status.currentReplicas',
         *    and '.status.readyReplicas'.
         * 2. The value of '.status.updateRevision' matches '.status.currentRevision'.
         *
         * If the StatefulSet has not reached a Ready state after 10 minutes, it will
         * time out and mark the resource update as Failed. You can override the default timeout value
         * by setting the 'customTimeouts' option on the resource.
         */
        interface StatefulSet {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apps/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"StatefulSet">;
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines the desired identities of pods in this set.
             */
            spec?: pulumi.Input<inputs.apps.v1beta1.StatefulSetSpec>;
            /**
             * Status is the current status of Pods in this StatefulSet. This data may be out of date by some window of time.
             */
            status?: pulumi.Input<inputs.apps.v1beta1.StatefulSetStatus>;
        }
        /**
         * StatefulSetCondition describes the state of a statefulset at a certain point.
         */
        interface StatefulSetCondition {
            /**
             * Last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of statefulset condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * A StatefulSetSpec is the specification of a StatefulSet.
         */
        interface StatefulSetSpec {
            /**
             * podManagementPolicy controls how pods are created during initial scale up, when replacing pods on nodes, or when scaling down. The default policy is `OrderedReady`, where pods are created in increasing order (pod-0, then pod-1, etc) and the controller will wait until each pod is ready before continuing. When scaling down, the pods are removed in the opposite order. The alternative policy is `Parallel` which will create pods in parallel to match the desired scale without waiting, and on scale down will delete all pods at once.
             */
            podManagementPolicy?: pulumi.Input<string>;
            /**
             * replicas is the desired number of replicas of the given Template. These are replicas in the sense that they are instantiations of the same Template, but individual replicas also have a consistent identity. If unspecified, defaults to 1.
             */
            replicas?: pulumi.Input<number>;
            /**
             * revisionHistoryLimit is the maximum number of revisions that will be maintained in the StatefulSet's revision history. The revision history consists of all revisions not represented by a currently applied StatefulSetSpec version. The default value is 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * selector is a label query over pods that should match the replica count. If empty, defaulted to labels on the pod template. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * serviceName is the name of the service that governs this StatefulSet. This service must exist before the StatefulSet, and is responsible for the network identity of the set. Pods get DNS/hostnames that follow the pattern: pod-specific-string.serviceName.default.svc.cluster.local where "pod-specific-string" is managed by the StatefulSet controller.
             */
            serviceName: pulumi.Input<string>;
            /**
             * template is the object that describes the pod that will be created if insufficient replicas are detected. Each pod stamped out by the StatefulSet will fulfill this Template, but have a unique identity from the rest of the StatefulSet.
             */
            template: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
            /**
             * updateStrategy indicates the StatefulSetUpdateStrategy that will be employed to update Pods in the StatefulSet when a revision is made to Template.
             */
            updateStrategy?: pulumi.Input<inputs.apps.v1beta1.StatefulSetUpdateStrategy>;
            /**
             * volumeClaimTemplates is a list of claims that pods are allowed to reference. The StatefulSet controller is responsible for mapping network identities to claims in a way that maintains the identity of a pod. Every claim in this list must have at least one matching (by name) volumeMount in one container in the template. A claim in this list takes precedence over any volumes in the template, with the same name.
             */
            volumeClaimTemplates?: pulumi.Input<pulumi.Input<inputs.core.v1.PersistentVolumeClaim>[]>;
        }
        /**
         * A StatefulSetSpec is the specification of a StatefulSet.
         */
        interface StatefulSetSpecPatch {
            /**
             * podManagementPolicy controls how pods are created during initial scale up, when replacing pods on nodes, or when scaling down. The default policy is `OrderedReady`, where pods are created in increasing order (pod-0, then pod-1, etc) and the controller will wait until each pod is ready before continuing. When scaling down, the pods are removed in the opposite order. The alternative policy is `Parallel` which will create pods in parallel to match the desired scale without waiting, and on scale down will delete all pods at once.
             */
            podManagementPolicy?: pulumi.Input<string>;
            /**
             * replicas is the desired number of replicas of the given Template. These are replicas in the sense that they are instantiations of the same Template, but individual replicas also have a consistent identity. If unspecified, defaults to 1.
             */
            replicas?: pulumi.Input<number>;
            /**
             * revisionHistoryLimit is the maximum number of revisions that will be maintained in the StatefulSet's revision history. The revision history consists of all revisions not represented by a currently applied StatefulSetSpec version. The default value is 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * selector is a label query over pods that should match the replica count. If empty, defaulted to labels on the pod template. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * serviceName is the name of the service that governs this StatefulSet. This service must exist before the StatefulSet, and is responsible for the network identity of the set. Pods get DNS/hostnames that follow the pattern: pod-specific-string.serviceName.default.svc.cluster.local where "pod-specific-string" is managed by the StatefulSet controller.
             */
            serviceName?: pulumi.Input<string>;
            /**
             * template is the object that describes the pod that will be created if insufficient replicas are detected. Each pod stamped out by the StatefulSet will fulfill this Template, but have a unique identity from the rest of the StatefulSet.
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
            /**
             * updateStrategy indicates the StatefulSetUpdateStrategy that will be employed to update Pods in the StatefulSet when a revision is made to Template.
             */
            updateStrategy?: pulumi.Input<inputs.apps.v1beta1.StatefulSetUpdateStrategyPatch>;
            /**
             * volumeClaimTemplates is a list of claims that pods are allowed to reference. The StatefulSet controller is responsible for mapping network identities to claims in a way that maintains the identity of a pod. Every claim in this list must have at least one matching (by name) volumeMount in one container in the template. A claim in this list takes precedence over any volumes in the template, with the same name.
             */
            volumeClaimTemplates?: pulumi.Input<pulumi.Input<inputs.core.v1.PersistentVolumeClaimPatch>[]>;
        }
        /**
         * StatefulSetStatus represents the current state of a StatefulSet.
         */
        interface StatefulSetStatus {
            /**
             * collisionCount is the count of hash collisions for the StatefulSet. The StatefulSet controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ControllerRevision.
             */
            collisionCount?: pulumi.Input<number>;
            /**
             * Represents the latest available observations of a statefulset's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.apps.v1beta1.StatefulSetCondition>[]>;
            /**
             * currentReplicas is the number of Pods created by the StatefulSet controller from the StatefulSet version indicated by currentRevision.
             */
            currentReplicas?: pulumi.Input<number>;
            /**
             * currentRevision, if not empty, indicates the version of the StatefulSet used to generate Pods in the sequence [0,currentReplicas).
             */
            currentRevision?: pulumi.Input<string>;
            /**
             * observedGeneration is the most recent generation observed for this StatefulSet. It corresponds to the StatefulSet's generation, which is updated on mutation by the API Server.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * readyReplicas is the number of Pods created by the StatefulSet controller that have a Ready Condition.
             */
            readyReplicas?: pulumi.Input<number>;
            /**
             * replicas is the number of Pods created by the StatefulSet controller.
             */
            replicas: pulumi.Input<number>;
            /**
             * updateRevision, if not empty, indicates the version of the StatefulSet used to generate Pods in the sequence [replicas-updatedReplicas,replicas)
             */
            updateRevision?: pulumi.Input<string>;
            /**
             * updatedReplicas is the number of Pods created by the StatefulSet controller from the StatefulSet version indicated by updateRevision.
             */
            updatedReplicas?: pulumi.Input<number>;
        }
        /**
         * StatefulSetUpdateStrategy indicates the strategy that the StatefulSet controller will use to perform updates. It includes any additional parameters necessary to perform the update for the indicated strategy.
         */
        interface StatefulSetUpdateStrategy {
            /**
             * RollingUpdate is used to communicate parameters when Type is RollingUpdateStatefulSetStrategyType.
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1beta1.RollingUpdateStatefulSetStrategy>;
            /**
             * Type indicates the type of the StatefulSetUpdateStrategy.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * StatefulSetUpdateStrategy indicates the strategy that the StatefulSet controller will use to perform updates. It includes any additional parameters necessary to perform the update for the indicated strategy.
         */
        interface StatefulSetUpdateStrategyPatch {
            /**
             * RollingUpdate is used to communicate parameters when Type is RollingUpdateStatefulSetStrategyType.
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1beta1.RollingUpdateStatefulSetStrategyPatch>;
            /**
             * Type indicates the type of the StatefulSetUpdateStrategy.
             */
            type?: pulumi.Input<string>;
        }
    }
    namespace v1beta2 {
        /**
         * ControllerRevision implements an immutable snapshot of state data. Clients are responsible for serializing and deserializing the objects that contain their internal state. Once a ControllerRevision has been successfully created, it can not be updated. The API Server will fail validation of all requests that attempt to mutate the Data field. ControllerRevisions may, however, be deleted. Note that, due to its use by both the DaemonSet and StatefulSet controllers for update and rollback, this object is beta. However, it may be subject to name and representation changes in future releases, and clients should not depend on its stability. It is primarily for internal use by controllers.
         */
        interface ControllerRevision {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apps/v1beta2">;
            /**
             * Data is the serialized representation of the state.
             */
            data?: any;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ControllerRevision">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Revision indicates the revision of the state represented by Data.
             */
            revision: pulumi.Input<number>;
        }
        /**
         * DaemonSet represents the configuration of a daemon set.
         */
        interface DaemonSet {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apps/v1beta2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"DaemonSet">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * The desired behavior of this daemon set. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.apps.v1beta2.DaemonSetSpec>;
            /**
             * The current status of this daemon set. This data may be out of date by some window of time. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.apps.v1beta2.DaemonSetStatus>;
        }
        /**
         * DaemonSetCondition describes the state of a DaemonSet at a certain point.
         */
        interface DaemonSetCondition {
            /**
             * Last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of DaemonSet condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * DaemonSetSpec is the specification of a daemon set.
         */
        interface DaemonSetSpec {
            /**
             * The minimum number of seconds for which a newly created DaemonSet pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready).
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * The number of old history to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * A label query over pods that are managed by the daemon set. Must match in order to be controlled. It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * An object that describes the pod that will be created. The DaemonSet will create exactly one copy of this pod on every node that matches the template's node selector (or on every node if no node selector is specified). More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
             */
            template: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
            /**
             * An update strategy to replace existing DaemonSet pods with new pods.
             */
            updateStrategy?: pulumi.Input<inputs.apps.v1beta2.DaemonSetUpdateStrategy>;
        }
        /**
         * DaemonSetSpec is the specification of a daemon set.
         */
        interface DaemonSetSpecPatch {
            /**
             * The minimum number of seconds for which a newly created DaemonSet pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready).
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * The number of old history to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * A label query over pods that are managed by the daemon set. Must match in order to be controlled. It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * An object that describes the pod that will be created. The DaemonSet will create exactly one copy of this pod on every node that matches the template's node selector (or on every node if no node selector is specified). More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
            /**
             * An update strategy to replace existing DaemonSet pods with new pods.
             */
            updateStrategy?: pulumi.Input<inputs.apps.v1beta2.DaemonSetUpdateStrategyPatch>;
        }
        /**
         * DaemonSetStatus represents the current status of a daemon set.
         */
        interface DaemonSetStatus {
            /**
             * Count of hash collisions for the DaemonSet. The DaemonSet controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ControllerRevision.
             */
            collisionCount?: pulumi.Input<number>;
            /**
             * Represents the latest available observations of a DaemonSet's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.apps.v1beta2.DaemonSetCondition>[]>;
            /**
             * The number of nodes that are running at least 1 daemon pod and are supposed to run the daemon pod. More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
             */
            currentNumberScheduled: pulumi.Input<number>;
            /**
             * The total number of nodes that should be running the daemon pod (including nodes correctly running the daemon pod). More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
             */
            desiredNumberScheduled: pulumi.Input<number>;
            /**
             * The number of nodes that should be running the daemon pod and have one or more of the daemon pod running and available (ready for at least spec.minReadySeconds)
             */
            numberAvailable?: pulumi.Input<number>;
            /**
             * The number of nodes that are running the daemon pod, but are not supposed to run the daemon pod. More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
             */
            numberMisscheduled: pulumi.Input<number>;
            /**
             * The number of nodes that should be running the daemon pod and have one or more of the daemon pod running and ready.
             */
            numberReady: pulumi.Input<number>;
            /**
             * The number of nodes that should be running the daemon pod and have none of the daemon pod running and available (ready for at least spec.minReadySeconds)
             */
            numberUnavailable?: pulumi.Input<number>;
            /**
             * The most recent generation observed by the daemon set controller.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * The total number of nodes that are running updated daemon pod
             */
            updatedNumberScheduled?: pulumi.Input<number>;
        }
        /**
         * DaemonSetUpdateStrategy is a struct used to control the update strategy for a DaemonSet.
         */
        interface DaemonSetUpdateStrategy {
            /**
             * Rolling update config params. Present only if type = "RollingUpdate".
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1beta2.RollingUpdateDaemonSet>;
            /**
             * Type of daemon set update. Can be "RollingUpdate" or "OnDelete". Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * DaemonSetUpdateStrategy is a struct used to control the update strategy for a DaemonSet.
         */
        interface DaemonSetUpdateStrategyPatch {
            /**
             * Rolling update config params. Present only if type = "RollingUpdate".
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1beta2.RollingUpdateDaemonSetPatch>;
            /**
             * Type of daemon set update. Can be "RollingUpdate" or "OnDelete". Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * Deployment enables declarative updates for Pods and ReplicaSets.
         *
         * This resource waits until its status is ready before registering success
         * for create/update, and populating output properties from the current state of the resource.
         * The following conditions are used to determine whether the resource creation has
         * succeeded or failed:
         *
         * 1. The Deployment has begun to be updated by the Deployment controller. If the current
         *    generation of the Deployment is > 1, then this means that the current generation must
         *    be different from the generation reported by the last outputs.
         * 2. There exists a ReplicaSet whose revision is equal to the current revision of the
         *    Deployment.
         * 3. The Deployment's '.status.conditions' has a status of type 'Available' whose 'status'
         *    member is set to 'True'.
         * 4. If the Deployment has generation > 1, then '.status.conditions' has a status of type
         *    'Progressing', whose 'status' member is set to 'True', and whose 'reason' is
         *    'NewReplicaSetAvailable'. For generation <= 1, this status field does not exist,
         *    because it doesn't do a rollout (i.e., it simply creates the Deployment and
         *    corresponding ReplicaSet), and therefore there is no rollout to mark as 'Progressing'.
         *
         * If the Deployment has not reached a Ready state after 10 minutes, it will
         * time out and mark the resource update as Failed. You can override the default timeout value
         * by setting the 'customTimeouts' option on the resource.
         */
        interface Deployment {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apps/v1beta2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Deployment">;
            /**
             * Standard object metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the Deployment.
             */
            spec?: pulumi.Input<inputs.apps.v1beta2.DeploymentSpec>;
            /**
             * Most recently observed status of the Deployment.
             */
            status?: pulumi.Input<inputs.apps.v1beta2.DeploymentStatus>;
        }
        /**
         * DeploymentCondition describes the state of a deployment at a certain point.
         */
        interface DeploymentCondition {
            /**
             * Last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * The last time this condition was updated.
             */
            lastUpdateTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of deployment condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * DeploymentSpec is the specification of the desired behavior of the Deployment.
         */
        interface DeploymentSpec {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Indicates that the deployment is paused.
             */
            paused?: pulumi.Input<boolean>;
            /**
             * The maximum time in seconds for a deployment to make progress before it is considered to be failed. The deployment controller will continue to process failed deployments and a condition with a ProgressDeadlineExceeded reason will be surfaced in the deployment status. Note that progress will not be estimated during the time a deployment is paused. Defaults to 600s.
             */
            progressDeadlineSeconds?: pulumi.Input<number>;
            /**
             * Number of desired pods. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1.
             */
            replicas?: pulumi.Input<number>;
            /**
             * The number of old ReplicaSets to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * Label selector for pods. Existing ReplicaSets whose pods are selected by this will be the ones affected by this deployment. It must match the pod template's labels.
             */
            selector: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * The deployment strategy to use to replace existing pods with new ones.
             */
            strategy?: pulumi.Input<inputs.apps.v1beta2.DeploymentStrategy>;
            /**
             * Template describes the pods that will be created.
             */
            template: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
        }
        /**
         * DeploymentSpec is the specification of the desired behavior of the Deployment.
         */
        interface DeploymentSpecPatch {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Indicates that the deployment is paused.
             */
            paused?: pulumi.Input<boolean>;
            /**
             * The maximum time in seconds for a deployment to make progress before it is considered to be failed. The deployment controller will continue to process failed deployments and a condition with a ProgressDeadlineExceeded reason will be surfaced in the deployment status. Note that progress will not be estimated during the time a deployment is paused. Defaults to 600s.
             */
            progressDeadlineSeconds?: pulumi.Input<number>;
            /**
             * Number of desired pods. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1.
             */
            replicas?: pulumi.Input<number>;
            /**
             * The number of old ReplicaSets to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * Label selector for pods. Existing ReplicaSets whose pods are selected by this will be the ones affected by this deployment. It must match the pod template's labels.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * The deployment strategy to use to replace existing pods with new ones.
             */
            strategy?: pulumi.Input<inputs.apps.v1beta2.DeploymentStrategyPatch>;
            /**
             * Template describes the pods that will be created.
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
        }
        /**
         * DeploymentStatus is the most recently observed status of the Deployment.
         */
        interface DeploymentStatus {
            /**
             * Total number of available pods (ready for at least minReadySeconds) targeted by this deployment.
             */
            availableReplicas?: pulumi.Input<number>;
            /**
             * Count of hash collisions for the Deployment. The Deployment controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ReplicaSet.
             */
            collisionCount?: pulumi.Input<number>;
            /**
             * Represents the latest available observations of a deployment's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.apps.v1beta2.DeploymentCondition>[]>;
            /**
             * The generation observed by the deployment controller.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * Total number of ready pods targeted by this deployment.
             */
            readyReplicas?: pulumi.Input<number>;
            /**
             * Total number of non-terminated pods targeted by this deployment (their labels match the selector).
             */
            replicas?: pulumi.Input<number>;
            /**
             * Total number of unavailable pods targeted by this deployment. This is the total number of pods that are still required for the deployment to have 100% available capacity. They may either be pods that are running but not yet available or pods that still have not been created.
             */
            unavailableReplicas?: pulumi.Input<number>;
            /**
             * Total number of non-terminated pods targeted by this deployment that have the desired template spec.
             */
            updatedReplicas?: pulumi.Input<number>;
        }
        /**
         * DeploymentStrategy describes how to replace existing pods with new ones.
         */
        interface DeploymentStrategy {
            /**
             * Rolling update config params. Present only if DeploymentStrategyType = RollingUpdate.
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1beta2.RollingUpdateDeployment>;
            /**
             * Type of deployment. Can be "Recreate" or "RollingUpdate". Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * DeploymentStrategy describes how to replace existing pods with new ones.
         */
        interface DeploymentStrategyPatch {
            /**
             * Rolling update config params. Present only if DeploymentStrategyType = RollingUpdate.
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1beta2.RollingUpdateDeploymentPatch>;
            /**
             * Type of deployment. Can be "Recreate" or "RollingUpdate". Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * ReplicaSet ensures that a specified number of pod replicas are running at any given time.
         */
        interface ReplicaSet {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apps/v1beta2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ReplicaSet">;
            /**
             * If the Labels of a ReplicaSet are empty, they are defaulted to be the same as the Pod(s) that the ReplicaSet manages. Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines the specification of the desired behavior of the ReplicaSet. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.apps.v1beta2.ReplicaSetSpec>;
            /**
             * Status is the most recently observed status of the ReplicaSet. This data may be out of date by some window of time. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.apps.v1beta2.ReplicaSetStatus>;
        }
        /**
         * ReplicaSetCondition describes the state of a replica set at a certain point.
         */
        interface ReplicaSetCondition {
            /**
             * The last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of replica set condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * ReplicaSetSpec is the specification of a ReplicaSet.
         */
        interface ReplicaSetSpec {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Replicas is the number of desired replicas. This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller/#what-is-a-replicationcontroller
             */
            replicas?: pulumi.Input<number>;
            /**
             * Selector is a label query over pods that should match the replica count. Label keys and values that must match in order to be controlled by this replica set. It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * Template is the object that describes the pod that will be created if insufficient replicas are detected. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
        }
        /**
         * ReplicaSetSpec is the specification of a ReplicaSet.
         */
        interface ReplicaSetSpecPatch {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Replicas is the number of desired replicas. This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller/#what-is-a-replicationcontroller
             */
            replicas?: pulumi.Input<number>;
            /**
             * Selector is a label query over pods that should match the replica count. Label keys and values that must match in order to be controlled by this replica set. It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * Template is the object that describes the pod that will be created if insufficient replicas are detected. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
        }
        /**
         * ReplicaSetStatus represents the current status of a ReplicaSet.
         */
        interface ReplicaSetStatus {
            /**
             * The number of available replicas (ready for at least minReadySeconds) for this replica set.
             */
            availableReplicas?: pulumi.Input<number>;
            /**
             * Represents the latest available observations of a replica set's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.apps.v1beta2.ReplicaSetCondition>[]>;
            /**
             * The number of pods that have labels matching the labels of the pod template of the replicaset.
             */
            fullyLabeledReplicas?: pulumi.Input<number>;
            /**
             * ObservedGeneration reflects the generation of the most recently observed ReplicaSet.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * The number of ready replicas for this replica set.
             */
            readyReplicas?: pulumi.Input<number>;
            /**
             * Replicas is the most recently oberved number of replicas. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller/#what-is-a-replicationcontroller
             */
            replicas: pulumi.Input<number>;
        }
        /**
         * Spec to control the desired behavior of daemon set rolling update.
         */
        interface RollingUpdateDaemonSet {
            /**
             * The maximum number of DaemonSet pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of total number of DaemonSet pods at the start of the update (ex: 10%). Absolute number is calculated from percentage by rounding up. This cannot be 0. Default value is 1. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their pods stopped for an update at any given time. The update starts by stopping at most 30% of those DaemonSet pods and then brings up new DaemonSet pods in their place. Once the new pods are available, it then proceeds onto other DaemonSet pods, thus ensuring that at least 70% of original number of DaemonSet pods are available at all times during the update.
             */
            maxUnavailable?: pulumi.Input<number | string>;
        }
        /**
         * Spec to control the desired behavior of daemon set rolling update.
         */
        interface RollingUpdateDaemonSetPatch {
            /**
             * The maximum number of DaemonSet pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of total number of DaemonSet pods at the start of the update (ex: 10%). Absolute number is calculated from percentage by rounding up. This cannot be 0. Default value is 1. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their pods stopped for an update at any given time. The update starts by stopping at most 30% of those DaemonSet pods and then brings up new DaemonSet pods in their place. Once the new pods are available, it then proceeds onto other DaemonSet pods, thus ensuring that at least 70% of original number of DaemonSet pods are available at all times during the update.
             */
            maxUnavailable?: pulumi.Input<number | string>;
        }
        /**
         * Spec to control the desired behavior of rolling update.
         */
        interface RollingUpdateDeployment {
            /**
             * The maximum number of pods that can be scheduled above the desired number of pods. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). This can not be 0 if MaxUnavailable is 0. Absolute number is calculated from percentage by rounding up. Defaults to 25%. Example: when this is set to 30%, the new ReplicaSet can be scaled up immediately when the rolling update starts, such that the total number of old and new pods do not exceed 130% of desired pods. Once old pods have been killed, new ReplicaSet can be scaled up further, ensuring that total number of pods running at any time during the update is at most 130% of desired pods.
             */
            maxSurge?: pulumi.Input<number | string>;
            /**
             * The maximum number of pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). Absolute number is calculated from percentage by rounding down. This can not be 0 if MaxSurge is 0. Defaults to 25%. Example: when this is set to 30%, the old ReplicaSet can be scaled down to 70% of desired pods immediately when the rolling update starts. Once new pods are ready, old ReplicaSet can be scaled down further, followed by scaling up the new ReplicaSet, ensuring that the total number of pods available at all times during the update is at least 70% of desired pods.
             */
            maxUnavailable?: pulumi.Input<number | string>;
        }
        /**
         * Spec to control the desired behavior of rolling update.
         */
        interface RollingUpdateDeploymentPatch {
            /**
             * The maximum number of pods that can be scheduled above the desired number of pods. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). This can not be 0 if MaxUnavailable is 0. Absolute number is calculated from percentage by rounding up. Defaults to 25%. Example: when this is set to 30%, the new ReplicaSet can be scaled up immediately when the rolling update starts, such that the total number of old and new pods do not exceed 130% of desired pods. Once old pods have been killed, new ReplicaSet can be scaled up further, ensuring that total number of pods running at any time during the update is at most 130% of desired pods.
             */
            maxSurge?: pulumi.Input<number | string>;
            /**
             * The maximum number of pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). Absolute number is calculated from percentage by rounding down. This can not be 0 if MaxSurge is 0. Defaults to 25%. Example: when this is set to 30%, the old ReplicaSet can be scaled down to 70% of desired pods immediately when the rolling update starts. Once new pods are ready, old ReplicaSet can be scaled down further, followed by scaling up the new ReplicaSet, ensuring that the total number of pods available at all times during the update is at least 70% of desired pods.
             */
            maxUnavailable?: pulumi.Input<number | string>;
        }
        /**
         * RollingUpdateStatefulSetStrategy is used to communicate parameter for RollingUpdateStatefulSetStrategyType.
         */
        interface RollingUpdateStatefulSetStrategy {
            /**
             * Partition indicates the ordinal at which the StatefulSet should be partitioned. Default value is 0.
             */
            partition?: pulumi.Input<number>;
        }
        /**
         * RollingUpdateStatefulSetStrategy is used to communicate parameter for RollingUpdateStatefulSetStrategyType.
         */
        interface RollingUpdateStatefulSetStrategyPatch {
            /**
             * Partition indicates the ordinal at which the StatefulSet should be partitioned. Default value is 0.
             */
            partition?: pulumi.Input<number>;
        }
        /**
         * StatefulSet represents a set of pods with consistent identities. Identities are defined as:
         *  - Network: A single stable DNS and hostname.
         *  - Storage: As many VolumeClaims as requested.
         * The StatefulSet guarantees that a given network identity will always map to the same storage identity.
         *
         * This resource waits until its status is ready before registering success
         * for create/update, and populating output properties from the current state of the resource.
         * The following conditions are used to determine whether the resource creation has
         * succeeded or failed:
         *
         * 1. The value of 'spec.replicas' matches '.status.replicas', '.status.currentReplicas',
         *    and '.status.readyReplicas'.
         * 2. The value of '.status.updateRevision' matches '.status.currentRevision'.
         *
         * If the StatefulSet has not reached a Ready state after 10 minutes, it will
         * time out and mark the resource update as Failed. You can override the default timeout value
         * by setting the 'customTimeouts' option on the resource.
         */
        interface StatefulSet {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"apps/v1beta2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"StatefulSet">;
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines the desired identities of pods in this set.
             */
            spec?: pulumi.Input<inputs.apps.v1beta2.StatefulSetSpec>;
            /**
             * Status is the current status of Pods in this StatefulSet. This data may be out of date by some window of time.
             */
            status?: pulumi.Input<inputs.apps.v1beta2.StatefulSetStatus>;
        }
        /**
         * StatefulSetCondition describes the state of a statefulset at a certain point.
         */
        interface StatefulSetCondition {
            /**
             * Last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of statefulset condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * A StatefulSetSpec is the specification of a StatefulSet.
         */
        interface StatefulSetSpec {
            /**
             * podManagementPolicy controls how pods are created during initial scale up, when replacing pods on nodes, or when scaling down. The default policy is `OrderedReady`, where pods are created in increasing order (pod-0, then pod-1, etc) and the controller will wait until each pod is ready before continuing. When scaling down, the pods are removed in the opposite order. The alternative policy is `Parallel` which will create pods in parallel to match the desired scale without waiting, and on scale down will delete all pods at once.
             */
            podManagementPolicy?: pulumi.Input<string>;
            /**
             * replicas is the desired number of replicas of the given Template. These are replicas in the sense that they are instantiations of the same Template, but individual replicas also have a consistent identity. If unspecified, defaults to 1.
             */
            replicas?: pulumi.Input<number>;
            /**
             * revisionHistoryLimit is the maximum number of revisions that will be maintained in the StatefulSet's revision history. The revision history consists of all revisions not represented by a currently applied StatefulSetSpec version. The default value is 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * selector is a label query over pods that should match the replica count. It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * serviceName is the name of the service that governs this StatefulSet. This service must exist before the StatefulSet, and is responsible for the network identity of the set. Pods get DNS/hostnames that follow the pattern: pod-specific-string.serviceName.default.svc.cluster.local where "pod-specific-string" is managed by the StatefulSet controller.
             */
            serviceName: pulumi.Input<string>;
            /**
             * template is the object that describes the pod that will be created if insufficient replicas are detected. Each pod stamped out by the StatefulSet will fulfill this Template, but have a unique identity from the rest of the StatefulSet.
             */
            template: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
            /**
             * updateStrategy indicates the StatefulSetUpdateStrategy that will be employed to update Pods in the StatefulSet when a revision is made to Template.
             */
            updateStrategy?: pulumi.Input<inputs.apps.v1beta2.StatefulSetUpdateStrategy>;
            /**
             * volumeClaimTemplates is a list of claims that pods are allowed to reference. The StatefulSet controller is responsible for mapping network identities to claims in a way that maintains the identity of a pod. Every claim in this list must have at least one matching (by name) volumeMount in one container in the template. A claim in this list takes precedence over any volumes in the template, with the same name.
             */
            volumeClaimTemplates?: pulumi.Input<pulumi.Input<inputs.core.v1.PersistentVolumeClaim>[]>;
        }
        /**
         * A StatefulSetSpec is the specification of a StatefulSet.
         */
        interface StatefulSetSpecPatch {
            /**
             * podManagementPolicy controls how pods are created during initial scale up, when replacing pods on nodes, or when scaling down. The default policy is `OrderedReady`, where pods are created in increasing order (pod-0, then pod-1, etc) and the controller will wait until each pod is ready before continuing. When scaling down, the pods are removed in the opposite order. The alternative policy is `Parallel` which will create pods in parallel to match the desired scale without waiting, and on scale down will delete all pods at once.
             */
            podManagementPolicy?: pulumi.Input<string>;
            /**
             * replicas is the desired number of replicas of the given Template. These are replicas in the sense that they are instantiations of the same Template, but individual replicas also have a consistent identity. If unspecified, defaults to 1.
             */
            replicas?: pulumi.Input<number>;
            /**
             * revisionHistoryLimit is the maximum number of revisions that will be maintained in the StatefulSet's revision history. The revision history consists of all revisions not represented by a currently applied StatefulSetSpec version. The default value is 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * selector is a label query over pods that should match the replica count. It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * serviceName is the name of the service that governs this StatefulSet. This service must exist before the StatefulSet, and is responsible for the network identity of the set. Pods get DNS/hostnames that follow the pattern: pod-specific-string.serviceName.default.svc.cluster.local where "pod-specific-string" is managed by the StatefulSet controller.
             */
            serviceName?: pulumi.Input<string>;
            /**
             * template is the object that describes the pod that will be created if insufficient replicas are detected. Each pod stamped out by the StatefulSet will fulfill this Template, but have a unique identity from the rest of the StatefulSet.
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
            /**
             * updateStrategy indicates the StatefulSetUpdateStrategy that will be employed to update Pods in the StatefulSet when a revision is made to Template.
             */
            updateStrategy?: pulumi.Input<inputs.apps.v1beta2.StatefulSetUpdateStrategyPatch>;
            /**
             * volumeClaimTemplates is a list of claims that pods are allowed to reference. The StatefulSet controller is responsible for mapping network identities to claims in a way that maintains the identity of a pod. Every claim in this list must have at least one matching (by name) volumeMount in one container in the template. A claim in this list takes precedence over any volumes in the template, with the same name.
             */
            volumeClaimTemplates?: pulumi.Input<pulumi.Input<inputs.core.v1.PersistentVolumeClaimPatch>[]>;
        }
        /**
         * StatefulSetStatus represents the current state of a StatefulSet.
         */
        interface StatefulSetStatus {
            /**
             * collisionCount is the count of hash collisions for the StatefulSet. The StatefulSet controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ControllerRevision.
             */
            collisionCount?: pulumi.Input<number>;
            /**
             * Represents the latest available observations of a statefulset's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.apps.v1beta2.StatefulSetCondition>[]>;
            /**
             * currentReplicas is the number of Pods created by the StatefulSet controller from the StatefulSet version indicated by currentRevision.
             */
            currentReplicas?: pulumi.Input<number>;
            /**
             * currentRevision, if not empty, indicates the version of the StatefulSet used to generate Pods in the sequence [0,currentReplicas).
             */
            currentRevision?: pulumi.Input<string>;
            /**
             * observedGeneration is the most recent generation observed for this StatefulSet. It corresponds to the StatefulSet's generation, which is updated on mutation by the API Server.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * readyReplicas is the number of Pods created by the StatefulSet controller that have a Ready Condition.
             */
            readyReplicas?: pulumi.Input<number>;
            /**
             * replicas is the number of Pods created by the StatefulSet controller.
             */
            replicas: pulumi.Input<number>;
            /**
             * updateRevision, if not empty, indicates the version of the StatefulSet used to generate Pods in the sequence [replicas-updatedReplicas,replicas)
             */
            updateRevision?: pulumi.Input<string>;
            /**
             * updatedReplicas is the number of Pods created by the StatefulSet controller from the StatefulSet version indicated by updateRevision.
             */
            updatedReplicas?: pulumi.Input<number>;
        }
        /**
         * StatefulSetUpdateStrategy indicates the strategy that the StatefulSet controller will use to perform updates. It includes any additional parameters necessary to perform the update for the indicated strategy.
         */
        interface StatefulSetUpdateStrategy {
            /**
             * RollingUpdate is used to communicate parameters when Type is RollingUpdateStatefulSetStrategyType.
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1beta2.RollingUpdateStatefulSetStrategy>;
            /**
             * Type indicates the type of the StatefulSetUpdateStrategy. Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * StatefulSetUpdateStrategy indicates the strategy that the StatefulSet controller will use to perform updates. It includes any additional parameters necessary to perform the update for the indicated strategy.
         */
        interface StatefulSetUpdateStrategyPatch {
            /**
             * RollingUpdate is used to communicate parameters when Type is RollingUpdateStatefulSetStrategyType.
             */
            rollingUpdate?: pulumi.Input<inputs.apps.v1beta2.RollingUpdateStatefulSetStrategyPatch>;
            /**
             * Type indicates the type of the StatefulSetUpdateStrategy. Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
    }
}
export declare namespace auditregistration {
    namespace v1alpha1 {
        /**
         * AuditSink represents a cluster level audit sink
         */
        interface AuditSink {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"auditregistration.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"AuditSink">;
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines the audit configuration spec
             */
            spec?: pulumi.Input<inputs.auditregistration.v1alpha1.AuditSinkSpec>;
        }
        /**
         * AuditSinkSpec holds the spec for the audit sink
         */
        interface AuditSinkSpec {
            /**
             * Policy defines the policy for selecting which events should be sent to the webhook required
             */
            policy: pulumi.Input<inputs.auditregistration.v1alpha1.Policy>;
            /**
             * Webhook to send events required
             */
            webhook: pulumi.Input<inputs.auditregistration.v1alpha1.Webhook>;
        }
        /**
         * AuditSinkSpec holds the spec for the audit sink
         */
        interface AuditSinkSpecPatch {
            /**
             * Policy defines the policy for selecting which events should be sent to the webhook required
             */
            policy?: pulumi.Input<inputs.auditregistration.v1alpha1.PolicyPatch>;
            /**
             * Webhook to send events required
             */
            webhook?: pulumi.Input<inputs.auditregistration.v1alpha1.WebhookPatch>;
        }
        /**
         * Policy defines the configuration of how audit events are logged
         */
        interface Policy {
            /**
             * The Level that all requests are recorded at. available options: None, Metadata, Request, RequestResponse required
             */
            level: pulumi.Input<string>;
            /**
             * Stages is a list of stages for which events are created.
             */
            stages?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * Policy defines the configuration of how audit events are logged
         */
        interface PolicyPatch {
            /**
             * The Level that all requests are recorded at. available options: None, Metadata, Request, RequestResponse required
             */
            level?: pulumi.Input<string>;
            /**
             * Stages is a list of stages for which events are created.
             */
            stages?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ServiceReference holds a reference to Service.legacy.k8s.io
         */
        interface ServiceReference {
            /**
             * `name` is the name of the service. Required
             */
            name: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of the service. Required
             */
            namespace: pulumi.Input<string>;
            /**
             * `path` is an optional URL path which will be sent in any request to this service.
             */
            path?: pulumi.Input<string>;
            /**
             * If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive).
             */
            port?: pulumi.Input<number>;
        }
        /**
         * ServiceReference holds a reference to Service.legacy.k8s.io
         */
        interface ServiceReferencePatch {
            /**
             * `name` is the name of the service. Required
             */
            name?: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of the service. Required
             */
            namespace?: pulumi.Input<string>;
            /**
             * `path` is an optional URL path which will be sent in any request to this service.
             */
            path?: pulumi.Input<string>;
            /**
             * If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive).
             */
            port?: pulumi.Input<number>;
        }
        /**
         * Webhook holds the configuration of the webhook
         */
        interface Webhook {
            /**
             * ClientConfig holds the connection parameters for the webhook required
             */
            clientConfig: pulumi.Input<inputs.auditregistration.v1alpha1.WebhookClientConfig>;
            /**
             * Throttle holds the options for throttling the webhook
             */
            throttle?: pulumi.Input<inputs.auditregistration.v1alpha1.WebhookThrottleConfig>;
        }
        /**
         * WebhookClientConfig contains the information to make a connection with the webhook
         */
        interface WebhookClientConfig {
            /**
             * `caBundle` is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used.
             */
            caBundle?: pulumi.Input<string>;
            /**
             * `service` is a reference to the service for this webhook. Either `service` or `url` must be specified.
             *
             * If the webhook is running within the cluster, then you should use `service`.
             */
            service?: pulumi.Input<inputs.auditregistration.v1alpha1.ServiceReference>;
            /**
             * `url` gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
             *
             * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
             *
             * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
             *
             * The scheme must be "https"; the URL must begin with "https://".
             *
             * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
             *
             * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
             */
            url?: pulumi.Input<string>;
        }
        /**
         * WebhookClientConfig contains the information to make a connection with the webhook
         */
        interface WebhookClientConfigPatch {
            /**
             * `caBundle` is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used.
             */
            caBundle?: pulumi.Input<string>;
            /**
             * `service` is a reference to the service for this webhook. Either `service` or `url` must be specified.
             *
             * If the webhook is running within the cluster, then you should use `service`.
             */
            service?: pulumi.Input<inputs.auditregistration.v1alpha1.ServiceReferencePatch>;
            /**
             * `url` gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
             *
             * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
             *
             * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
             *
             * The scheme must be "https"; the URL must begin with "https://".
             *
             * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
             *
             * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
             */
            url?: pulumi.Input<string>;
        }
        /**
         * Webhook holds the configuration of the webhook
         */
        interface WebhookPatch {
            /**
             * ClientConfig holds the connection parameters for the webhook required
             */
            clientConfig?: pulumi.Input<inputs.auditregistration.v1alpha1.WebhookClientConfigPatch>;
            /**
             * Throttle holds the options for throttling the webhook
             */
            throttle?: pulumi.Input<inputs.auditregistration.v1alpha1.WebhookThrottleConfigPatch>;
        }
        /**
         * WebhookThrottleConfig holds the configuration for throttling events
         */
        interface WebhookThrottleConfig {
            /**
             * ThrottleBurst is the maximum number of events sent at the same moment default 15 QPS
             */
            burst?: pulumi.Input<number>;
            /**
             * ThrottleQPS maximum number of batches per second default 10 QPS
             */
            qps?: pulumi.Input<number>;
        }
        /**
         * WebhookThrottleConfig holds the configuration for throttling events
         */
        interface WebhookThrottleConfigPatch {
            /**
             * ThrottleBurst is the maximum number of events sent at the same moment default 15 QPS
             */
            burst?: pulumi.Input<number>;
            /**
             * ThrottleQPS maximum number of batches per second default 10 QPS
             */
            qps?: pulumi.Input<number>;
        }
    }
}
export declare namespace authentication {
    namespace v1 {
    }
    namespace v1alpha1 {
    }
    namespace v1beta1 {
    }
}
export declare namespace authorization {
    namespace v1 {
    }
    namespace v1beta1 {
    }
}
export declare namespace autoscaling {
    namespace v1 {
        /**
         * CrossVersionObjectReference contains enough information to let you identify the referred resource.
         */
        interface CrossVersionObjectReference {
            /**
             * apiVersion is the API version of the referent
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * kind is the kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind: pulumi.Input<string>;
            /**
             * name is the name of the referent; More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name: pulumi.Input<string>;
        }
        /**
         * CrossVersionObjectReference contains enough information to let you identify the referred resource.
         */
        interface CrossVersionObjectReferencePatch {
            /**
             * apiVersion is the API version of the referent
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * kind is the kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<string>;
            /**
             * name is the name of the referent; More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
        }
        /**
         * configuration of a horizontal pod autoscaler.
         */
        interface HorizontalPodAutoscaler {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"autoscaling/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"HorizontalPodAutoscaler">;
            /**
             * Standard object metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec defines the behaviour of autoscaler. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status.
             */
            spec?: pulumi.Input<inputs.autoscaling.v1.HorizontalPodAutoscalerSpec>;
            /**
             * status is the current information about the autoscaler.
             */
            status?: pulumi.Input<inputs.autoscaling.v1.HorizontalPodAutoscalerStatus>;
        }
        /**
         * specification of a horizontal pod autoscaler.
         */
        interface HorizontalPodAutoscalerSpec {
            /**
             * maxReplicas is the upper limit for the number of pods that can be set by the autoscaler; cannot be smaller than MinReplicas.
             */
            maxReplicas: pulumi.Input<number>;
            /**
             * minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available.
             */
            minReplicas?: pulumi.Input<number>;
            /**
             * reference to scaled resource; horizontal pod autoscaler will learn the current resource consumption and will set the desired number of pods by using its Scale subresource.
             */
            scaleTargetRef: pulumi.Input<inputs.autoscaling.v1.CrossVersionObjectReference>;
            /**
             * targetCPUUtilizationPercentage is the target average CPU utilization (represented as a percentage of requested CPU) over all the pods; if not specified the default autoscaling policy will be used.
             */
            targetCPUUtilizationPercentage?: pulumi.Input<number>;
        }
        /**
         * specification of a horizontal pod autoscaler.
         */
        interface HorizontalPodAutoscalerSpecPatch {
            /**
             * maxReplicas is the upper limit for the number of pods that can be set by the autoscaler; cannot be smaller than MinReplicas.
             */
            maxReplicas?: pulumi.Input<number>;
            /**
             * minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available.
             */
            minReplicas?: pulumi.Input<number>;
            /**
             * reference to scaled resource; horizontal pod autoscaler will learn the current resource consumption and will set the desired number of pods by using its Scale subresource.
             */
            scaleTargetRef?: pulumi.Input<inputs.autoscaling.v1.CrossVersionObjectReferencePatch>;
            /**
             * targetCPUUtilizationPercentage is the target average CPU utilization (represented as a percentage of requested CPU) over all the pods; if not specified the default autoscaling policy will be used.
             */
            targetCPUUtilizationPercentage?: pulumi.Input<number>;
        }
        /**
         * current status of a horizontal pod autoscaler
         */
        interface HorizontalPodAutoscalerStatus {
            /**
             * currentCPUUtilizationPercentage is the current average CPU utilization over all pods, represented as a percentage of requested CPU, e.g. 70 means that an average pod is using now 70% of its requested CPU.
             */
            currentCPUUtilizationPercentage?: pulumi.Input<number>;
            /**
             * currentReplicas is the current number of replicas of pods managed by this autoscaler.
             */
            currentReplicas: pulumi.Input<number>;
            /**
             * desiredReplicas is the  desired number of replicas of pods managed by this autoscaler.
             */
            desiredReplicas: pulumi.Input<number>;
            /**
             * lastScaleTime is the last time the HorizontalPodAutoscaler scaled the number of pods; used by the autoscaler to control how often the number of pods is changed.
             */
            lastScaleTime?: pulumi.Input<string>;
            /**
             * observedGeneration is the most recent generation observed by this autoscaler.
             */
            observedGeneration?: pulumi.Input<number>;
        }
    }
    namespace v2 {
        /**
         * ContainerResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.
         */
        interface ContainerResourceMetricSource {
            /**
             * container is the name of the container in the pods of the scaling target
             */
            container: pulumi.Input<string>;
            /**
             * name is the name of the resource in question.
             */
            name: pulumi.Input<string>;
            /**
             * target specifies the target value for the given metric
             */
            target: pulumi.Input<inputs.autoscaling.v2.MetricTarget>;
        }
        /**
         * ContainerResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.
         */
        interface ContainerResourceMetricSourcePatch {
            /**
             * container is the name of the container in the pods of the scaling target
             */
            container?: pulumi.Input<string>;
            /**
             * name is the name of the resource in question.
             */
            name?: pulumi.Input<string>;
            /**
             * target specifies the target value for the given metric
             */
            target?: pulumi.Input<inputs.autoscaling.v2.MetricTargetPatch>;
        }
        /**
         * ContainerResourceMetricStatus indicates the current value of a resource metric known to Kubernetes, as specified in requests and limits, describing a single container in each pod in the current scale target (e.g. CPU or memory).  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
         */
        interface ContainerResourceMetricStatus {
            /**
             * container is the name of the container in the pods of the scaling target
             */
            container: pulumi.Input<string>;
            /**
             * current contains the current value for the given metric
             */
            current: pulumi.Input<inputs.autoscaling.v2.MetricValueStatus>;
            /**
             * name is the name of the resource in question.
             */
            name: pulumi.Input<string>;
        }
        /**
         * CrossVersionObjectReference contains enough information to let you identify the referred resource.
         */
        interface CrossVersionObjectReference {
            /**
             * apiVersion is the API version of the referent
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * kind is the kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind: pulumi.Input<string>;
            /**
             * name is the name of the referent; More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name: pulumi.Input<string>;
        }
        /**
         * CrossVersionObjectReference contains enough information to let you identify the referred resource.
         */
        interface CrossVersionObjectReferencePatch {
            /**
             * apiVersion is the API version of the referent
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * kind is the kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<string>;
            /**
             * name is the name of the referent; More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
        }
        /**
         * ExternalMetricSource indicates how to scale on a metric not associated with any Kubernetes object (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).
         */
        interface ExternalMetricSource {
            /**
             * metric identifies the target metric by name and selector
             */
            metric: pulumi.Input<inputs.autoscaling.v2.MetricIdentifier>;
            /**
             * target specifies the target value for the given metric
             */
            target: pulumi.Input<inputs.autoscaling.v2.MetricTarget>;
        }
        /**
         * ExternalMetricSource indicates how to scale on a metric not associated with any Kubernetes object (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).
         */
        interface ExternalMetricSourcePatch {
            /**
             * metric identifies the target metric by name and selector
             */
            metric?: pulumi.Input<inputs.autoscaling.v2.MetricIdentifierPatch>;
            /**
             * target specifies the target value for the given metric
             */
            target?: pulumi.Input<inputs.autoscaling.v2.MetricTargetPatch>;
        }
        /**
         * ExternalMetricStatus indicates the current value of a global metric not associated with any Kubernetes object.
         */
        interface ExternalMetricStatus {
            /**
             * current contains the current value for the given metric
             */
            current: pulumi.Input<inputs.autoscaling.v2.MetricValueStatus>;
            /**
             * metric identifies the target metric by name and selector
             */
            metric: pulumi.Input<inputs.autoscaling.v2.MetricIdentifier>;
        }
        /**
         * HPAScalingPolicy is a single policy which must hold true for a specified past interval.
         */
        interface HPAScalingPolicy {
            /**
             * periodSeconds specifies the window of time for which the policy should hold true. PeriodSeconds must be greater than zero and less than or equal to 1800 (30 min).
             */
            periodSeconds: pulumi.Input<number>;
            /**
             * type is used to specify the scaling policy.
             */
            type: pulumi.Input<string>;
            /**
             * value contains the amount of change which is permitted by the policy. It must be greater than zero
             */
            value: pulumi.Input<number>;
        }
        /**
         * HPAScalingPolicy is a single policy which must hold true for a specified past interval.
         */
        interface HPAScalingPolicyPatch {
            /**
             * periodSeconds specifies the window of time for which the policy should hold true. PeriodSeconds must be greater than zero and less than or equal to 1800 (30 min).
             */
            periodSeconds?: pulumi.Input<number>;
            /**
             * type is used to specify the scaling policy.
             */
            type?: pulumi.Input<string>;
            /**
             * value contains the amount of change which is permitted by the policy. It must be greater than zero
             */
            value?: pulumi.Input<number>;
        }
        /**
         * HPAScalingRules configures the scaling behavior for one direction via scaling Policy Rules and a configurable metric tolerance.
         *
         * Scaling Policy Rules are applied after calculating DesiredReplicas from metrics for the HPA. They can limit the scaling velocity by specifying scaling policies. They can prevent flapping by specifying the stabilization window, so that the number of replicas is not set instantly, instead, the safest value from the stabilization window is chosen.
         *
         * The tolerance is applied to the metric values and prevents scaling too eagerly for small metric variations. (Note that setting a tolerance requires enabling the alpha HPAConfigurableTolerance feature gate.)
         */
        interface HPAScalingRules {
            /**
             * policies is a list of potential scaling polices which can be used during scaling. If not set, use the default values: - For scale up: allow doubling the number of pods, or an absolute change of 4 pods in a 15s window. - For scale down: allow all pods to be removed in a 15s window.
             */
            policies?: pulumi.Input<pulumi.Input<inputs.autoscaling.v2.HPAScalingPolicy>[]>;
            /**
             * selectPolicy is used to specify which policy should be used. If not set, the default value Max is used.
             */
            selectPolicy?: pulumi.Input<string>;
            /**
             * stabilizationWindowSeconds is the number of seconds for which past recommendations should be considered while scaling up or scaling down. StabilizationWindowSeconds must be greater than or equal to zero and less than or equal to 3600 (one hour). If not set, use the default values: - For scale up: 0 (i.e. no stabilization is done). - For scale down: 300 (i.e. the stabilization window is 300 seconds long).
             */
            stabilizationWindowSeconds?: pulumi.Input<number>;
            /**
             * tolerance is the tolerance on the ratio between the current and desired metric value under which no updates are made to the desired number of replicas (e.g. 0.01 for 1%). Must be greater than or equal to zero. If not set, the default cluster-wide tolerance is applied (by default 10%).
             *
             * For example, if autoscaling is configured with a memory consumption target of 100Mi, and scale-down and scale-up tolerances of 5% and 1% respectively, scaling will be triggered when the actual consumption falls below 95Mi or exceeds 101Mi.
             *
             * This is an alpha field and requires enabling the HPAConfigurableTolerance feature gate.
             */
            tolerance?: pulumi.Input<string>;
        }
        /**
         * HPAScalingRules configures the scaling behavior for one direction via scaling Policy Rules and a configurable metric tolerance.
         *
         * Scaling Policy Rules are applied after calculating DesiredReplicas from metrics for the HPA. They can limit the scaling velocity by specifying scaling policies. They can prevent flapping by specifying the stabilization window, so that the number of replicas is not set instantly, instead, the safest value from the stabilization window is chosen.
         *
         * The tolerance is applied to the metric values and prevents scaling too eagerly for small metric variations. (Note that setting a tolerance requires enabling the alpha HPAConfigurableTolerance feature gate.)
         */
        interface HPAScalingRulesPatch {
            /**
             * policies is a list of potential scaling polices which can be used during scaling. If not set, use the default values: - For scale up: allow doubling the number of pods, or an absolute change of 4 pods in a 15s window. - For scale down: allow all pods to be removed in a 15s window.
             */
            policies?: pulumi.Input<pulumi.Input<inputs.autoscaling.v2.HPAScalingPolicyPatch>[]>;
            /**
             * selectPolicy is used to specify which policy should be used. If not set, the default value Max is used.
             */
            selectPolicy?: pulumi.Input<string>;
            /**
             * stabilizationWindowSeconds is the number of seconds for which past recommendations should be considered while scaling up or scaling down. StabilizationWindowSeconds must be greater than or equal to zero and less than or equal to 3600 (one hour). If not set, use the default values: - For scale up: 0 (i.e. no stabilization is done). - For scale down: 300 (i.e. the stabilization window is 300 seconds long).
             */
            stabilizationWindowSeconds?: pulumi.Input<number>;
            /**
             * tolerance is the tolerance on the ratio between the current and desired metric value under which no updates are made to the desired number of replicas (e.g. 0.01 for 1%). Must be greater than or equal to zero. If not set, the default cluster-wide tolerance is applied (by default 10%).
             *
             * For example, if autoscaling is configured with a memory consumption target of 100Mi, and scale-down and scale-up tolerances of 5% and 1% respectively, scaling will be triggered when the actual consumption falls below 95Mi or exceeds 101Mi.
             *
             * This is an alpha field and requires enabling the HPAConfigurableTolerance feature gate.
             */
            tolerance?: pulumi.Input<string>;
        }
        /**
         * HorizontalPodAutoscaler is the configuration for a horizontal pod autoscaler, which automatically manages the replica count of any resource implementing the scale subresource based on the metrics specified.
         */
        interface HorizontalPodAutoscaler {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"autoscaling/v2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"HorizontalPodAutoscaler">;
            /**
             * metadata is the standard object metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec is the specification for the behaviour of the autoscaler. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status.
             */
            spec?: pulumi.Input<inputs.autoscaling.v2.HorizontalPodAutoscalerSpec>;
            /**
             * status is the current information about the autoscaler.
             */
            status?: pulumi.Input<inputs.autoscaling.v2.HorizontalPodAutoscalerStatus>;
        }
        /**
         * HorizontalPodAutoscalerBehavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively).
         */
        interface HorizontalPodAutoscalerBehavior {
            /**
             * scaleDown is scaling policy for scaling Down. If not set, the default value is to allow to scale down to minReplicas pods, with a 300 second stabilization window (i.e., the highest recommendation for the last 300sec is used).
             */
            scaleDown?: pulumi.Input<inputs.autoscaling.v2.HPAScalingRules>;
            /**
             * scaleUp is scaling policy for scaling Up. If not set, the default value is the higher of:
             *   * increase no more than 4 pods per 60 seconds
             *   * double the number of pods per 60 seconds
             * No stabilization is used.
             */
            scaleUp?: pulumi.Input<inputs.autoscaling.v2.HPAScalingRules>;
        }
        /**
         * HorizontalPodAutoscalerBehavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively).
         */
        interface HorizontalPodAutoscalerBehaviorPatch {
            /**
             * scaleDown is scaling policy for scaling Down. If not set, the default value is to allow to scale down to minReplicas pods, with a 300 second stabilization window (i.e., the highest recommendation for the last 300sec is used).
             */
            scaleDown?: pulumi.Input<inputs.autoscaling.v2.HPAScalingRulesPatch>;
            /**
             * scaleUp is scaling policy for scaling Up. If not set, the default value is the higher of:
             *   * increase no more than 4 pods per 60 seconds
             *   * double the number of pods per 60 seconds
             * No stabilization is used.
             */
            scaleUp?: pulumi.Input<inputs.autoscaling.v2.HPAScalingRulesPatch>;
        }
        /**
         * HorizontalPodAutoscalerCondition describes the state of a HorizontalPodAutoscaler at a certain point.
         */
        interface HorizontalPodAutoscalerCondition {
            /**
             * lastTransitionTime is the last time the condition transitioned from one status to another
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * message is a human-readable explanation containing details about the transition
             */
            message?: pulumi.Input<string>;
            /**
             * reason is the reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * status is the status of the condition (True, False, Unknown)
             */
            status: pulumi.Input<string>;
            /**
             * type describes the current condition
             */
            type: pulumi.Input<string>;
        }
        /**
         * HorizontalPodAutoscalerSpec describes the desired functionality of the HorizontalPodAutoscaler.
         */
        interface HorizontalPodAutoscalerSpec {
            /**
             * behavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively). If not set, the default HPAScalingRules for scale up and scale down are used.
             */
            behavior?: pulumi.Input<inputs.autoscaling.v2.HorizontalPodAutoscalerBehavior>;
            /**
             * maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up. It cannot be less that minReplicas.
             */
            maxReplicas: pulumi.Input<number>;
            /**
             * metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used).  The desired replica count is calculated multiplying the ratio between the target value and the current value by the current number of pods.  Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond. If not set, the default metric will be set to 80% average CPU utilization.
             */
            metrics?: pulumi.Input<pulumi.Input<inputs.autoscaling.v2.MetricSpec>[]>;
            /**
             * minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available.
             */
            minReplicas?: pulumi.Input<number>;
            /**
             * scaleTargetRef points to the target resource to scale, and is used to the pods for which metrics should be collected, as well as to actually change the replica count.
             */
            scaleTargetRef: pulumi.Input<inputs.autoscaling.v2.CrossVersionObjectReference>;
        }
        /**
         * HorizontalPodAutoscalerSpec describes the desired functionality of the HorizontalPodAutoscaler.
         */
        interface HorizontalPodAutoscalerSpecPatch {
            /**
             * behavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively). If not set, the default HPAScalingRules for scale up and scale down are used.
             */
            behavior?: pulumi.Input<inputs.autoscaling.v2.HorizontalPodAutoscalerBehaviorPatch>;
            /**
             * maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up. It cannot be less that minReplicas.
             */
            maxReplicas?: pulumi.Input<number>;
            /**
             * metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used).  The desired replica count is calculated multiplying the ratio between the target value and the current value by the current number of pods.  Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond. If not set, the default metric will be set to 80% average CPU utilization.
             */
            metrics?: pulumi.Input<pulumi.Input<inputs.autoscaling.v2.MetricSpecPatch>[]>;
            /**
             * minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available.
             */
            minReplicas?: pulumi.Input<number>;
            /**
             * scaleTargetRef points to the target resource to scale, and is used to the pods for which metrics should be collected, as well as to actually change the replica count.
             */
            scaleTargetRef?: pulumi.Input<inputs.autoscaling.v2.CrossVersionObjectReferencePatch>;
        }
        /**
         * HorizontalPodAutoscalerStatus describes the current status of a horizontal pod autoscaler.
         */
        interface HorizontalPodAutoscalerStatus {
            /**
             * conditions is the set of conditions required for this autoscaler to scale its target, and indicates whether or not those conditions are met.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.autoscaling.v2.HorizontalPodAutoscalerCondition>[]>;
            /**
             * currentMetrics is the last read state of the metrics used by this autoscaler.
             */
            currentMetrics?: pulumi.Input<pulumi.Input<inputs.autoscaling.v2.MetricStatus>[]>;
            /**
             * currentReplicas is current number of replicas of pods managed by this autoscaler, as last seen by the autoscaler.
             */
            currentReplicas?: pulumi.Input<number>;
            /**
             * desiredReplicas is the desired number of replicas of pods managed by this autoscaler, as last calculated by the autoscaler.
             */
            desiredReplicas: pulumi.Input<number>;
            /**
             * lastScaleTime is the last time the HorizontalPodAutoscaler scaled the number of pods, used by the autoscaler to control how often the number of pods is changed.
             */
            lastScaleTime?: pulumi.Input<string>;
            /**
             * observedGeneration is the most recent generation observed by this autoscaler.
             */
            observedGeneration?: pulumi.Input<number>;
        }
        /**
         * MetricIdentifier defines the name and optionally selector for a metric
         */
        interface MetricIdentifier {
            /**
             * name is the name of the given metric
             */
            name: pulumi.Input<string>;
            /**
             * selector is the string-encoded form of a standard kubernetes label selector for the given metric When set, it is passed as an additional parameter to the metrics server for more specific metrics scoping. When unset, just the metricName will be used to gather metrics.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
        }
        /**
         * MetricIdentifier defines the name and optionally selector for a metric
         */
        interface MetricIdentifierPatch {
            /**
             * name is the name of the given metric
             */
            name?: pulumi.Input<string>;
            /**
             * selector is the string-encoded form of a standard kubernetes label selector for the given metric When set, it is passed as an additional parameter to the metrics server for more specific metrics scoping. When unset, just the metricName will be used to gather metrics.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
        }
        /**
         * MetricSpec specifies how to scale based on a single metric (only `type` and one other matching field should be set at once).
         */
        interface MetricSpec {
            /**
             * containerResource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing a single container in each pod of the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
             */
            containerResource?: pulumi.Input<inputs.autoscaling.v2.ContainerResourceMetricSource>;
            /**
             * external refers to a global metric that is not associated with any Kubernetes object. It allows autoscaling based on information coming from components running outside of cluster (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).
             */
            external?: pulumi.Input<inputs.autoscaling.v2.ExternalMetricSource>;
            /**
             * object refers to a metric describing a single kubernetes object (for example, hits-per-second on an Ingress object).
             */
            object?: pulumi.Input<inputs.autoscaling.v2.ObjectMetricSource>;
            /**
             * pods refers to a metric describing each pod in the current scale target (for example, transactions-processed-per-second).  The values will be averaged together before being compared to the target value.
             */
            pods?: pulumi.Input<inputs.autoscaling.v2.PodsMetricSource>;
            /**
             * resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
             */
            resource?: pulumi.Input<inputs.autoscaling.v2.ResourceMetricSource>;
            /**
             * type is the type of metric source.  It should be one of "ContainerResource", "External", "Object", "Pods" or "Resource", each mapping to a matching field in the object.
             */
            type: pulumi.Input<string>;
        }
        /**
         * MetricSpec specifies how to scale based on a single metric (only `type` and one other matching field should be set at once).
         */
        interface MetricSpecPatch {
            /**
             * containerResource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing a single container in each pod of the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
             */
            containerResource?: pulumi.Input<inputs.autoscaling.v2.ContainerResourceMetricSourcePatch>;
            /**
             * external refers to a global metric that is not associated with any Kubernetes object. It allows autoscaling based on information coming from components running outside of cluster (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).
             */
            external?: pulumi.Input<inputs.autoscaling.v2.ExternalMetricSourcePatch>;
            /**
             * object refers to a metric describing a single kubernetes object (for example, hits-per-second on an Ingress object).
             */
            object?: pulumi.Input<inputs.autoscaling.v2.ObjectMetricSourcePatch>;
            /**
             * pods refers to a metric describing each pod in the current scale target (for example, transactions-processed-per-second).  The values will be averaged together before being compared to the target value.
             */
            pods?: pulumi.Input<inputs.autoscaling.v2.PodsMetricSourcePatch>;
            /**
             * resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
             */
            resource?: pulumi.Input<inputs.autoscaling.v2.ResourceMetricSourcePatch>;
            /**
             * type is the type of metric source.  It should be one of "ContainerResource", "External", "Object", "Pods" or "Resource", each mapping to a matching field in the object.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * MetricStatus describes the last-read state of a single metric.
         */
        interface MetricStatus {
            /**
             * container resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing a single container in each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
             */
            containerResource?: pulumi.Input<inputs.autoscaling.v2.ContainerResourceMetricStatus>;
            /**
             * external refers to a global metric that is not associated with any Kubernetes object. It allows autoscaling based on information coming from components running outside of cluster (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).
             */
            external?: pulumi.Input<inputs.autoscaling.v2.ExternalMetricStatus>;
            /**
             * object refers to a metric describing a single kubernetes object (for example, hits-per-second on an Ingress object).
             */
            object?: pulumi.Input<inputs.autoscaling.v2.ObjectMetricStatus>;
            /**
             * pods refers to a metric describing each pod in the current scale target (for example, transactions-processed-per-second).  The values will be averaged together before being compared to the target value.
             */
            pods?: pulumi.Input<inputs.autoscaling.v2.PodsMetricStatus>;
            /**
             * resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
             */
            resource?: pulumi.Input<inputs.autoscaling.v2.ResourceMetricStatus>;
            /**
             * type is the type of metric source.  It will be one of "ContainerResource", "External", "Object", "Pods" or "Resource", each corresponds to a matching field in the object.
             */
            type: pulumi.Input<string>;
        }
        /**
         * MetricTarget defines the target value, average value, or average utilization of a specific metric
         */
        interface MetricTarget {
            /**
             * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. Currently only valid for Resource metric source type
             */
            averageUtilization?: pulumi.Input<number>;
            /**
             * averageValue is the target value of the average of the metric across all relevant pods (as a quantity)
             */
            averageValue?: pulumi.Input<string>;
            /**
             * type represents whether the metric type is Utilization, Value, or AverageValue
             */
            type: pulumi.Input<string>;
            /**
             * value is the target value of the metric (as a quantity).
             */
            value?: pulumi.Input<string>;
        }
        /**
         * MetricTarget defines the target value, average value, or average utilization of a specific metric
         */
        interface MetricTargetPatch {
            /**
             * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. Currently only valid for Resource metric source type
             */
            averageUtilization?: pulumi.Input<number>;
            /**
             * averageValue is the target value of the average of the metric across all relevant pods (as a quantity)
             */
            averageValue?: pulumi.Input<string>;
            /**
             * type represents whether the metric type is Utilization, Value, or AverageValue
             */
            type?: pulumi.Input<string>;
            /**
             * value is the target value of the metric (as a quantity).
             */
            value?: pulumi.Input<string>;
        }
        /**
         * MetricValueStatus holds the current value for a metric
         */
        interface MetricValueStatus {
            /**
             * currentAverageUtilization is the current value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
             */
            averageUtilization?: pulumi.Input<number>;
            /**
             * averageValue is the current value of the average of the metric across all relevant pods (as a quantity)
             */
            averageValue?: pulumi.Input<string>;
            /**
             * value is the current value of the metric (as a quantity).
             */
            value?: pulumi.Input<string>;
        }
        /**
         * ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).
         */
        interface ObjectMetricSource {
            /**
             * describedObject specifies the descriptions of a object,such as kind,name apiVersion
             */
            describedObject: pulumi.Input<inputs.autoscaling.v2.CrossVersionObjectReference>;
            /**
             * metric identifies the target metric by name and selector
             */
            metric: pulumi.Input<inputs.autoscaling.v2.MetricIdentifier>;
            /**
             * target specifies the target value for the given metric
             */
            target: pulumi.Input<inputs.autoscaling.v2.MetricTarget>;
        }
        /**
         * ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).
         */
        interface ObjectMetricSourcePatch {
            /**
             * describedObject specifies the descriptions of a object,such as kind,name apiVersion
             */
            describedObject?: pulumi.Input<inputs.autoscaling.v2.CrossVersionObjectReferencePatch>;
            /**
             * metric identifies the target metric by name and selector
             */
            metric?: pulumi.Input<inputs.autoscaling.v2.MetricIdentifierPatch>;
            /**
             * target specifies the target value for the given metric
             */
            target?: pulumi.Input<inputs.autoscaling.v2.MetricTargetPatch>;
        }
        /**
         * ObjectMetricStatus indicates the current value of a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).
         */
        interface ObjectMetricStatus {
            /**
             * current contains the current value for the given metric
             */
            current: pulumi.Input<inputs.autoscaling.v2.MetricValueStatus>;
            /**
             * DescribedObject specifies the descriptions of a object,such as kind,name apiVersion
             */
            describedObject: pulumi.Input<inputs.autoscaling.v2.CrossVersionObjectReference>;
            /**
             * metric identifies the target metric by name and selector
             */
            metric: pulumi.Input<inputs.autoscaling.v2.MetricIdentifier>;
        }
        /**
         * PodsMetricSource indicates how to scale on a metric describing each pod in the current scale target (for example, transactions-processed-per-second). The values will be averaged together before being compared to the target value.
         */
        interface PodsMetricSource {
            /**
             * metric identifies the target metric by name and selector
             */
            metric: pulumi.Input<inputs.autoscaling.v2.MetricIdentifier>;
            /**
             * target specifies the target value for the given metric
             */
            target: pulumi.Input<inputs.autoscaling.v2.MetricTarget>;
        }
        /**
         * PodsMetricSource indicates how to scale on a metric describing each pod in the current scale target (for example, transactions-processed-per-second). The values will be averaged together before being compared to the target value.
         */
        interface PodsMetricSourcePatch {
            /**
             * metric identifies the target metric by name and selector
             */
            metric?: pulumi.Input<inputs.autoscaling.v2.MetricIdentifierPatch>;
            /**
             * target specifies the target value for the given metric
             */
            target?: pulumi.Input<inputs.autoscaling.v2.MetricTargetPatch>;
        }
        /**
         * PodsMetricStatus indicates the current value of a metric describing each pod in the current scale target (for example, transactions-processed-per-second).
         */
        interface PodsMetricStatus {
            /**
             * current contains the current value for the given metric
             */
            current: pulumi.Input<inputs.autoscaling.v2.MetricValueStatus>;
            /**
             * metric identifies the target metric by name and selector
             */
            metric: pulumi.Input<inputs.autoscaling.v2.MetricIdentifier>;
        }
        /**
         * ResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.
         */
        interface ResourceMetricSource {
            /**
             * name is the name of the resource in question.
             */
            name: pulumi.Input<string>;
            /**
             * target specifies the target value for the given metric
             */
            target: pulumi.Input<inputs.autoscaling.v2.MetricTarget>;
        }
        /**
         * ResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.
         */
        interface ResourceMetricSourcePatch {
            /**
             * name is the name of the resource in question.
             */
            name?: pulumi.Input<string>;
            /**
             * target specifies the target value for the given metric
             */
            target?: pulumi.Input<inputs.autoscaling.v2.MetricTargetPatch>;
        }
        /**
         * ResourceMetricStatus indicates the current value of a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
         */
        interface ResourceMetricStatus {
            /**
             * current contains the current value for the given metric
             */
            current: pulumi.Input<inputs.autoscaling.v2.MetricValueStatus>;
            /**
             * name is the name of the resource in question.
             */
            name: pulumi.Input<string>;
        }
    }
    namespace v2beta1 {
        /**
         * ContainerResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.
         */
        interface ContainerResourceMetricSource {
            /**
             * container is the name of the container in the pods of the scaling target
             */
            container: pulumi.Input<string>;
            /**
             * name is the name of the resource in question.
             */
            name: pulumi.Input<string>;
            /**
             * targetAverageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
             */
            targetAverageUtilization?: pulumi.Input<number>;
            /**
             * targetAverageValue is the target value of the average of the resource metric across all relevant pods, as a raw value (instead of as a percentage of the request), similar to the "pods" metric source type.
             */
            targetAverageValue?: pulumi.Input<string>;
        }
        /**
         * ContainerResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.
         */
        interface ContainerResourceMetricSourcePatch {
            /**
             * container is the name of the container in the pods of the scaling target
             */
            container?: pulumi.Input<string>;
            /**
             * name is the name of the resource in question.
             */
            name?: pulumi.Input<string>;
            /**
             * targetAverageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
             */
            targetAverageUtilization?: pulumi.Input<number>;
            /**
             * targetAverageValue is the target value of the average of the resource metric across all relevant pods, as a raw value (instead of as a percentage of the request), similar to the "pods" metric source type.
             */
            targetAverageValue?: pulumi.Input<string>;
        }
        /**
         * ContainerResourceMetricStatus indicates the current value of a resource metric known to Kubernetes, as specified in requests and limits, describing a single container in each pod in the current scale target (e.g. CPU or memory).  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
         */
        interface ContainerResourceMetricStatus {
            /**
             * container is the name of the container in the pods of the scaling target
             */
            container: pulumi.Input<string>;
            /**
             * currentAverageUtilization is the current value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.  It will only be present if `targetAverageValue` was set in the corresponding metric specification.
             */
            currentAverageUtilization?: pulumi.Input<number>;
            /**
             * currentAverageValue is the current value of the average of the resource metric across all relevant pods, as a raw value (instead of as a percentage of the request), similar to the "pods" metric source type. It will always be set, regardless of the corresponding metric specification.
             */
            currentAverageValue: pulumi.Input<string>;
            /**
             * name is the name of the resource in question.
             */
            name: pulumi.Input<string>;
        }
        /**
         * CrossVersionObjectReference contains enough information to let you identify the referred resource.
         */
        interface CrossVersionObjectReference {
            /**
             * API version of the referent
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * Kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds"
             */
            kind: pulumi.Input<string>;
            /**
             * Name of the referent; More info: http://kubernetes.io/docs/user-guide/identifiers#names
             */
            name: pulumi.Input<string>;
        }
        /**
         * CrossVersionObjectReference contains enough information to let you identify the referred resource.
         */
        interface CrossVersionObjectReferencePatch {
            /**
             * API version of the referent
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * Kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds"
             */
            kind?: pulumi.Input<string>;
            /**
             * Name of the referent; More info: http://kubernetes.io/docs/user-guide/identifiers#names
             */
            name?: pulumi.Input<string>;
        }
        /**
         * ExternalMetricSource indicates how to scale on a metric not associated with any Kubernetes object (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster). Exactly one "target" type should be set.
         */
        interface ExternalMetricSource {
            /**
             * metricName is the name of the metric in question.
             */
            metricName: pulumi.Input<string>;
            /**
             * metricSelector is used to identify a specific time series within a given metric.
             */
            metricSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * targetAverageValue is the target per-pod value of global metric (as a quantity). Mutually exclusive with TargetValue.
             */
            targetAverageValue?: pulumi.Input<string>;
            /**
             * targetValue is the target value of the metric (as a quantity). Mutually exclusive with TargetAverageValue.
             */
            targetValue?: pulumi.Input<string>;
        }
        /**
         * ExternalMetricSource indicates how to scale on a metric not associated with any Kubernetes object (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster). Exactly one "target" type should be set.
         */
        interface ExternalMetricSourcePatch {
            /**
             * metricName is the name of the metric in question.
             */
            metricName?: pulumi.Input<string>;
            /**
             * metricSelector is used to identify a specific time series within a given metric.
             */
            metricSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * targetAverageValue is the target per-pod value of global metric (as a quantity). Mutually exclusive with TargetValue.
             */
            targetAverageValue?: pulumi.Input<string>;
            /**
             * targetValue is the target value of the metric (as a quantity). Mutually exclusive with TargetAverageValue.
             */
            targetValue?: pulumi.Input<string>;
        }
        /**
         * ExternalMetricStatus indicates the current value of a global metric not associated with any Kubernetes object.
         */
        interface ExternalMetricStatus {
            /**
             * currentAverageValue is the current value of metric averaged over autoscaled pods.
             */
            currentAverageValue?: pulumi.Input<string>;
            /**
             * currentValue is the current value of the metric (as a quantity)
             */
            currentValue: pulumi.Input<string>;
            /**
             * metricName is the name of a metric used for autoscaling in metric system.
             */
            metricName: pulumi.Input<string>;
            /**
             * metricSelector is used to identify a specific time series within a given metric.
             */
            metricSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
        }
        /**
         * HorizontalPodAutoscaler is the configuration for a horizontal pod autoscaler, which automatically manages the replica count of any resource implementing the scale subresource based on the metrics specified.
         */
        interface HorizontalPodAutoscaler {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"autoscaling/v2beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"HorizontalPodAutoscaler">;
            /**
             * metadata is the standard object metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec is the specification for the behaviour of the autoscaler. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status.
             */
            spec?: pulumi.Input<inputs.autoscaling.v2beta1.HorizontalPodAutoscalerSpec>;
            /**
             * status is the current information about the autoscaler.
             */
            status?: pulumi.Input<inputs.autoscaling.v2beta1.HorizontalPodAutoscalerStatus>;
        }
        /**
         * HorizontalPodAutoscalerCondition describes the state of a HorizontalPodAutoscaler at a certain point.
         */
        interface HorizontalPodAutoscalerCondition {
            /**
             * lastTransitionTime is the last time the condition transitioned from one status to another
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * message is a human-readable explanation containing details about the transition
             */
            message?: pulumi.Input<string>;
            /**
             * reason is the reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * status is the status of the condition (True, False, Unknown)
             */
            status: pulumi.Input<string>;
            /**
             * type describes the current condition
             */
            type: pulumi.Input<string>;
        }
        /**
         * HorizontalPodAutoscalerSpec describes the desired functionality of the HorizontalPodAutoscaler.
         */
        interface HorizontalPodAutoscalerSpec {
            /**
             * maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up. It cannot be less that minReplicas.
             */
            maxReplicas: pulumi.Input<number>;
            /**
             * metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used).  The desired replica count is calculated multiplying the ratio between the target value and the current value by the current number of pods.  Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond.
             */
            metrics?: pulumi.Input<pulumi.Input<inputs.autoscaling.v2beta1.MetricSpec>[]>;
            /**
             * minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available.
             */
            minReplicas?: pulumi.Input<number>;
            /**
             * scaleTargetRef points to the target resource to scale, and is used to the pods for which metrics should be collected, as well as to actually change the replica count.
             */
            scaleTargetRef: pulumi.Input<inputs.autoscaling.v2beta1.CrossVersionObjectReference>;
        }
        /**
         * HorizontalPodAutoscalerSpec describes the desired functionality of the HorizontalPodAutoscaler.
         */
        interface HorizontalPodAutoscalerSpecPatch {
            /**
             * maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up. It cannot be less that minReplicas.
             */
            maxReplicas?: pulumi.Input<number>;
            /**
             * metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used).  The desired replica count is calculated multiplying the ratio between the target value and the current value by the current number of pods.  Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond.
             */
            metrics?: pulumi.Input<pulumi.Input<inputs.autoscaling.v2beta1.MetricSpecPatch>[]>;
            /**
             * minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available.
             */
            minReplicas?: pulumi.Input<number>;
            /**
             * scaleTargetRef points to the target resource to scale, and is used to the pods for which metrics should be collected, as well as to actually change the replica count.
             */
            scaleTargetRef?: pulumi.Input<inputs.autoscaling.v2beta1.CrossVersionObjectReferencePatch>;
        }
        /**
         * HorizontalPodAutoscalerStatus describes the current status of a horizontal pod autoscaler.
         */
        interface HorizontalPodAutoscalerStatus {
            /**
             * conditions is the set of conditions required for this autoscaler to scale its target, and indicates whether or not those conditions are met.
             */
            conditions: pulumi.Input<pulumi.Input<inputs.autoscaling.v2beta1.HorizontalPodAutoscalerCondition>[]>;
            /**
             * currentMetrics is the last read state of the metrics used by this autoscaler.
             */
            currentMetrics?: pulumi.Input<pulumi.Input<inputs.autoscaling.v2beta1.MetricStatus>[]>;
            /**
             * currentReplicas is current number of replicas of pods managed by this autoscaler, as last seen by the autoscaler.
             */
            currentReplicas: pulumi.Input<number>;
            /**
             * desiredReplicas is the desired number of replicas of pods managed by this autoscaler, as last calculated by the autoscaler.
             */
            desiredReplicas: pulumi.Input<number>;
            /**
             * lastScaleTime is the last time the HorizontalPodAutoscaler scaled the number of pods, used by the autoscaler to control how often the number of pods is changed.
             */
            lastScaleTime?: pulumi.Input<string>;
            /**
             * observedGeneration is the most recent generation observed by this autoscaler.
             */
            observedGeneration?: pulumi.Input<number>;
        }
        /**
         * MetricSpec specifies how to scale based on a single metric (only `type` and one other matching field should be set at once).
         */
        interface MetricSpec {
            /**
             * container resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing a single container in each pod of the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. This is an alpha feature and can be enabled by the HPAContainerMetrics feature flag.
             */
            containerResource?: pulumi.Input<inputs.autoscaling.v2beta1.ContainerResourceMetricSource>;
            /**
             * external refers to a global metric that is not associated with any Kubernetes object. It allows autoscaling based on information coming from components running outside of cluster (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).
             */
            external?: pulumi.Input<inputs.autoscaling.v2beta1.ExternalMetricSource>;
            /**
             * object refers to a metric describing a single kubernetes object (for example, hits-per-second on an Ingress object).
             */
            object?: pulumi.Input<inputs.autoscaling.v2beta1.ObjectMetricSource>;
            /**
             * pods refers to a metric describing each pod in the current scale target (for example, transactions-processed-per-second).  The values will be averaged together before being compared to the target value.
             */
            pods?: pulumi.Input<inputs.autoscaling.v2beta1.PodsMetricSource>;
            /**
             * resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
             */
            resource?: pulumi.Input<inputs.autoscaling.v2beta1.ResourceMetricSource>;
            /**
             * type is the type of metric source.  It should be one of "Object", "Pods" or "Resource", each mapping to a matching field in the object.
             */
            type: pulumi.Input<string>;
        }
        /**
         * MetricSpec specifies how to scale based on a single metric (only `type` and one other matching field should be set at once).
         */
        interface MetricSpecPatch {
            /**
             * container resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing a single container in each pod of the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. This is an alpha feature and can be enabled by the HPAContainerMetrics feature flag.
             */
            containerResource?: pulumi.Input<inputs.autoscaling.v2beta1.ContainerResourceMetricSourcePatch>;
            /**
             * external refers to a global metric that is not associated with any Kubernetes object. It allows autoscaling based on information coming from components running outside of cluster (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).
             */
            external?: pulumi.Input<inputs.autoscaling.v2beta1.ExternalMetricSourcePatch>;
            /**
             * object refers to a metric describing a single kubernetes object (for example, hits-per-second on an Ingress object).
             */
            object?: pulumi.Input<inputs.autoscaling.v2beta1.ObjectMetricSourcePatch>;
            /**
             * pods refers to a metric describing each pod in the current scale target (for example, transactions-processed-per-second).  The values will be averaged together before being compared to the target value.
             */
            pods?: pulumi.Input<inputs.autoscaling.v2beta1.PodsMetricSourcePatch>;
            /**
             * resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
             */
            resource?: pulumi.Input<inputs.autoscaling.v2beta1.ResourceMetricSourcePatch>;
            /**
             * type is the type of metric source.  It should be one of "Object", "Pods" or "Resource", each mapping to a matching field in the object.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * MetricStatus describes the last-read state of a single metric.
         */
        interface MetricStatus {
            /**
             * container resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing a single container in each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
             */
            containerResource?: pulumi.Input<inputs.autoscaling.v2beta1.ContainerResourceMetricStatus>;
            /**
             * external refers to a global metric that is not associated with any Kubernetes object. It allows autoscaling based on information coming from components running outside of cluster (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).
             */
            external?: pulumi.Input<inputs.autoscaling.v2beta1.ExternalMetricStatus>;
            /**
             * object refers to a metric describing a single kubernetes object (for example, hits-per-second on an Ingress object).
             */
            object?: pulumi.Input<inputs.autoscaling.v2beta1.ObjectMetricStatus>;
            /**
             * pods refers to a metric describing each pod in the current scale target (for example, transactions-processed-per-second).  The values will be averaged together before being compared to the target value.
             */
            pods?: pulumi.Input<inputs.autoscaling.v2beta1.PodsMetricStatus>;
            /**
             * resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
             */
            resource?: pulumi.Input<inputs.autoscaling.v2beta1.ResourceMetricStatus>;
            /**
             * type is the type of metric source.  It will be one of "Object", "Pods" or "Resource", each corresponds to a matching field in the object.
             */
            type: pulumi.Input<string>;
        }
        /**
         * ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).
         */
        interface ObjectMetricSource {
            /**
             * averageValue is the target value of the average of the metric across all relevant pods (as a quantity)
             */
            averageValue?: pulumi.Input<string>;
            /**
             * metricName is the name of the metric in question.
             */
            metricName: pulumi.Input<string>;
            /**
             * selector is the string-encoded form of a standard kubernetes label selector for the given metric When set, it is passed as an additional parameter to the metrics server for more specific metrics scoping When unset, just the metricName will be used to gather metrics.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * target is the described Kubernetes object.
             */
            target: pulumi.Input<inputs.autoscaling.v2beta1.CrossVersionObjectReference>;
            /**
             * targetValue is the target value of the metric (as a quantity).
             */
            targetValue: pulumi.Input<string>;
        }
        /**
         * ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).
         */
        interface ObjectMetricSourcePatch {
            /**
             * averageValue is the target value of the average of the metric across all relevant pods (as a quantity)
             */
            averageValue?: pulumi.Input<string>;
            /**
             * metricName is the name of the metric in question.
             */
            metricName?: pulumi.Input<string>;
            /**
             * selector is the string-encoded form of a standard kubernetes label selector for the given metric When set, it is passed as an additional parameter to the metrics server for more specific metrics scoping When unset, just the metricName will be used to gather metrics.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * target is the described Kubernetes object.
             */
            target?: pulumi.Input<inputs.autoscaling.v2beta1.CrossVersionObjectReferencePatch>;
            /**
             * targetValue is the target value of the metric (as a quantity).
             */
            targetValue?: pulumi.Input<string>;
        }
        /**
         * ObjectMetricStatus indicates the current value of a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).
         */
        interface ObjectMetricStatus {
            /**
             * averageValue is the current value of the average of the metric across all relevant pods (as a quantity)
             */
            averageValue?: pulumi.Input<string>;
            /**
             * currentValue is the current value of the metric (as a quantity).
             */
            currentValue: pulumi.Input<string>;
            /**
             * metricName is the name of the metric in question.
             */
            metricName: pulumi.Input<string>;
            /**
             * selector is the string-encoded form of a standard kubernetes label selector for the given metric When set in the ObjectMetricSource, it is passed as an additional parameter to the metrics server for more specific metrics scoping. When unset, just the metricName will be used to gather metrics.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * target is the described Kubernetes object.
             */
            target: pulumi.Input<inputs.autoscaling.v2beta1.CrossVersionObjectReference>;
        }
        /**
         * PodsMetricSource indicates how to scale on a metric describing each pod in the current scale target (for example, transactions-processed-per-second). The values will be averaged together before being compared to the target value.
         */
        interface PodsMetricSource {
            /**
             * metricName is the name of the metric in question
             */
            metricName: pulumi.Input<string>;
            /**
             * selector is the string-encoded form of a standard kubernetes label selector for the given metric When set, it is passed as an additional parameter to the metrics server for more specific metrics scoping When unset, just the metricName will be used to gather metrics.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * targetAverageValue is the target value of the average of the metric across all relevant pods (as a quantity)
             */
            targetAverageValue: pulumi.Input<string>;
        }
        /**
         * PodsMetricSource indicates how to scale on a metric describing each pod in the current scale target (for example, transactions-processed-per-second). The values will be averaged together before being compared to the target value.
         */
        interface PodsMetricSourcePatch {
            /**
             * metricName is the name of the metric in question
             */
            metricName?: pulumi.Input<string>;
            /**
             * selector is the string-encoded form of a standard kubernetes label selector for the given metric When set, it is passed as an additional parameter to the metrics server for more specific metrics scoping When unset, just the metricName will be used to gather metrics.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * targetAverageValue is the target value of the average of the metric across all relevant pods (as a quantity)
             */
            targetAverageValue?: pulumi.Input<string>;
        }
        /**
         * PodsMetricStatus indicates the current value of a metric describing each pod in the current scale target (for example, transactions-processed-per-second).
         */
        interface PodsMetricStatus {
            /**
             * currentAverageValue is the current value of the average of the metric across all relevant pods (as a quantity)
             */
            currentAverageValue: pulumi.Input<string>;
            /**
             * metricName is the name of the metric in question
             */
            metricName: pulumi.Input<string>;
            /**
             * selector is the string-encoded form of a standard kubernetes label selector for the given metric When set in the PodsMetricSource, it is passed as an additional parameter to the metrics server for more specific metrics scoping. When unset, just the metricName will be used to gather metrics.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
        }
        /**
         * ResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.
         */
        interface ResourceMetricSource {
            /**
             * name is the name of the resource in question.
             */
            name: pulumi.Input<string>;
            /**
             * targetAverageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
             */
            targetAverageUtilization?: pulumi.Input<number>;
            /**
             * targetAverageValue is the target value of the average of the resource metric across all relevant pods, as a raw value (instead of as a percentage of the request), similar to the "pods" metric source type.
             */
            targetAverageValue?: pulumi.Input<string>;
        }
        /**
         * ResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.
         */
        interface ResourceMetricSourcePatch {
            /**
             * name is the name of the resource in question.
             */
            name?: pulumi.Input<string>;
            /**
             * targetAverageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
             */
            targetAverageUtilization?: pulumi.Input<number>;
            /**
             * targetAverageValue is the target value of the average of the resource metric across all relevant pods, as a raw value (instead of as a percentage of the request), similar to the "pods" metric source type.
             */
            targetAverageValue?: pulumi.Input<string>;
        }
        /**
         * ResourceMetricStatus indicates the current value of a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
         */
        interface ResourceMetricStatus {
            /**
             * currentAverageUtilization is the current value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.  It will only be present if `targetAverageValue` was set in the corresponding metric specification.
             */
            currentAverageUtilization?: pulumi.Input<number>;
            /**
             * currentAverageValue is the current value of the average of the resource metric across all relevant pods, as a raw value (instead of as a percentage of the request), similar to the "pods" metric source type. It will always be set, regardless of the corresponding metric specification.
             */
            currentAverageValue: pulumi.Input<string>;
            /**
             * name is the name of the resource in question.
             */
            name: pulumi.Input<string>;
        }
    }
    namespace v2beta2 {
        /**
         * ContainerResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.
         */
        interface ContainerResourceMetricSource {
            /**
             * container is the name of the container in the pods of the scaling target
             */
            container: pulumi.Input<string>;
            /**
             * name is the name of the resource in question.
             */
            name: pulumi.Input<string>;
            /**
             * target specifies the target value for the given metric
             */
            target: pulumi.Input<inputs.autoscaling.v2beta2.MetricTarget>;
        }
        /**
         * ContainerResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.
         */
        interface ContainerResourceMetricSourcePatch {
            /**
             * container is the name of the container in the pods of the scaling target
             */
            container?: pulumi.Input<string>;
            /**
             * name is the name of the resource in question.
             */
            name?: pulumi.Input<string>;
            /**
             * target specifies the target value for the given metric
             */
            target?: pulumi.Input<inputs.autoscaling.v2beta2.MetricTargetPatch>;
        }
        /**
         * ContainerResourceMetricStatus indicates the current value of a resource metric known to Kubernetes, as specified in requests and limits, describing a single container in each pod in the current scale target (e.g. CPU or memory).  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
         */
        interface ContainerResourceMetricStatus {
            /**
             * Container is the name of the container in the pods of the scaling target
             */
            container: pulumi.Input<string>;
            /**
             * current contains the current value for the given metric
             */
            current: pulumi.Input<inputs.autoscaling.v2beta2.MetricValueStatus>;
            /**
             * Name is the name of the resource in question.
             */
            name: pulumi.Input<string>;
        }
        /**
         * CrossVersionObjectReference contains enough information to let you identify the referred resource.
         */
        interface CrossVersionObjectReference {
            /**
             * API version of the referent
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * Kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds"
             */
            kind: pulumi.Input<string>;
            /**
             * Name of the referent; More info: http://kubernetes.io/docs/user-guide/identifiers#names
             */
            name: pulumi.Input<string>;
        }
        /**
         * CrossVersionObjectReference contains enough information to let you identify the referred resource.
         */
        interface CrossVersionObjectReferencePatch {
            /**
             * API version of the referent
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * Kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds"
             */
            kind?: pulumi.Input<string>;
            /**
             * Name of the referent; More info: http://kubernetes.io/docs/user-guide/identifiers#names
             */
            name?: pulumi.Input<string>;
        }
        /**
         * ExternalMetricSource indicates how to scale on a metric not associated with any Kubernetes object (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).
         */
        interface ExternalMetricSource {
            /**
             * metric identifies the target metric by name and selector
             */
            metric: pulumi.Input<inputs.autoscaling.v2beta2.MetricIdentifier>;
            /**
             * target specifies the target value for the given metric
             */
            target: pulumi.Input<inputs.autoscaling.v2beta2.MetricTarget>;
        }
        /**
         * ExternalMetricSource indicates how to scale on a metric not associated with any Kubernetes object (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).
         */
        interface ExternalMetricSourcePatch {
            /**
             * metric identifies the target metric by name and selector
             */
            metric?: pulumi.Input<inputs.autoscaling.v2beta2.MetricIdentifierPatch>;
            /**
             * target specifies the target value for the given metric
             */
            target?: pulumi.Input<inputs.autoscaling.v2beta2.MetricTargetPatch>;
        }
        /**
         * ExternalMetricStatus indicates the current value of a global metric not associated with any Kubernetes object.
         */
        interface ExternalMetricStatus {
            /**
             * current contains the current value for the given metric
             */
            current: pulumi.Input<inputs.autoscaling.v2beta2.MetricValueStatus>;
            /**
             * metric identifies the target metric by name and selector
             */
            metric: pulumi.Input<inputs.autoscaling.v2beta2.MetricIdentifier>;
        }
        /**
         * HPAScalingPolicy is a single policy which must hold true for a specified past interval.
         */
        interface HPAScalingPolicy {
            /**
             * PeriodSeconds specifies the window of time for which the policy should hold true. PeriodSeconds must be greater than zero and less than or equal to 1800 (30 min).
             */
            periodSeconds: pulumi.Input<number>;
            /**
             * Type is used to specify the scaling policy.
             */
            type: pulumi.Input<string>;
            /**
             * Value contains the amount of change which is permitted by the policy. It must be greater than zero
             */
            value: pulumi.Input<number>;
        }
        /**
         * HPAScalingPolicy is a single policy which must hold true for a specified past interval.
         */
        interface HPAScalingPolicyPatch {
            /**
             * PeriodSeconds specifies the window of time for which the policy should hold true. PeriodSeconds must be greater than zero and less than or equal to 1800 (30 min).
             */
            periodSeconds?: pulumi.Input<number>;
            /**
             * Type is used to specify the scaling policy.
             */
            type?: pulumi.Input<string>;
            /**
             * Value contains the amount of change which is permitted by the policy. It must be greater than zero
             */
            value?: pulumi.Input<number>;
        }
        /**
         * HPAScalingRules configures the scaling behavior for one direction. These Rules are applied after calculating DesiredReplicas from metrics for the HPA. They can limit the scaling velocity by specifying scaling policies. They can prevent flapping by specifying the stabilization window, so that the number of replicas is not set instantly, instead, the safest value from the stabilization window is chosen.
         */
        interface HPAScalingRules {
            /**
             * policies is a list of potential scaling polices which can be used during scaling. At least one policy must be specified, otherwise the HPAScalingRules will be discarded as invalid
             */
            policies?: pulumi.Input<pulumi.Input<inputs.autoscaling.v2beta2.HPAScalingPolicy>[]>;
            /**
             * selectPolicy is used to specify which policy should be used. If not set, the default value MaxPolicySelect is used.
             */
            selectPolicy?: pulumi.Input<string>;
            /**
             * StabilizationWindowSeconds is the number of seconds for which past recommendations should be considered while scaling up or scaling down. StabilizationWindowSeconds must be greater than or equal to zero and less than or equal to 3600 (one hour). If not set, use the default values: - For scale up: 0 (i.e. no stabilization is done). - For scale down: 300 (i.e. the stabilization window is 300 seconds long).
             */
            stabilizationWindowSeconds?: pulumi.Input<number>;
        }
        /**
         * HPAScalingRules configures the scaling behavior for one direction. These Rules are applied after calculating DesiredReplicas from metrics for the HPA. They can limit the scaling velocity by specifying scaling policies. They can prevent flapping by specifying the stabilization window, so that the number of replicas is not set instantly, instead, the safest value from the stabilization window is chosen.
         */
        interface HPAScalingRulesPatch {
            /**
             * policies is a list of potential scaling polices which can be used during scaling. At least one policy must be specified, otherwise the HPAScalingRules will be discarded as invalid
             */
            policies?: pulumi.Input<pulumi.Input<inputs.autoscaling.v2beta2.HPAScalingPolicyPatch>[]>;
            /**
             * selectPolicy is used to specify which policy should be used. If not set, the default value MaxPolicySelect is used.
             */
            selectPolicy?: pulumi.Input<string>;
            /**
             * StabilizationWindowSeconds is the number of seconds for which past recommendations should be considered while scaling up or scaling down. StabilizationWindowSeconds must be greater than or equal to zero and less than or equal to 3600 (one hour). If not set, use the default values: - For scale up: 0 (i.e. no stabilization is done). - For scale down: 300 (i.e. the stabilization window is 300 seconds long).
             */
            stabilizationWindowSeconds?: pulumi.Input<number>;
        }
        /**
         * HorizontalPodAutoscaler is the configuration for a horizontal pod autoscaler, which automatically manages the replica count of any resource implementing the scale subresource based on the metrics specified.
         */
        interface HorizontalPodAutoscaler {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"autoscaling/v2beta2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"HorizontalPodAutoscaler">;
            /**
             * metadata is the standard object metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec is the specification for the behaviour of the autoscaler. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status.
             */
            spec?: pulumi.Input<inputs.autoscaling.v2beta2.HorizontalPodAutoscalerSpec>;
            /**
             * status is the current information about the autoscaler.
             */
            status?: pulumi.Input<inputs.autoscaling.v2beta2.HorizontalPodAutoscalerStatus>;
        }
        /**
         * HorizontalPodAutoscalerBehavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively).
         */
        interface HorizontalPodAutoscalerBehavior {
            /**
             * scaleDown is scaling policy for scaling Down. If not set, the default value is to allow to scale down to minReplicas pods, with a 300 second stabilization window (i.e., the highest recommendation for the last 300sec is used).
             */
            scaleDown?: pulumi.Input<inputs.autoscaling.v2beta2.HPAScalingRules>;
            /**
             * scaleUp is scaling policy for scaling Up. If not set, the default value is the higher of:
             *   * increase no more than 4 pods per 60 seconds
             *   * double the number of pods per 60 seconds
             * No stabilization is used.
             */
            scaleUp?: pulumi.Input<inputs.autoscaling.v2beta2.HPAScalingRules>;
        }
        /**
         * HorizontalPodAutoscalerBehavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively).
         */
        interface HorizontalPodAutoscalerBehaviorPatch {
            /**
             * scaleDown is scaling policy for scaling Down. If not set, the default value is to allow to scale down to minReplicas pods, with a 300 second stabilization window (i.e., the highest recommendation for the last 300sec is used).
             */
            scaleDown?: pulumi.Input<inputs.autoscaling.v2beta2.HPAScalingRulesPatch>;
            /**
             * scaleUp is scaling policy for scaling Up. If not set, the default value is the higher of:
             *   * increase no more than 4 pods per 60 seconds
             *   * double the number of pods per 60 seconds
             * No stabilization is used.
             */
            scaleUp?: pulumi.Input<inputs.autoscaling.v2beta2.HPAScalingRulesPatch>;
        }
        /**
         * HorizontalPodAutoscalerCondition describes the state of a HorizontalPodAutoscaler at a certain point.
         */
        interface HorizontalPodAutoscalerCondition {
            /**
             * lastTransitionTime is the last time the condition transitioned from one status to another
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * message is a human-readable explanation containing details about the transition
             */
            message?: pulumi.Input<string>;
            /**
             * reason is the reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * status is the status of the condition (True, False, Unknown)
             */
            status: pulumi.Input<string>;
            /**
             * type describes the current condition
             */
            type: pulumi.Input<string>;
        }
        /**
         * HorizontalPodAutoscalerSpec describes the desired functionality of the HorizontalPodAutoscaler.
         */
        interface HorizontalPodAutoscalerSpec {
            /**
             * behavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively). If not set, the default HPAScalingRules for scale up and scale down are used.
             */
            behavior?: pulumi.Input<inputs.autoscaling.v2beta2.HorizontalPodAutoscalerBehavior>;
            /**
             * maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up. It cannot be less that minReplicas.
             */
            maxReplicas: pulumi.Input<number>;
            /**
             * metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used).  The desired replica count is calculated multiplying the ratio between the target value and the current value by the current number of pods.  Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond. If not set, the default metric will be set to 80% average CPU utilization.
             */
            metrics?: pulumi.Input<pulumi.Input<inputs.autoscaling.v2beta2.MetricSpec>[]>;
            /**
             * minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available.
             */
            minReplicas?: pulumi.Input<number>;
            /**
             * scaleTargetRef points to the target resource to scale, and is used to the pods for which metrics should be collected, as well as to actually change the replica count.
             */
            scaleTargetRef: pulumi.Input<inputs.autoscaling.v2beta2.CrossVersionObjectReference>;
        }
        /**
         * HorizontalPodAutoscalerSpec describes the desired functionality of the HorizontalPodAutoscaler.
         */
        interface HorizontalPodAutoscalerSpecPatch {
            /**
             * behavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively). If not set, the default HPAScalingRules for scale up and scale down are used.
             */
            behavior?: pulumi.Input<inputs.autoscaling.v2beta2.HorizontalPodAutoscalerBehaviorPatch>;
            /**
             * maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up. It cannot be less that minReplicas.
             */
            maxReplicas?: pulumi.Input<number>;
            /**
             * metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used).  The desired replica count is calculated multiplying the ratio between the target value and the current value by the current number of pods.  Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond. If not set, the default metric will be set to 80% average CPU utilization.
             */
            metrics?: pulumi.Input<pulumi.Input<inputs.autoscaling.v2beta2.MetricSpecPatch>[]>;
            /**
             * minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available.
             */
            minReplicas?: pulumi.Input<number>;
            /**
             * scaleTargetRef points to the target resource to scale, and is used to the pods for which metrics should be collected, as well as to actually change the replica count.
             */
            scaleTargetRef?: pulumi.Input<inputs.autoscaling.v2beta2.CrossVersionObjectReferencePatch>;
        }
        /**
         * HorizontalPodAutoscalerStatus describes the current status of a horizontal pod autoscaler.
         */
        interface HorizontalPodAutoscalerStatus {
            /**
             * conditions is the set of conditions required for this autoscaler to scale its target, and indicates whether or not those conditions are met.
             */
            conditions: pulumi.Input<pulumi.Input<inputs.autoscaling.v2beta2.HorizontalPodAutoscalerCondition>[]>;
            /**
             * currentMetrics is the last read state of the metrics used by this autoscaler.
             */
            currentMetrics?: pulumi.Input<pulumi.Input<inputs.autoscaling.v2beta2.MetricStatus>[]>;
            /**
             * currentReplicas is current number of replicas of pods managed by this autoscaler, as last seen by the autoscaler.
             */
            currentReplicas: pulumi.Input<number>;
            /**
             * desiredReplicas is the desired number of replicas of pods managed by this autoscaler, as last calculated by the autoscaler.
             */
            desiredReplicas: pulumi.Input<number>;
            /**
             * lastScaleTime is the last time the HorizontalPodAutoscaler scaled the number of pods, used by the autoscaler to control how often the number of pods is changed.
             */
            lastScaleTime?: pulumi.Input<string>;
            /**
             * observedGeneration is the most recent generation observed by this autoscaler.
             */
            observedGeneration?: pulumi.Input<number>;
        }
        /**
         * MetricIdentifier defines the name and optionally selector for a metric
         */
        interface MetricIdentifier {
            /**
             * name is the name of the given metric
             */
            name: pulumi.Input<string>;
            /**
             * selector is the string-encoded form of a standard kubernetes label selector for the given metric When set, it is passed as an additional parameter to the metrics server for more specific metrics scoping. When unset, just the metricName will be used to gather metrics.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
        }
        /**
         * MetricIdentifier defines the name and optionally selector for a metric
         */
        interface MetricIdentifierPatch {
            /**
             * name is the name of the given metric
             */
            name?: pulumi.Input<string>;
            /**
             * selector is the string-encoded form of a standard kubernetes label selector for the given metric When set, it is passed as an additional parameter to the metrics server for more specific metrics scoping. When unset, just the metricName will be used to gather metrics.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
        }
        /**
         * MetricSpec specifies how to scale based on a single metric (only `type` and one other matching field should be set at once).
         */
        interface MetricSpec {
            /**
             * container resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing a single container in each pod of the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. This is an alpha feature and can be enabled by the HPAContainerMetrics feature flag.
             */
            containerResource?: pulumi.Input<inputs.autoscaling.v2beta2.ContainerResourceMetricSource>;
            /**
             * external refers to a global metric that is not associated with any Kubernetes object. It allows autoscaling based on information coming from components running outside of cluster (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).
             */
            external?: pulumi.Input<inputs.autoscaling.v2beta2.ExternalMetricSource>;
            /**
             * object refers to a metric describing a single kubernetes object (for example, hits-per-second on an Ingress object).
             */
            object?: pulumi.Input<inputs.autoscaling.v2beta2.ObjectMetricSource>;
            /**
             * pods refers to a metric describing each pod in the current scale target (for example, transactions-processed-per-second).  The values will be averaged together before being compared to the target value.
             */
            pods?: pulumi.Input<inputs.autoscaling.v2beta2.PodsMetricSource>;
            /**
             * resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
             */
            resource?: pulumi.Input<inputs.autoscaling.v2beta2.ResourceMetricSource>;
            /**
             * type is the type of metric source.  It should be one of "Object", "Pods" or "Resource", each mapping to a matching field in the object.
             */
            type: pulumi.Input<string>;
        }
        /**
         * MetricSpec specifies how to scale based on a single metric (only `type` and one other matching field should be set at once).
         */
        interface MetricSpecPatch {
            /**
             * container resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing a single container in each pod of the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. This is an alpha feature and can be enabled by the HPAContainerMetrics feature flag.
             */
            containerResource?: pulumi.Input<inputs.autoscaling.v2beta2.ContainerResourceMetricSourcePatch>;
            /**
             * external refers to a global metric that is not associated with any Kubernetes object. It allows autoscaling based on information coming from components running outside of cluster (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).
             */
            external?: pulumi.Input<inputs.autoscaling.v2beta2.ExternalMetricSourcePatch>;
            /**
             * object refers to a metric describing a single kubernetes object (for example, hits-per-second on an Ingress object).
             */
            object?: pulumi.Input<inputs.autoscaling.v2beta2.ObjectMetricSourcePatch>;
            /**
             * pods refers to a metric describing each pod in the current scale target (for example, transactions-processed-per-second).  The values will be averaged together before being compared to the target value.
             */
            pods?: pulumi.Input<inputs.autoscaling.v2beta2.PodsMetricSourcePatch>;
            /**
             * resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
             */
            resource?: pulumi.Input<inputs.autoscaling.v2beta2.ResourceMetricSourcePatch>;
            /**
             * type is the type of metric source.  It should be one of "Object", "Pods" or "Resource", each mapping to a matching field in the object.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * MetricStatus describes the last-read state of a single metric.
         */
        interface MetricStatus {
            /**
             * container resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing a single container in each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
             */
            containerResource?: pulumi.Input<inputs.autoscaling.v2beta2.ContainerResourceMetricStatus>;
            /**
             * external refers to a global metric that is not associated with any Kubernetes object. It allows autoscaling based on information coming from components running outside of cluster (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).
             */
            external?: pulumi.Input<inputs.autoscaling.v2beta2.ExternalMetricStatus>;
            /**
             * object refers to a metric describing a single kubernetes object (for example, hits-per-second on an Ingress object).
             */
            object?: pulumi.Input<inputs.autoscaling.v2beta2.ObjectMetricStatus>;
            /**
             * pods refers to a metric describing each pod in the current scale target (for example, transactions-processed-per-second).  The values will be averaged together before being compared to the target value.
             */
            pods?: pulumi.Input<inputs.autoscaling.v2beta2.PodsMetricStatus>;
            /**
             * resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
             */
            resource?: pulumi.Input<inputs.autoscaling.v2beta2.ResourceMetricStatus>;
            /**
             * type is the type of metric source.  It will be one of "Object", "Pods" or "Resource", each corresponds to a matching field in the object.
             */
            type: pulumi.Input<string>;
        }
        /**
         * MetricTarget defines the target value, average value, or average utilization of a specific metric
         */
        interface MetricTarget {
            /**
             * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. Currently only valid for Resource metric source type
             */
            averageUtilization?: pulumi.Input<number>;
            /**
             * averageValue is the target value of the average of the metric across all relevant pods (as a quantity)
             */
            averageValue?: pulumi.Input<string>;
            /**
             * type represents whether the metric type is Utilization, Value, or AverageValue
             */
            type: pulumi.Input<string>;
            /**
             * value is the target value of the metric (as a quantity).
             */
            value?: pulumi.Input<string>;
        }
        /**
         * MetricTarget defines the target value, average value, or average utilization of a specific metric
         */
        interface MetricTargetPatch {
            /**
             * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. Currently only valid for Resource metric source type
             */
            averageUtilization?: pulumi.Input<number>;
            /**
             * averageValue is the target value of the average of the metric across all relevant pods (as a quantity)
             */
            averageValue?: pulumi.Input<string>;
            /**
             * type represents whether the metric type is Utilization, Value, or AverageValue
             */
            type?: pulumi.Input<string>;
            /**
             * value is the target value of the metric (as a quantity).
             */
            value?: pulumi.Input<string>;
        }
        /**
         * MetricValueStatus holds the current value for a metric
         */
        interface MetricValueStatus {
            /**
             * currentAverageUtilization is the current value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
             */
            averageUtilization?: pulumi.Input<number>;
            /**
             * averageValue is the current value of the average of the metric across all relevant pods (as a quantity)
             */
            averageValue?: pulumi.Input<string>;
            /**
             * value is the current value of the metric (as a quantity).
             */
            value?: pulumi.Input<string>;
        }
        /**
         * ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).
         */
        interface ObjectMetricSource {
            describedObject: pulumi.Input<inputs.autoscaling.v2beta2.CrossVersionObjectReference>;
            /**
             * metric identifies the target metric by name and selector
             */
            metric: pulumi.Input<inputs.autoscaling.v2beta2.MetricIdentifier>;
            /**
             * target specifies the target value for the given metric
             */
            target: pulumi.Input<inputs.autoscaling.v2beta2.MetricTarget>;
        }
        /**
         * ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).
         */
        interface ObjectMetricSourcePatch {
            describedObject?: pulumi.Input<inputs.autoscaling.v2beta2.CrossVersionObjectReferencePatch>;
            /**
             * metric identifies the target metric by name and selector
             */
            metric?: pulumi.Input<inputs.autoscaling.v2beta2.MetricIdentifierPatch>;
            /**
             * target specifies the target value for the given metric
             */
            target?: pulumi.Input<inputs.autoscaling.v2beta2.MetricTargetPatch>;
        }
        /**
         * ObjectMetricStatus indicates the current value of a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).
         */
        interface ObjectMetricStatus {
            /**
             * current contains the current value for the given metric
             */
            current: pulumi.Input<inputs.autoscaling.v2beta2.MetricValueStatus>;
            describedObject: pulumi.Input<inputs.autoscaling.v2beta2.CrossVersionObjectReference>;
            /**
             * metric identifies the target metric by name and selector
             */
            metric: pulumi.Input<inputs.autoscaling.v2beta2.MetricIdentifier>;
        }
        /**
         * PodsMetricSource indicates how to scale on a metric describing each pod in the current scale target (for example, transactions-processed-per-second). The values will be averaged together before being compared to the target value.
         */
        interface PodsMetricSource {
            /**
             * metric identifies the target metric by name and selector
             */
            metric: pulumi.Input<inputs.autoscaling.v2beta2.MetricIdentifier>;
            /**
             * target specifies the target value for the given metric
             */
            target: pulumi.Input<inputs.autoscaling.v2beta2.MetricTarget>;
        }
        /**
         * PodsMetricSource indicates how to scale on a metric describing each pod in the current scale target (for example, transactions-processed-per-second). The values will be averaged together before being compared to the target value.
         */
        interface PodsMetricSourcePatch {
            /**
             * metric identifies the target metric by name and selector
             */
            metric?: pulumi.Input<inputs.autoscaling.v2beta2.MetricIdentifierPatch>;
            /**
             * target specifies the target value for the given metric
             */
            target?: pulumi.Input<inputs.autoscaling.v2beta2.MetricTargetPatch>;
        }
        /**
         * PodsMetricStatus indicates the current value of a metric describing each pod in the current scale target (for example, transactions-processed-per-second).
         */
        interface PodsMetricStatus {
            /**
             * current contains the current value for the given metric
             */
            current: pulumi.Input<inputs.autoscaling.v2beta2.MetricValueStatus>;
            /**
             * metric identifies the target metric by name and selector
             */
            metric: pulumi.Input<inputs.autoscaling.v2beta2.MetricIdentifier>;
        }
        /**
         * ResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.
         */
        interface ResourceMetricSource {
            /**
             * name is the name of the resource in question.
             */
            name: pulumi.Input<string>;
            /**
             * target specifies the target value for the given metric
             */
            target: pulumi.Input<inputs.autoscaling.v2beta2.MetricTarget>;
        }
        /**
         * ResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.
         */
        interface ResourceMetricSourcePatch {
            /**
             * name is the name of the resource in question.
             */
            name?: pulumi.Input<string>;
            /**
             * target specifies the target value for the given metric
             */
            target?: pulumi.Input<inputs.autoscaling.v2beta2.MetricTargetPatch>;
        }
        /**
         * ResourceMetricStatus indicates the current value of a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
         */
        interface ResourceMetricStatus {
            /**
             * current contains the current value for the given metric
             */
            current: pulumi.Input<inputs.autoscaling.v2beta2.MetricValueStatus>;
            /**
             * Name is the name of the resource in question.
             */
            name: pulumi.Input<string>;
        }
    }
}
export declare namespace batch {
    namespace v1 {
        /**
         * CronJob represents the configuration of a single cron job.
         */
        interface CronJob {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"batch/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"CronJob">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of a cron job, including the schedule. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.batch.v1.CronJobSpec>;
            /**
             * Current status of a cron job. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.batch.v1.CronJobStatus>;
        }
        /**
         * CronJobSpec describes how the job execution will look like and when it will actually run.
         */
        interface CronJobSpec {
            /**
             * Specifies how to treat concurrent executions of a Job. Valid values are:
             *
             * - "Allow" (default): allows CronJobs to run concurrently; - "Forbid": forbids concurrent runs, skipping next run if previous run hasn't finished yet; - "Replace": cancels currently running job and replaces it with a new one
             */
            concurrencyPolicy?: pulumi.Input<string>;
            /**
             * The number of failed finished jobs to retain. Value must be non-negative integer. Defaults to 1.
             */
            failedJobsHistoryLimit?: pulumi.Input<number>;
            /**
             * Specifies the job that will be created when executing a CronJob.
             */
            jobTemplate: pulumi.Input<inputs.batch.v1.JobTemplateSpec>;
            /**
             * The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron.
             */
            schedule: pulumi.Input<string>;
            /**
             * Optional deadline in seconds for starting the job if it misses scheduled time for any reason.  Missed jobs executions will be counted as failed ones.
             */
            startingDeadlineSeconds?: pulumi.Input<number>;
            /**
             * The number of successful finished jobs to retain. Value must be non-negative integer. Defaults to 3.
             */
            successfulJobsHistoryLimit?: pulumi.Input<number>;
            /**
             * This flag tells the controller to suspend subsequent executions, it does not apply to already started executions.  Defaults to false.
             */
            suspend?: pulumi.Input<boolean>;
            /**
             * The time zone name for the given schedule, see https://en.wikipedia.org/wiki/List_of_tz_database_time_zones. If not specified, this will default to the time zone of the kube-controller-manager process. The set of valid time zone names and the time zone offset is loaded from the system-wide time zone database by the API server during CronJob validation and the controller manager during execution. If no system-wide time zone database can be found a bundled version of the database is used instead. If the time zone name becomes invalid during the lifetime of a CronJob or due to a change in host configuration, the controller will stop creating new new Jobs and will create a system event with the reason UnknownTimeZone. More information can be found in https://kubernetes.io/docs/concepts/workloads/controllers/cron-jobs/#time-zones
             */
            timeZone?: pulumi.Input<string>;
        }
        /**
         * CronJobSpec describes how the job execution will look like and when it will actually run.
         */
        interface CronJobSpecPatch {
            /**
             * Specifies how to treat concurrent executions of a Job. Valid values are:
             *
             * - "Allow" (default): allows CronJobs to run concurrently; - "Forbid": forbids concurrent runs, skipping next run if previous run hasn't finished yet; - "Replace": cancels currently running job and replaces it with a new one
             */
            concurrencyPolicy?: pulumi.Input<string>;
            /**
             * The number of failed finished jobs to retain. Value must be non-negative integer. Defaults to 1.
             */
            failedJobsHistoryLimit?: pulumi.Input<number>;
            /**
             * Specifies the job that will be created when executing a CronJob.
             */
            jobTemplate?: pulumi.Input<inputs.batch.v1.JobTemplateSpecPatch>;
            /**
             * The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron.
             */
            schedule?: pulumi.Input<string>;
            /**
             * Optional deadline in seconds for starting the job if it misses scheduled time for any reason.  Missed jobs executions will be counted as failed ones.
             */
            startingDeadlineSeconds?: pulumi.Input<number>;
            /**
             * The number of successful finished jobs to retain. Value must be non-negative integer. Defaults to 3.
             */
            successfulJobsHistoryLimit?: pulumi.Input<number>;
            /**
             * This flag tells the controller to suspend subsequent executions, it does not apply to already started executions.  Defaults to false.
             */
            suspend?: pulumi.Input<boolean>;
            /**
             * The time zone name for the given schedule, see https://en.wikipedia.org/wiki/List_of_tz_database_time_zones. If not specified, this will default to the time zone of the kube-controller-manager process. The set of valid time zone names and the time zone offset is loaded from the system-wide time zone database by the API server during CronJob validation and the controller manager during execution. If no system-wide time zone database can be found a bundled version of the database is used instead. If the time zone name becomes invalid during the lifetime of a CronJob or due to a change in host configuration, the controller will stop creating new new Jobs and will create a system event with the reason UnknownTimeZone. More information can be found in https://kubernetes.io/docs/concepts/workloads/controllers/cron-jobs/#time-zones
             */
            timeZone?: pulumi.Input<string>;
        }
        /**
         * CronJobStatus represents the current state of a cron job.
         */
        interface CronJobStatus {
            /**
             * A list of pointers to currently running jobs.
             */
            active?: pulumi.Input<pulumi.Input<inputs.core.v1.ObjectReference>[]>;
            /**
             * Information when was the last time the job was successfully scheduled.
             */
            lastScheduleTime?: pulumi.Input<string>;
            /**
             * Information when was the last time the job successfully completed.
             */
            lastSuccessfulTime?: pulumi.Input<string>;
        }
        /**
         * Job represents the configuration of a single job.
         *
         * This resource waits until its status is ready before registering success
         * for create/update, and populating output properties from the current state of the resource.
         * The following conditions are used to determine whether the resource creation has
         * succeeded or failed:
         *
         * 1. The Job's '.status.startTime' is set, which indicates that the Job has started running.
         * 2. The Job's '.status.conditions' has a status of type 'Complete', and a 'status' set
         *    to 'True'.
         * 3. The Job's '.status.conditions' do not have a status of type 'Failed', with a
         * 	'status' set to 'True'. If this condition is set, we should fail the Job immediately.
         *
         * If the Job has not reached a Ready state after 10 minutes, it will
         * time out and mark the resource update as Failed. You can override the default timeout value
         * by setting the 'customTimeouts' option on the resource.
         *
         * By default, if a resource failed to become ready in a previous update,
         * Pulumi will continue to wait for readiness on the next update. If you would prefer
         * to schedule a replacement for an unready resource on the next update, you can add the
         * "pulumi.com/replaceUnready": "true" annotation to the resource definition.
         */
        interface Job {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"batch/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Job">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of a job. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.batch.v1.JobSpec>;
            /**
             * Current status of a job. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.batch.v1.JobStatus>;
        }
        /**
         * JobCondition describes current state of a job.
         */
        interface JobCondition {
            /**
             * Last time the condition was checked.
             */
            lastProbeTime?: pulumi.Input<string>;
            /**
             * Last time the condition transit from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * Human readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * (brief) reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of job condition, Complete or Failed.
             */
            type: pulumi.Input<string>;
        }
        /**
         * JobSpec describes how the job execution will look like.
         */
        interface JobSpec {
            /**
             * Specifies the duration in seconds relative to the startTime that the job may be continuously active before the system tries to terminate it; value must be positive integer. If a Job is suspended (at creation or through an update), this timer will effectively be stopped and reset when the Job is resumed again.
             */
            activeDeadlineSeconds?: pulumi.Input<number>;
            /**
             * Specifies the number of retries before marking this job failed. Defaults to 6
             */
            backoffLimit?: pulumi.Input<number>;
            /**
             * Specifies the limit for the number of retries within an index before marking this index as failed. When enabled the number of failures per index is kept in the pod's batch.kubernetes.io/job-index-failure-count annotation. It can only be set when Job's completionMode=Indexed, and the Pod's restart policy is Never. The field is immutable.
             */
            backoffLimitPerIndex?: pulumi.Input<number>;
            /**
             * completionMode specifies how Pod completions are tracked. It can be `NonIndexed` (default) or `Indexed`.
             *
             * `NonIndexed` means that the Job is considered complete when there have been .spec.completions successfully completed Pods. Each Pod completion is homologous to each other.
             *
             * `Indexed` means that the Pods of a Job get an associated completion index from 0 to (.spec.completions - 1), available in the annotation batch.kubernetes.io/job-completion-index. The Job is considered complete when there is one successfully completed Pod for each index. When value is `Indexed`, .spec.completions must be specified and `.spec.parallelism` must be less than or equal to 10^5. In addition, The Pod name takes the form `$(job-name)-$(index)-$(random-string)`, the Pod hostname takes the form `$(job-name)-$(index)`.
             *
             * More completion modes can be added in the future. If the Job controller observes a mode that it doesn't recognize, which is possible during upgrades due to version skew, the controller skips updates for the Job.
             */
            completionMode?: pulumi.Input<string>;
            /**
             * Specifies the desired number of successfully finished pods the job should be run with.  Setting to null means that the success of any pod signals the success of all pods, and allows parallelism to have any positive value.  Setting to 1 means that parallelism is limited to 1 and the success of that pod signals the success of the job. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/
             */
            completions?: pulumi.Input<number>;
            /**
             * ManagedBy field indicates the controller that manages a Job. The k8s Job controller reconciles jobs which don't have this field at all or the field value is the reserved string `kubernetes.io/job-controller`, but skips reconciling Jobs with a custom value for this field. The value must be a valid domain-prefixed path (e.g. acme.io/foo) - all characters before the first "/" must be a valid subdomain as defined by RFC 1123. All characters trailing the first "/" must be valid HTTP Path characters as defined by RFC 3986. The value cannot exceed 63 characters. This field is immutable.
             *
             * This field is beta-level. The job controller accepts setting the field when the feature gate JobManagedBy is enabled (enabled by default).
             */
            managedBy?: pulumi.Input<string>;
            /**
             * manualSelector controls generation of pod labels and pod selectors. Leave `manualSelector` unset unless you are certain what you are doing. When false or unset, the system pick labels unique to this job and appends those labels to the pod template.  When true, the user is responsible for picking unique labels and specifying the selector.  Failure to pick a unique label may cause this and other jobs to not function correctly.  However, You may see `manualSelector=true` in jobs that were created with the old `extensions/v1beta1` API. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/#specifying-your-own-pod-selector
             */
            manualSelector?: pulumi.Input<boolean>;
            /**
             * Specifies the maximal number of failed indexes before marking the Job as failed, when backoffLimitPerIndex is set. Once the number of failed indexes exceeds this number the entire Job is marked as Failed and its execution is terminated. When left as null the job continues execution of all of its indexes and is marked with the `Complete` Job condition. It can only be specified when backoffLimitPerIndex is set. It can be null or up to completions. It is required and must be less than or equal to 10^4 when is completions greater than 10^5.
             */
            maxFailedIndexes?: pulumi.Input<number>;
            /**
             * Specifies the maximum desired number of pods the job should run at any given time. The actual number of pods running in steady state will be less than this number when ((.spec.completions - .status.successful) < .spec.parallelism), i.e. when the work left to do is less than max parallelism. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/
             */
            parallelism?: pulumi.Input<number>;
            /**
             * Specifies the policy of handling failed pods. In particular, it allows to specify the set of actions and conditions which need to be satisfied to take the associated action. If empty, the default behaviour applies - the counter of failed pods, represented by the jobs's .status.failed field, is incremented and it is checked against the backoffLimit. This field cannot be used in combination with restartPolicy=OnFailure.
             */
            podFailurePolicy?: pulumi.Input<inputs.batch.v1.PodFailurePolicy>;
            /**
             * podReplacementPolicy specifies when to create replacement Pods. Possible values are: - TerminatingOrFailed means that we recreate pods
             *   when they are terminating (has a metadata.deletionTimestamp) or failed.
             * - Failed means to wait until a previously created Pod is fully terminated (has phase
             *   Failed or Succeeded) before creating a replacement Pod.
             *
             * When using podFailurePolicy, Failed is the the only allowed value. TerminatingOrFailed and Failed are allowed values when podFailurePolicy is not in use. This is an beta field. To use this, enable the JobPodReplacementPolicy feature toggle. This is on by default.
             */
            podReplacementPolicy?: pulumi.Input<string>;
            /**
             * A label query over pods that should match the pod count. Normally, the system sets this field for you. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * successPolicy specifies the policy when the Job can be declared as succeeded. If empty, the default behavior applies - the Job is declared as succeeded only when the number of succeeded pods equals to the completions. When the field is specified, it must be immutable and works only for the Indexed Jobs. Once the Job meets the SuccessPolicy, the lingering pods are terminated.
             */
            successPolicy?: pulumi.Input<inputs.batch.v1.SuccessPolicy>;
            /**
             * suspend specifies whether the Job controller should create Pods or not. If a Job is created with suspend set to true, no Pods are created by the Job controller. If a Job is suspended after creation (i.e. the flag goes from false to true), the Job controller will delete all active Pods associated with this Job. Users must design their workload to gracefully handle this. Suspending a Job will reset the StartTime field of the Job, effectively resetting the ActiveDeadlineSeconds timer too. Defaults to false.
             */
            suspend?: pulumi.Input<boolean>;
            /**
             * Describes the pod that will be created when executing a job. The only allowed template.spec.restartPolicy values are "Never" or "OnFailure". More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/
             */
            template: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
            /**
             * ttlSecondsAfterFinished limits the lifetime of a Job that has finished execution (either Complete or Failed). If this field is set, ttlSecondsAfterFinished after the Job finishes, it is eligible to be automatically deleted. When the Job is being deleted, its lifecycle guarantees (e.g. finalizers) will be honored. If this field is unset, the Job won't be automatically deleted. If this field is set to zero, the Job becomes eligible to be deleted immediately after it finishes.
             */
            ttlSecondsAfterFinished?: pulumi.Input<number>;
        }
        /**
         * JobSpec describes how the job execution will look like.
         */
        interface JobSpecPatch {
            /**
             * Specifies the duration in seconds relative to the startTime that the job may be continuously active before the system tries to terminate it; value must be positive integer. If a Job is suspended (at creation or through an update), this timer will effectively be stopped and reset when the Job is resumed again.
             */
            activeDeadlineSeconds?: pulumi.Input<number>;
            /**
             * Specifies the number of retries before marking this job failed. Defaults to 6
             */
            backoffLimit?: pulumi.Input<number>;
            /**
             * Specifies the limit for the number of retries within an index before marking this index as failed. When enabled the number of failures per index is kept in the pod's batch.kubernetes.io/job-index-failure-count annotation. It can only be set when Job's completionMode=Indexed, and the Pod's restart policy is Never. The field is immutable.
             */
            backoffLimitPerIndex?: pulumi.Input<number>;
            /**
             * completionMode specifies how Pod completions are tracked. It can be `NonIndexed` (default) or `Indexed`.
             *
             * `NonIndexed` means that the Job is considered complete when there have been .spec.completions successfully completed Pods. Each Pod completion is homologous to each other.
             *
             * `Indexed` means that the Pods of a Job get an associated completion index from 0 to (.spec.completions - 1), available in the annotation batch.kubernetes.io/job-completion-index. The Job is considered complete when there is one successfully completed Pod for each index. When value is `Indexed`, .spec.completions must be specified and `.spec.parallelism` must be less than or equal to 10^5. In addition, The Pod name takes the form `$(job-name)-$(index)-$(random-string)`, the Pod hostname takes the form `$(job-name)-$(index)`.
             *
             * More completion modes can be added in the future. If the Job controller observes a mode that it doesn't recognize, which is possible during upgrades due to version skew, the controller skips updates for the Job.
             */
            completionMode?: pulumi.Input<string>;
            /**
             * Specifies the desired number of successfully finished pods the job should be run with.  Setting to null means that the success of any pod signals the success of all pods, and allows parallelism to have any positive value.  Setting to 1 means that parallelism is limited to 1 and the success of that pod signals the success of the job. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/
             */
            completions?: pulumi.Input<number>;
            /**
             * ManagedBy field indicates the controller that manages a Job. The k8s Job controller reconciles jobs which don't have this field at all or the field value is the reserved string `kubernetes.io/job-controller`, but skips reconciling Jobs with a custom value for this field. The value must be a valid domain-prefixed path (e.g. acme.io/foo) - all characters before the first "/" must be a valid subdomain as defined by RFC 1123. All characters trailing the first "/" must be valid HTTP Path characters as defined by RFC 3986. The value cannot exceed 63 characters. This field is immutable.
             *
             * This field is beta-level. The job controller accepts setting the field when the feature gate JobManagedBy is enabled (enabled by default).
             */
            managedBy?: pulumi.Input<string>;
            /**
             * manualSelector controls generation of pod labels and pod selectors. Leave `manualSelector` unset unless you are certain what you are doing. When false or unset, the system pick labels unique to this job and appends those labels to the pod template.  When true, the user is responsible for picking unique labels and specifying the selector.  Failure to pick a unique label may cause this and other jobs to not function correctly.  However, You may see `manualSelector=true` in jobs that were created with the old `extensions/v1beta1` API. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/#specifying-your-own-pod-selector
             */
            manualSelector?: pulumi.Input<boolean>;
            /**
             * Specifies the maximal number of failed indexes before marking the Job as failed, when backoffLimitPerIndex is set. Once the number of failed indexes exceeds this number the entire Job is marked as Failed and its execution is terminated. When left as null the job continues execution of all of its indexes and is marked with the `Complete` Job condition. It can only be specified when backoffLimitPerIndex is set. It can be null or up to completions. It is required and must be less than or equal to 10^4 when is completions greater than 10^5.
             */
            maxFailedIndexes?: pulumi.Input<number>;
            /**
             * Specifies the maximum desired number of pods the job should run at any given time. The actual number of pods running in steady state will be less than this number when ((.spec.completions - .status.successful) < .spec.parallelism), i.e. when the work left to do is less than max parallelism. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/
             */
            parallelism?: pulumi.Input<number>;
            /**
             * Specifies the policy of handling failed pods. In particular, it allows to specify the set of actions and conditions which need to be satisfied to take the associated action. If empty, the default behaviour applies - the counter of failed pods, represented by the jobs's .status.failed field, is incremented and it is checked against the backoffLimit. This field cannot be used in combination with restartPolicy=OnFailure.
             */
            podFailurePolicy?: pulumi.Input<inputs.batch.v1.PodFailurePolicyPatch>;
            /**
             * podReplacementPolicy specifies when to create replacement Pods. Possible values are: - TerminatingOrFailed means that we recreate pods
             *   when they are terminating (has a metadata.deletionTimestamp) or failed.
             * - Failed means to wait until a previously created Pod is fully terminated (has phase
             *   Failed or Succeeded) before creating a replacement Pod.
             *
             * When using podFailurePolicy, Failed is the the only allowed value. TerminatingOrFailed and Failed are allowed values when podFailurePolicy is not in use. This is an beta field. To use this, enable the JobPodReplacementPolicy feature toggle. This is on by default.
             */
            podReplacementPolicy?: pulumi.Input<string>;
            /**
             * A label query over pods that should match the pod count. Normally, the system sets this field for you. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * successPolicy specifies the policy when the Job can be declared as succeeded. If empty, the default behavior applies - the Job is declared as succeeded only when the number of succeeded pods equals to the completions. When the field is specified, it must be immutable and works only for the Indexed Jobs. Once the Job meets the SuccessPolicy, the lingering pods are terminated.
             */
            successPolicy?: pulumi.Input<inputs.batch.v1.SuccessPolicyPatch>;
            /**
             * suspend specifies whether the Job controller should create Pods or not. If a Job is created with suspend set to true, no Pods are created by the Job controller. If a Job is suspended after creation (i.e. the flag goes from false to true), the Job controller will delete all active Pods associated with this Job. Users must design their workload to gracefully handle this. Suspending a Job will reset the StartTime field of the Job, effectively resetting the ActiveDeadlineSeconds timer too. Defaults to false.
             */
            suspend?: pulumi.Input<boolean>;
            /**
             * Describes the pod that will be created when executing a job. The only allowed template.spec.restartPolicy values are "Never" or "OnFailure". More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
            /**
             * ttlSecondsAfterFinished limits the lifetime of a Job that has finished execution (either Complete or Failed). If this field is set, ttlSecondsAfterFinished after the Job finishes, it is eligible to be automatically deleted. When the Job is being deleted, its lifecycle guarantees (e.g. finalizers) will be honored. If this field is unset, the Job won't be automatically deleted. If this field is set to zero, the Job becomes eligible to be deleted immediately after it finishes.
             */
            ttlSecondsAfterFinished?: pulumi.Input<number>;
        }
        /**
         * JobStatus represents the current state of a Job.
         */
        interface JobStatus {
            /**
             * The number of pending and running pods which are not terminating (without a deletionTimestamp). The value is zero for finished jobs.
             */
            active?: pulumi.Input<number>;
            /**
             * completedIndexes holds the completed indexes when .spec.completionMode = "Indexed" in a text format. The indexes are represented as decimal integers separated by commas. The numbers are listed in increasing order. Three or more consecutive numbers are compressed and represented by the first and last element of the series, separated by a hyphen. For example, if the completed indexes are 1, 3, 4, 5 and 7, they are represented as "1,3-5,7".
             */
            completedIndexes?: pulumi.Input<string>;
            /**
             * Represents time when the job was completed. It is not guaranteed to be set in happens-before order across separate operations. It is represented in RFC3339 form and is in UTC. The completion time is set when the job finishes successfully, and only then. The value cannot be updated or removed. The value indicates the same or later point in time as the startTime field.
             */
            completionTime?: pulumi.Input<string>;
            /**
             * The latest available observations of an object's current state. When a Job fails, one of the conditions will have type "Failed" and status true. When a Job is suspended, one of the conditions will have type "Suspended" and status true; when the Job is resumed, the status of this condition will become false. When a Job is completed, one of the conditions will have type "Complete" and status true.
             *
             * A job is considered finished when it is in a terminal condition, either "Complete" or "Failed". A Job cannot have both the "Complete" and "Failed" conditions. Additionally, it cannot be in the "Complete" and "FailureTarget" conditions. The "Complete", "Failed" and "FailureTarget" conditions cannot be disabled.
             *
             * More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.batch.v1.JobCondition>[]>;
            /**
             * The number of pods which reached phase Failed. The value increases monotonically.
             */
            failed?: pulumi.Input<number>;
            /**
             * FailedIndexes holds the failed indexes when spec.backoffLimitPerIndex is set. The indexes are represented in the text format analogous as for the `completedIndexes` field, ie. they are kept as decimal integers separated by commas. The numbers are listed in increasing order. Three or more consecutive numbers are compressed and represented by the first and last element of the series, separated by a hyphen. For example, if the failed indexes are 1, 3, 4, 5 and 7, they are represented as "1,3-5,7". The set of failed indexes cannot overlap with the set of completed indexes.
             */
            failedIndexes?: pulumi.Input<string>;
            /**
             * The number of active pods which have a Ready condition and are not terminating (without a deletionTimestamp).
             */
            ready?: pulumi.Input<number>;
            /**
             * Represents time when the job controller started processing a job. When a Job is created in the suspended state, this field is not set until the first time it is resumed. This field is reset every time a Job is resumed from suspension. It is represented in RFC3339 form and is in UTC.
             *
             * Once set, the field can only be removed when the job is suspended. The field cannot be modified while the job is unsuspended or finished.
             */
            startTime?: pulumi.Input<string>;
            /**
             * The number of pods which reached phase Succeeded. The value increases monotonically for a given spec. However, it may decrease in reaction to scale down of elastic indexed jobs.
             */
            succeeded?: pulumi.Input<number>;
            /**
             * The number of pods which are terminating (in phase Pending or Running and have a deletionTimestamp).
             *
             * This field is beta-level. The job controller populates the field when the feature gate JobPodReplacementPolicy is enabled (enabled by default).
             */
            terminating?: pulumi.Input<number>;
            /**
             * uncountedTerminatedPods holds the UIDs of Pods that have terminated but the job controller hasn't yet accounted for in the status counters.
             *
             * The job controller creates pods with a finalizer. When a pod terminates (succeeded or failed), the controller does three steps to account for it in the job status:
             *
             * 1. Add the pod UID to the arrays in this field. 2. Remove the pod finalizer. 3. Remove the pod UID from the arrays while increasing the corresponding
             *     counter.
             *
             * Old jobs might not be tracked using this field, in which case the field remains null. The structure is empty for finished jobs.
             */
            uncountedTerminatedPods?: pulumi.Input<inputs.batch.v1.UncountedTerminatedPods>;
        }
        /**
         * JobTemplateSpec describes the data a Job should have when created from a template
         */
        interface JobTemplateSpec {
            /**
             * Standard object's metadata of the jobs created from this template. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the job. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.batch.v1.JobSpec>;
        }
        /**
         * JobTemplateSpec describes the data a Job should have when created from a template
         */
        interface JobTemplateSpecPatch {
            /**
             * Standard object's metadata of the jobs created from this template. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMetaPatch>;
            /**
             * Specification of the desired behavior of the job. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.batch.v1.JobSpecPatch>;
        }
        /**
         * PodFailurePolicy describes how failed pods influence the backoffLimit.
         */
        interface PodFailurePolicy {
            /**
             * A list of pod failure policy rules. The rules are evaluated in order. Once a rule matches a Pod failure, the remaining of the rules are ignored. When no rule matches the Pod failure, the default handling applies - the counter of pod failures is incremented and it is checked against the backoffLimit. At most 20 elements are allowed.
             */
            rules: pulumi.Input<pulumi.Input<inputs.batch.v1.PodFailurePolicyRule>[]>;
        }
        /**
         * PodFailurePolicyOnExitCodesRequirement describes the requirement for handling a failed pod based on its container exit codes. In particular, it lookups the .state.terminated.exitCode for each app container and init container status, represented by the .status.containerStatuses and .status.initContainerStatuses fields in the Pod status, respectively. Containers completed with success (exit code 0) are excluded from the requirement check.
         */
        interface PodFailurePolicyOnExitCodesRequirement {
            /**
             * Restricts the check for exit codes to the container with the specified name. When null, the rule applies to all containers. When specified, it should match one the container or initContainer names in the pod template.
             */
            containerName?: pulumi.Input<string>;
            /**
             * Represents the relationship between the container exit code(s) and the specified values. Containers completed with success (exit code 0) are excluded from the requirement check. Possible values are:
             *
             * - In: the requirement is satisfied if at least one container exit code
             *   (might be multiple if there are multiple containers not restricted
             *   by the 'containerName' field) is in the set of specified values.
             * - NotIn: the requirement is satisfied if at least one container exit code
             *   (might be multiple if there are multiple containers not restricted
             *   by the 'containerName' field) is not in the set of specified values.
             * Additional values are considered to be added in the future. Clients should react to an unknown operator by assuming the requirement is not satisfied.
             */
            operator: pulumi.Input<string>;
            /**
             * Specifies the set of values. Each returned container exit code (might be multiple in case of multiple containers) is checked against this set of values with respect to the operator. The list of values must be ordered and must not contain duplicates. Value '0' cannot be used for the In operator. At least one element is required. At most 255 elements are allowed.
             */
            values: pulumi.Input<pulumi.Input<number>[]>;
        }
        /**
         * PodFailurePolicyOnExitCodesRequirement describes the requirement for handling a failed pod based on its container exit codes. In particular, it lookups the .state.terminated.exitCode for each app container and init container status, represented by the .status.containerStatuses and .status.initContainerStatuses fields in the Pod status, respectively. Containers completed with success (exit code 0) are excluded from the requirement check.
         */
        interface PodFailurePolicyOnExitCodesRequirementPatch {
            /**
             * Restricts the check for exit codes to the container with the specified name. When null, the rule applies to all containers. When specified, it should match one the container or initContainer names in the pod template.
             */
            containerName?: pulumi.Input<string>;
            /**
             * Represents the relationship between the container exit code(s) and the specified values. Containers completed with success (exit code 0) are excluded from the requirement check. Possible values are:
             *
             * - In: the requirement is satisfied if at least one container exit code
             *   (might be multiple if there are multiple containers not restricted
             *   by the 'containerName' field) is in the set of specified values.
             * - NotIn: the requirement is satisfied if at least one container exit code
             *   (might be multiple if there are multiple containers not restricted
             *   by the 'containerName' field) is not in the set of specified values.
             * Additional values are considered to be added in the future. Clients should react to an unknown operator by assuming the requirement is not satisfied.
             */
            operator?: pulumi.Input<string>;
            /**
             * Specifies the set of values. Each returned container exit code (might be multiple in case of multiple containers) is checked against this set of values with respect to the operator. The list of values must be ordered and must not contain duplicates. Value '0' cannot be used for the In operator. At least one element is required. At most 255 elements are allowed.
             */
            values?: pulumi.Input<pulumi.Input<number>[]>;
        }
        /**
         * PodFailurePolicyOnPodConditionsPattern describes a pattern for matching an actual pod condition type.
         */
        interface PodFailurePolicyOnPodConditionsPattern {
            /**
             * Specifies the required Pod condition status. To match a pod condition it is required that the specified status equals the pod condition status. Defaults to True.
             */
            status: pulumi.Input<string>;
            /**
             * Specifies the required Pod condition type. To match a pod condition it is required that specified type equals the pod condition type.
             */
            type: pulumi.Input<string>;
        }
        /**
         * PodFailurePolicyOnPodConditionsPattern describes a pattern for matching an actual pod condition type.
         */
        interface PodFailurePolicyOnPodConditionsPatternPatch {
            /**
             * Specifies the required Pod condition status. To match a pod condition it is required that the specified status equals the pod condition status. Defaults to True.
             */
            status?: pulumi.Input<string>;
            /**
             * Specifies the required Pod condition type. To match a pod condition it is required that specified type equals the pod condition type.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * PodFailurePolicy describes how failed pods influence the backoffLimit.
         */
        interface PodFailurePolicyPatch {
            /**
             * A list of pod failure policy rules. The rules are evaluated in order. Once a rule matches a Pod failure, the remaining of the rules are ignored. When no rule matches the Pod failure, the default handling applies - the counter of pod failures is incremented and it is checked against the backoffLimit. At most 20 elements are allowed.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.batch.v1.PodFailurePolicyRulePatch>[]>;
        }
        /**
         * PodFailurePolicyRule describes how a pod failure is handled when the requirements are met. One of onExitCodes and onPodConditions, but not both, can be used in each rule.
         */
        interface PodFailurePolicyRule {
            /**
             * Specifies the action taken on a pod failure when the requirements are satisfied. Possible values are:
             *
             * - FailJob: indicates that the pod's job is marked as Failed and all
             *   running pods are terminated.
             * - FailIndex: indicates that the pod's index is marked as Failed and will
             *   not be restarted.
             * - Ignore: indicates that the counter towards the .backoffLimit is not
             *   incremented and a replacement pod is created.
             * - Count: indicates that the pod is handled in the default way - the
             *   counter towards the .backoffLimit is incremented.
             * Additional values are considered to be added in the future. Clients should react to an unknown action by skipping the rule.
             */
            action: pulumi.Input<string>;
            /**
             * Represents the requirement on the container exit codes.
             */
            onExitCodes?: pulumi.Input<inputs.batch.v1.PodFailurePolicyOnExitCodesRequirement>;
            /**
             * Represents the requirement on the pod conditions. The requirement is represented as a list of pod condition patterns. The requirement is satisfied if at least one pattern matches an actual pod condition. At most 20 elements are allowed.
             */
            onPodConditions?: pulumi.Input<pulumi.Input<inputs.batch.v1.PodFailurePolicyOnPodConditionsPattern>[]>;
        }
        /**
         * PodFailurePolicyRule describes how a pod failure is handled when the requirements are met. One of onExitCodes and onPodConditions, but not both, can be used in each rule.
         */
        interface PodFailurePolicyRulePatch {
            /**
             * Specifies the action taken on a pod failure when the requirements are satisfied. Possible values are:
             *
             * - FailJob: indicates that the pod's job is marked as Failed and all
             *   running pods are terminated.
             * - FailIndex: indicates that the pod's index is marked as Failed and will
             *   not be restarted.
             * - Ignore: indicates that the counter towards the .backoffLimit is not
             *   incremented and a replacement pod is created.
             * - Count: indicates that the pod is handled in the default way - the
             *   counter towards the .backoffLimit is incremented.
             * Additional values are considered to be added in the future. Clients should react to an unknown action by skipping the rule.
             */
            action?: pulumi.Input<string>;
            /**
             * Represents the requirement on the container exit codes.
             */
            onExitCodes?: pulumi.Input<inputs.batch.v1.PodFailurePolicyOnExitCodesRequirementPatch>;
            /**
             * Represents the requirement on the pod conditions. The requirement is represented as a list of pod condition patterns. The requirement is satisfied if at least one pattern matches an actual pod condition. At most 20 elements are allowed.
             */
            onPodConditions?: pulumi.Input<pulumi.Input<inputs.batch.v1.PodFailurePolicyOnPodConditionsPatternPatch>[]>;
        }
        /**
         * SuccessPolicy describes when a Job can be declared as succeeded based on the success of some indexes.
         */
        interface SuccessPolicy {
            /**
             * rules represents the list of alternative rules for the declaring the Jobs as successful before `.status.succeeded >= .spec.completions`. Once any of the rules are met, the "SucceededCriteriaMet" condition is added, and the lingering pods are removed. The terminal state for such a Job has the "Complete" condition. Additionally, these rules are evaluated in order; Once the Job meets one of the rules, other rules are ignored. At most 20 elements are allowed.
             */
            rules: pulumi.Input<pulumi.Input<inputs.batch.v1.SuccessPolicyRule>[]>;
        }
        /**
         * SuccessPolicy describes when a Job can be declared as succeeded based on the success of some indexes.
         */
        interface SuccessPolicyPatch {
            /**
             * rules represents the list of alternative rules for the declaring the Jobs as successful before `.status.succeeded >= .spec.completions`. Once any of the rules are met, the "SucceededCriteriaMet" condition is added, and the lingering pods are removed. The terminal state for such a Job has the "Complete" condition. Additionally, these rules are evaluated in order; Once the Job meets one of the rules, other rules are ignored. At most 20 elements are allowed.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.batch.v1.SuccessPolicyRulePatch>[]>;
        }
        /**
         * SuccessPolicyRule describes rule for declaring a Job as succeeded. Each rule must have at least one of the "succeededIndexes" or "succeededCount" specified.
         */
        interface SuccessPolicyRule {
            /**
             * succeededCount specifies the minimal required size of the actual set of the succeeded indexes for the Job. When succeededCount is used along with succeededIndexes, the check is constrained only to the set of indexes specified by succeededIndexes. For example, given that succeededIndexes is "1-4", succeededCount is "3", and completed indexes are "1", "3", and "5", the Job isn't declared as succeeded because only "1" and "3" indexes are considered in that rules. When this field is null, this doesn't default to any value and is never evaluated at any time. When specified it needs to be a positive integer.
             */
            succeededCount?: pulumi.Input<number>;
            /**
             * succeededIndexes specifies the set of indexes which need to be contained in the actual set of the succeeded indexes for the Job. The list of indexes must be within 0 to ".spec.completions-1" and must not contain duplicates. At least one element is required. The indexes are represented as intervals separated by commas. The intervals can be a decimal integer or a pair of decimal integers separated by a hyphen. The number are listed in represented by the first and last element of the series, separated by a hyphen. For example, if the completed indexes are 1, 3, 4, 5 and 7, they are represented as "1,3-5,7". When this field is null, this field doesn't default to any value and is never evaluated at any time.
             */
            succeededIndexes?: pulumi.Input<string>;
        }
        /**
         * SuccessPolicyRule describes rule for declaring a Job as succeeded. Each rule must have at least one of the "succeededIndexes" or "succeededCount" specified.
         */
        interface SuccessPolicyRulePatch {
            /**
             * succeededCount specifies the minimal required size of the actual set of the succeeded indexes for the Job. When succeededCount is used along with succeededIndexes, the check is constrained only to the set of indexes specified by succeededIndexes. For example, given that succeededIndexes is "1-4", succeededCount is "3", and completed indexes are "1", "3", and "5", the Job isn't declared as succeeded because only "1" and "3" indexes are considered in that rules. When this field is null, this doesn't default to any value and is never evaluated at any time. When specified it needs to be a positive integer.
             */
            succeededCount?: pulumi.Input<number>;
            /**
             * succeededIndexes specifies the set of indexes which need to be contained in the actual set of the succeeded indexes for the Job. The list of indexes must be within 0 to ".spec.completions-1" and must not contain duplicates. At least one element is required. The indexes are represented as intervals separated by commas. The intervals can be a decimal integer or a pair of decimal integers separated by a hyphen. The number are listed in represented by the first and last element of the series, separated by a hyphen. For example, if the completed indexes are 1, 3, 4, 5 and 7, they are represented as "1,3-5,7". When this field is null, this field doesn't default to any value and is never evaluated at any time.
             */
            succeededIndexes?: pulumi.Input<string>;
        }
        /**
         * UncountedTerminatedPods holds UIDs of Pods that have terminated but haven't been accounted in Job status counters.
         */
        interface UncountedTerminatedPods {
            /**
             * failed holds UIDs of failed Pods.
             */
            failed?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * succeeded holds UIDs of succeeded Pods.
             */
            succeeded?: pulumi.Input<pulumi.Input<string>[]>;
        }
    }
    namespace v1beta1 {
        /**
         * CronJob represents the configuration of a single cron job.
         */
        interface CronJob {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"batch/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"CronJob">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of a cron job, including the schedule. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.batch.v1beta1.CronJobSpec>;
            /**
             * Current status of a cron job. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.batch.v1beta1.CronJobStatus>;
        }
        /**
         * CronJobSpec describes how the job execution will look like and when it will actually run.
         */
        interface CronJobSpec {
            /**
             * Specifies how to treat concurrent executions of a Job. Valid values are: - "Allow" (default): allows CronJobs to run concurrently; - "Forbid": forbids concurrent runs, skipping next run if previous run hasn't finished yet; - "Replace": cancels currently running job and replaces it with a new one
             */
            concurrencyPolicy?: pulumi.Input<string>;
            /**
             * The number of failed finished jobs to retain. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1.
             */
            failedJobsHistoryLimit?: pulumi.Input<number>;
            /**
             * Specifies the job that will be created when executing a CronJob.
             */
            jobTemplate: pulumi.Input<inputs.batch.v1beta1.JobTemplateSpec>;
            /**
             * The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron.
             */
            schedule: pulumi.Input<string>;
            /**
             * Optional deadline in seconds for starting the job if it misses scheduled time for any reason.  Missed jobs executions will be counted as failed ones.
             */
            startingDeadlineSeconds?: pulumi.Input<number>;
            /**
             * The number of successful finished jobs to retain. This is a pointer to distinguish between explicit zero and not specified. Defaults to 3.
             */
            successfulJobsHistoryLimit?: pulumi.Input<number>;
            /**
             * This flag tells the controller to suspend subsequent executions, it does not apply to already started executions.  Defaults to false.
             */
            suspend?: pulumi.Input<boolean>;
        }
        /**
         * CronJobSpec describes how the job execution will look like and when it will actually run.
         */
        interface CronJobSpecPatch {
            /**
             * Specifies how to treat concurrent executions of a Job. Valid values are: - "Allow" (default): allows CronJobs to run concurrently; - "Forbid": forbids concurrent runs, skipping next run if previous run hasn't finished yet; - "Replace": cancels currently running job and replaces it with a new one
             */
            concurrencyPolicy?: pulumi.Input<string>;
            /**
             * The number of failed finished jobs to retain. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1.
             */
            failedJobsHistoryLimit?: pulumi.Input<number>;
            /**
             * Specifies the job that will be created when executing a CronJob.
             */
            jobTemplate?: pulumi.Input<inputs.batch.v1beta1.JobTemplateSpecPatch>;
            /**
             * The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron.
             */
            schedule?: pulumi.Input<string>;
            /**
             * Optional deadline in seconds for starting the job if it misses scheduled time for any reason.  Missed jobs executions will be counted as failed ones.
             */
            startingDeadlineSeconds?: pulumi.Input<number>;
            /**
             * The number of successful finished jobs to retain. This is a pointer to distinguish between explicit zero and not specified. Defaults to 3.
             */
            successfulJobsHistoryLimit?: pulumi.Input<number>;
            /**
             * This flag tells the controller to suspend subsequent executions, it does not apply to already started executions.  Defaults to false.
             */
            suspend?: pulumi.Input<boolean>;
        }
        /**
         * CronJobStatus represents the current state of a cron job.
         */
        interface CronJobStatus {
            /**
             * A list of pointers to currently running jobs.
             */
            active?: pulumi.Input<pulumi.Input<inputs.core.v1.ObjectReference>[]>;
            /**
             * Information when was the last time the job was successfully scheduled.
             */
            lastScheduleTime?: pulumi.Input<string>;
        }
        /**
         * JobTemplateSpec describes the data a Job should have when created from a template
         */
        interface JobTemplateSpec {
            /**
             * Standard object's metadata of the jobs created from this template. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the job. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.batch.v1.JobSpec>;
        }
        /**
         * JobTemplateSpec describes the data a Job should have when created from a template
         */
        interface JobTemplateSpecPatch {
            /**
             * Standard object's metadata of the jobs created from this template. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMetaPatch>;
            /**
             * Specification of the desired behavior of the job. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.batch.v1.JobSpecPatch>;
        }
    }
    namespace v2alpha1 {
        /**
         * CronJob represents the configuration of a single cron job.
         */
        interface CronJob {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"batch/v2alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"CronJob">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of a cron job, including the schedule. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.batch.v2alpha1.CronJobSpec>;
            /**
             * Current status of a cron job. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.batch.v2alpha1.CronJobStatus>;
        }
        /**
         * CronJobSpec describes how the job execution will look like and when it will actually run.
         */
        interface CronJobSpec {
            /**
             * Specifies how to treat concurrent executions of a Job. Valid values are: - "Allow" (default): allows CronJobs to run concurrently; - "Forbid": forbids concurrent runs, skipping next run if previous run hasn't finished yet; - "Replace": cancels currently running job and replaces it with a new one
             */
            concurrencyPolicy?: pulumi.Input<string>;
            /**
             * The number of failed finished jobs to retain. This is a pointer to distinguish between explicit zero and not specified.
             */
            failedJobsHistoryLimit?: pulumi.Input<number>;
            /**
             * Specifies the job that will be created when executing a CronJob.
             */
            jobTemplate: pulumi.Input<inputs.batch.v2alpha1.JobTemplateSpec>;
            /**
             * The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron.
             */
            schedule: pulumi.Input<string>;
            /**
             * Optional deadline in seconds for starting the job if it misses scheduled time for any reason.  Missed jobs executions will be counted as failed ones.
             */
            startingDeadlineSeconds?: pulumi.Input<number>;
            /**
             * The number of successful finished jobs to retain. This is a pointer to distinguish between explicit zero and not specified.
             */
            successfulJobsHistoryLimit?: pulumi.Input<number>;
            /**
             * This flag tells the controller to suspend subsequent executions, it does not apply to already started executions.  Defaults to false.
             */
            suspend?: pulumi.Input<boolean>;
        }
        /**
         * CronJobSpec describes how the job execution will look like and when it will actually run.
         */
        interface CronJobSpecPatch {
            /**
             * Specifies how to treat concurrent executions of a Job. Valid values are: - "Allow" (default): allows CronJobs to run concurrently; - "Forbid": forbids concurrent runs, skipping next run if previous run hasn't finished yet; - "Replace": cancels currently running job and replaces it with a new one
             */
            concurrencyPolicy?: pulumi.Input<string>;
            /**
             * The number of failed finished jobs to retain. This is a pointer to distinguish between explicit zero and not specified.
             */
            failedJobsHistoryLimit?: pulumi.Input<number>;
            /**
             * Specifies the job that will be created when executing a CronJob.
             */
            jobTemplate?: pulumi.Input<inputs.batch.v2alpha1.JobTemplateSpecPatch>;
            /**
             * The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron.
             */
            schedule?: pulumi.Input<string>;
            /**
             * Optional deadline in seconds for starting the job if it misses scheduled time for any reason.  Missed jobs executions will be counted as failed ones.
             */
            startingDeadlineSeconds?: pulumi.Input<number>;
            /**
             * The number of successful finished jobs to retain. This is a pointer to distinguish between explicit zero and not specified.
             */
            successfulJobsHistoryLimit?: pulumi.Input<number>;
            /**
             * This flag tells the controller to suspend subsequent executions, it does not apply to already started executions.  Defaults to false.
             */
            suspend?: pulumi.Input<boolean>;
        }
        /**
         * CronJobStatus represents the current state of a cron job.
         */
        interface CronJobStatus {
            /**
             * A list of pointers to currently running jobs.
             */
            active?: pulumi.Input<pulumi.Input<inputs.core.v1.ObjectReference>[]>;
            /**
             * Information when was the last time the job was successfully scheduled.
             */
            lastScheduleTime?: pulumi.Input<string>;
        }
        /**
         * JobTemplateSpec describes the data a Job should have when created from a template
         */
        interface JobTemplateSpec {
            /**
             * Standard object's metadata of the jobs created from this template. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the job. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.batch.v1.JobSpec>;
        }
        /**
         * JobTemplateSpec describes the data a Job should have when created from a template
         */
        interface JobTemplateSpecPatch {
            /**
             * Standard object's metadata of the jobs created from this template. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMetaPatch>;
            /**
             * Specification of the desired behavior of the job. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.batch.v1.JobSpecPatch>;
        }
    }
}
export declare namespace certificates {
    namespace v1 {
        /**
         * CertificateSigningRequest objects provide a mechanism to obtain x509 certificates by submitting a certificate signing request, and having it asynchronously approved and issued.
         *
         * Kubelets use this API to obtain:
         *  1. client certificates to authenticate to kube-apiserver (with the "kubernetes.io/kube-apiserver-client-kubelet" signerName).
         *  2. serving certificates for TLS endpoints kube-apiserver can connect to securely (with the "kubernetes.io/kubelet-serving" signerName).
         *
         * This API can be used to request client certificates to authenticate to kube-apiserver (with the "kubernetes.io/kube-apiserver-client" signerName), or to obtain certificates from custom non-Kubernetes signers.
         */
        interface CertificateSigningRequest {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"certificates.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"CertificateSigningRequest">;
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec contains the certificate request, and is immutable after creation. Only the request, signerName, expirationSeconds, and usages fields can be set on creation. Other fields are derived by Kubernetes and cannot be modified by users.
             */
            spec: pulumi.Input<inputs.certificates.v1.CertificateSigningRequestSpec>;
            /**
             * status contains information about whether the request is approved or denied, and the certificate issued by the signer, or the failure condition indicating signer failure.
             */
            status?: pulumi.Input<inputs.certificates.v1.CertificateSigningRequestStatus>;
        }
        /**
         * CertificateSigningRequestCondition describes a condition of a CertificateSigningRequest object
         */
        interface CertificateSigningRequestCondition {
            /**
             * lastTransitionTime is the time the condition last transitioned from one status to another. If unset, when a new condition type is added or an existing condition's status is changed, the server defaults this to the current time.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * lastUpdateTime is the time of the last update to this condition
             */
            lastUpdateTime?: pulumi.Input<string>;
            /**
             * message contains a human readable message with details about the request state
             */
            message?: pulumi.Input<string>;
            /**
             * reason indicates a brief reason for the request state
             */
            reason?: pulumi.Input<string>;
            /**
             * status of the condition, one of True, False, Unknown. Approved, Denied, and Failed conditions may not be "False" or "Unknown".
             */
            status: pulumi.Input<string>;
            /**
             * type of the condition. Known conditions are "Approved", "Denied", and "Failed".
             *
             * An "Approved" condition is added via the /approval subresource, indicating the request was approved and should be issued by the signer.
             *
             * A "Denied" condition is added via the /approval subresource, indicating the request was denied and should not be issued by the signer.
             *
             * A "Failed" condition is added via the /status subresource, indicating the signer failed to issue the certificate.
             *
             * Approved and Denied conditions are mutually exclusive. Approved, Denied, and Failed conditions cannot be removed once added.
             *
             * Only one condition of a given type is allowed.
             */
            type: pulumi.Input<string>;
        }
        /**
         * CertificateSigningRequestSpec contains the certificate request.
         */
        interface CertificateSigningRequestSpec {
            /**
             * expirationSeconds is the requested duration of validity of the issued certificate. The certificate signer may issue a certificate with a different validity duration so a client must check the delta between the notBefore and and notAfter fields in the issued certificate to determine the actual duration.
             *
             * The v1.22+ in-tree implementations of the well-known Kubernetes signers will honor this field as long as the requested duration is not greater than the maximum duration they will honor per the --cluster-signing-duration CLI flag to the Kubernetes controller manager.
             *
             * Certificate signers may not honor this field for various reasons:
             *
             *   1. Old signer that is unaware of the field (such as the in-tree
             *      implementations prior to v1.22)
             *   2. Signer whose configured maximum is shorter than the requested duration
             *   3. Signer whose configured minimum is longer than the requested duration
             *
             * The minimum valid value for expirationSeconds is 600, i.e. 10 minutes.
             */
            expirationSeconds?: pulumi.Input<number>;
            /**
             * extra contains extra attributes of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable.
             */
            extra?: pulumi.Input<{
                [key: string]: pulumi.Input<pulumi.Input<string>[]>;
            }>;
            /**
             * groups contains group membership of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable.
             */
            groups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * request contains an x509 certificate signing request encoded in a "CERTIFICATE REQUEST" PEM block. When serialized as JSON or YAML, the data is additionally base64-encoded.
             */
            request: pulumi.Input<string>;
            /**
             * signerName indicates the requested signer, and is a qualified name.
             *
             * List/watch requests for CertificateSigningRequests can filter on this field using a "spec.signerName=NAME" fieldSelector.
             *
             * Well-known Kubernetes signers are:
             *  1. "kubernetes.io/kube-apiserver-client": issues client certificates that can be used to authenticate to kube-apiserver.
             *   Requests for this signer are never auto-approved by kube-controller-manager, can be issued by the "csrsigning" controller in kube-controller-manager.
             *  2. "kubernetes.io/kube-apiserver-client-kubelet": issues client certificates that kubelets use to authenticate to kube-apiserver.
             *   Requests for this signer can be auto-approved by the "csrapproving" controller in kube-controller-manager, and can be issued by the "csrsigning" controller in kube-controller-manager.
             *  3. "kubernetes.io/kubelet-serving" issues serving certificates that kubelets use to serve TLS endpoints, which kube-apiserver can connect to securely.
             *   Requests for this signer are never auto-approved by kube-controller-manager, and can be issued by the "csrsigning" controller in kube-controller-manager.
             *
             * More details are available at https://k8s.io/docs/reference/access-authn-authz/certificate-signing-requests/#kubernetes-signers
             *
             * Custom signerNames can also be specified. The signer defines:
             *  1. Trust distribution: how trust (CA bundles) are distributed.
             *  2. Permitted subjects: and behavior when a disallowed subject is requested.
             *  3. Required, permitted, or forbidden x509 extensions in the request (including whether subjectAltNames are allowed, which types, restrictions on allowed values) and behavior when a disallowed extension is requested.
             *  4. Required, permitted, or forbidden key usages / extended key usages.
             *  5. Expiration/certificate lifetime: whether it is fixed by the signer, configurable by the admin.
             *  6. Whether or not requests for CA certificates are allowed.
             */
            signerName: pulumi.Input<string>;
            /**
             * uid contains the uid of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable.
             */
            uid?: pulumi.Input<string>;
            /**
             * usages specifies a set of key usages requested in the issued certificate.
             *
             * Requests for TLS client certificates typically request: "digital signature", "key encipherment", "client auth".
             *
             * Requests for TLS serving certificates typically request: "key encipherment", "digital signature", "server auth".
             *
             * Valid values are:
             *  "signing", "digital signature", "content commitment",
             *  "key encipherment", "key agreement", "data encipherment",
             *  "cert sign", "crl sign", "encipher only", "decipher only", "any",
             *  "server auth", "client auth",
             *  "code signing", "email protection", "s/mime",
             *  "ipsec end system", "ipsec tunnel", "ipsec user",
             *  "timestamping", "ocsp signing", "microsoft sgc", "netscape sgc"
             */
            usages?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * username contains the name of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable.
             */
            username?: pulumi.Input<string>;
        }
        /**
         * CertificateSigningRequestSpec contains the certificate request.
         */
        interface CertificateSigningRequestSpecPatch {
            /**
             * expirationSeconds is the requested duration of validity of the issued certificate. The certificate signer may issue a certificate with a different validity duration so a client must check the delta between the notBefore and and notAfter fields in the issued certificate to determine the actual duration.
             *
             * The v1.22+ in-tree implementations of the well-known Kubernetes signers will honor this field as long as the requested duration is not greater than the maximum duration they will honor per the --cluster-signing-duration CLI flag to the Kubernetes controller manager.
             *
             * Certificate signers may not honor this field for various reasons:
             *
             *   1. Old signer that is unaware of the field (such as the in-tree
             *      implementations prior to v1.22)
             *   2. Signer whose configured maximum is shorter than the requested duration
             *   3. Signer whose configured minimum is longer than the requested duration
             *
             * The minimum valid value for expirationSeconds is 600, i.e. 10 minutes.
             */
            expirationSeconds?: pulumi.Input<number>;
            /**
             * extra contains extra attributes of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable.
             */
            extra?: pulumi.Input<{
                [key: string]: pulumi.Input<pulumi.Input<string>[]>;
            }>;
            /**
             * groups contains group membership of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable.
             */
            groups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * request contains an x509 certificate signing request encoded in a "CERTIFICATE REQUEST" PEM block. When serialized as JSON or YAML, the data is additionally base64-encoded.
             */
            request?: pulumi.Input<string>;
            /**
             * signerName indicates the requested signer, and is a qualified name.
             *
             * List/watch requests for CertificateSigningRequests can filter on this field using a "spec.signerName=NAME" fieldSelector.
             *
             * Well-known Kubernetes signers are:
             *  1. "kubernetes.io/kube-apiserver-client": issues client certificates that can be used to authenticate to kube-apiserver.
             *   Requests for this signer are never auto-approved by kube-controller-manager, can be issued by the "csrsigning" controller in kube-controller-manager.
             *  2. "kubernetes.io/kube-apiserver-client-kubelet": issues client certificates that kubelets use to authenticate to kube-apiserver.
             *   Requests for this signer can be auto-approved by the "csrapproving" controller in kube-controller-manager, and can be issued by the "csrsigning" controller in kube-controller-manager.
             *  3. "kubernetes.io/kubelet-serving" issues serving certificates that kubelets use to serve TLS endpoints, which kube-apiserver can connect to securely.
             *   Requests for this signer are never auto-approved by kube-controller-manager, and can be issued by the "csrsigning" controller in kube-controller-manager.
             *
             * More details are available at https://k8s.io/docs/reference/access-authn-authz/certificate-signing-requests/#kubernetes-signers
             *
             * Custom signerNames can also be specified. The signer defines:
             *  1. Trust distribution: how trust (CA bundles) are distributed.
             *  2. Permitted subjects: and behavior when a disallowed subject is requested.
             *  3. Required, permitted, or forbidden x509 extensions in the request (including whether subjectAltNames are allowed, which types, restrictions on allowed values) and behavior when a disallowed extension is requested.
             *  4. Required, permitted, or forbidden key usages / extended key usages.
             *  5. Expiration/certificate lifetime: whether it is fixed by the signer, configurable by the admin.
             *  6. Whether or not requests for CA certificates are allowed.
             */
            signerName?: pulumi.Input<string>;
            /**
             * uid contains the uid of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable.
             */
            uid?: pulumi.Input<string>;
            /**
             * usages specifies a set of key usages requested in the issued certificate.
             *
             * Requests for TLS client certificates typically request: "digital signature", "key encipherment", "client auth".
             *
             * Requests for TLS serving certificates typically request: "key encipherment", "digital signature", "server auth".
             *
             * Valid values are:
             *  "signing", "digital signature", "content commitment",
             *  "key encipherment", "key agreement", "data encipherment",
             *  "cert sign", "crl sign", "encipher only", "decipher only", "any",
             *  "server auth", "client auth",
             *  "code signing", "email protection", "s/mime",
             *  "ipsec end system", "ipsec tunnel", "ipsec user",
             *  "timestamping", "ocsp signing", "microsoft sgc", "netscape sgc"
             */
            usages?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * username contains the name of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable.
             */
            username?: pulumi.Input<string>;
        }
        /**
         * CertificateSigningRequestStatus contains conditions used to indicate approved/denied/failed status of the request, and the issued certificate.
         */
        interface CertificateSigningRequestStatus {
            /**
             * certificate is populated with an issued certificate by the signer after an Approved condition is present. This field is set via the /status subresource. Once populated, this field is immutable.
             *
             * If the certificate signing request is denied, a condition of type "Denied" is added and this field remains empty. If the signer cannot issue the certificate, a condition of type "Failed" is added and this field remains empty.
             *
             * Validation requirements:
             *  1. certificate must contain one or more PEM blocks.
             *  2. All PEM blocks must have the "CERTIFICATE" label, contain no headers, and the encoded data
             *   must be a BER-encoded ASN.1 Certificate structure as described in section 4 of RFC5280.
             *  3. Non-PEM content may appear before or after the "CERTIFICATE" PEM blocks and is unvalidated,
             *   to allow for explanatory text as described in section 5.2 of RFC7468.
             *
             * If more than one PEM block is present, and the definition of the requested spec.signerName does not indicate otherwise, the first block is the issued certificate, and subsequent blocks should be treated as intermediate certificates and presented in TLS handshakes.
             *
             * The certificate is encoded in PEM format.
             *
             * When serialized as JSON or YAML, the data is additionally base64-encoded, so it consists of:
             *
             *     base64(
             *     -----BEGIN CERTIFICATE-----
             *     ...
             *     -----END CERTIFICATE-----
             *     )
             */
            certificate?: pulumi.Input<string>;
            /**
             * conditions applied to the request. Known conditions are "Approved", "Denied", and "Failed".
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.certificates.v1.CertificateSigningRequestCondition>[]>;
        }
    }
    namespace v1alpha1 {
        /**
         * ClusterTrustBundle is a cluster-scoped container for X.509 trust anchors (root certificates).
         *
         * ClusterTrustBundle objects are considered to be readable by any authenticated user in the cluster, because they can be mounted by pods using the `clusterTrustBundle` projection.  All service accounts have read access to ClusterTrustBundles by default.  Users who only have namespace-level access to a cluster can read ClusterTrustBundles by impersonating a serviceaccount that they have access to.
         *
         * It can be optionally associated with a particular assigner, in which case it contains one valid set of trust anchors for that signer. Signers may have multiple associated ClusterTrustBundles; each is an independent set of trust anchors for that signer. Admission control is used to enforce that only users with permissions on the signer can create or modify the corresponding bundle.
         */
        interface ClusterTrustBundle {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"certificates.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ClusterTrustBundle">;
            /**
             * metadata contains the object metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec contains the signer (if any) and trust anchors.
             */
            spec: pulumi.Input<inputs.certificates.v1alpha1.ClusterTrustBundleSpec>;
        }
        /**
         * ClusterTrustBundleSpec contains the signer and trust anchors.
         */
        interface ClusterTrustBundleSpec {
            /**
             * signerName indicates the associated signer, if any.
             *
             * In order to create or update a ClusterTrustBundle that sets signerName, you must have the following cluster-scoped permission: group=certificates.k8s.io resource=signers resourceName=<the signer name> verb=attest.
             *
             * If signerName is not empty, then the ClusterTrustBundle object must be named with the signer name as a prefix (translating slashes to colons). For example, for the signer name `example.com/foo`, valid ClusterTrustBundle object names include `example.com:foo:abc` and `example.com:foo:v1`.
             *
             * If signerName is empty, then the ClusterTrustBundle object's name must not have such a prefix.
             *
             * List/watch requests for ClusterTrustBundles can filter on this field using a `spec.signerName=NAME` field selector.
             */
            signerName?: pulumi.Input<string>;
            /**
             * trustBundle contains the individual X.509 trust anchors for this bundle, as PEM bundle of PEM-wrapped, DER-formatted X.509 certificates.
             *
             * The data must consist only of PEM certificate blocks that parse as valid X.509 certificates.  Each certificate must include a basic constraints extension with the CA bit set.  The API server will reject objects that contain duplicate certificates, or that use PEM block headers.
             *
             * Users of ClusterTrustBundles, including Kubelet, are free to reorder and deduplicate certificate blocks in this file according to their own logic, as well as to drop PEM block headers and inter-block data.
             */
            trustBundle: pulumi.Input<string>;
        }
        /**
         * ClusterTrustBundleSpec contains the signer and trust anchors.
         */
        interface ClusterTrustBundleSpecPatch {
            /**
             * signerName indicates the associated signer, if any.
             *
             * In order to create or update a ClusterTrustBundle that sets signerName, you must have the following cluster-scoped permission: group=certificates.k8s.io resource=signers resourceName=<the signer name> verb=attest.
             *
             * If signerName is not empty, then the ClusterTrustBundle object must be named with the signer name as a prefix (translating slashes to colons). For example, for the signer name `example.com/foo`, valid ClusterTrustBundle object names include `example.com:foo:abc` and `example.com:foo:v1`.
             *
             * If signerName is empty, then the ClusterTrustBundle object's name must not have such a prefix.
             *
             * List/watch requests for ClusterTrustBundles can filter on this field using a `spec.signerName=NAME` field selector.
             */
            signerName?: pulumi.Input<string>;
            /**
             * trustBundle contains the individual X.509 trust anchors for this bundle, as PEM bundle of PEM-wrapped, DER-formatted X.509 certificates.
             *
             * The data must consist only of PEM certificate blocks that parse as valid X.509 certificates.  Each certificate must include a basic constraints extension with the CA bit set.  The API server will reject objects that contain duplicate certificates, or that use PEM block headers.
             *
             * Users of ClusterTrustBundles, including Kubelet, are free to reorder and deduplicate certificate blocks in this file according to their own logic, as well as to drop PEM block headers and inter-block data.
             */
            trustBundle?: pulumi.Input<string>;
        }
    }
    namespace v1beta1 {
        /**
         * Describes a certificate signing request
         */
        interface CertificateSigningRequest {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"certificates.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"CertificateSigningRequest">;
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * The certificate request itself and any additional information.
             */
            spec?: pulumi.Input<inputs.certificates.v1beta1.CertificateSigningRequestSpec>;
            /**
             * Derived information about the request.
             */
            status?: pulumi.Input<inputs.certificates.v1beta1.CertificateSigningRequestStatus>;
        }
        interface CertificateSigningRequestCondition {
            /**
             * lastTransitionTime is the time the condition last transitioned from one status to another. If unset, when a new condition type is added or an existing condition's status is changed, the server defaults this to the current time.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * timestamp for the last update to this condition
             */
            lastUpdateTime?: pulumi.Input<string>;
            /**
             * human readable message with details about the request state
             */
            message?: pulumi.Input<string>;
            /**
             * brief reason for the request state
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown. Approved, Denied, and Failed conditions may not be "False" or "Unknown". Defaults to "True". If unset, should be treated as "True".
             */
            status?: pulumi.Input<string>;
            /**
             * request approval state, currently Approved or Denied.
             */
            type: pulumi.Input<string>;
        }
        /**
         * This information is immutable after the request is created. Only the Request and Usages fields can be set on creation, other fields are derived by Kubernetes and cannot be modified by users.
         */
        interface CertificateSigningRequestSpec {
            /**
             * Extra information about the requesting user. See user.Info interface for details.
             */
            extra?: pulumi.Input<{
                [key: string]: pulumi.Input<pulumi.Input<string>[]>;
            }>;
            /**
             * Group information about the requesting user. See user.Info interface for details.
             */
            groups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Base64-encoded PKCS#10 CSR data
             */
            request: pulumi.Input<string>;
            /**
             * Requested signer for the request. It is a qualified name in the form: `scope-hostname.io/name`. If empty, it will be defaulted:
             *  1. If it's a kubelet client certificate, it is assigned
             *     "kubernetes.io/kube-apiserver-client-kubelet".
             *  2. If it's a kubelet serving certificate, it is assigned
             *     "kubernetes.io/kubelet-serving".
             *  3. Otherwise, it is assigned "kubernetes.io/legacy-unknown".
             * Distribution of trust for signers happens out of band. You can select on this field using `spec.signerName`.
             */
            signerName?: pulumi.Input<string>;
            /**
             * UID information about the requesting user. See user.Info interface for details.
             */
            uid?: pulumi.Input<string>;
            /**
             * allowedUsages specifies a set of usage contexts the key will be valid for. See: https://tools.ietf.org/html/rfc5280#section-4.2.1.3
             *      https://tools.ietf.org/html/rfc5280#section-4.2.1.12
             */
            usages?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Information about the requesting user. See user.Info interface for details.
             */
            username?: pulumi.Input<string>;
        }
        /**
         * This information is immutable after the request is created. Only the Request and Usages fields can be set on creation, other fields are derived by Kubernetes and cannot be modified by users.
         */
        interface CertificateSigningRequestSpecPatch {
            /**
             * Extra information about the requesting user. See user.Info interface for details.
             */
            extra?: pulumi.Input<{
                [key: string]: pulumi.Input<pulumi.Input<string>[]>;
            }>;
            /**
             * Group information about the requesting user. See user.Info interface for details.
             */
            groups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Base64-encoded PKCS#10 CSR data
             */
            request?: pulumi.Input<string>;
            /**
             * Requested signer for the request. It is a qualified name in the form: `scope-hostname.io/name`. If empty, it will be defaulted:
             *  1. If it's a kubelet client certificate, it is assigned
             *     "kubernetes.io/kube-apiserver-client-kubelet".
             *  2. If it's a kubelet serving certificate, it is assigned
             *     "kubernetes.io/kubelet-serving".
             *  3. Otherwise, it is assigned "kubernetes.io/legacy-unknown".
             * Distribution of trust for signers happens out of band. You can select on this field using `spec.signerName`.
             */
            signerName?: pulumi.Input<string>;
            /**
             * UID information about the requesting user. See user.Info interface for details.
             */
            uid?: pulumi.Input<string>;
            /**
             * allowedUsages specifies a set of usage contexts the key will be valid for. See: https://tools.ietf.org/html/rfc5280#section-4.2.1.3
             *      https://tools.ietf.org/html/rfc5280#section-4.2.1.12
             */
            usages?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Information about the requesting user. See user.Info interface for details.
             */
            username?: pulumi.Input<string>;
        }
        interface CertificateSigningRequestStatus {
            /**
             * If request was approved, the controller will place the issued certificate here.
             */
            certificate?: pulumi.Input<string>;
            /**
             * Conditions applied to the request, such as approval or denial.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.certificates.v1beta1.CertificateSigningRequestCondition>[]>;
        }
        /**
         * ClusterTrustBundle is a cluster-scoped container for X.509 trust anchors (root certificates).
         *
         * ClusterTrustBundle objects are considered to be readable by any authenticated user in the cluster, because they can be mounted by pods using the `clusterTrustBundle` projection.  All service accounts have read access to ClusterTrustBundles by default.  Users who only have namespace-level access to a cluster can read ClusterTrustBundles by impersonating a serviceaccount that they have access to.
         *
         * It can be optionally associated with a particular assigner, in which case it contains one valid set of trust anchors for that signer. Signers may have multiple associated ClusterTrustBundles; each is an independent set of trust anchors for that signer. Admission control is used to enforce that only users with permissions on the signer can create or modify the corresponding bundle.
         */
        interface ClusterTrustBundle {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"certificates.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ClusterTrustBundle">;
            /**
             * metadata contains the object metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec contains the signer (if any) and trust anchors.
             */
            spec: pulumi.Input<inputs.certificates.v1beta1.ClusterTrustBundleSpec>;
        }
        /**
         * ClusterTrustBundleSpec contains the signer and trust anchors.
         */
        interface ClusterTrustBundleSpec {
            /**
             * signerName indicates the associated signer, if any.
             *
             * In order to create or update a ClusterTrustBundle that sets signerName, you must have the following cluster-scoped permission: group=certificates.k8s.io resource=signers resourceName=<the signer name> verb=attest.
             *
             * If signerName is not empty, then the ClusterTrustBundle object must be named with the signer name as a prefix (translating slashes to colons). For example, for the signer name `example.com/foo`, valid ClusterTrustBundle object names include `example.com:foo:abc` and `example.com:foo:v1`.
             *
             * If signerName is empty, then the ClusterTrustBundle object's name must not have such a prefix.
             *
             * List/watch requests for ClusterTrustBundles can filter on this field using a `spec.signerName=NAME` field selector.
             */
            signerName?: pulumi.Input<string>;
            /**
             * trustBundle contains the individual X.509 trust anchors for this bundle, as PEM bundle of PEM-wrapped, DER-formatted X.509 certificates.
             *
             * The data must consist only of PEM certificate blocks that parse as valid X.509 certificates.  Each certificate must include a basic constraints extension with the CA bit set.  The API server will reject objects that contain duplicate certificates, or that use PEM block headers.
             *
             * Users of ClusterTrustBundles, including Kubelet, are free to reorder and deduplicate certificate blocks in this file according to their own logic, as well as to drop PEM block headers and inter-block data.
             */
            trustBundle: pulumi.Input<string>;
        }
        /**
         * ClusterTrustBundleSpec contains the signer and trust anchors.
         */
        interface ClusterTrustBundleSpecPatch {
            /**
             * signerName indicates the associated signer, if any.
             *
             * In order to create or update a ClusterTrustBundle that sets signerName, you must have the following cluster-scoped permission: group=certificates.k8s.io resource=signers resourceName=<the signer name> verb=attest.
             *
             * If signerName is not empty, then the ClusterTrustBundle object must be named with the signer name as a prefix (translating slashes to colons). For example, for the signer name `example.com/foo`, valid ClusterTrustBundle object names include `example.com:foo:abc` and `example.com:foo:v1`.
             *
             * If signerName is empty, then the ClusterTrustBundle object's name must not have such a prefix.
             *
             * List/watch requests for ClusterTrustBundles can filter on this field using a `spec.signerName=NAME` field selector.
             */
            signerName?: pulumi.Input<string>;
            /**
             * trustBundle contains the individual X.509 trust anchors for this bundle, as PEM bundle of PEM-wrapped, DER-formatted X.509 certificates.
             *
             * The data must consist only of PEM certificate blocks that parse as valid X.509 certificates.  Each certificate must include a basic constraints extension with the CA bit set.  The API server will reject objects that contain duplicate certificates, or that use PEM block headers.
             *
             * Users of ClusterTrustBundles, including Kubelet, are free to reorder and deduplicate certificate blocks in this file according to their own logic, as well as to drop PEM block headers and inter-block data.
             */
            trustBundle?: pulumi.Input<string>;
        }
    }
}
export declare namespace coordination {
    namespace v1 {
        /**
         * Lease defines a lease concept.
         */
        interface Lease {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"coordination.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Lease">;
            /**
             * More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec contains the specification of the Lease. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.coordination.v1.LeaseSpec>;
        }
        /**
         * LeaseSpec is a specification of a Lease.
         */
        interface LeaseSpec {
            /**
             * acquireTime is a time when the current lease was acquired.
             */
            acquireTime?: pulumi.Input<string>;
            /**
             * holderIdentity contains the identity of the holder of a current lease. If Coordinated Leader Election is used, the holder identity must be equal to the elected LeaseCandidate.metadata.name field.
             */
            holderIdentity?: pulumi.Input<string>;
            /**
             * leaseDurationSeconds is a duration that candidates for a lease need to wait to force acquire it. This is measured against the time of last observed renewTime.
             */
            leaseDurationSeconds?: pulumi.Input<number>;
            /**
             * leaseTransitions is the number of transitions of a lease between holders.
             */
            leaseTransitions?: pulumi.Input<number>;
            /**
             * PreferredHolder signals to a lease holder that the lease has a more optimal holder and should be given up. This field can only be set if Strategy is also set.
             */
            preferredHolder?: pulumi.Input<string>;
            /**
             * renewTime is a time when the current holder of a lease has last updated the lease.
             */
            renewTime?: pulumi.Input<string>;
            /**
             * Strategy indicates the strategy for picking the leader for coordinated leader election. If the field is not specified, there is no active coordination for this lease. (Alpha) Using this field requires the CoordinatedLeaderElection feature gate to be enabled.
             */
            strategy?: pulumi.Input<string>;
        }
        /**
         * LeaseSpec is a specification of a Lease.
         */
        interface LeaseSpecPatch {
            /**
             * acquireTime is a time when the current lease was acquired.
             */
            acquireTime?: pulumi.Input<string>;
            /**
             * holderIdentity contains the identity of the holder of a current lease. If Coordinated Leader Election is used, the holder identity must be equal to the elected LeaseCandidate.metadata.name field.
             */
            holderIdentity?: pulumi.Input<string>;
            /**
             * leaseDurationSeconds is a duration that candidates for a lease need to wait to force acquire it. This is measured against the time of last observed renewTime.
             */
            leaseDurationSeconds?: pulumi.Input<number>;
            /**
             * leaseTransitions is the number of transitions of a lease between holders.
             */
            leaseTransitions?: pulumi.Input<number>;
            /**
             * PreferredHolder signals to a lease holder that the lease has a more optimal holder and should be given up. This field can only be set if Strategy is also set.
             */
            preferredHolder?: pulumi.Input<string>;
            /**
             * renewTime is a time when the current holder of a lease has last updated the lease.
             */
            renewTime?: pulumi.Input<string>;
            /**
             * Strategy indicates the strategy for picking the leader for coordinated leader election. If the field is not specified, there is no active coordination for this lease. (Alpha) Using this field requires the CoordinatedLeaderElection feature gate to be enabled.
             */
            strategy?: pulumi.Input<string>;
        }
    }
    namespace v1alpha1 {
        /**
         * LeaseCandidate defines a candidate for a Lease object. Candidates are created such that coordinated leader election will pick the best leader from the list of candidates.
         */
        interface LeaseCandidate {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"coordination.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"LeaseCandidate">;
            /**
             * More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec contains the specification of the Lease. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.coordination.v1alpha1.LeaseCandidateSpec>;
        }
        /**
         * LeaseCandidateSpec is a specification of a Lease.
         */
        interface LeaseCandidateSpec {
            /**
             * BinaryVersion is the binary version. It must be in a semver format without leading `v`. This field is required when strategy is "OldestEmulationVersion"
             */
            binaryVersion?: pulumi.Input<string>;
            /**
             * EmulationVersion is the emulation version. It must be in a semver format without leading `v`. EmulationVersion must be less than or equal to BinaryVersion. This field is required when strategy is "OldestEmulationVersion"
             */
            emulationVersion?: pulumi.Input<string>;
            /**
             * LeaseName is the name of the lease for which this candidate is contending. This field is immutable.
             */
            leaseName: pulumi.Input<string>;
            /**
             * PingTime is the last time that the server has requested the LeaseCandidate to renew. It is only done during leader election to check if any LeaseCandidates have become ineligible. When PingTime is updated, the LeaseCandidate will respond by updating RenewTime.
             */
            pingTime?: pulumi.Input<string>;
            /**
             * PreferredStrategies indicates the list of strategies for picking the leader for coordinated leader election. The list is ordered, and the first strategy supersedes all other strategies. The list is used by coordinated leader election to make a decision about the final election strategy. This follows as - If all clients have strategy X as the first element in this list, strategy X will be used. - If a candidate has strategy [X] and another candidate has strategy [Y, X], Y supersedes X and strategy Y
             *   will be used.
             * - If a candidate has strategy [X, Y] and another candidate has strategy [Y, X], this is a user error and leader
             *   election will not operate the Lease until resolved.
             * (Alpha) Using this field requires the CoordinatedLeaderElection feature gate to be enabled.
             */
            preferredStrategies: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * RenewTime is the time that the LeaseCandidate was last updated. Any time a Lease needs to do leader election, the PingTime field is updated to signal to the LeaseCandidate that they should update the RenewTime. Old LeaseCandidate objects are also garbage collected if it has been hours since the last renew. The PingTime field is updated regularly to prevent garbage collection for still active LeaseCandidates.
             */
            renewTime?: pulumi.Input<string>;
        }
        /**
         * LeaseCandidateSpec is a specification of a Lease.
         */
        interface LeaseCandidateSpecPatch {
            /**
             * BinaryVersion is the binary version. It must be in a semver format without leading `v`. This field is required when strategy is "OldestEmulationVersion"
             */
            binaryVersion?: pulumi.Input<string>;
            /**
             * EmulationVersion is the emulation version. It must be in a semver format without leading `v`. EmulationVersion must be less than or equal to BinaryVersion. This field is required when strategy is "OldestEmulationVersion"
             */
            emulationVersion?: pulumi.Input<string>;
            /**
             * LeaseName is the name of the lease for which this candidate is contending. This field is immutable.
             */
            leaseName?: pulumi.Input<string>;
            /**
             * PingTime is the last time that the server has requested the LeaseCandidate to renew. It is only done during leader election to check if any LeaseCandidates have become ineligible. When PingTime is updated, the LeaseCandidate will respond by updating RenewTime.
             */
            pingTime?: pulumi.Input<string>;
            /**
             * PreferredStrategies indicates the list of strategies for picking the leader for coordinated leader election. The list is ordered, and the first strategy supersedes all other strategies. The list is used by coordinated leader election to make a decision about the final election strategy. This follows as - If all clients have strategy X as the first element in this list, strategy X will be used. - If a candidate has strategy [X] and another candidate has strategy [Y, X], Y supersedes X and strategy Y
             *   will be used.
             * - If a candidate has strategy [X, Y] and another candidate has strategy [Y, X], this is a user error and leader
             *   election will not operate the Lease until resolved.
             * (Alpha) Using this field requires the CoordinatedLeaderElection feature gate to be enabled.
             */
            preferredStrategies?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * RenewTime is the time that the LeaseCandidate was last updated. Any time a Lease needs to do leader election, the PingTime field is updated to signal to the LeaseCandidate that they should update the RenewTime. Old LeaseCandidate objects are also garbage collected if it has been hours since the last renew. The PingTime field is updated regularly to prevent garbage collection for still active LeaseCandidates.
             */
            renewTime?: pulumi.Input<string>;
        }
    }
    namespace v1alpha2 {
        /**
         * LeaseCandidate defines a candidate for a Lease object. Candidates are created such that coordinated leader election will pick the best leader from the list of candidates.
         */
        interface LeaseCandidate {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"coordination.k8s.io/v1alpha2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"LeaseCandidate">;
            /**
             * More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec contains the specification of the Lease. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.coordination.v1alpha2.LeaseCandidateSpec>;
        }
        /**
         * LeaseCandidateSpec is a specification of a Lease.
         */
        interface LeaseCandidateSpec {
            /**
             * BinaryVersion is the binary version. It must be in a semver format without leading `v`. This field is required.
             */
            binaryVersion: pulumi.Input<string>;
            /**
             * EmulationVersion is the emulation version. It must be in a semver format without leading `v`. EmulationVersion must be less than or equal to BinaryVersion. This field is required when strategy is "OldestEmulationVersion"
             */
            emulationVersion?: pulumi.Input<string>;
            /**
             * LeaseName is the name of the lease for which this candidate is contending. This field is immutable.
             */
            leaseName: pulumi.Input<string>;
            /**
             * PingTime is the last time that the server has requested the LeaseCandidate to renew. It is only done during leader election to check if any LeaseCandidates have become ineligible. When PingTime is updated, the LeaseCandidate will respond by updating RenewTime.
             */
            pingTime?: pulumi.Input<string>;
            /**
             * RenewTime is the time that the LeaseCandidate was last updated. Any time a Lease needs to do leader election, the PingTime field is updated to signal to the LeaseCandidate that they should update the RenewTime. Old LeaseCandidate objects are also garbage collected if it has been hours since the last renew. The PingTime field is updated regularly to prevent garbage collection for still active LeaseCandidates.
             */
            renewTime?: pulumi.Input<string>;
            /**
             * Strategy is the strategy that coordinated leader election will use for picking the leader. If multiple candidates for the same Lease return different strategies, the strategy provided by the candidate with the latest BinaryVersion will be used. If there is still conflict, this is a user error and coordinated leader election will not operate the Lease until resolved.
             */
            strategy: pulumi.Input<string>;
        }
        /**
         * LeaseCandidateSpec is a specification of a Lease.
         */
        interface LeaseCandidateSpecPatch {
            /**
             * BinaryVersion is the binary version. It must be in a semver format without leading `v`. This field is required.
             */
            binaryVersion?: pulumi.Input<string>;
            /**
             * EmulationVersion is the emulation version. It must be in a semver format without leading `v`. EmulationVersion must be less than or equal to BinaryVersion. This field is required when strategy is "OldestEmulationVersion"
             */
            emulationVersion?: pulumi.Input<string>;
            /**
             * LeaseName is the name of the lease for which this candidate is contending. This field is immutable.
             */
            leaseName?: pulumi.Input<string>;
            /**
             * PingTime is the last time that the server has requested the LeaseCandidate to renew. It is only done during leader election to check if any LeaseCandidates have become ineligible. When PingTime is updated, the LeaseCandidate will respond by updating RenewTime.
             */
            pingTime?: pulumi.Input<string>;
            /**
             * RenewTime is the time that the LeaseCandidate was last updated. Any time a Lease needs to do leader election, the PingTime field is updated to signal to the LeaseCandidate that they should update the RenewTime. Old LeaseCandidate objects are also garbage collected if it has been hours since the last renew. The PingTime field is updated regularly to prevent garbage collection for still active LeaseCandidates.
             */
            renewTime?: pulumi.Input<string>;
            /**
             * Strategy is the strategy that coordinated leader election will use for picking the leader. If multiple candidates for the same Lease return different strategies, the strategy provided by the candidate with the latest BinaryVersion will be used. If there is still conflict, this is a user error and coordinated leader election will not operate the Lease until resolved.
             */
            strategy?: pulumi.Input<string>;
        }
    }
    namespace v1beta1 {
        /**
         * Lease defines a lease concept.
         */
        interface Lease {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"coordination.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Lease">;
            /**
             * More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the Lease. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.coordination.v1beta1.LeaseSpec>;
        }
        /**
         * LeaseCandidate defines a candidate for a Lease object. Candidates are created such that coordinated leader election will pick the best leader from the list of candidates.
         */
        interface LeaseCandidate {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"coordination.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"LeaseCandidate">;
            /**
             * More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec contains the specification of the Lease. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.coordination.v1beta1.LeaseCandidateSpec>;
        }
        /**
         * LeaseCandidateSpec is a specification of a Lease.
         */
        interface LeaseCandidateSpec {
            /**
             * BinaryVersion is the binary version. It must be in a semver format without leading `v`. This field is required.
             */
            binaryVersion: pulumi.Input<string>;
            /**
             * EmulationVersion is the emulation version. It must be in a semver format without leading `v`. EmulationVersion must be less than or equal to BinaryVersion. This field is required when strategy is "OldestEmulationVersion"
             */
            emulationVersion?: pulumi.Input<string>;
            /**
             * LeaseName is the name of the lease for which this candidate is contending. The limits on this field are the same as on Lease.name. Multiple lease candidates may reference the same Lease.name. This field is immutable.
             */
            leaseName: pulumi.Input<string>;
            /**
             * PingTime is the last time that the server has requested the LeaseCandidate to renew. It is only done during leader election to check if any LeaseCandidates have become ineligible. When PingTime is updated, the LeaseCandidate will respond by updating RenewTime.
             */
            pingTime?: pulumi.Input<string>;
            /**
             * RenewTime is the time that the LeaseCandidate was last updated. Any time a Lease needs to do leader election, the PingTime field is updated to signal to the LeaseCandidate that they should update the RenewTime. Old LeaseCandidate objects are also garbage collected if it has been hours since the last renew. The PingTime field is updated regularly to prevent garbage collection for still active LeaseCandidates.
             */
            renewTime?: pulumi.Input<string>;
            /**
             * Strategy is the strategy that coordinated leader election will use for picking the leader. If multiple candidates for the same Lease return different strategies, the strategy provided by the candidate with the latest BinaryVersion will be used. If there is still conflict, this is a user error and coordinated leader election will not operate the Lease until resolved.
             */
            strategy: pulumi.Input<string>;
        }
        /**
         * LeaseCandidateSpec is a specification of a Lease.
         */
        interface LeaseCandidateSpecPatch {
            /**
             * BinaryVersion is the binary version. It must be in a semver format without leading `v`. This field is required.
             */
            binaryVersion?: pulumi.Input<string>;
            /**
             * EmulationVersion is the emulation version. It must be in a semver format without leading `v`. EmulationVersion must be less than or equal to BinaryVersion. This field is required when strategy is "OldestEmulationVersion"
             */
            emulationVersion?: pulumi.Input<string>;
            /**
             * LeaseName is the name of the lease for which this candidate is contending. The limits on this field are the same as on Lease.name. Multiple lease candidates may reference the same Lease.name. This field is immutable.
             */
            leaseName?: pulumi.Input<string>;
            /**
             * PingTime is the last time that the server has requested the LeaseCandidate to renew. It is only done during leader election to check if any LeaseCandidates have become ineligible. When PingTime is updated, the LeaseCandidate will respond by updating RenewTime.
             */
            pingTime?: pulumi.Input<string>;
            /**
             * RenewTime is the time that the LeaseCandidate was last updated. Any time a Lease needs to do leader election, the PingTime field is updated to signal to the LeaseCandidate that they should update the RenewTime. Old LeaseCandidate objects are also garbage collected if it has been hours since the last renew. The PingTime field is updated regularly to prevent garbage collection for still active LeaseCandidates.
             */
            renewTime?: pulumi.Input<string>;
            /**
             * Strategy is the strategy that coordinated leader election will use for picking the leader. If multiple candidates for the same Lease return different strategies, the strategy provided by the candidate with the latest BinaryVersion will be used. If there is still conflict, this is a user error and coordinated leader election will not operate the Lease until resolved.
             */
            strategy?: pulumi.Input<string>;
        }
        /**
         * LeaseSpec is a specification of a Lease.
         */
        interface LeaseSpec {
            /**
             * acquireTime is a time when the current lease was acquired.
             */
            acquireTime?: pulumi.Input<string>;
            /**
             * holderIdentity contains the identity of the holder of a current lease.
             */
            holderIdentity?: pulumi.Input<string>;
            /**
             * leaseDurationSeconds is a duration that candidates for a lease need to wait to force acquire it. This is measure against time of last observed RenewTime.
             */
            leaseDurationSeconds?: pulumi.Input<number>;
            /**
             * leaseTransitions is the number of transitions of a lease between holders.
             */
            leaseTransitions?: pulumi.Input<number>;
            /**
             * renewTime is a time when the current holder of a lease has last updated the lease.
             */
            renewTime?: pulumi.Input<string>;
        }
        /**
         * LeaseSpec is a specification of a Lease.
         */
        interface LeaseSpecPatch {
            /**
             * acquireTime is a time when the current lease was acquired.
             */
            acquireTime?: pulumi.Input<string>;
            /**
             * holderIdentity contains the identity of the holder of a current lease.
             */
            holderIdentity?: pulumi.Input<string>;
            /**
             * leaseDurationSeconds is a duration that candidates for a lease need to wait to force acquire it. This is measure against time of last observed RenewTime.
             */
            leaseDurationSeconds?: pulumi.Input<number>;
            /**
             * leaseTransitions is the number of transitions of a lease between holders.
             */
            leaseTransitions?: pulumi.Input<number>;
            /**
             * renewTime is a time when the current holder of a lease has last updated the lease.
             */
            renewTime?: pulumi.Input<string>;
        }
    }
}
export declare namespace core {
    namespace v1 {
        /**
         * Represents a Persistent Disk resource in AWS.
         *
         * An AWS EBS disk must exist before mounting to a container. The disk must also be in the same AWS zone as the kubelet. An AWS EBS disk can only be mounted as read/write once. AWS EBS volumes support ownership management and SELinux relabeling.
         */
        interface AWSElasticBlockStoreVolumeSource {
            /**
             * fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore
             */
            fsType?: pulumi.Input<string>;
            /**
             * partition is the partition in the volume that you want to mount. If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty).
             */
            partition?: pulumi.Input<number>;
            /**
             * readOnly value true will force the readOnly setting in VolumeMounts. More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * volumeID is unique ID of the persistent disk resource in AWS (Amazon EBS volume). More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore
             */
            volumeID: pulumi.Input<string>;
        }
        /**
         * Represents a Persistent Disk resource in AWS.
         *
         * An AWS EBS disk must exist before mounting to a container. The disk must also be in the same AWS zone as the kubelet. An AWS EBS disk can only be mounted as read/write once. AWS EBS volumes support ownership management and SELinux relabeling.
         */
        interface AWSElasticBlockStoreVolumeSourcePatch {
            /**
             * fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore
             */
            fsType?: pulumi.Input<string>;
            /**
             * partition is the partition in the volume that you want to mount. If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty).
             */
            partition?: pulumi.Input<number>;
            /**
             * readOnly value true will force the readOnly setting in VolumeMounts. More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * volumeID is unique ID of the persistent disk resource in AWS (Amazon EBS volume). More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore
             */
            volumeID?: pulumi.Input<string>;
        }
        /**
         * Affinity is a group of affinity scheduling rules.
         */
        interface Affinity {
            /**
             * Describes node affinity scheduling rules for the pod.
             */
            nodeAffinity?: pulumi.Input<inputs.core.v1.NodeAffinity>;
            /**
             * Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).
             */
            podAffinity?: pulumi.Input<inputs.core.v1.PodAffinity>;
            /**
             * Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)).
             */
            podAntiAffinity?: pulumi.Input<inputs.core.v1.PodAntiAffinity>;
        }
        /**
         * Affinity is a group of affinity scheduling rules.
         */
        interface AffinityPatch {
            /**
             * Describes node affinity scheduling rules for the pod.
             */
            nodeAffinity?: pulumi.Input<inputs.core.v1.NodeAffinityPatch>;
            /**
             * Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).
             */
            podAffinity?: pulumi.Input<inputs.core.v1.PodAffinityPatch>;
            /**
             * Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)).
             */
            podAntiAffinity?: pulumi.Input<inputs.core.v1.PodAntiAffinityPatch>;
        }
        /**
         * AppArmorProfile defines a pod or container's AppArmor settings.
         */
        interface AppArmorProfile {
            /**
             * localhostProfile indicates a profile loaded on the node that should be used. The profile must be preconfigured on the node to work. Must match the loaded name of the profile. Must be set if and only if type is "Localhost".
             */
            localhostProfile?: pulumi.Input<string>;
            /**
             * type indicates which kind of AppArmor profile will be applied. Valid options are:
             *   Localhost - a profile pre-loaded on the node.
             *   RuntimeDefault - the container runtime's default profile.
             *   Unconfined - no AppArmor enforcement.
             */
            type: pulumi.Input<string>;
        }
        /**
         * AppArmorProfile defines a pod or container's AppArmor settings.
         */
        interface AppArmorProfilePatch {
            /**
             * localhostProfile indicates a profile loaded on the node that should be used. The profile must be preconfigured on the node to work. Must match the loaded name of the profile. Must be set if and only if type is "Localhost".
             */
            localhostProfile?: pulumi.Input<string>;
            /**
             * type indicates which kind of AppArmor profile will be applied. Valid options are:
             *   Localhost - a profile pre-loaded on the node.
             *   RuntimeDefault - the container runtime's default profile.
             *   Unconfined - no AppArmor enforcement.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * AttachedVolume describes a volume attached to a node
         */
        interface AttachedVolume {
            /**
             * DevicePath represents the device path where the volume should be available
             */
            devicePath: pulumi.Input<string>;
            /**
             * Name of the attached volume
             */
            name: pulumi.Input<string>;
        }
        /**
         * AzureDisk represents an Azure Data Disk mount on the host and bind mount to the pod.
         */
        interface AzureDiskVolumeSource {
            /**
             * cachingMode is the Host Caching mode: None, Read Only, Read Write.
             */
            cachingMode?: pulumi.Input<string>;
            /**
             * diskName is the Name of the data disk in the blob storage
             */
            diskName: pulumi.Input<string>;
            /**
             * diskURI is the URI of data disk in the blob storage
             */
            diskURI: pulumi.Input<string>;
            /**
             * fsType is Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * kind expected values are Shared: multiple blob disks per storage account  Dedicated: single blob disk per storage account  Managed: azure managed data disk (only in managed availability set). defaults to shared
             */
            kind?: pulumi.Input<string>;
            /**
             * readOnly Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
        }
        /**
         * AzureDisk represents an Azure Data Disk mount on the host and bind mount to the pod.
         */
        interface AzureDiskVolumeSourcePatch {
            /**
             * cachingMode is the Host Caching mode: None, Read Only, Read Write.
             */
            cachingMode?: pulumi.Input<string>;
            /**
             * diskName is the Name of the data disk in the blob storage
             */
            diskName?: pulumi.Input<string>;
            /**
             * diskURI is the URI of data disk in the blob storage
             */
            diskURI?: pulumi.Input<string>;
            /**
             * fsType is Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * kind expected values are Shared: multiple blob disks per storage account  Dedicated: single blob disk per storage account  Managed: azure managed data disk (only in managed availability set). defaults to shared
             */
            kind?: pulumi.Input<string>;
            /**
             * readOnly Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
        }
        /**
         * AzureFile represents an Azure File Service mount on the host and bind mount to the pod.
         */
        interface AzureFilePersistentVolumeSource {
            /**
             * readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretName is the name of secret that contains Azure Storage Account Name and Key
             */
            secretName: pulumi.Input<string>;
            /**
             * secretNamespace is the namespace of the secret that contains Azure Storage Account Name and Key default is the same as the Pod
             */
            secretNamespace?: pulumi.Input<string>;
            /**
             * shareName is the azure Share Name
             */
            shareName: pulumi.Input<string>;
        }
        /**
         * AzureFile represents an Azure File Service mount on the host and bind mount to the pod.
         */
        interface AzureFilePersistentVolumeSourcePatch {
            /**
             * readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretName is the name of secret that contains Azure Storage Account Name and Key
             */
            secretName?: pulumi.Input<string>;
            /**
             * secretNamespace is the namespace of the secret that contains Azure Storage Account Name and Key default is the same as the Pod
             */
            secretNamespace?: pulumi.Input<string>;
            /**
             * shareName is the azure Share Name
             */
            shareName?: pulumi.Input<string>;
        }
        /**
         * AzureFile represents an Azure File Service mount on the host and bind mount to the pod.
         */
        interface AzureFileVolumeSource {
            /**
             * readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretName is the  name of secret that contains Azure Storage Account Name and Key
             */
            secretName: pulumi.Input<string>;
            /**
             * shareName is the azure share Name
             */
            shareName: pulumi.Input<string>;
        }
        /**
         * AzureFile represents an Azure File Service mount on the host and bind mount to the pod.
         */
        interface AzureFileVolumeSourcePatch {
            /**
             * readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretName is the  name of secret that contains Azure Storage Account Name and Key
             */
            secretName?: pulumi.Input<string>;
            /**
             * shareName is the azure share Name
             */
            shareName?: pulumi.Input<string>;
        }
        /**
         * Represents storage that is managed by an external CSI volume driver
         */
        interface CSIPersistentVolumeSource {
            /**
             * controllerExpandSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI ControllerExpandVolume call. This field is optional, and may be empty if no secret is required. If the secret object contains more than one secret, all secrets are passed.
             */
            controllerExpandSecretRef?: pulumi.Input<inputs.core.v1.SecretReference>;
            /**
             * controllerPublishSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI ControllerPublishVolume and ControllerUnpublishVolume calls. This field is optional, and may be empty if no secret is required. If the secret object contains more than one secret, all secrets are passed.
             */
            controllerPublishSecretRef?: pulumi.Input<inputs.core.v1.SecretReference>;
            /**
             * driver is the name of the driver to use for this volume. Required.
             */
            driver: pulumi.Input<string>;
            /**
             * fsType to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs".
             */
            fsType?: pulumi.Input<string>;
            /**
             * nodeExpandSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI NodeExpandVolume call. This field is optional, may be omitted if no secret is required. If the secret object contains more than one secret, all secrets are passed.
             */
            nodeExpandSecretRef?: pulumi.Input<inputs.core.v1.SecretReference>;
            /**
             * nodePublishSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI NodePublishVolume and NodeUnpublishVolume calls. This field is optional, and may be empty if no secret is required. If the secret object contains more than one secret, all secrets are passed.
             */
            nodePublishSecretRef?: pulumi.Input<inputs.core.v1.SecretReference>;
            /**
             * nodeStageSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI NodeStageVolume and NodeStageVolume and NodeUnstageVolume calls. This field is optional, and may be empty if no secret is required. If the secret object contains more than one secret, all secrets are passed.
             */
            nodeStageSecretRef?: pulumi.Input<inputs.core.v1.SecretReference>;
            /**
             * readOnly value to pass to ControllerPublishVolumeRequest. Defaults to false (read/write).
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * volumeAttributes of the volume to publish.
             */
            volumeAttributes?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * volumeHandle is the unique volume name returned by the CSI volume plugin’s CreateVolume to refer to the volume on all subsequent calls. Required.
             */
            volumeHandle: pulumi.Input<string>;
        }
        /**
         * Represents storage that is managed by an external CSI volume driver
         */
        interface CSIPersistentVolumeSourcePatch {
            /**
             * controllerExpandSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI ControllerExpandVolume call. This field is optional, and may be empty if no secret is required. If the secret object contains more than one secret, all secrets are passed.
             */
            controllerExpandSecretRef?: pulumi.Input<inputs.core.v1.SecretReferencePatch>;
            /**
             * controllerPublishSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI ControllerPublishVolume and ControllerUnpublishVolume calls. This field is optional, and may be empty if no secret is required. If the secret object contains more than one secret, all secrets are passed.
             */
            controllerPublishSecretRef?: pulumi.Input<inputs.core.v1.SecretReferencePatch>;
            /**
             * driver is the name of the driver to use for this volume. Required.
             */
            driver?: pulumi.Input<string>;
            /**
             * fsType to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs".
             */
            fsType?: pulumi.Input<string>;
            /**
             * nodeExpandSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI NodeExpandVolume call. This field is optional, may be omitted if no secret is required. If the secret object contains more than one secret, all secrets are passed.
             */
            nodeExpandSecretRef?: pulumi.Input<inputs.core.v1.SecretReferencePatch>;
            /**
             * nodePublishSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI NodePublishVolume and NodeUnpublishVolume calls. This field is optional, and may be empty if no secret is required. If the secret object contains more than one secret, all secrets are passed.
             */
            nodePublishSecretRef?: pulumi.Input<inputs.core.v1.SecretReferencePatch>;
            /**
             * nodeStageSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI NodeStageVolume and NodeStageVolume and NodeUnstageVolume calls. This field is optional, and may be empty if no secret is required. If the secret object contains more than one secret, all secrets are passed.
             */
            nodeStageSecretRef?: pulumi.Input<inputs.core.v1.SecretReferencePatch>;
            /**
             * readOnly value to pass to ControllerPublishVolumeRequest. Defaults to false (read/write).
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * volumeAttributes of the volume to publish.
             */
            volumeAttributes?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * volumeHandle is the unique volume name returned by the CSI volume plugin’s CreateVolume to refer to the volume on all subsequent calls. Required.
             */
            volumeHandle?: pulumi.Input<string>;
        }
        /**
         * Represents a source location of a volume to mount, managed by an external CSI driver
         */
        interface CSIVolumeSource {
            /**
             * driver is the name of the CSI driver that handles this volume. Consult with your admin for the correct name as registered in the cluster.
             */
            driver: pulumi.Input<string>;
            /**
             * fsType to mount. Ex. "ext4", "xfs", "ntfs". If not provided, the empty value is passed to the associated CSI driver which will determine the default filesystem to apply.
             */
            fsType?: pulumi.Input<string>;
            /**
             * nodePublishSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI NodePublishVolume and NodeUnpublishVolume calls. This field is optional, and  may be empty if no secret is required. If the secret object contains more than one secret, all secret references are passed.
             */
            nodePublishSecretRef?: pulumi.Input<inputs.core.v1.LocalObjectReference>;
            /**
             * readOnly specifies a read-only configuration for the volume. Defaults to false (read/write).
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * volumeAttributes stores driver-specific properties that are passed to the CSI driver. Consult your driver's documentation for supported values.
             */
            volumeAttributes?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * Represents a source location of a volume to mount, managed by an external CSI driver
         */
        interface CSIVolumeSourcePatch {
            /**
             * driver is the name of the CSI driver that handles this volume. Consult with your admin for the correct name as registered in the cluster.
             */
            driver?: pulumi.Input<string>;
            /**
             * fsType to mount. Ex. "ext4", "xfs", "ntfs". If not provided, the empty value is passed to the associated CSI driver which will determine the default filesystem to apply.
             */
            fsType?: pulumi.Input<string>;
            /**
             * nodePublishSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI NodePublishVolume and NodeUnpublishVolume calls. This field is optional, and  may be empty if no secret is required. If the secret object contains more than one secret, all secret references are passed.
             */
            nodePublishSecretRef?: pulumi.Input<inputs.core.v1.LocalObjectReferencePatch>;
            /**
             * readOnly specifies a read-only configuration for the volume. Defaults to false (read/write).
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * volumeAttributes stores driver-specific properties that are passed to the CSI driver. Consult your driver's documentation for supported values.
             */
            volumeAttributes?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * Adds and removes POSIX capabilities from running containers.
         */
        interface Capabilities {
            /**
             * Added capabilities
             */
            add?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Removed capabilities
             */
            drop?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * Adds and removes POSIX capabilities from running containers.
         */
        interface CapabilitiesPatch {
            /**
             * Added capabilities
             */
            add?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Removed capabilities
             */
            drop?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * Represents a Ceph Filesystem mount that lasts the lifetime of a pod Cephfs volumes do not support ownership management or SELinux relabeling.
         */
        interface CephFSPersistentVolumeSource {
            /**
             * monitors is Required: Monitors is a collection of Ceph monitors More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            monitors: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * path is Optional: Used as the mounted root, rather than the full Ceph tree, default is /
             */
            path?: pulumi.Input<string>;
            /**
             * readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretFile is Optional: SecretFile is the path to key ring for User, default is /etc/ceph/user.secret More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            secretFile?: pulumi.Input<string>;
            /**
             * secretRef is Optional: SecretRef is reference to the authentication secret for User, default is empty. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            secretRef?: pulumi.Input<inputs.core.v1.SecretReference>;
            /**
             * user is Optional: User is the rados user name, default is admin More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            user?: pulumi.Input<string>;
        }
        /**
         * Represents a Ceph Filesystem mount that lasts the lifetime of a pod Cephfs volumes do not support ownership management or SELinux relabeling.
         */
        interface CephFSPersistentVolumeSourcePatch {
            /**
             * monitors is Required: Monitors is a collection of Ceph monitors More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            monitors?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * path is Optional: Used as the mounted root, rather than the full Ceph tree, default is /
             */
            path?: pulumi.Input<string>;
            /**
             * readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretFile is Optional: SecretFile is the path to key ring for User, default is /etc/ceph/user.secret More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            secretFile?: pulumi.Input<string>;
            /**
             * secretRef is Optional: SecretRef is reference to the authentication secret for User, default is empty. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            secretRef?: pulumi.Input<inputs.core.v1.SecretReferencePatch>;
            /**
             * user is Optional: User is the rados user name, default is admin More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            user?: pulumi.Input<string>;
        }
        /**
         * Represents a Ceph Filesystem mount that lasts the lifetime of a pod Cephfs volumes do not support ownership management or SELinux relabeling.
         */
        interface CephFSVolumeSource {
            /**
             * monitors is Required: Monitors is a collection of Ceph monitors More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            monitors: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * path is Optional: Used as the mounted root, rather than the full Ceph tree, default is /
             */
            path?: pulumi.Input<string>;
            /**
             * readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretFile is Optional: SecretFile is the path to key ring for User, default is /etc/ceph/user.secret More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            secretFile?: pulumi.Input<string>;
            /**
             * secretRef is Optional: SecretRef is reference to the authentication secret for User, default is empty. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            secretRef?: pulumi.Input<inputs.core.v1.LocalObjectReference>;
            /**
             * user is optional: User is the rados user name, default is admin More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            user?: pulumi.Input<string>;
        }
        /**
         * Represents a Ceph Filesystem mount that lasts the lifetime of a pod Cephfs volumes do not support ownership management or SELinux relabeling.
         */
        interface CephFSVolumeSourcePatch {
            /**
             * monitors is Required: Monitors is a collection of Ceph monitors More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            monitors?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * path is Optional: Used as the mounted root, rather than the full Ceph tree, default is /
             */
            path?: pulumi.Input<string>;
            /**
             * readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretFile is Optional: SecretFile is the path to key ring for User, default is /etc/ceph/user.secret More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            secretFile?: pulumi.Input<string>;
            /**
             * secretRef is Optional: SecretRef is reference to the authentication secret for User, default is empty. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            secretRef?: pulumi.Input<inputs.core.v1.LocalObjectReferencePatch>;
            /**
             * user is optional: User is the rados user name, default is admin More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it
             */
            user?: pulumi.Input<string>;
        }
        /**
         * Represents a cinder volume resource in Openstack. A Cinder volume must exist before mounting to a container. The volume must also be in the same region as the kubelet. Cinder volumes support ownership management and SELinux relabeling.
         */
        interface CinderPersistentVolumeSource {
            /**
             * fsType Filesystem type to mount. Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            fsType?: pulumi.Input<string>;
            /**
             * readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is Optional: points to a secret object containing parameters used to connect to OpenStack.
             */
            secretRef?: pulumi.Input<inputs.core.v1.SecretReference>;
            /**
             * volumeID used to identify the volume in cinder. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            volumeID: pulumi.Input<string>;
        }
        /**
         * Represents a cinder volume resource in Openstack. A Cinder volume must exist before mounting to a container. The volume must also be in the same region as the kubelet. Cinder volumes support ownership management and SELinux relabeling.
         */
        interface CinderPersistentVolumeSourcePatch {
            /**
             * fsType Filesystem type to mount. Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            fsType?: pulumi.Input<string>;
            /**
             * readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is Optional: points to a secret object containing parameters used to connect to OpenStack.
             */
            secretRef?: pulumi.Input<inputs.core.v1.SecretReferencePatch>;
            /**
             * volumeID used to identify the volume in cinder. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            volumeID?: pulumi.Input<string>;
        }
        /**
         * Represents a cinder volume resource in Openstack. A Cinder volume must exist before mounting to a container. The volume must also be in the same region as the kubelet. Cinder volumes support ownership management and SELinux relabeling.
         */
        interface CinderVolumeSource {
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            fsType?: pulumi.Input<string>;
            /**
             * readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is optional: points to a secret object containing parameters used to connect to OpenStack.
             */
            secretRef?: pulumi.Input<inputs.core.v1.LocalObjectReference>;
            /**
             * volumeID used to identify the volume in cinder. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            volumeID: pulumi.Input<string>;
        }
        /**
         * Represents a cinder volume resource in Openstack. A Cinder volume must exist before mounting to a container. The volume must also be in the same region as the kubelet. Cinder volumes support ownership management and SELinux relabeling.
         */
        interface CinderVolumeSourcePatch {
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            fsType?: pulumi.Input<string>;
            /**
             * readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is optional: points to a secret object containing parameters used to connect to OpenStack.
             */
            secretRef?: pulumi.Input<inputs.core.v1.LocalObjectReferencePatch>;
            /**
             * volumeID used to identify the volume in cinder. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            volumeID?: pulumi.Input<string>;
        }
        /**
         * ClaimSource describes a reference to a ResourceClaim.
         *
         * Exactly one of these fields should be set.  Consumers of this type must treat an empty object as if it has an unknown value.
         */
        interface ClaimSource {
            /**
             * ResourceClaimName is the name of a ResourceClaim object in the same namespace as this pod.
             */
            resourceClaimName?: pulumi.Input<string>;
            /**
             * ResourceClaimTemplateName is the name of a ResourceClaimTemplate object in the same namespace as this pod.
             *
             * The template will be used to create a new ResourceClaim, which will be bound to this pod. When this pod is deleted, the ResourceClaim will also be deleted. The name of the ResourceClaim will be <pod name>-<resource name>, where <resource name> is the PodResourceClaim.Name. Pod validation will reject the pod if the concatenated name is not valid for a ResourceClaim (e.g. too long).
             *
             * An existing ResourceClaim with that name that is not owned by the pod will not be used for the pod to avoid using an unrelated resource by mistake. Scheduling and pod startup are then blocked until the unrelated ResourceClaim is removed.
             *
             * This field is immutable and no changes will be made to the corresponding ResourceClaim by the control plane after creating the ResourceClaim.
             */
            resourceClaimTemplateName?: pulumi.Input<string>;
        }
        /**
         * ClaimSource describes a reference to a ResourceClaim.
         *
         * Exactly one of these fields should be set.  Consumers of this type must treat an empty object as if it has an unknown value.
         */
        interface ClaimSourcePatch {
            /**
             * ResourceClaimName is the name of a ResourceClaim object in the same namespace as this pod.
             */
            resourceClaimName?: pulumi.Input<string>;
            /**
             * ResourceClaimTemplateName is the name of a ResourceClaimTemplate object in the same namespace as this pod.
             *
             * The template will be used to create a new ResourceClaim, which will be bound to this pod. When this pod is deleted, the ResourceClaim will also be deleted. The name of the ResourceClaim will be <pod name>-<resource name>, where <resource name> is the PodResourceClaim.Name. Pod validation will reject the pod if the concatenated name is not valid for a ResourceClaim (e.g. too long).
             *
             * An existing ResourceClaim with that name that is not owned by the pod will not be used for the pod to avoid using an unrelated resource by mistake. Scheduling and pod startup are then blocked until the unrelated ResourceClaim is removed.
             *
             * This field is immutable and no changes will be made to the corresponding ResourceClaim by the control plane after creating the ResourceClaim.
             */
            resourceClaimTemplateName?: pulumi.Input<string>;
        }
        /**
         * ClientIPConfig represents the configurations of Client IP based session affinity.
         */
        interface ClientIPConfig {
            /**
             * timeoutSeconds specifies the seconds of ClientIP type session sticky time. The value must be >0 && <=86400(for 1 day) if ServiceAffinity == "ClientIP". Default value is 10800(for 3 hours).
             */
            timeoutSeconds?: pulumi.Input<number>;
        }
        /**
         * ClientIPConfig represents the configurations of Client IP based session affinity.
         */
        interface ClientIPConfigPatch {
            /**
             * timeoutSeconds specifies the seconds of ClientIP type session sticky time. The value must be >0 && <=86400(for 1 day) if ServiceAffinity == "ClientIP". Default value is 10800(for 3 hours).
             */
            timeoutSeconds?: pulumi.Input<number>;
        }
        /**
         * ClusterTrustBundleProjection describes how to select a set of ClusterTrustBundle objects and project their contents into the pod filesystem.
         */
        interface ClusterTrustBundleProjection {
            /**
             * Select all ClusterTrustBundles that match this label selector.  Only has effect if signerName is set.  Mutually-exclusive with name.  If unset, interpreted as "match nothing".  If set but empty, interpreted as "match everything".
             */
            labelSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * Select a single ClusterTrustBundle by object name.  Mutually-exclusive with signerName and labelSelector.
             */
            name?: pulumi.Input<string>;
            /**
             * If true, don't block pod startup if the referenced ClusterTrustBundle(s) aren't available.  If using name, then the named ClusterTrustBundle is allowed not to exist.  If using signerName, then the combination of signerName and labelSelector is allowed to match zero ClusterTrustBundles.
             */
            optional?: pulumi.Input<boolean>;
            /**
             * Relative path from the volume root to write the bundle.
             */
            path: pulumi.Input<string>;
            /**
             * Select all ClusterTrustBundles that match this signer name. Mutually-exclusive with name.  The contents of all selected ClusterTrustBundles will be unified and deduplicated.
             */
            signerName?: pulumi.Input<string>;
        }
        /**
         * ClusterTrustBundleProjection describes how to select a set of ClusterTrustBundle objects and project their contents into the pod filesystem.
         */
        interface ClusterTrustBundleProjectionPatch {
            /**
             * Select all ClusterTrustBundles that match this label selector.  Only has effect if signerName is set.  Mutually-exclusive with name.  If unset, interpreted as "match nothing".  If set but empty, interpreted as "match everything".
             */
            labelSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * Select a single ClusterTrustBundle by object name.  Mutually-exclusive with signerName and labelSelector.
             */
            name?: pulumi.Input<string>;
            /**
             * If true, don't block pod startup if the referenced ClusterTrustBundle(s) aren't available.  If using name, then the named ClusterTrustBundle is allowed not to exist.  If using signerName, then the combination of signerName and labelSelector is allowed to match zero ClusterTrustBundles.
             */
            optional?: pulumi.Input<boolean>;
            /**
             * Relative path from the volume root to write the bundle.
             */
            path?: pulumi.Input<string>;
            /**
             * Select all ClusterTrustBundles that match this signer name. Mutually-exclusive with name.  The contents of all selected ClusterTrustBundles will be unified and deduplicated.
             */
            signerName?: pulumi.Input<string>;
        }
        /**
         * ConfigMap holds configuration data for pods to consume.
         */
        interface ConfigMap {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * BinaryData contains the binary data. Each key must consist of alphanumeric characters, '-', '_' or '.'. BinaryData can contain byte sequences that are not in the UTF-8 range. The keys stored in BinaryData must not overlap with the ones in the Data field, this is enforced during validation process. Using this field will require 1.10+ apiserver and kubelet.
             */
            binaryData?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Data contains the configuration data. Each key must consist of alphanumeric characters, '-', '_' or '.'. Values with non-UTF-8 byte sequences must use the BinaryData field. The keys stored in Data must not overlap with the keys in the BinaryData field, this is enforced during validation process.
             */
            data?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Immutable, if set to true, ensures that data stored in the ConfigMap cannot be updated (only object metadata can be modified). If not set to true, the field can be modified at any time. Defaulted to nil.
             */
            immutable?: pulumi.Input<boolean>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ConfigMap">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
        }
        /**
         * ConfigMapEnvSource selects a ConfigMap to populate the environment variables with.
         *
         * The contents of the target ConfigMap's Data field will represent the key-value pairs as environment variables.
         */
        interface ConfigMapEnvSource {
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * Specify whether the ConfigMap must be defined
             */
            optional?: pulumi.Input<boolean>;
        }
        /**
         * ConfigMapEnvSource selects a ConfigMap to populate the environment variables with.
         *
         * The contents of the target ConfigMap's Data field will represent the key-value pairs as environment variables.
         */
        interface ConfigMapEnvSourcePatch {
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * Specify whether the ConfigMap must be defined
             */
            optional?: pulumi.Input<boolean>;
        }
        /**
         * Selects a key from a ConfigMap.
         */
        interface ConfigMapKeySelector {
            /**
             * The key to select.
             */
            key: pulumi.Input<string>;
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * Specify whether the ConfigMap or its key must be defined
             */
            optional?: pulumi.Input<boolean>;
        }
        /**
         * Selects a key from a ConfigMap.
         */
        interface ConfigMapKeySelectorPatch {
            /**
             * The key to select.
             */
            key?: pulumi.Input<string>;
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * Specify whether the ConfigMap or its key must be defined
             */
            optional?: pulumi.Input<boolean>;
        }
        /**
         * ConfigMapNodeConfigSource contains the information to reference a ConfigMap as a config source for the Node. This API is deprecated since 1.22: https://git.k8s.io/enhancements/keps/sig-node/281-dynamic-kubelet-configuration
         */
        interface ConfigMapNodeConfigSource {
            /**
             * KubeletConfigKey declares which key of the referenced ConfigMap corresponds to the KubeletConfiguration structure This field is required in all cases.
             */
            kubeletConfigKey: pulumi.Input<string>;
            /**
             * Name is the metadata.name of the referenced ConfigMap. This field is required in all cases.
             */
            name: pulumi.Input<string>;
            /**
             * Namespace is the metadata.namespace of the referenced ConfigMap. This field is required in all cases.
             */
            namespace: pulumi.Input<string>;
            /**
             * ResourceVersion is the metadata.ResourceVersion of the referenced ConfigMap. This field is forbidden in Node.Spec, and required in Node.Status.
             */
            resourceVersion?: pulumi.Input<string>;
            /**
             * UID is the metadata.UID of the referenced ConfigMap. This field is forbidden in Node.Spec, and required in Node.Status.
             */
            uid?: pulumi.Input<string>;
        }
        /**
         * ConfigMapNodeConfigSource contains the information to reference a ConfigMap as a config source for the Node. This API is deprecated since 1.22: https://git.k8s.io/enhancements/keps/sig-node/281-dynamic-kubelet-configuration
         */
        interface ConfigMapNodeConfigSourcePatch {
            /**
             * KubeletConfigKey declares which key of the referenced ConfigMap corresponds to the KubeletConfiguration structure This field is required in all cases.
             */
            kubeletConfigKey?: pulumi.Input<string>;
            /**
             * Name is the metadata.name of the referenced ConfigMap. This field is required in all cases.
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace is the metadata.namespace of the referenced ConfigMap. This field is required in all cases.
             */
            namespace?: pulumi.Input<string>;
            /**
             * ResourceVersion is the metadata.ResourceVersion of the referenced ConfigMap. This field is forbidden in Node.Spec, and required in Node.Status.
             */
            resourceVersion?: pulumi.Input<string>;
            /**
             * UID is the metadata.UID of the referenced ConfigMap. This field is forbidden in Node.Spec, and required in Node.Status.
             */
            uid?: pulumi.Input<string>;
        }
        /**
         * Adapts a ConfigMap into a projected volume.
         *
         * The contents of the target ConfigMap's Data field will be presented in a projected volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. Note that this is identical to a configmap volume source without the default mode.
         */
        interface ConfigMapProjection {
            /**
             * items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
             */
            items?: pulumi.Input<pulumi.Input<inputs.core.v1.KeyToPath>[]>;
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * optional specify whether the ConfigMap or its keys must be defined
             */
            optional?: pulumi.Input<boolean>;
        }
        /**
         * Adapts a ConfigMap into a projected volume.
         *
         * The contents of the target ConfigMap's Data field will be presented in a projected volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. Note that this is identical to a configmap volume source without the default mode.
         */
        interface ConfigMapProjectionPatch {
            /**
             * items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
             */
            items?: pulumi.Input<pulumi.Input<inputs.core.v1.KeyToPathPatch>[]>;
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * optional specify whether the ConfigMap or its keys must be defined
             */
            optional?: pulumi.Input<boolean>;
        }
        /**
         * Adapts a ConfigMap into a volume.
         *
         * The contents of the target ConfigMap's Data field will be presented in a volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. ConfigMap volumes support ownership management and SELinux relabeling.
         */
        interface ConfigMapVolumeSource {
            /**
             * defaultMode is optional: mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
             */
            defaultMode?: pulumi.Input<number>;
            /**
             * items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
             */
            items?: pulumi.Input<pulumi.Input<inputs.core.v1.KeyToPath>[]>;
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * optional specify whether the ConfigMap or its keys must be defined
             */
            optional?: pulumi.Input<boolean>;
        }
        /**
         * Adapts a ConfigMap into a volume.
         *
         * The contents of the target ConfigMap's Data field will be presented in a volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. ConfigMap volumes support ownership management and SELinux relabeling.
         */
        interface ConfigMapVolumeSourcePatch {
            /**
             * defaultMode is optional: mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
             */
            defaultMode?: pulumi.Input<number>;
            /**
             * items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
             */
            items?: pulumi.Input<pulumi.Input<inputs.core.v1.KeyToPathPatch>[]>;
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * optional specify whether the ConfigMap or its keys must be defined
             */
            optional?: pulumi.Input<boolean>;
        }
        /**
         * A single application container that you want to run within a pod.
         */
        interface Container {
            /**
             * Arguments to the entrypoint. The container image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
             */
            args?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Entrypoint array. Not executed within a shell. The container image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
             */
            command?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * List of environment variables to set in the container. Cannot be updated.
             */
            env?: pulumi.Input<pulumi.Input<inputs.core.v1.EnvVar>[]>;
            /**
             * List of sources to populate environment variables in the container. The keys defined within a source must be a C_IDENTIFIER. All invalid keys will be reported as an event when the container is starting. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated.
             */
            envFrom?: pulumi.Input<pulumi.Input<inputs.core.v1.EnvFromSource>[]>;
            /**
             * Container image name. More info: https://kubernetes.io/docs/concepts/containers/images This field is optional to allow higher level config management to default or override container images in workload controllers like Deployments and StatefulSets.
             */
            image?: pulumi.Input<string>;
            /**
             * Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images
             */
            imagePullPolicy?: pulumi.Input<string>;
            /**
             * Actions that the management system should take in response to container lifecycle events. Cannot be updated.
             */
            lifecycle?: pulumi.Input<inputs.core.v1.Lifecycle>;
            /**
             * Periodic probe of container liveness. Container will be restarted if the probe fails. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
             */
            livenessProbe?: pulumi.Input<inputs.core.v1.Probe>;
            /**
             * Name of the container specified as a DNS_LABEL. Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
             */
            name: pulumi.Input<string>;
            /**
             * List of ports to expose from the container. Not specifying a port here DOES NOT prevent that port from being exposed. Any port which is listening on the default "0.0.0.0" address inside a container will be accessible from the network. Modifying this array with strategic merge patch may corrupt the data. For more information See https://github.com/kubernetes/kubernetes/issues/108255. Cannot be updated.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.core.v1.ContainerPort>[]>;
            /**
             * Periodic probe of container service readiness. Container will be removed from service endpoints if the probe fails. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
             */
            readinessProbe?: pulumi.Input<inputs.core.v1.Probe>;
            /**
             * Resources resize policy for the container.
             */
            resizePolicy?: pulumi.Input<pulumi.Input<inputs.core.v1.ContainerResizePolicy>[]>;
            /**
             * Compute Resources required by this container. Cannot be updated. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
             */
            resources?: pulumi.Input<inputs.core.v1.ResourceRequirements>;
            /**
             * RestartPolicy defines the restart behavior of individual containers in a pod. This field may only be set for init containers, and the only allowed value is "Always". For non-init containers or when this field is not specified, the restart behavior is defined by the Pod's restart policy and the container type. Setting the RestartPolicy as "Always" for the init container will have the following effect: this init container will be continually restarted on exit until all regular containers have terminated. Once all regular containers have completed, all init containers with restartPolicy "Always" will be shut down. This lifecycle differs from normal init containers and is often referred to as a "sidecar" container. Although this init container still starts in the init container sequence, it does not wait for the container to complete before proceeding to the next init container. Instead, the next init container starts immediately after this init container is started, or after any startupProbe has successfully completed.
             */
            restartPolicy?: pulumi.Input<string>;
            /**
             * SecurityContext defines the security options the container should be run with. If set, the fields of SecurityContext override the equivalent fields of PodSecurityContext. More info: https://kubernetes.io/docs/tasks/configure-pod-container/security-context/
             */
            securityContext?: pulumi.Input<inputs.core.v1.SecurityContext>;
            /**
             * StartupProbe indicates that the Pod has successfully initialized. If specified, no other probes are executed until this completes successfully. If this probe fails, the Pod will be restarted, just as if the livenessProbe failed. This can be used to provide different probe parameters at the beginning of a Pod's lifecycle, when it might take a long time to load data or warm a cache, than during steady-state operation. This cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
             */
            startupProbe?: pulumi.Input<inputs.core.v1.Probe>;
            /**
             * Whether this container should allocate a buffer for stdin in the container runtime. If this is not set, reads from stdin in the container will always result in EOF. Default is false.
             */
            stdin?: pulumi.Input<boolean>;
            /**
             * Whether the container runtime should close the stdin channel after it has been opened by a single attach. When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false
             */
            stdinOnce?: pulumi.Input<boolean>;
            /**
             * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem. Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated.
             */
            terminationMessagePath?: pulumi.Input<string>;
            /**
             * Indicate how the termination message should be populated. File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
             */
            terminationMessagePolicy?: pulumi.Input<string>;
            /**
             * Whether this container should allocate a TTY for itself, also requires 'stdin' to be true. Default is false.
             */
            tty?: pulumi.Input<boolean>;
            /**
             * volumeDevices is the list of block devices to be used by the container.
             */
            volumeDevices?: pulumi.Input<pulumi.Input<inputs.core.v1.VolumeDevice>[]>;
            /**
             * Pod volumes to mount into the container's filesystem. Cannot be updated.
             */
            volumeMounts?: pulumi.Input<pulumi.Input<inputs.core.v1.VolumeMount>[]>;
            /**
             * Container's working directory. If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
             */
            workingDir?: pulumi.Input<string>;
        }
        /**
         * Describe a container image
         */
        interface ContainerImage {
            /**
             * Names by which this image is known. e.g. ["kubernetes.example/hyperkube:v1.0.7", "cloud-vendor.registry.example/cloud-vendor/hyperkube:v1.0.7"]
             */
            names: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * The size of the image in bytes.
             */
            sizeBytes?: pulumi.Input<number>;
        }
        /**
         * A single application container that you want to run within a pod.
         */
        interface ContainerPatch {
            /**
             * Arguments to the entrypoint. The container image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
             */
            args?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Entrypoint array. Not executed within a shell. The container image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
             */
            command?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * List of environment variables to set in the container. Cannot be updated.
             */
            env?: pulumi.Input<pulumi.Input<inputs.core.v1.EnvVarPatch>[]>;
            /**
             * List of sources to populate environment variables in the container. The keys defined within a source must be a C_IDENTIFIER. All invalid keys will be reported as an event when the container is starting. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated.
             */
            envFrom?: pulumi.Input<pulumi.Input<inputs.core.v1.EnvFromSourcePatch>[]>;
            /**
             * Container image name. More info: https://kubernetes.io/docs/concepts/containers/images This field is optional to allow higher level config management to default or override container images in workload controllers like Deployments and StatefulSets.
             */
            image?: pulumi.Input<string>;
            /**
             * Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images
             */
            imagePullPolicy?: pulumi.Input<string>;
            /**
             * Actions that the management system should take in response to container lifecycle events. Cannot be updated.
             */
            lifecycle?: pulumi.Input<inputs.core.v1.LifecyclePatch>;
            /**
             * Periodic probe of container liveness. Container will be restarted if the probe fails. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
             */
            livenessProbe?: pulumi.Input<inputs.core.v1.ProbePatch>;
            /**
             * Name of the container specified as a DNS_LABEL. Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
             */
            name?: pulumi.Input<string>;
            /**
             * List of ports to expose from the container. Not specifying a port here DOES NOT prevent that port from being exposed. Any port which is listening on the default "0.0.0.0" address inside a container will be accessible from the network. Modifying this array with strategic merge patch may corrupt the data. For more information See https://github.com/kubernetes/kubernetes/issues/108255. Cannot be updated.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.core.v1.ContainerPortPatch>[]>;
            /**
             * Periodic probe of container service readiness. Container will be removed from service endpoints if the probe fails. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
             */
            readinessProbe?: pulumi.Input<inputs.core.v1.ProbePatch>;
            /**
             * Resources resize policy for the container.
             */
            resizePolicy?: pulumi.Input<pulumi.Input<inputs.core.v1.ContainerResizePolicyPatch>[]>;
            /**
             * Compute Resources required by this container. Cannot be updated. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
             */
            resources?: pulumi.Input<inputs.core.v1.ResourceRequirementsPatch>;
            /**
             * RestartPolicy defines the restart behavior of individual containers in a pod. This field may only be set for init containers, and the only allowed value is "Always". For non-init containers or when this field is not specified, the restart behavior is defined by the Pod's restart policy and the container type. Setting the RestartPolicy as "Always" for the init container will have the following effect: this init container will be continually restarted on exit until all regular containers have terminated. Once all regular containers have completed, all init containers with restartPolicy "Always" will be shut down. This lifecycle differs from normal init containers and is often referred to as a "sidecar" container. Although this init container still starts in the init container sequence, it does not wait for the container to complete before proceeding to the next init container. Instead, the next init container starts immediately after this init container is started, or after any startupProbe has successfully completed.
             */
            restartPolicy?: pulumi.Input<string>;
            /**
             * SecurityContext defines the security options the container should be run with. If set, the fields of SecurityContext override the equivalent fields of PodSecurityContext. More info: https://kubernetes.io/docs/tasks/configure-pod-container/security-context/
             */
            securityContext?: pulumi.Input<inputs.core.v1.SecurityContextPatch>;
            /**
             * StartupProbe indicates that the Pod has successfully initialized. If specified, no other probes are executed until this completes successfully. If this probe fails, the Pod will be restarted, just as if the livenessProbe failed. This can be used to provide different probe parameters at the beginning of a Pod's lifecycle, when it might take a long time to load data or warm a cache, than during steady-state operation. This cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
             */
            startupProbe?: pulumi.Input<inputs.core.v1.ProbePatch>;
            /**
             * Whether this container should allocate a buffer for stdin in the container runtime. If this is not set, reads from stdin in the container will always result in EOF. Default is false.
             */
            stdin?: pulumi.Input<boolean>;
            /**
             * Whether the container runtime should close the stdin channel after it has been opened by a single attach. When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false
             */
            stdinOnce?: pulumi.Input<boolean>;
            /**
             * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem. Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated.
             */
            terminationMessagePath?: pulumi.Input<string>;
            /**
             * Indicate how the termination message should be populated. File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
             */
            terminationMessagePolicy?: pulumi.Input<string>;
            /**
             * Whether this container should allocate a TTY for itself, also requires 'stdin' to be true. Default is false.
             */
            tty?: pulumi.Input<boolean>;
            /**
             * volumeDevices is the list of block devices to be used by the container.
             */
            volumeDevices?: pulumi.Input<pulumi.Input<inputs.core.v1.VolumeDevicePatch>[]>;
            /**
             * Pod volumes to mount into the container's filesystem. Cannot be updated.
             */
            volumeMounts?: pulumi.Input<pulumi.Input<inputs.core.v1.VolumeMountPatch>[]>;
            /**
             * Container's working directory. If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
             */
            workingDir?: pulumi.Input<string>;
        }
        /**
         * ContainerPort represents a network port in a single container.
         */
        interface ContainerPort {
            /**
             * Number of port to expose on the pod's IP address. This must be a valid port number, 0 < x < 65536.
             */
            containerPort: pulumi.Input<number>;
            /**
             * What host IP to bind the external port to.
             */
            hostIP?: pulumi.Input<string>;
            /**
             * Number of port to expose on the host. If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
             */
            hostPort?: pulumi.Input<number>;
            /**
             * If specified, this must be an IANA_SVC_NAME and unique within the pod. Each named port in a pod must have a unique name. Name for the port that can be referred to by services.
             */
            name?: pulumi.Input<string>;
            /**
             * Protocol for port. Must be UDP, TCP, or SCTP. Defaults to "TCP".
             */
            protocol?: pulumi.Input<string>;
        }
        /**
         * ContainerPort represents a network port in a single container.
         */
        interface ContainerPortPatch {
            /**
             * Number of port to expose on the pod's IP address. This must be a valid port number, 0 < x < 65536.
             */
            containerPort?: pulumi.Input<number>;
            /**
             * What host IP to bind the external port to.
             */
            hostIP?: pulumi.Input<string>;
            /**
             * Number of port to expose on the host. If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
             */
            hostPort?: pulumi.Input<number>;
            /**
             * If specified, this must be an IANA_SVC_NAME and unique within the pod. Each named port in a pod must have a unique name. Name for the port that can be referred to by services.
             */
            name?: pulumi.Input<string>;
            /**
             * Protocol for port. Must be UDP, TCP, or SCTP. Defaults to "TCP".
             */
            protocol?: pulumi.Input<string>;
        }
        /**
         * ContainerResizePolicy represents resource resize policy for the container.
         */
        interface ContainerResizePolicy {
            /**
             * Name of the resource to which this resource resize policy applies. Supported values: cpu, memory.
             */
            resourceName: pulumi.Input<string>;
            /**
             * Restart policy to apply when specified resource is resized. If not specified, it defaults to NotRequired.
             */
            restartPolicy: pulumi.Input<string>;
        }
        /**
         * ContainerResizePolicy represents resource resize policy for the container.
         */
        interface ContainerResizePolicyPatch {
            /**
             * Name of the resource to which this resource resize policy applies. Supported values: cpu, memory.
             */
            resourceName?: pulumi.Input<string>;
            /**
             * Restart policy to apply when specified resource is resized. If not specified, it defaults to NotRequired.
             */
            restartPolicy?: pulumi.Input<string>;
        }
        /**
         * ContainerState holds a possible state of container. Only one of its members may be specified. If none of them is specified, the default one is ContainerStateWaiting.
         */
        interface ContainerState {
            /**
             * Details about a running container
             */
            running?: pulumi.Input<inputs.core.v1.ContainerStateRunning>;
            /**
             * Details about a terminated container
             */
            terminated?: pulumi.Input<inputs.core.v1.ContainerStateTerminated>;
            /**
             * Details about a waiting container
             */
            waiting?: pulumi.Input<inputs.core.v1.ContainerStateWaiting>;
        }
        /**
         * ContainerStateRunning is a running state of a container.
         */
        interface ContainerStateRunning {
            /**
             * Time at which the container was last (re-)started
             */
            startedAt?: pulumi.Input<string>;
        }
        /**
         * ContainerStateTerminated is a terminated state of a container.
         */
        interface ContainerStateTerminated {
            /**
             * Container's ID in the format '<type>://<container_id>'
             */
            containerID?: pulumi.Input<string>;
            /**
             * Exit status from the last termination of the container
             */
            exitCode: pulumi.Input<number>;
            /**
             * Time at which the container last terminated
             */
            finishedAt?: pulumi.Input<string>;
            /**
             * Message regarding the last termination of the container
             */
            message?: pulumi.Input<string>;
            /**
             * (brief) reason from the last termination of the container
             */
            reason?: pulumi.Input<string>;
            /**
             * Signal from the last termination of the container
             */
            signal?: pulumi.Input<number>;
            /**
             * Time at which previous execution of the container started
             */
            startedAt?: pulumi.Input<string>;
        }
        /**
         * ContainerStateWaiting is a waiting state of a container.
         */
        interface ContainerStateWaiting {
            /**
             * Message regarding why the container is not yet running.
             */
            message?: pulumi.Input<string>;
            /**
             * (brief) reason the container is not yet running.
             */
            reason?: pulumi.Input<string>;
        }
        /**
         * ContainerStatus contains details for the current status of this container.
         */
        interface ContainerStatus {
            /**
             * AllocatedResources represents the compute resources allocated for this container by the node. Kubelet sets this value to Container.Resources.Requests upon successful pod admission and after successfully admitting desired pod resize.
             */
            allocatedResources?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * AllocatedResourcesStatus represents the status of various resources allocated for this Pod.
             */
            allocatedResourcesStatus?: pulumi.Input<pulumi.Input<inputs.core.v1.ResourceStatus>[]>;
            /**
             * ContainerID is the ID of the container in the format '<type>://<container_id>'. Where type is a container runtime identifier, returned from Version call of CRI API (for example "containerd").
             */
            containerID?: pulumi.Input<string>;
            /**
             * Image is the name of container image that the container is running. The container image may not match the image used in the PodSpec, as it may have been resolved by the runtime. More info: https://kubernetes.io/docs/concepts/containers/images.
             */
            image: pulumi.Input<string>;
            /**
             * ImageID is the image ID of the container's image. The image ID may not match the image ID of the image used in the PodSpec, as it may have been resolved by the runtime.
             */
            imageID: pulumi.Input<string>;
            /**
             * LastTerminationState holds the last termination state of the container to help debug container crashes and restarts. This field is not populated if the container is still running and RestartCount is 0.
             */
            lastState?: pulumi.Input<inputs.core.v1.ContainerState>;
            /**
             * Name is a DNS_LABEL representing the unique name of the container. Each container in a pod must have a unique name across all container types. Cannot be updated.
             */
            name: pulumi.Input<string>;
            /**
             * Ready specifies whether the container is currently passing its readiness check. The value will change as readiness probes keep executing. If no readiness probes are specified, this field defaults to true once the container is fully started (see Started field).
             *
             * The value is typically used to determine whether a container is ready to accept traffic.
             */
            ready: pulumi.Input<boolean>;
            /**
             * Resources represents the compute resource requests and limits that have been successfully enacted on the running container after it has been started or has been successfully resized.
             */
            resources?: pulumi.Input<inputs.core.v1.ResourceRequirements>;
            /**
             * RestartCount holds the number of times the container has been restarted. Kubelet makes an effort to always increment the value, but there are cases when the state may be lost due to node restarts and then the value may be reset to 0. The value is never negative.
             */
            restartCount: pulumi.Input<number>;
            /**
             * Started indicates whether the container has finished its postStart lifecycle hook and passed its startup probe. Initialized as false, becomes true after startupProbe is considered successful. Resets to false when the container is restarted, or if kubelet loses state temporarily. In both cases, startup probes will run again. Is always true when no startupProbe is defined and container is running and has passed the postStart lifecycle hook. The null value must be treated the same as false.
             */
            started?: pulumi.Input<boolean>;
            /**
             * State holds details about the container's current condition.
             */
            state?: pulumi.Input<inputs.core.v1.ContainerState>;
            /**
             * StopSignal reports the effective stop signal for this container
             */
            stopSignal?: pulumi.Input<string>;
            /**
             * User represents user identity information initially attached to the first process of the container
             */
            user?: pulumi.Input<inputs.core.v1.ContainerUser>;
            /**
             * Status of volume mounts.
             */
            volumeMounts?: pulumi.Input<pulumi.Input<inputs.core.v1.VolumeMountStatus>[]>;
        }
        /**
         * ContainerUser represents user identity information
         */
        interface ContainerUser {
            /**
             * Linux holds user identity information initially attached to the first process of the containers in Linux. Note that the actual running identity can be changed if the process has enough privilege to do so.
             */
            linux?: pulumi.Input<inputs.core.v1.LinuxContainerUser>;
        }
        /**
         * DaemonEndpoint contains information about a single Daemon endpoint.
         */
        interface DaemonEndpoint {
            /**
             * Port number of the given endpoint.
             */
            Port: pulumi.Input<number>;
        }
        /**
         * Represents downward API info for projecting into a projected volume. Note that this is identical to a downwardAPI volume source without the default mode.
         */
        interface DownwardAPIProjection {
            /**
             * Items is a list of DownwardAPIVolume file
             */
            items?: pulumi.Input<pulumi.Input<inputs.core.v1.DownwardAPIVolumeFile>[]>;
        }
        /**
         * Represents downward API info for projecting into a projected volume. Note that this is identical to a downwardAPI volume source without the default mode.
         */
        interface DownwardAPIProjectionPatch {
            /**
             * Items is a list of DownwardAPIVolume file
             */
            items?: pulumi.Input<pulumi.Input<inputs.core.v1.DownwardAPIVolumeFilePatch>[]>;
        }
        /**
         * DownwardAPIVolumeFile represents information to create the file containing the pod field
         */
        interface DownwardAPIVolumeFile {
            /**
             * Required: Selects a field of the pod: only annotations, labels, name, namespace and uid are supported.
             */
            fieldRef?: pulumi.Input<inputs.core.v1.ObjectFieldSelector>;
            /**
             * Optional: mode bits used to set permissions on this file, must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
             */
            mode?: pulumi.Input<number>;
            /**
             * Required: Path is  the relative path name of the file to be created. Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
             */
            path: pulumi.Input<string>;
            /**
             * Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, requests.cpu and requests.memory) are currently supported.
             */
            resourceFieldRef?: pulumi.Input<inputs.core.v1.ResourceFieldSelector>;
        }
        /**
         * DownwardAPIVolumeFile represents information to create the file containing the pod field
         */
        interface DownwardAPIVolumeFilePatch {
            /**
             * Required: Selects a field of the pod: only annotations, labels, name, namespace and uid are supported.
             */
            fieldRef?: pulumi.Input<inputs.core.v1.ObjectFieldSelectorPatch>;
            /**
             * Optional: mode bits used to set permissions on this file, must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
             */
            mode?: pulumi.Input<number>;
            /**
             * Required: Path is  the relative path name of the file to be created. Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
             */
            path?: pulumi.Input<string>;
            /**
             * Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, requests.cpu and requests.memory) are currently supported.
             */
            resourceFieldRef?: pulumi.Input<inputs.core.v1.ResourceFieldSelectorPatch>;
        }
        /**
         * DownwardAPIVolumeSource represents a volume containing downward API info. Downward API volumes support ownership management and SELinux relabeling.
         */
        interface DownwardAPIVolumeSource {
            /**
             * Optional: mode bits to use on created files by default. Must be a Optional: mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
             */
            defaultMode?: pulumi.Input<number>;
            /**
             * Items is a list of downward API volume file
             */
            items?: pulumi.Input<pulumi.Input<inputs.core.v1.DownwardAPIVolumeFile>[]>;
        }
        /**
         * DownwardAPIVolumeSource represents a volume containing downward API info. Downward API volumes support ownership management and SELinux relabeling.
         */
        interface DownwardAPIVolumeSourcePatch {
            /**
             * Optional: mode bits to use on created files by default. Must be a Optional: mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
             */
            defaultMode?: pulumi.Input<number>;
            /**
             * Items is a list of downward API volume file
             */
            items?: pulumi.Input<pulumi.Input<inputs.core.v1.DownwardAPIVolumeFilePatch>[]>;
        }
        /**
         * Represents an empty directory for a pod. Empty directory volumes support ownership management and SELinux relabeling.
         */
        interface EmptyDirVolumeSource {
            /**
             * medium represents what type of storage medium should back this directory. The default is "" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir
             */
            medium?: pulumi.Input<string>;
            /**
             * sizeLimit is the total amount of local storage required for this EmptyDir volume. The size limit is also applicable for memory medium. The maximum usage on memory medium EmptyDir would be the minimum value between the SizeLimit specified here and the sum of memory limits of all containers in a pod. The default is nil which means that the limit is undefined. More info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir
             */
            sizeLimit?: pulumi.Input<string>;
        }
        /**
         * Represents an empty directory for a pod. Empty directory volumes support ownership management and SELinux relabeling.
         */
        interface EmptyDirVolumeSourcePatch {
            /**
             * medium represents what type of storage medium should back this directory. The default is "" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir
             */
            medium?: pulumi.Input<string>;
            /**
             * sizeLimit is the total amount of local storage required for this EmptyDir volume. The size limit is also applicable for memory medium. The maximum usage on memory medium EmptyDir would be the minimum value between the SizeLimit specified here and the sum of memory limits of all containers in a pod. The default is nil which means that the limit is undefined. More info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir
             */
            sizeLimit?: pulumi.Input<string>;
        }
        /**
         * EndpointAddress is a tuple that describes single IP address. Deprecated: This API is deprecated in v1.33+.
         */
        interface EndpointAddress {
            /**
             * The Hostname of this endpoint
             */
            hostname?: pulumi.Input<string>;
            /**
             * The IP of this endpoint. May not be loopback (127.0.0.0/8 or ::1), link-local (169.254.0.0/16 or fe80::/10), or link-local multicast (224.0.0.0/24 or ff02::/16).
             */
            ip: pulumi.Input<string>;
            /**
             * Optional: Node hosting this endpoint. This can be used to determine endpoints local to a node.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * Reference to object providing the endpoint.
             */
            targetRef?: pulumi.Input<inputs.core.v1.ObjectReference>;
        }
        /**
         * EndpointAddress is a tuple that describes single IP address. Deprecated: This API is deprecated in v1.33+.
         */
        interface EndpointAddressPatch {
            /**
             * The Hostname of this endpoint
             */
            hostname?: pulumi.Input<string>;
            /**
             * The IP of this endpoint. May not be loopback (127.0.0.0/8 or ::1), link-local (169.254.0.0/16 or fe80::/10), or link-local multicast (224.0.0.0/24 or ff02::/16).
             */
            ip?: pulumi.Input<string>;
            /**
             * Optional: Node hosting this endpoint. This can be used to determine endpoints local to a node.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * Reference to object providing the endpoint.
             */
            targetRef?: pulumi.Input<inputs.core.v1.ObjectReferencePatch>;
        }
        /**
         * EndpointPort is a tuple that describes a single port. Deprecated: This API is deprecated in v1.33+.
         */
        interface EndpointPort {
            /**
             * The application protocol for this port. This is used as a hint for implementations to offer richer behavior for protocols that they understand. This field follows standard Kubernetes label syntax. Valid values are either:
             *
             * * Un-prefixed protocol names - reserved for IANA standard service names (as per RFC-6335 and https://www.iana.org/assignments/service-names).
             *
             * * Kubernetes-defined prefixed names:
             *   * 'kubernetes.io/h2c' - HTTP/2 prior knowledge over cleartext as described in https://www.rfc-editor.org/rfc/rfc9113.html#name-starting-http-2-with-prior-
             *   * 'kubernetes.io/ws'  - WebSocket over cleartext as described in https://www.rfc-editor.org/rfc/rfc6455
             *   * 'kubernetes.io/wss' - WebSocket over TLS as described in https://www.rfc-editor.org/rfc/rfc6455
             *
             * * Other protocols should use implementation-defined prefixed names such as mycompany.com/my-custom-protocol.
             */
            appProtocol?: pulumi.Input<string>;
            /**
             * The name of this port.  This must match the 'name' field in the corresponding ServicePort. Must be a DNS_LABEL. Optional only if one port is defined.
             */
            name?: pulumi.Input<string>;
            /**
             * The port number of the endpoint.
             */
            port: pulumi.Input<number>;
            /**
             * The IP protocol for this port. Must be UDP, TCP, or SCTP. Default is TCP.
             */
            protocol?: pulumi.Input<string>;
        }
        /**
         * EndpointPort is a tuple that describes a single port. Deprecated: This API is deprecated in v1.33+.
         */
        interface EndpointPortPatch {
            /**
             * The application protocol for this port. This is used as a hint for implementations to offer richer behavior for protocols that they understand. This field follows standard Kubernetes label syntax. Valid values are either:
             *
             * * Un-prefixed protocol names - reserved for IANA standard service names (as per RFC-6335 and https://www.iana.org/assignments/service-names).
             *
             * * Kubernetes-defined prefixed names:
             *   * 'kubernetes.io/h2c' - HTTP/2 prior knowledge over cleartext as described in https://www.rfc-editor.org/rfc/rfc9113.html#name-starting-http-2-with-prior-
             *   * 'kubernetes.io/ws'  - WebSocket over cleartext as described in https://www.rfc-editor.org/rfc/rfc6455
             *   * 'kubernetes.io/wss' - WebSocket over TLS as described in https://www.rfc-editor.org/rfc/rfc6455
             *
             * * Other protocols should use implementation-defined prefixed names such as mycompany.com/my-custom-protocol.
             */
            appProtocol?: pulumi.Input<string>;
            /**
             * The name of this port.  This must match the 'name' field in the corresponding ServicePort. Must be a DNS_LABEL. Optional only if one port is defined.
             */
            name?: pulumi.Input<string>;
            /**
             * The port number of the endpoint.
             */
            port?: pulumi.Input<number>;
            /**
             * The IP protocol for this port. Must be UDP, TCP, or SCTP. Default is TCP.
             */
            protocol?: pulumi.Input<string>;
        }
        /**
         * EndpointSubset is a group of addresses with a common set of ports. The expanded set of endpoints is the Cartesian product of Addresses x Ports. For example, given:
         *
         * 	{
         * 	  Addresses: [{"ip": "10.10.1.1"}, {"ip": "10.10.2.2"}],
         * 	  Ports:     [{"name": "a", "port": 8675}, {"name": "b", "port": 309}]
         * 	}
         *
         * The resulting set of endpoints can be viewed as:
         *
         * 	a: [ 10.10.1.1:8675, 10.10.2.2:8675 ],
         * 	b: [ 10.10.1.1:309, 10.10.2.2:309 ]
         *
         * Deprecated: This API is deprecated in v1.33+.
         */
        interface EndpointSubset {
            /**
             * IP addresses which offer the related ports that are marked as ready. These endpoints should be considered safe for load balancers and clients to utilize.
             */
            addresses?: pulumi.Input<pulumi.Input<inputs.core.v1.EndpointAddress>[]>;
            /**
             * IP addresses which offer the related ports but are not currently marked as ready because they have not yet finished starting, have recently failed a readiness check, or have recently failed a liveness check.
             */
            notReadyAddresses?: pulumi.Input<pulumi.Input<inputs.core.v1.EndpointAddress>[]>;
            /**
             * Port numbers available on the related IP addresses.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.core.v1.EndpointPort>[]>;
        }
        /**
         * EndpointSubset is a group of addresses with a common set of ports. The expanded set of endpoints is the Cartesian product of Addresses x Ports. For example, given:
         *
         * 	{
         * 	  Addresses: [{"ip": "10.10.1.1"}, {"ip": "10.10.2.2"}],
         * 	  Ports:     [{"name": "a", "port": 8675}, {"name": "b", "port": 309}]
         * 	}
         *
         * The resulting set of endpoints can be viewed as:
         *
         * 	a: [ 10.10.1.1:8675, 10.10.2.2:8675 ],
         * 	b: [ 10.10.1.1:309, 10.10.2.2:309 ]
         *
         * Deprecated: This API is deprecated in v1.33+.
         */
        interface EndpointSubsetPatch {
            /**
             * IP addresses which offer the related ports that are marked as ready. These endpoints should be considered safe for load balancers and clients to utilize.
             */
            addresses?: pulumi.Input<pulumi.Input<inputs.core.v1.EndpointAddressPatch>[]>;
            /**
             * IP addresses which offer the related ports but are not currently marked as ready because they have not yet finished starting, have recently failed a readiness check, or have recently failed a liveness check.
             */
            notReadyAddresses?: pulumi.Input<pulumi.Input<inputs.core.v1.EndpointAddressPatch>[]>;
            /**
             * Port numbers available on the related IP addresses.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.core.v1.EndpointPortPatch>[]>;
        }
        /**
         * Endpoints is a collection of endpoints that implement the actual service. Example:
         *
         * 	 Name: "mysvc",
         * 	 Subsets: [
         * 	   {
         * 	     Addresses: [{"ip": "10.10.1.1"}, {"ip": "10.10.2.2"}],
         * 	     Ports: [{"name": "a", "port": 8675}, {"name": "b", "port": 309}]
         * 	   },
         * 	   {
         * 	     Addresses: [{"ip": "10.10.3.3"}],
         * 	     Ports: [{"name": "a", "port": 93}, {"name": "b", "port": 76}]
         * 	   },
         * 	]
         *
         * Endpoints is a legacy API and does not contain information about all Service features. Use discoveryv1.EndpointSlice for complete information about Service endpoints.
         *
         * Deprecated: This API is deprecated in v1.33+. Use discoveryv1.EndpointSlice.
         */
        interface Endpoints {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Endpoints">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * The set of all endpoints is the union of all subsets. Addresses are placed into subsets according to the IPs they share. A single address with multiple ports, some of which are ready and some of which are not (because they come from different containers) will result in the address being displayed in different subsets for the different ports. No address will appear in both Addresses and NotReadyAddresses in the same subset. Sets of addresses and ports that comprise a service.
             */
            subsets?: pulumi.Input<pulumi.Input<inputs.core.v1.EndpointSubset>[]>;
        }
        /**
         * EnvFromSource represents the source of a set of ConfigMaps or Secrets
         */
        interface EnvFromSource {
            /**
             * The ConfigMap to select from
             */
            configMapRef?: pulumi.Input<inputs.core.v1.ConfigMapEnvSource>;
            /**
             * Optional text to prepend to the name of each environment variable. Must be a C_IDENTIFIER.
             */
            prefix?: pulumi.Input<string>;
            /**
             * The Secret to select from
             */
            secretRef?: pulumi.Input<inputs.core.v1.SecretEnvSource>;
        }
        /**
         * EnvFromSource represents the source of a set of ConfigMaps or Secrets
         */
        interface EnvFromSourcePatch {
            /**
             * The ConfigMap to select from
             */
            configMapRef?: pulumi.Input<inputs.core.v1.ConfigMapEnvSourcePatch>;
            /**
             * Optional text to prepend to the name of each environment variable. Must be a C_IDENTIFIER.
             */
            prefix?: pulumi.Input<string>;
            /**
             * The Secret to select from
             */
            secretRef?: pulumi.Input<inputs.core.v1.SecretEnvSourcePatch>;
        }
        /**
         * EnvVar represents an environment variable present in a Container.
         */
        interface EnvVar {
            /**
             * Name of the environment variable. Must be a C_IDENTIFIER.
             */
            name: pulumi.Input<string>;
            /**
             * Variable references $(VAR_NAME) are expanded using the previously defined environment variables in the container and any service environment variables. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
             */
            value?: pulumi.Input<string>;
            /**
             * Source for the environment variable's value. Cannot be used if value is not empty.
             */
            valueFrom?: pulumi.Input<inputs.core.v1.EnvVarSource>;
        }
        /**
         * EnvVar represents an environment variable present in a Container.
         */
        interface EnvVarPatch {
            /**
             * Name of the environment variable. Must be a C_IDENTIFIER.
             */
            name?: pulumi.Input<string>;
            /**
             * Variable references $(VAR_NAME) are expanded using the previously defined environment variables in the container and any service environment variables. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
             */
            value?: pulumi.Input<string>;
            /**
             * Source for the environment variable's value. Cannot be used if value is not empty.
             */
            valueFrom?: pulumi.Input<inputs.core.v1.EnvVarSourcePatch>;
        }
        /**
         * EnvVarSource represents a source for the value of an EnvVar.
         */
        interface EnvVarSource {
            /**
             * Selects a key of a ConfigMap.
             */
            configMapKeyRef?: pulumi.Input<inputs.core.v1.ConfigMapKeySelector>;
            /**
             * Selects a field of the pod: supports metadata.name, metadata.namespace, `metadata.labels['<KEY>']`, `metadata.annotations['<KEY>']`, spec.nodeName, spec.serviceAccountName, status.hostIP, status.podIP, status.podIPs.
             */
            fieldRef?: pulumi.Input<inputs.core.v1.ObjectFieldSelector>;
            /**
             * Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, limits.ephemeral-storage, requests.cpu, requests.memory and requests.ephemeral-storage) are currently supported.
             */
            resourceFieldRef?: pulumi.Input<inputs.core.v1.ResourceFieldSelector>;
            /**
             * Selects a key of a secret in the pod's namespace
             */
            secretKeyRef?: pulumi.Input<inputs.core.v1.SecretKeySelector>;
        }
        /**
         * EnvVarSource represents a source for the value of an EnvVar.
         */
        interface EnvVarSourcePatch {
            /**
             * Selects a key of a ConfigMap.
             */
            configMapKeyRef?: pulumi.Input<inputs.core.v1.ConfigMapKeySelectorPatch>;
            /**
             * Selects a field of the pod: supports metadata.name, metadata.namespace, `metadata.labels['<KEY>']`, `metadata.annotations['<KEY>']`, spec.nodeName, spec.serviceAccountName, status.hostIP, status.podIP, status.podIPs.
             */
            fieldRef?: pulumi.Input<inputs.core.v1.ObjectFieldSelectorPatch>;
            /**
             * Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, limits.ephemeral-storage, requests.cpu, requests.memory and requests.ephemeral-storage) are currently supported.
             */
            resourceFieldRef?: pulumi.Input<inputs.core.v1.ResourceFieldSelectorPatch>;
            /**
             * Selects a key of a secret in the pod's namespace
             */
            secretKeyRef?: pulumi.Input<inputs.core.v1.SecretKeySelectorPatch>;
        }
        /**
         * An EphemeralContainer is a temporary container that you may add to an existing Pod for user-initiated activities such as debugging. Ephemeral containers have no resource or scheduling guarantees, and they will not be restarted when they exit or when a Pod is removed or restarted. The kubelet may evict a Pod if an ephemeral container causes the Pod to exceed its resource allocation.
         *
         * To add an ephemeral container, use the ephemeralcontainers subresource of an existing Pod. Ephemeral containers may not be removed or restarted.
         */
        interface EphemeralContainer {
            /**
             * Arguments to the entrypoint. The image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
             */
            args?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Entrypoint array. Not executed within a shell. The image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
             */
            command?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * List of environment variables to set in the container. Cannot be updated.
             */
            env?: pulumi.Input<pulumi.Input<inputs.core.v1.EnvVar>[]>;
            /**
             * List of sources to populate environment variables in the container. The keys defined within a source must be a C_IDENTIFIER. All invalid keys will be reported as an event when the container is starting. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated.
             */
            envFrom?: pulumi.Input<pulumi.Input<inputs.core.v1.EnvFromSource>[]>;
            /**
             * Container image name. More info: https://kubernetes.io/docs/concepts/containers/images
             */
            image?: pulumi.Input<string>;
            /**
             * Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images
             */
            imagePullPolicy?: pulumi.Input<string>;
            /**
             * Lifecycle is not allowed for ephemeral containers.
             */
            lifecycle?: pulumi.Input<inputs.core.v1.Lifecycle>;
            /**
             * Probes are not allowed for ephemeral containers.
             */
            livenessProbe?: pulumi.Input<inputs.core.v1.Probe>;
            /**
             * Name of the ephemeral container specified as a DNS_LABEL. This name must be unique among all containers, init containers and ephemeral containers.
             */
            name: pulumi.Input<string>;
            /**
             * Ports are not allowed for ephemeral containers.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.core.v1.ContainerPort>[]>;
            /**
             * Probes are not allowed for ephemeral containers.
             */
            readinessProbe?: pulumi.Input<inputs.core.v1.Probe>;
            /**
             * Resources resize policy for the container.
             */
            resizePolicy?: pulumi.Input<pulumi.Input<inputs.core.v1.ContainerResizePolicy>[]>;
            /**
             * Resources are not allowed for ephemeral containers. Ephemeral containers use spare resources already allocated to the pod.
             */
            resources?: pulumi.Input<inputs.core.v1.ResourceRequirements>;
            /**
             * Restart policy for the container to manage the restart behavior of each container within a pod. This may only be set for init containers. You cannot set this field on ephemeral containers.
             */
            restartPolicy?: pulumi.Input<string>;
            /**
             * Optional: SecurityContext defines the security options the ephemeral container should be run with. If set, the fields of SecurityContext override the equivalent fields of PodSecurityContext.
             */
            securityContext?: pulumi.Input<inputs.core.v1.SecurityContext>;
            /**
             * Probes are not allowed for ephemeral containers.
             */
            startupProbe?: pulumi.Input<inputs.core.v1.Probe>;
            /**
             * Whether this container should allocate a buffer for stdin in the container runtime. If this is not set, reads from stdin in the container will always result in EOF. Default is false.
             */
            stdin?: pulumi.Input<boolean>;
            /**
             * Whether the container runtime should close the stdin channel after it has been opened by a single attach. When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false
             */
            stdinOnce?: pulumi.Input<boolean>;
            /**
             * If set, the name of the container from PodSpec that this ephemeral container targets. The ephemeral container will be run in the namespaces (IPC, PID, etc) of this container. If not set then the ephemeral container uses the namespaces configured in the Pod spec.
             *
             * The container runtime must implement support for this feature. If the runtime does not support namespace targeting then the result of setting this field is undefined.
             */
            targetContainerName?: pulumi.Input<string>;
            /**
             * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem. Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated.
             */
            terminationMessagePath?: pulumi.Input<string>;
            /**
             * Indicate how the termination message should be populated. File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
             */
            terminationMessagePolicy?: pulumi.Input<string>;
            /**
             * Whether this container should allocate a TTY for itself, also requires 'stdin' to be true. Default is false.
             */
            tty?: pulumi.Input<boolean>;
            /**
             * volumeDevices is the list of block devices to be used by the container.
             */
            volumeDevices?: pulumi.Input<pulumi.Input<inputs.core.v1.VolumeDevice>[]>;
            /**
             * Pod volumes to mount into the container's filesystem. Subpath mounts are not allowed for ephemeral containers. Cannot be updated.
             */
            volumeMounts?: pulumi.Input<pulumi.Input<inputs.core.v1.VolumeMount>[]>;
            /**
             * Container's working directory. If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
             */
            workingDir?: pulumi.Input<string>;
        }
        /**
         * An EphemeralContainer is a temporary container that you may add to an existing Pod for user-initiated activities such as debugging. Ephemeral containers have no resource or scheduling guarantees, and they will not be restarted when they exit or when a Pod is removed or restarted. The kubelet may evict a Pod if an ephemeral container causes the Pod to exceed its resource allocation.
         *
         * To add an ephemeral container, use the ephemeralcontainers subresource of an existing Pod. Ephemeral containers may not be removed or restarted.
         */
        interface EphemeralContainerPatch {
            /**
             * Arguments to the entrypoint. The image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
             */
            args?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Entrypoint array. Not executed within a shell. The image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
             */
            command?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * List of environment variables to set in the container. Cannot be updated.
             */
            env?: pulumi.Input<pulumi.Input<inputs.core.v1.EnvVarPatch>[]>;
            /**
             * List of sources to populate environment variables in the container. The keys defined within a source must be a C_IDENTIFIER. All invalid keys will be reported as an event when the container is starting. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated.
             */
            envFrom?: pulumi.Input<pulumi.Input<inputs.core.v1.EnvFromSourcePatch>[]>;
            /**
             * Container image name. More info: https://kubernetes.io/docs/concepts/containers/images
             */
            image?: pulumi.Input<string>;
            /**
             * Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images
             */
            imagePullPolicy?: pulumi.Input<string>;
            /**
             * Lifecycle is not allowed for ephemeral containers.
             */
            lifecycle?: pulumi.Input<inputs.core.v1.LifecyclePatch>;
            /**
             * Probes are not allowed for ephemeral containers.
             */
            livenessProbe?: pulumi.Input<inputs.core.v1.ProbePatch>;
            /**
             * Name of the ephemeral container specified as a DNS_LABEL. This name must be unique among all containers, init containers and ephemeral containers.
             */
            name?: pulumi.Input<string>;
            /**
             * Ports are not allowed for ephemeral containers.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.core.v1.ContainerPortPatch>[]>;
            /**
             * Probes are not allowed for ephemeral containers.
             */
            readinessProbe?: pulumi.Input<inputs.core.v1.ProbePatch>;
            /**
             * Resources resize policy for the container.
             */
            resizePolicy?: pulumi.Input<pulumi.Input<inputs.core.v1.ContainerResizePolicyPatch>[]>;
            /**
             * Resources are not allowed for ephemeral containers. Ephemeral containers use spare resources already allocated to the pod.
             */
            resources?: pulumi.Input<inputs.core.v1.ResourceRequirementsPatch>;
            /**
             * Restart policy for the container to manage the restart behavior of each container within a pod. This may only be set for init containers. You cannot set this field on ephemeral containers.
             */
            restartPolicy?: pulumi.Input<string>;
            /**
             * Optional: SecurityContext defines the security options the ephemeral container should be run with. If set, the fields of SecurityContext override the equivalent fields of PodSecurityContext.
             */
            securityContext?: pulumi.Input<inputs.core.v1.SecurityContextPatch>;
            /**
             * Probes are not allowed for ephemeral containers.
             */
            startupProbe?: pulumi.Input<inputs.core.v1.ProbePatch>;
            /**
             * Whether this container should allocate a buffer for stdin in the container runtime. If this is not set, reads from stdin in the container will always result in EOF. Default is false.
             */
            stdin?: pulumi.Input<boolean>;
            /**
             * Whether the container runtime should close the stdin channel after it has been opened by a single attach. When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false
             */
            stdinOnce?: pulumi.Input<boolean>;
            /**
             * If set, the name of the container from PodSpec that this ephemeral container targets. The ephemeral container will be run in the namespaces (IPC, PID, etc) of this container. If not set then the ephemeral container uses the namespaces configured in the Pod spec.
             *
             * The container runtime must implement support for this feature. If the runtime does not support namespace targeting then the result of setting this field is undefined.
             */
            targetContainerName?: pulumi.Input<string>;
            /**
             * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem. Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated.
             */
            terminationMessagePath?: pulumi.Input<string>;
            /**
             * Indicate how the termination message should be populated. File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
             */
            terminationMessagePolicy?: pulumi.Input<string>;
            /**
             * Whether this container should allocate a TTY for itself, also requires 'stdin' to be true. Default is false.
             */
            tty?: pulumi.Input<boolean>;
            /**
             * volumeDevices is the list of block devices to be used by the container.
             */
            volumeDevices?: pulumi.Input<pulumi.Input<inputs.core.v1.VolumeDevicePatch>[]>;
            /**
             * Pod volumes to mount into the container's filesystem. Subpath mounts are not allowed for ephemeral containers. Cannot be updated.
             */
            volumeMounts?: pulumi.Input<pulumi.Input<inputs.core.v1.VolumeMountPatch>[]>;
            /**
             * Container's working directory. If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
             */
            workingDir?: pulumi.Input<string>;
        }
        /**
         * Represents an ephemeral volume that is handled by a normal storage driver.
         */
        interface EphemeralVolumeSource {
            /**
             * Specifies a read-only configuration for the volume. Defaults to false (read/write).
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * Will be used to create a stand-alone PVC to provision the volume. The pod in which this EphemeralVolumeSource is embedded will be the owner of the PVC, i.e. the PVC will be deleted together with the pod.  The name of the PVC will be `<pod name>-<volume name>` where `<volume name>` is the name from the `PodSpec.Volumes` array entry. Pod validation will reject the pod if the concatenated name is not valid for a PVC (for example, too long).
             *
             * An existing PVC with that name that is not owned by the pod will *not* be used for the pod to avoid using an unrelated volume by mistake. Starting the pod is then blocked until the unrelated PVC is removed. If such a pre-created PVC is meant to be used by the pod, the PVC has to updated with an owner reference to the pod once the pod exists. Normally this should not be necessary, but it may be useful when manually reconstructing a broken cluster.
             *
             * This field is read-only and no changes will be made by Kubernetes to the PVC after it has been created.
             *
             * Required, must not be nil.
             */
            volumeClaimTemplate?: pulumi.Input<inputs.core.v1.PersistentVolumeClaimTemplate>;
        }
        /**
         * Represents an ephemeral volume that is handled by a normal storage driver.
         */
        interface EphemeralVolumeSourcePatch {
            /**
             * Specifies a read-only configuration for the volume. Defaults to false (read/write).
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * Will be used to create a stand-alone PVC to provision the volume. The pod in which this EphemeralVolumeSource is embedded will be the owner of the PVC, i.e. the PVC will be deleted together with the pod.  The name of the PVC will be `<pod name>-<volume name>` where `<volume name>` is the name from the `PodSpec.Volumes` array entry. Pod validation will reject the pod if the concatenated name is not valid for a PVC (for example, too long).
             *
             * An existing PVC with that name that is not owned by the pod will *not* be used for the pod to avoid using an unrelated volume by mistake. Starting the pod is then blocked until the unrelated PVC is removed. If such a pre-created PVC is meant to be used by the pod, the PVC has to updated with an owner reference to the pod once the pod exists. Normally this should not be necessary, but it may be useful when manually reconstructing a broken cluster.
             *
             * This field is read-only and no changes will be made by Kubernetes to the PVC after it has been created.
             *
             * Required, must not be nil.
             */
            volumeClaimTemplate?: pulumi.Input<inputs.core.v1.PersistentVolumeClaimTemplatePatch>;
        }
        /**
         * Event is a report of an event somewhere in the cluster.  Events have a limited retention time and triggers and messages may evolve with time.  Event consumers should not rely on the timing of an event with a given Reason reflecting a consistent underlying trigger, or the continued existence of events with that Reason.  Events should be treated as informative, best-effort, supplemental data.
         */
        interface Event {
            /**
             * What action was taken/failed regarding to the Regarding object.
             */
            action?: pulumi.Input<string>;
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * The number of times this event has occurred.
             */
            count?: pulumi.Input<number>;
            /**
             * Time when this Event was first observed.
             */
            eventTime?: pulumi.Input<string>;
            /**
             * The time at which the event was first recorded. (Time of server receipt is in TypeMeta.)
             */
            firstTimestamp?: pulumi.Input<string>;
            /**
             * The object that this event is about.
             */
            involvedObject: pulumi.Input<inputs.core.v1.ObjectReference>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Event">;
            /**
             * The time at which the most recent occurrence of this event was recorded.
             */
            lastTimestamp?: pulumi.Input<string>;
            /**
             * A human-readable description of the status of this operation.
             */
            message?: pulumi.Input<string>;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * This should be a short, machine understandable string that gives the reason for the transition into the object's current status.
             */
            reason?: pulumi.Input<string>;
            /**
             * Optional secondary object for more complex actions.
             */
            related?: pulumi.Input<inputs.core.v1.ObjectReference>;
            /**
             * Name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`.
             */
            reportingComponent?: pulumi.Input<string>;
            /**
             * ID of the controller instance, e.g. `kubelet-xyzf`.
             */
            reportingInstance?: pulumi.Input<string>;
            /**
             * Data about the Event series this event represents or nil if it's a singleton Event.
             */
            series?: pulumi.Input<inputs.core.v1.EventSeries>;
            /**
             * The component reporting this event. Should be a short machine understandable string.
             */
            source?: pulumi.Input<inputs.core.v1.EventSource>;
            /**
             * Type of this event (Normal, Warning), new types could be added in the future
             */
            type?: pulumi.Input<string>;
        }
        /**
         * EventSeries contain information on series of events, i.e. thing that was/is happening continuously for some time.
         */
        interface EventSeries {
            /**
             * Number of occurrences in this series up to the last heartbeat time
             */
            count?: pulumi.Input<number>;
            /**
             * Time of the last occurrence observed
             */
            lastObservedTime?: pulumi.Input<string>;
            /**
             * State of this Series: Ongoing or Finished Deprecated. Planned removal for 1.18
             */
            state?: pulumi.Input<string>;
        }
        /**
         * EventSeries contain information on series of events, i.e. thing that was/is happening continuously for some time.
         */
        interface EventSeriesPatch {
            /**
             * Number of occurrences in this series up to the last heartbeat time
             */
            count?: pulumi.Input<number>;
            /**
             * Time of the last occurrence observed
             */
            lastObservedTime?: pulumi.Input<string>;
            /**
             * State of this Series: Ongoing or Finished Deprecated. Planned removal for 1.18
             */
            state?: pulumi.Input<string>;
        }
        /**
         * EventSource contains information for an event.
         */
        interface EventSource {
            /**
             * Component from which the event is generated.
             */
            component?: pulumi.Input<string>;
            /**
             * Node name on which the event is generated.
             */
            host?: pulumi.Input<string>;
        }
        /**
         * EventSource contains information for an event.
         */
        interface EventSourcePatch {
            /**
             * Component from which the event is generated.
             */
            component?: pulumi.Input<string>;
            /**
             * Node name on which the event is generated.
             */
            host?: pulumi.Input<string>;
        }
        /**
         * ExecAction describes a "run in container" action.
         */
        interface ExecAction {
            /**
             * Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
             */
            command?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ExecAction describes a "run in container" action.
         */
        interface ExecActionPatch {
            /**
             * Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
             */
            command?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * Represents a Fibre Channel volume. Fibre Channel volumes can only be mounted as read/write once. Fibre Channel volumes support ownership management and SELinux relabeling.
         */
        interface FCVolumeSource {
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * lun is Optional: FC target lun number
             */
            lun?: pulumi.Input<number>;
            /**
             * readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * targetWWNs is Optional: FC target worldwide names (WWNs)
             */
            targetWWNs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * wwids Optional: FC volume world wide identifiers (wwids) Either wwids or combination of targetWWNs and lun must be set, but not both simultaneously.
             */
            wwids?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * Represents a Fibre Channel volume. Fibre Channel volumes can only be mounted as read/write once. Fibre Channel volumes support ownership management and SELinux relabeling.
         */
        interface FCVolumeSourcePatch {
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * lun is Optional: FC target lun number
             */
            lun?: pulumi.Input<number>;
            /**
             * readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * targetWWNs is Optional: FC target worldwide names (WWNs)
             */
            targetWWNs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * wwids Optional: FC volume world wide identifiers (wwids) Either wwids or combination of targetWWNs and lun must be set, but not both simultaneously.
             */
            wwids?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * FlexPersistentVolumeSource represents a generic persistent volume resource that is provisioned/attached using an exec based plugin.
         */
        interface FlexPersistentVolumeSource {
            /**
             * driver is the name of the driver to use for this volume.
             */
            driver: pulumi.Input<string>;
            /**
             * fsType is the Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.
             */
            fsType?: pulumi.Input<string>;
            /**
             * options is Optional: this field holds extra command options if any.
             */
            options?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * readOnly is Optional: defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is Optional: SecretRef is reference to the secret object containing sensitive information to pass to the plugin scripts. This may be empty if no secret object is specified. If the secret object contains more than one secret, all secrets are passed to the plugin scripts.
             */
            secretRef?: pulumi.Input<inputs.core.v1.SecretReference>;
        }
        /**
         * FlexPersistentVolumeSource represents a generic persistent volume resource that is provisioned/attached using an exec based plugin.
         */
        interface FlexPersistentVolumeSourcePatch {
            /**
             * driver is the name of the driver to use for this volume.
             */
            driver?: pulumi.Input<string>;
            /**
             * fsType is the Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.
             */
            fsType?: pulumi.Input<string>;
            /**
             * options is Optional: this field holds extra command options if any.
             */
            options?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * readOnly is Optional: defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is Optional: SecretRef is reference to the secret object containing sensitive information to pass to the plugin scripts. This may be empty if no secret object is specified. If the secret object contains more than one secret, all secrets are passed to the plugin scripts.
             */
            secretRef?: pulumi.Input<inputs.core.v1.SecretReferencePatch>;
        }
        /**
         * FlexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin.
         */
        interface FlexVolumeSource {
            /**
             * driver is the name of the driver to use for this volume.
             */
            driver: pulumi.Input<string>;
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.
             */
            fsType?: pulumi.Input<string>;
            /**
             * options is Optional: this field holds extra command options if any.
             */
            options?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * readOnly is Optional: defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is Optional: secretRef is reference to the secret object containing sensitive information to pass to the plugin scripts. This may be empty if no secret object is specified. If the secret object contains more than one secret, all secrets are passed to the plugin scripts.
             */
            secretRef?: pulumi.Input<inputs.core.v1.LocalObjectReference>;
        }
        /**
         * FlexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin.
         */
        interface FlexVolumeSourcePatch {
            /**
             * driver is the name of the driver to use for this volume.
             */
            driver?: pulumi.Input<string>;
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.
             */
            fsType?: pulumi.Input<string>;
            /**
             * options is Optional: this field holds extra command options if any.
             */
            options?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * readOnly is Optional: defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is Optional: secretRef is reference to the secret object containing sensitive information to pass to the plugin scripts. This may be empty if no secret object is specified. If the secret object contains more than one secret, all secrets are passed to the plugin scripts.
             */
            secretRef?: pulumi.Input<inputs.core.v1.LocalObjectReferencePatch>;
        }
        /**
         * Represents a Flocker volume mounted by the Flocker agent. One and only one of datasetName and datasetUUID should be set. Flocker volumes do not support ownership management or SELinux relabeling.
         */
        interface FlockerVolumeSource {
            /**
             * datasetName is Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated
             */
            datasetName?: pulumi.Input<string>;
            /**
             * datasetUUID is the UUID of the dataset. This is unique identifier of a Flocker dataset
             */
            datasetUUID?: pulumi.Input<string>;
        }
        /**
         * Represents a Flocker volume mounted by the Flocker agent. One and only one of datasetName and datasetUUID should be set. Flocker volumes do not support ownership management or SELinux relabeling.
         */
        interface FlockerVolumeSourcePatch {
            /**
             * datasetName is Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated
             */
            datasetName?: pulumi.Input<string>;
            /**
             * datasetUUID is the UUID of the dataset. This is unique identifier of a Flocker dataset
             */
            datasetUUID?: pulumi.Input<string>;
        }
        /**
         * Represents a Persistent Disk resource in Google Compute Engine.
         *
         * A GCE PD must exist before mounting to a container. The disk must also be in the same GCE project and zone as the kubelet. A GCE PD can only be mounted as read/write once or read-only many times. GCE PDs support ownership management and SELinux relabeling.
         */
        interface GCEPersistentDiskVolumeSource {
            /**
             * fsType is filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk
             */
            fsType?: pulumi.Input<string>;
            /**
             * partition is the partition in the volume that you want to mount. If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk
             */
            partition?: pulumi.Input<number>;
            /**
             * pdName is unique name of the PD resource in GCE. Used to identify the disk in GCE. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk
             */
            pdName: pulumi.Input<string>;
            /**
             * readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk
             */
            readOnly?: pulumi.Input<boolean>;
        }
        /**
         * Represents a Persistent Disk resource in Google Compute Engine.
         *
         * A GCE PD must exist before mounting to a container. The disk must also be in the same GCE project and zone as the kubelet. A GCE PD can only be mounted as read/write once or read-only many times. GCE PDs support ownership management and SELinux relabeling.
         */
        interface GCEPersistentDiskVolumeSourcePatch {
            /**
             * fsType is filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk
             */
            fsType?: pulumi.Input<string>;
            /**
             * partition is the partition in the volume that you want to mount. If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk
             */
            partition?: pulumi.Input<number>;
            /**
             * pdName is unique name of the PD resource in GCE. Used to identify the disk in GCE. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk
             */
            pdName?: pulumi.Input<string>;
            /**
             * readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk
             */
            readOnly?: pulumi.Input<boolean>;
        }
        /**
         * GRPCAction specifies an action involving a GRPC service.
         */
        interface GRPCAction {
            /**
             * Port number of the gRPC service. Number must be in the range 1 to 65535.
             */
            port: pulumi.Input<number>;
            /**
             * Service is the name of the service to place in the gRPC HealthCheckRequest (see https://github.com/grpc/grpc/blob/master/doc/health-checking.md).
             *
             * If this is not specified, the default behavior is defined by gRPC.
             */
            service?: pulumi.Input<string>;
        }
        /**
         * GRPCAction specifies an action involving a GRPC service.
         */
        interface GRPCActionPatch {
            /**
             * Port number of the gRPC service. Number must be in the range 1 to 65535.
             */
            port?: pulumi.Input<number>;
            /**
             * Service is the name of the service to place in the gRPC HealthCheckRequest (see https://github.com/grpc/grpc/blob/master/doc/health-checking.md).
             *
             * If this is not specified, the default behavior is defined by gRPC.
             */
            service?: pulumi.Input<string>;
        }
        /**
         * Represents a volume that is populated with the contents of a git repository. Git repo volumes do not support ownership management. Git repo volumes support SELinux relabeling.
         *
         * DEPRECATED: GitRepo is deprecated. To provision a container with a git repo, mount an EmptyDir into an InitContainer that clones the repo using git, then mount the EmptyDir into the Pod's container.
         */
        interface GitRepoVolumeSource {
            /**
             * directory is the target directory name. Must not contain or start with '..'.  If '.' is supplied, the volume directory will be the git repository.  Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name.
             */
            directory?: pulumi.Input<string>;
            /**
             * repository is the URL
             */
            repository: pulumi.Input<string>;
            /**
             * revision is the commit hash for the specified revision.
             */
            revision?: pulumi.Input<string>;
        }
        /**
         * Represents a volume that is populated with the contents of a git repository. Git repo volumes do not support ownership management. Git repo volumes support SELinux relabeling.
         *
         * DEPRECATED: GitRepo is deprecated. To provision a container with a git repo, mount an EmptyDir into an InitContainer that clones the repo using git, then mount the EmptyDir into the Pod's container.
         */
        interface GitRepoVolumeSourcePatch {
            /**
             * directory is the target directory name. Must not contain or start with '..'.  If '.' is supplied, the volume directory will be the git repository.  Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name.
             */
            directory?: pulumi.Input<string>;
            /**
             * repository is the URL
             */
            repository?: pulumi.Input<string>;
            /**
             * revision is the commit hash for the specified revision.
             */
            revision?: pulumi.Input<string>;
        }
        /**
         * Represents a Glusterfs mount that lasts the lifetime of a pod. Glusterfs volumes do not support ownership management or SELinux relabeling.
         */
        interface GlusterfsPersistentVolumeSource {
            /**
             * endpoints is the endpoint name that details Glusterfs topology. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
             */
            endpoints: pulumi.Input<string>;
            /**
             * endpointsNamespace is the namespace that contains Glusterfs endpoint. If this field is empty, the EndpointNamespace defaults to the same namespace as the bound PVC. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
             */
            endpointsNamespace?: pulumi.Input<string>;
            /**
             * path is the Glusterfs volume path. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
             */
            path: pulumi.Input<string>;
            /**
             * readOnly here will force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
             */
            readOnly?: pulumi.Input<boolean>;
        }
        /**
         * Represents a Glusterfs mount that lasts the lifetime of a pod. Glusterfs volumes do not support ownership management or SELinux relabeling.
         */
        interface GlusterfsPersistentVolumeSourcePatch {
            /**
             * endpoints is the endpoint name that details Glusterfs topology. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
             */
            endpoints?: pulumi.Input<string>;
            /**
             * endpointsNamespace is the namespace that contains Glusterfs endpoint. If this field is empty, the EndpointNamespace defaults to the same namespace as the bound PVC. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
             */
            endpointsNamespace?: pulumi.Input<string>;
            /**
             * path is the Glusterfs volume path. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
             */
            path?: pulumi.Input<string>;
            /**
             * readOnly here will force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
             */
            readOnly?: pulumi.Input<boolean>;
        }
        /**
         * Represents a Glusterfs mount that lasts the lifetime of a pod. Glusterfs volumes do not support ownership management or SELinux relabeling.
         */
        interface GlusterfsVolumeSource {
            /**
             * endpoints is the endpoint name that details Glusterfs topology. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
             */
            endpoints: pulumi.Input<string>;
            /**
             * path is the Glusterfs volume path. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
             */
            path: pulumi.Input<string>;
            /**
             * readOnly here will force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
             */
            readOnly?: pulumi.Input<boolean>;
        }
        /**
         * Represents a Glusterfs mount that lasts the lifetime of a pod. Glusterfs volumes do not support ownership management or SELinux relabeling.
         */
        interface GlusterfsVolumeSourcePatch {
            /**
             * endpoints is the endpoint name that details Glusterfs topology. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
             */
            endpoints?: pulumi.Input<string>;
            /**
             * path is the Glusterfs volume path. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
             */
            path?: pulumi.Input<string>;
            /**
             * readOnly here will force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
             */
            readOnly?: pulumi.Input<boolean>;
        }
        /**
         * HTTPGetAction describes an action based on HTTP Get requests.
         */
        interface HTTPGetAction {
            /**
             * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
             */
            host?: pulumi.Input<string>;
            /**
             * Custom headers to set in the request. HTTP allows repeated headers.
             */
            httpHeaders?: pulumi.Input<pulumi.Input<inputs.core.v1.HTTPHeader>[]>;
            /**
             * Path to access on the HTTP server.
             */
            path?: pulumi.Input<string>;
            /**
             * Name or number of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
             */
            port: pulumi.Input<number | string>;
            /**
             * Scheme to use for connecting to the host. Defaults to HTTP.
             */
            scheme?: pulumi.Input<string>;
        }
        /**
         * HTTPGetAction describes an action based on HTTP Get requests.
         */
        interface HTTPGetActionPatch {
            /**
             * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
             */
            host?: pulumi.Input<string>;
            /**
             * Custom headers to set in the request. HTTP allows repeated headers.
             */
            httpHeaders?: pulumi.Input<pulumi.Input<inputs.core.v1.HTTPHeaderPatch>[]>;
            /**
             * Path to access on the HTTP server.
             */
            path?: pulumi.Input<string>;
            /**
             * Name or number of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
             */
            port?: pulumi.Input<number | string>;
            /**
             * Scheme to use for connecting to the host. Defaults to HTTP.
             */
            scheme?: pulumi.Input<string>;
        }
        /**
         * HTTPHeader describes a custom header to be used in HTTP probes
         */
        interface HTTPHeader {
            /**
             * The header field name. This will be canonicalized upon output, so case-variant names will be understood as the same header.
             */
            name: pulumi.Input<string>;
            /**
             * The header field value
             */
            value: pulumi.Input<string>;
        }
        /**
         * HTTPHeader describes a custom header to be used in HTTP probes
         */
        interface HTTPHeaderPatch {
            /**
             * The header field name. This will be canonicalized upon output, so case-variant names will be understood as the same header.
             */
            name?: pulumi.Input<string>;
            /**
             * The header field value
             */
            value?: pulumi.Input<string>;
        }
        /**
         * HostAlias holds the mapping between IP and hostnames that will be injected as an entry in the pod's hosts file.
         */
        interface HostAlias {
            /**
             * Hostnames for the above IP address.
             */
            hostnames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * IP address of the host file entry.
             */
            ip: pulumi.Input<string>;
        }
        /**
         * HostAlias holds the mapping between IP and hostnames that will be injected as an entry in the pod's hosts file.
         */
        interface HostAliasPatch {
            /**
             * Hostnames for the above IP address.
             */
            hostnames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * IP address of the host file entry.
             */
            ip?: pulumi.Input<string>;
        }
        /**
         * HostIP represents a single IP address allocated to the host.
         */
        interface HostIP {
            /**
             * IP is the IP address assigned to the host
             */
            ip: pulumi.Input<string>;
        }
        /**
         * Represents a host path mapped into a pod. Host path volumes do not support ownership management or SELinux relabeling.
         */
        interface HostPathVolumeSource {
            /**
             * path of the directory on the host. If the path is a symlink, it will follow the link to the real path. More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath
             */
            path: pulumi.Input<string>;
            /**
             * type for HostPath Volume Defaults to "" More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath
             */
            type?: pulumi.Input<string>;
        }
        /**
         * Represents a host path mapped into a pod. Host path volumes do not support ownership management or SELinux relabeling.
         */
        interface HostPathVolumeSourcePatch {
            /**
             * path of the directory on the host. If the path is a symlink, it will follow the link to the real path. More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath
             */
            path?: pulumi.Input<string>;
            /**
             * type for HostPath Volume Defaults to "" More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath
             */
            type?: pulumi.Input<string>;
        }
        /**
         * ISCSIPersistentVolumeSource represents an ISCSI disk. ISCSI volumes can only be mounted as read/write once. ISCSI volumes support ownership management and SELinux relabeling.
         */
        interface ISCSIPersistentVolumeSource {
            /**
             * chapAuthDiscovery defines whether support iSCSI Discovery CHAP authentication
             */
            chapAuthDiscovery?: pulumi.Input<boolean>;
            /**
             * chapAuthSession defines whether support iSCSI Session CHAP authentication
             */
            chapAuthSession?: pulumi.Input<boolean>;
            /**
             * fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#iscsi
             */
            fsType?: pulumi.Input<string>;
            /**
             * initiatorName is the custom iSCSI Initiator Name. If initiatorName is specified with iscsiInterface simultaneously, new iSCSI interface <target portal>:<volume name> will be created for the connection.
             */
            initiatorName?: pulumi.Input<string>;
            /**
             * iqn is Target iSCSI Qualified Name.
             */
            iqn: pulumi.Input<string>;
            /**
             * iscsiInterface is the interface Name that uses an iSCSI transport. Defaults to 'default' (tcp).
             */
            iscsiInterface?: pulumi.Input<string>;
            /**
             * lun is iSCSI Target Lun number.
             */
            lun: pulumi.Input<number>;
            /**
             * portals is the iSCSI Target Portal List. The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
             */
            portals?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is the CHAP Secret for iSCSI target and initiator authentication
             */
            secretRef?: pulumi.Input<inputs.core.v1.SecretReference>;
            /**
             * targetPortal is iSCSI Target Portal. The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
             */
            targetPortal: pulumi.Input<string>;
        }
        /**
         * ISCSIPersistentVolumeSource represents an ISCSI disk. ISCSI volumes can only be mounted as read/write once. ISCSI volumes support ownership management and SELinux relabeling.
         */
        interface ISCSIPersistentVolumeSourcePatch {
            /**
             * chapAuthDiscovery defines whether support iSCSI Discovery CHAP authentication
             */
            chapAuthDiscovery?: pulumi.Input<boolean>;
            /**
             * chapAuthSession defines whether support iSCSI Session CHAP authentication
             */
            chapAuthSession?: pulumi.Input<boolean>;
            /**
             * fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#iscsi
             */
            fsType?: pulumi.Input<string>;
            /**
             * initiatorName is the custom iSCSI Initiator Name. If initiatorName is specified with iscsiInterface simultaneously, new iSCSI interface <target portal>:<volume name> will be created for the connection.
             */
            initiatorName?: pulumi.Input<string>;
            /**
             * iqn is Target iSCSI Qualified Name.
             */
            iqn?: pulumi.Input<string>;
            /**
             * iscsiInterface is the interface Name that uses an iSCSI transport. Defaults to 'default' (tcp).
             */
            iscsiInterface?: pulumi.Input<string>;
            /**
             * lun is iSCSI Target Lun number.
             */
            lun?: pulumi.Input<number>;
            /**
             * portals is the iSCSI Target Portal List. The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
             */
            portals?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is the CHAP Secret for iSCSI target and initiator authentication
             */
            secretRef?: pulumi.Input<inputs.core.v1.SecretReferencePatch>;
            /**
             * targetPortal is iSCSI Target Portal. The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
             */
            targetPortal?: pulumi.Input<string>;
        }
        /**
         * Represents an ISCSI disk. ISCSI volumes can only be mounted as read/write once. ISCSI volumes support ownership management and SELinux relabeling.
         */
        interface ISCSIVolumeSource {
            /**
             * chapAuthDiscovery defines whether support iSCSI Discovery CHAP authentication
             */
            chapAuthDiscovery?: pulumi.Input<boolean>;
            /**
             * chapAuthSession defines whether support iSCSI Session CHAP authentication
             */
            chapAuthSession?: pulumi.Input<boolean>;
            /**
             * fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#iscsi
             */
            fsType?: pulumi.Input<string>;
            /**
             * initiatorName is the custom iSCSI Initiator Name. If initiatorName is specified with iscsiInterface simultaneously, new iSCSI interface <target portal>:<volume name> will be created for the connection.
             */
            initiatorName?: pulumi.Input<string>;
            /**
             * iqn is the target iSCSI Qualified Name.
             */
            iqn: pulumi.Input<string>;
            /**
             * iscsiInterface is the interface Name that uses an iSCSI transport. Defaults to 'default' (tcp).
             */
            iscsiInterface?: pulumi.Input<string>;
            /**
             * lun represents iSCSI Target Lun number.
             */
            lun: pulumi.Input<number>;
            /**
             * portals is the iSCSI Target Portal List. The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
             */
            portals?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is the CHAP Secret for iSCSI target and initiator authentication
             */
            secretRef?: pulumi.Input<inputs.core.v1.LocalObjectReference>;
            /**
             * targetPortal is iSCSI Target Portal. The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
             */
            targetPortal: pulumi.Input<string>;
        }
        /**
         * Represents an ISCSI disk. ISCSI volumes can only be mounted as read/write once. ISCSI volumes support ownership management and SELinux relabeling.
         */
        interface ISCSIVolumeSourcePatch {
            /**
             * chapAuthDiscovery defines whether support iSCSI Discovery CHAP authentication
             */
            chapAuthDiscovery?: pulumi.Input<boolean>;
            /**
             * chapAuthSession defines whether support iSCSI Session CHAP authentication
             */
            chapAuthSession?: pulumi.Input<boolean>;
            /**
             * fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#iscsi
             */
            fsType?: pulumi.Input<string>;
            /**
             * initiatorName is the custom iSCSI Initiator Name. If initiatorName is specified with iscsiInterface simultaneously, new iSCSI interface <target portal>:<volume name> will be created for the connection.
             */
            initiatorName?: pulumi.Input<string>;
            /**
             * iqn is the target iSCSI Qualified Name.
             */
            iqn?: pulumi.Input<string>;
            /**
             * iscsiInterface is the interface Name that uses an iSCSI transport. Defaults to 'default' (tcp).
             */
            iscsiInterface?: pulumi.Input<string>;
            /**
             * lun represents iSCSI Target Lun number.
             */
            lun?: pulumi.Input<number>;
            /**
             * portals is the iSCSI Target Portal List. The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
             */
            portals?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is the CHAP Secret for iSCSI target and initiator authentication
             */
            secretRef?: pulumi.Input<inputs.core.v1.LocalObjectReferencePatch>;
            /**
             * targetPortal is iSCSI Target Portal. The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
             */
            targetPortal?: pulumi.Input<string>;
        }
        /**
         * ImageVolumeSource represents a image volume resource.
         */
        interface ImageVolumeSource {
            /**
             * Policy for pulling OCI objects. Possible values are: Always: the kubelet always attempts to pull the reference. Container creation will fail If the pull fails. Never: the kubelet never pulls the reference and only uses a local image or artifact. Container creation will fail if the reference isn't present. IfNotPresent: the kubelet pulls if the reference isn't already present on disk. Container creation will fail if the reference isn't present and the pull fails. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise.
             */
            pullPolicy?: pulumi.Input<string>;
            /**
             * Required: Image or artifact reference to be used. Behaves in the same way as pod.spec.containers[*].image. Pull secrets will be assembled in the same way as for the container image by looking up node credentials, SA image pull secrets, and pod spec image pull secrets. More info: https://kubernetes.io/docs/concepts/containers/images This field is optional to allow higher level config management to default or override container images in workload controllers like Deployments and StatefulSets.
             */
            reference?: pulumi.Input<string>;
        }
        /**
         * ImageVolumeSource represents a image volume resource.
         */
        interface ImageVolumeSourcePatch {
            /**
             * Policy for pulling OCI objects. Possible values are: Always: the kubelet always attempts to pull the reference. Container creation will fail If the pull fails. Never: the kubelet never pulls the reference and only uses a local image or artifact. Container creation will fail if the reference isn't present. IfNotPresent: the kubelet pulls if the reference isn't already present on disk. Container creation will fail if the reference isn't present and the pull fails. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise.
             */
            pullPolicy?: pulumi.Input<string>;
            /**
             * Required: Image or artifact reference to be used. Behaves in the same way as pod.spec.containers[*].image. Pull secrets will be assembled in the same way as for the container image by looking up node credentials, SA image pull secrets, and pod spec image pull secrets. More info: https://kubernetes.io/docs/concepts/containers/images This field is optional to allow higher level config management to default or override container images in workload controllers like Deployments and StatefulSets.
             */
            reference?: pulumi.Input<string>;
        }
        /**
         * Maps a string key to a path within a volume.
         */
        interface KeyToPath {
            /**
             * key is the key to project.
             */
            key: pulumi.Input<string>;
            /**
             * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
             */
            mode?: pulumi.Input<number>;
            /**
             * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
             */
            path: pulumi.Input<string>;
        }
        /**
         * Maps a string key to a path within a volume.
         */
        interface KeyToPathPatch {
            /**
             * key is the key to project.
             */
            key?: pulumi.Input<string>;
            /**
             * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
             */
            mode?: pulumi.Input<number>;
            /**
             * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
             */
            path?: pulumi.Input<string>;
        }
        /**
         * Lifecycle describes actions that the management system should take in response to container lifecycle events. For the PostStart and PreStop lifecycle handlers, management of the container blocks until the action is complete, unless the container process fails, in which case the handler is aborted.
         */
        interface Lifecycle {
            /**
             * PostStart is called immediately after a container is created. If the handler fails, the container is terminated and restarted according to its restart policy. Other management of the container blocks until the hook completes. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks
             */
            postStart?: pulumi.Input<inputs.core.v1.LifecycleHandler>;
            /**
             * PreStop is called immediately before a container is terminated due to an API request or management event such as liveness/startup probe failure, preemption, resource contention, etc. The handler is not called if the container crashes or exits. The Pod's termination grace period countdown begins before the PreStop hook is executed. Regardless of the outcome of the handler, the container will eventually terminate within the Pod's termination grace period (unless delayed by finalizers). Other management of the container blocks until the hook completes or until the termination grace period is reached. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks
             */
            preStop?: pulumi.Input<inputs.core.v1.LifecycleHandler>;
            /**
             * StopSignal defines which signal will be sent to a container when it is being stopped. If not specified, the default is defined by the container runtime in use. StopSignal can only be set for Pods with a non-empty .spec.os.name
             */
            stopSignal?: pulumi.Input<string>;
        }
        /**
         * LifecycleHandler defines a specific action that should be taken in a lifecycle hook. One and only one of the fields, except TCPSocket must be specified.
         */
        interface LifecycleHandler {
            /**
             * Exec specifies a command to execute in the container.
             */
            exec?: pulumi.Input<inputs.core.v1.ExecAction>;
            /**
             * HTTPGet specifies an HTTP GET request to perform.
             */
            httpGet?: pulumi.Input<inputs.core.v1.HTTPGetAction>;
            /**
             * Sleep represents a duration that the container should sleep.
             */
            sleep?: pulumi.Input<inputs.core.v1.SleepAction>;
            /**
             * Deprecated. TCPSocket is NOT supported as a LifecycleHandler and kept for backward compatibility. There is no validation of this field and lifecycle hooks will fail at runtime when it is specified.
             */
            tcpSocket?: pulumi.Input<inputs.core.v1.TCPSocketAction>;
        }
        /**
         * LifecycleHandler defines a specific action that should be taken in a lifecycle hook. One and only one of the fields, except TCPSocket must be specified.
         */
        interface LifecycleHandlerPatch {
            /**
             * Exec specifies a command to execute in the container.
             */
            exec?: pulumi.Input<inputs.core.v1.ExecActionPatch>;
            /**
             * HTTPGet specifies an HTTP GET request to perform.
             */
            httpGet?: pulumi.Input<inputs.core.v1.HTTPGetActionPatch>;
            /**
             * Sleep represents a duration that the container should sleep.
             */
            sleep?: pulumi.Input<inputs.core.v1.SleepActionPatch>;
            /**
             * Deprecated. TCPSocket is NOT supported as a LifecycleHandler and kept for backward compatibility. There is no validation of this field and lifecycle hooks will fail at runtime when it is specified.
             */
            tcpSocket?: pulumi.Input<inputs.core.v1.TCPSocketActionPatch>;
        }
        /**
         * Lifecycle describes actions that the management system should take in response to container lifecycle events. For the PostStart and PreStop lifecycle handlers, management of the container blocks until the action is complete, unless the container process fails, in which case the handler is aborted.
         */
        interface LifecyclePatch {
            /**
             * PostStart is called immediately after a container is created. If the handler fails, the container is terminated and restarted according to its restart policy. Other management of the container blocks until the hook completes. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks
             */
            postStart?: pulumi.Input<inputs.core.v1.LifecycleHandlerPatch>;
            /**
             * PreStop is called immediately before a container is terminated due to an API request or management event such as liveness/startup probe failure, preemption, resource contention, etc. The handler is not called if the container crashes or exits. The Pod's termination grace period countdown begins before the PreStop hook is executed. Regardless of the outcome of the handler, the container will eventually terminate within the Pod's termination grace period (unless delayed by finalizers). Other management of the container blocks until the hook completes or until the termination grace period is reached. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks
             */
            preStop?: pulumi.Input<inputs.core.v1.LifecycleHandlerPatch>;
            /**
             * StopSignal defines which signal will be sent to a container when it is being stopped. If not specified, the default is defined by the container runtime in use. StopSignal can only be set for Pods with a non-empty .spec.os.name
             */
            stopSignal?: pulumi.Input<string>;
        }
        /**
         * LimitRange sets resource usage limits for each kind of resource in a Namespace.
         */
        interface LimitRange {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"LimitRange">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines the limits enforced. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.core.v1.LimitRangeSpec>;
        }
        /**
         * LimitRangeItem defines a min/max usage limit for any resource that matches on kind.
         */
        interface LimitRangeItem {
            /**
             * Default resource requirement limit value by resource name if resource limit is omitted.
             */
            default?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * DefaultRequest is the default resource requirement request value by resource name if resource request is omitted.
             */
            defaultRequest?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Max usage constraints on this kind by resource name.
             */
            max?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * MaxLimitRequestRatio if specified, the named resource must have a request and limit that are both non-zero where limit divided by request is less than or equal to the enumerated value; this represents the max burst for the named resource.
             */
            maxLimitRequestRatio?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Min usage constraints on this kind by resource name.
             */
            min?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Type of resource that this limit applies to.
             */
            type: pulumi.Input<string>;
        }
        /**
         * LimitRangeItem defines a min/max usage limit for any resource that matches on kind.
         */
        interface LimitRangeItemPatch {
            /**
             * Default resource requirement limit value by resource name if resource limit is omitted.
             */
            default?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * DefaultRequest is the default resource requirement request value by resource name if resource request is omitted.
             */
            defaultRequest?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Max usage constraints on this kind by resource name.
             */
            max?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * MaxLimitRequestRatio if specified, the named resource must have a request and limit that are both non-zero where limit divided by request is less than or equal to the enumerated value; this represents the max burst for the named resource.
             */
            maxLimitRequestRatio?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Min usage constraints on this kind by resource name.
             */
            min?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Type of resource that this limit applies to.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * LimitRangeSpec defines a min/max usage limit for resources that match on kind.
         */
        interface LimitRangeSpec {
            /**
             * Limits is the list of LimitRangeItem objects that are enforced.
             */
            limits: pulumi.Input<pulumi.Input<inputs.core.v1.LimitRangeItem>[]>;
        }
        /**
         * LimitRangeSpec defines a min/max usage limit for resources that match on kind.
         */
        interface LimitRangeSpecPatch {
            /**
             * Limits is the list of LimitRangeItem objects that are enforced.
             */
            limits?: pulumi.Input<pulumi.Input<inputs.core.v1.LimitRangeItemPatch>[]>;
        }
        /**
         * LinuxContainerUser represents user identity information in Linux containers
         */
        interface LinuxContainerUser {
            /**
             * GID is the primary gid initially attached to the first process in the container
             */
            gid: pulumi.Input<number>;
            /**
             * SupplementalGroups are the supplemental groups initially attached to the first process in the container
             */
            supplementalGroups?: pulumi.Input<pulumi.Input<number>[]>;
            /**
             * UID is the primary uid initially attached to the first process in the container
             */
            uid: pulumi.Input<number>;
        }
        /**
         * LoadBalancerIngress represents the status of a load-balancer ingress point: traffic intended for the service should be sent to an ingress point.
         */
        interface LoadBalancerIngress {
            /**
             * Hostname is set for load-balancer ingress points that are DNS based (typically AWS load-balancers)
             */
            hostname?: pulumi.Input<string>;
            /**
             * IP is set for load-balancer ingress points that are IP based (typically GCE or OpenStack load-balancers)
             */
            ip?: pulumi.Input<string>;
            /**
             * IPMode specifies how the load-balancer IP behaves, and may only be specified when the ip field is specified. Setting this to "VIP" indicates that traffic is delivered to the node with the destination set to the load-balancer's IP and port. Setting this to "Proxy" indicates that traffic is delivered to the node or pod with the destination set to the node's IP and node port or the pod's IP and port. Service implementations may use this information to adjust traffic routing.
             */
            ipMode?: pulumi.Input<string>;
            /**
             * Ports is a list of records of service ports If used, every port defined in the service should have an entry in it
             */
            ports?: pulumi.Input<pulumi.Input<inputs.core.v1.PortStatus>[]>;
        }
        /**
         * LoadBalancerStatus represents the status of a load-balancer.
         */
        interface LoadBalancerStatus {
            /**
             * Ingress is a list containing ingress points for the load-balancer. Traffic intended for the service should be sent to these ingress points.
             */
            ingress?: pulumi.Input<pulumi.Input<inputs.core.v1.LoadBalancerIngress>[]>;
        }
        /**
         * LocalObjectReference contains enough information to let you locate the referenced object inside the same namespace.
         */
        interface LocalObjectReference {
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
        }
        /**
         * LocalObjectReference contains enough information to let you locate the referenced object inside the same namespace.
         */
        interface LocalObjectReferencePatch {
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
        }
        /**
         * Local represents directly-attached storage with node affinity
         */
        interface LocalVolumeSource {
            /**
             * fsType is the filesystem type to mount. It applies only when the Path is a block device. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default value is to auto-select a filesystem if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * path of the full path to the volume on the node. It can be either a directory or block device (disk, partition, ...).
             */
            path: pulumi.Input<string>;
        }
        /**
         * Local represents directly-attached storage with node affinity
         */
        interface LocalVolumeSourcePatch {
            /**
             * fsType is the filesystem type to mount. It applies only when the Path is a block device. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default value is to auto-select a filesystem if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * path of the full path to the volume on the node. It can be either a directory or block device (disk, partition, ...).
             */
            path?: pulumi.Input<string>;
        }
        /**
         * ModifyVolumeStatus represents the status object of ControllerModifyVolume operation
         */
        interface ModifyVolumeStatus {
            /**
             * status is the status of the ControllerModifyVolume operation. It can be in any of following states:
             *  - Pending
             *    Pending indicates that the PersistentVolumeClaim cannot be modified due to unmet requirements, such as
             *    the specified VolumeAttributesClass not existing.
             *  - InProgress
             *    InProgress indicates that the volume is being modified.
             *  - Infeasible
             *   Infeasible indicates that the request has been rejected as invalid by the CSI driver. To
             * 	  resolve the error, a valid VolumeAttributesClass needs to be specified.
             * Note: New statuses can be added in the future. Consumers should check for unknown statuses and fail appropriately.
             */
            status: pulumi.Input<string>;
            /**
             * targetVolumeAttributesClassName is the name of the VolumeAttributesClass the PVC currently being reconciled
             */
            targetVolumeAttributesClassName?: pulumi.Input<string>;
        }
        /**
         * ModifyVolumeStatus represents the status object of ControllerModifyVolume operation
         */
        interface ModifyVolumeStatusPatch {
            /**
             * status is the status of the ControllerModifyVolume operation. It can be in any of following states:
             *  - Pending
             *    Pending indicates that the PersistentVolumeClaim cannot be modified due to unmet requirements, such as
             *    the specified VolumeAttributesClass not existing.
             *  - InProgress
             *    InProgress indicates that the volume is being modified.
             *  - Infeasible
             *   Infeasible indicates that the request has been rejected as invalid by the CSI driver. To
             * 	  resolve the error, a valid VolumeAttributesClass needs to be specified.
             * Note: New statuses can be added in the future. Consumers should check for unknown statuses and fail appropriately.
             */
            status?: pulumi.Input<string>;
            /**
             * targetVolumeAttributesClassName is the name of the VolumeAttributesClass the PVC currently being reconciled
             */
            targetVolumeAttributesClassName?: pulumi.Input<string>;
        }
        /**
         * Represents an NFS mount that lasts the lifetime of a pod. NFS volumes do not support ownership management or SELinux relabeling.
         */
        interface NFSVolumeSource {
            /**
             * path that is exported by the NFS server. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs
             */
            path: pulumi.Input<string>;
            /**
             * readOnly here will force the NFS export to be mounted with read-only permissions. Defaults to false. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * server is the hostname or IP address of the NFS server. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs
             */
            server: pulumi.Input<string>;
        }
        /**
         * Represents an NFS mount that lasts the lifetime of a pod. NFS volumes do not support ownership management or SELinux relabeling.
         */
        interface NFSVolumeSourcePatch {
            /**
             * path that is exported by the NFS server. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs
             */
            path?: pulumi.Input<string>;
            /**
             * readOnly here will force the NFS export to be mounted with read-only permissions. Defaults to false. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * server is the hostname or IP address of the NFS server. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs
             */
            server?: pulumi.Input<string>;
        }
        /**
         * Namespace provides a scope for Names. Use of multiple namespaces is optional.
         */
        interface Namespace {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Namespace">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines the behavior of the Namespace. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.core.v1.NamespaceSpec>;
            /**
             * Status describes the current status of a Namespace. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.core.v1.NamespaceStatus>;
        }
        /**
         * NamespaceCondition contains details about state of namespace.
         */
        interface NamespaceCondition {
            /**
             * Last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * Human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * Unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of namespace controller condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * NamespaceSpec describes the attributes on a Namespace.
         */
        interface NamespaceSpec {
            /**
             * Finalizers is an opaque list of values that must be empty to permanently remove object from storage. More info: https://kubernetes.io/docs/tasks/administer-cluster/namespaces/
             */
            finalizers?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * NamespaceSpec describes the attributes on a Namespace.
         */
        interface NamespaceSpecPatch {
            /**
             * Finalizers is an opaque list of values that must be empty to permanently remove object from storage. More info: https://kubernetes.io/docs/tasks/administer-cluster/namespaces/
             */
            finalizers?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * NamespaceStatus is information about the current status of a Namespace.
         */
        interface NamespaceStatus {
            /**
             * Represents the latest available observations of a namespace's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.core.v1.NamespaceCondition>[]>;
            /**
             * Phase is the current lifecycle phase of the namespace. More info: https://kubernetes.io/docs/tasks/administer-cluster/namespaces/
             */
            phase?: pulumi.Input<string>;
        }
        /**
         * Node is a worker node in Kubernetes. Each node will have a unique identifier in the cache (i.e. in etcd).
         */
        interface Node {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Node">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines the behavior of a node. https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.core.v1.NodeSpec>;
            /**
             * Most recently observed status of the node. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.core.v1.NodeStatus>;
        }
        /**
         * NodeAddress contains information for the node's address.
         */
        interface NodeAddress {
            /**
             * The node address.
             */
            address: pulumi.Input<string>;
            /**
             * Node address type, one of Hostname, ExternalIP or InternalIP.
             */
            type: pulumi.Input<string>;
        }
        /**
         * Node affinity is a group of node affinity scheduling rules.
         */
        interface NodeAffinity {
            /**
             * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred.
             */
            preferredDuringSchedulingIgnoredDuringExecution?: pulumi.Input<pulumi.Input<inputs.core.v1.PreferredSchedulingTerm>[]>;
            /**
             * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to an update), the system may or may not try to eventually evict the pod from its node.
             */
            requiredDuringSchedulingIgnoredDuringExecution?: pulumi.Input<inputs.core.v1.NodeSelector>;
        }
        /**
         * Node affinity is a group of node affinity scheduling rules.
         */
        interface NodeAffinityPatch {
            /**
             * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred.
             */
            preferredDuringSchedulingIgnoredDuringExecution?: pulumi.Input<pulumi.Input<inputs.core.v1.PreferredSchedulingTermPatch>[]>;
            /**
             * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to an update), the system may or may not try to eventually evict the pod from its node.
             */
            requiredDuringSchedulingIgnoredDuringExecution?: pulumi.Input<inputs.core.v1.NodeSelectorPatch>;
        }
        /**
         * NodeCondition contains condition information for a node.
         */
        interface NodeCondition {
            /**
             * Last time we got an update on a given condition.
             */
            lastHeartbeatTime?: pulumi.Input<string>;
            /**
             * Last time the condition transit from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * Human readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * (brief) reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of node condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * NodeConfigSource specifies a source of node configuration. Exactly one subfield (excluding metadata) must be non-nil. This API is deprecated since 1.22
         */
        interface NodeConfigSource {
            /**
             * ConfigMap is a reference to a Node's ConfigMap
             */
            configMap?: pulumi.Input<inputs.core.v1.ConfigMapNodeConfigSource>;
        }
        /**
         * NodeConfigSource specifies a source of node configuration. Exactly one subfield (excluding metadata) must be non-nil. This API is deprecated since 1.22
         */
        interface NodeConfigSourcePatch {
            /**
             * ConfigMap is a reference to a Node's ConfigMap
             */
            configMap?: pulumi.Input<inputs.core.v1.ConfigMapNodeConfigSourcePatch>;
        }
        /**
         * NodeConfigStatus describes the status of the config assigned by Node.Spec.ConfigSource.
         */
        interface NodeConfigStatus {
            /**
             * Active reports the checkpointed config the node is actively using. Active will represent either the current version of the Assigned config, or the current LastKnownGood config, depending on whether attempting to use the Assigned config results in an error.
             */
            active?: pulumi.Input<inputs.core.v1.NodeConfigSource>;
            /**
             * Assigned reports the checkpointed config the node will try to use. When Node.Spec.ConfigSource is updated, the node checkpoints the associated config payload to local disk, along with a record indicating intended config. The node refers to this record to choose its config checkpoint, and reports this record in Assigned. Assigned only updates in the status after the record has been checkpointed to disk. When the Kubelet is restarted, it tries to make the Assigned config the Active config by loading and validating the checkpointed payload identified by Assigned.
             */
            assigned?: pulumi.Input<inputs.core.v1.NodeConfigSource>;
            /**
             * Error describes any problems reconciling the Spec.ConfigSource to the Active config. Errors may occur, for example, attempting to checkpoint Spec.ConfigSource to the local Assigned record, attempting to checkpoint the payload associated with Spec.ConfigSource, attempting to load or validate the Assigned config, etc. Errors may occur at different points while syncing config. Earlier errors (e.g. download or checkpointing errors) will not result in a rollback to LastKnownGood, and may resolve across Kubelet retries. Later errors (e.g. loading or validating a checkpointed config) will result in a rollback to LastKnownGood. In the latter case, it is usually possible to resolve the error by fixing the config assigned in Spec.ConfigSource. You can find additional information for debugging by searching the error message in the Kubelet log. Error is a human-readable description of the error state; machines can check whether or not Error is empty, but should not rely on the stability of the Error text across Kubelet versions.
             */
            error?: pulumi.Input<string>;
            /**
             * LastKnownGood reports the checkpointed config the node will fall back to when it encounters an error attempting to use the Assigned config. The Assigned config becomes the LastKnownGood config when the node determines that the Assigned config is stable and correct. This is currently implemented as a 10-minute soak period starting when the local record of Assigned config is updated. If the Assigned config is Active at the end of this period, it becomes the LastKnownGood. Note that if Spec.ConfigSource is reset to nil (use local defaults), the LastKnownGood is also immediately reset to nil, because the local default config is always assumed good. You should not make assumptions about the node's method of determining config stability and correctness, as this may change or become configurable in the future.
             */
            lastKnownGood?: pulumi.Input<inputs.core.v1.NodeConfigSource>;
        }
        /**
         * NodeDaemonEndpoints lists ports opened by daemons running on the Node.
         */
        interface NodeDaemonEndpoints {
            /**
             * Endpoint on which Kubelet is listening.
             */
            kubeletEndpoint?: pulumi.Input<inputs.core.v1.DaemonEndpoint>;
        }
        /**
         * NodeFeatures describes the set of features implemented by the CRI implementation. The features contained in the NodeFeatures should depend only on the cri implementation independent of runtime handlers.
         */
        interface NodeFeatures {
            /**
             * SupplementalGroupsPolicy is set to true if the runtime supports SupplementalGroupsPolicy and ContainerUser.
             */
            supplementalGroupsPolicy?: pulumi.Input<boolean>;
        }
        /**
         * NodeRuntimeHandler is a set of runtime handler information.
         */
        interface NodeRuntimeHandler {
            /**
             * Supported features.
             */
            features?: pulumi.Input<inputs.core.v1.NodeRuntimeHandlerFeatures>;
            /**
             * Runtime handler name. Empty for the default runtime handler.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * NodeRuntimeHandlerFeatures is a set of features implemented by the runtime handler.
         */
        interface NodeRuntimeHandlerFeatures {
            /**
             * RecursiveReadOnlyMounts is set to true if the runtime handler supports RecursiveReadOnlyMounts.
             */
            recursiveReadOnlyMounts?: pulumi.Input<boolean>;
            /**
             * UserNamespaces is set to true if the runtime handler supports UserNamespaces, including for volumes.
             */
            userNamespaces?: pulumi.Input<boolean>;
        }
        /**
         * A node selector represents the union of the results of one or more label queries over a set of nodes; that is, it represents the OR of the selectors represented by the node selector terms.
         */
        interface NodeSelector {
            /**
             * Required. A list of node selector terms. The terms are ORed.
             */
            nodeSelectorTerms: pulumi.Input<pulumi.Input<inputs.core.v1.NodeSelectorTerm>[]>;
        }
        /**
         * A node selector represents the union of the results of one or more label queries over a set of nodes; that is, it represents the OR of the selectors represented by the node selector terms.
         */
        interface NodeSelectorPatch {
            /**
             * Required. A list of node selector terms. The terms are ORed.
             */
            nodeSelectorTerms?: pulumi.Input<pulumi.Input<inputs.core.v1.NodeSelectorTermPatch>[]>;
        }
        /**
         * A node selector requirement is a selector that contains values, a key, and an operator that relates the key and values.
         */
        interface NodeSelectorRequirement {
            /**
             * The label key that the selector applies to.
             */
            key: pulumi.Input<string>;
            /**
             * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
             */
            operator: pulumi.Input<string>;
            /**
             * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
             */
            values?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * A node selector requirement is a selector that contains values, a key, and an operator that relates the key and values.
         */
        interface NodeSelectorRequirementPatch {
            /**
             * The label key that the selector applies to.
             */
            key?: pulumi.Input<string>;
            /**
             * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
             */
            operator?: pulumi.Input<string>;
            /**
             * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
             */
            values?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * A null or empty node selector term matches no objects. The requirements of them are ANDed. The TopologySelectorTerm type implements a subset of the NodeSelectorTerm.
         */
        interface NodeSelectorTerm {
            /**
             * A list of node selector requirements by node's labels.
             */
            matchExpressions?: pulumi.Input<pulumi.Input<inputs.core.v1.NodeSelectorRequirement>[]>;
            /**
             * A list of node selector requirements by node's fields.
             */
            matchFields?: pulumi.Input<pulumi.Input<inputs.core.v1.NodeSelectorRequirement>[]>;
        }
        /**
         * A null or empty node selector term matches no objects. The requirements of them are ANDed. The TopologySelectorTerm type implements a subset of the NodeSelectorTerm.
         */
        interface NodeSelectorTermPatch {
            /**
             * A list of node selector requirements by node's labels.
             */
            matchExpressions?: pulumi.Input<pulumi.Input<inputs.core.v1.NodeSelectorRequirementPatch>[]>;
            /**
             * A list of node selector requirements by node's fields.
             */
            matchFields?: pulumi.Input<pulumi.Input<inputs.core.v1.NodeSelectorRequirementPatch>[]>;
        }
        /**
         * NodeSpec describes the attributes that a node is created with.
         */
        interface NodeSpec {
            /**
             * Deprecated: Previously used to specify the source of the node's configuration for the DynamicKubeletConfig feature. This feature is removed.
             */
            configSource?: pulumi.Input<inputs.core.v1.NodeConfigSource>;
            /**
             * Deprecated. Not all kubelets will set this field. Remove field after 1.13. see: https://issues.k8s.io/61966
             */
            externalID?: pulumi.Input<string>;
            /**
             * PodCIDR represents the pod IP range assigned to the node.
             */
            podCIDR?: pulumi.Input<string>;
            /**
             * podCIDRs represents the IP ranges assigned to the node for usage by Pods on that node. If this field is specified, the 0th entry must match the podCIDR field. It may contain at most 1 value for each of IPv4 and IPv6.
             */
            podCIDRs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ID of the node assigned by the cloud provider in the format: <ProviderName>://<ProviderSpecificNodeID>
             */
            providerID?: pulumi.Input<string>;
            /**
             * If specified, the node's taints.
             */
            taints?: pulumi.Input<pulumi.Input<inputs.core.v1.Taint>[]>;
            /**
             * Unschedulable controls node schedulability of new pods. By default, node is schedulable. More info: https://kubernetes.io/docs/concepts/nodes/node/#manual-node-administration
             */
            unschedulable?: pulumi.Input<boolean>;
        }
        /**
         * NodeSpec describes the attributes that a node is created with.
         */
        interface NodeSpecPatch {
            /**
             * Deprecated: Previously used to specify the source of the node's configuration for the DynamicKubeletConfig feature. This feature is removed.
             */
            configSource?: pulumi.Input<inputs.core.v1.NodeConfigSourcePatch>;
            /**
             * Deprecated. Not all kubelets will set this field. Remove field after 1.13. see: https://issues.k8s.io/61966
             */
            externalID?: pulumi.Input<string>;
            /**
             * PodCIDR represents the pod IP range assigned to the node.
             */
            podCIDR?: pulumi.Input<string>;
            /**
             * podCIDRs represents the IP ranges assigned to the node for usage by Pods on that node. If this field is specified, the 0th entry must match the podCIDR field. It may contain at most 1 value for each of IPv4 and IPv6.
             */
            podCIDRs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ID of the node assigned by the cloud provider in the format: <ProviderName>://<ProviderSpecificNodeID>
             */
            providerID?: pulumi.Input<string>;
            /**
             * If specified, the node's taints.
             */
            taints?: pulumi.Input<pulumi.Input<inputs.core.v1.TaintPatch>[]>;
            /**
             * Unschedulable controls node schedulability of new pods. By default, node is schedulable. More info: https://kubernetes.io/docs/concepts/nodes/node/#manual-node-administration
             */
            unschedulable?: pulumi.Input<boolean>;
        }
        /**
         * NodeStatus is information about the current status of a node.
         */
        interface NodeStatus {
            /**
             * List of addresses reachable to the node. Queried from cloud provider, if available. More info: https://kubernetes.io/docs/reference/node/node-status/#addresses Note: This field is declared as mergeable, but the merge key is not sufficiently unique, which can cause data corruption when it is merged. Callers should instead use a full-replacement patch. See https://pr.k8s.io/79391 for an example. Consumers should assume that addresses can change during the lifetime of a Node. However, there are some exceptions where this may not be possible, such as Pods that inherit a Node's address in its own status or consumers of the downward API (status.hostIP).
             */
            addresses?: pulumi.Input<pulumi.Input<inputs.core.v1.NodeAddress>[]>;
            /**
             * Allocatable represents the resources of a node that are available for scheduling. Defaults to Capacity.
             */
            allocatable?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Capacity represents the total resources of a node. More info: https://kubernetes.io/docs/reference/node/node-status/#capacity
             */
            capacity?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Conditions is an array of current observed node conditions. More info: https://kubernetes.io/docs/reference/node/node-status/#condition
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.core.v1.NodeCondition>[]>;
            /**
             * Status of the config assigned to the node via the dynamic Kubelet config feature.
             */
            config?: pulumi.Input<inputs.core.v1.NodeConfigStatus>;
            /**
             * Endpoints of daemons running on the Node.
             */
            daemonEndpoints?: pulumi.Input<inputs.core.v1.NodeDaemonEndpoints>;
            /**
             * Features describes the set of features implemented by the CRI implementation.
             */
            features?: pulumi.Input<inputs.core.v1.NodeFeatures>;
            /**
             * List of container images on this node
             */
            images?: pulumi.Input<pulumi.Input<inputs.core.v1.ContainerImage>[]>;
            /**
             * Set of ids/uuids to uniquely identify the node. More info: https://kubernetes.io/docs/reference/node/node-status/#info
             */
            nodeInfo?: pulumi.Input<inputs.core.v1.NodeSystemInfo>;
            /**
             * NodePhase is the recently observed lifecycle phase of the node. More info: https://kubernetes.io/docs/concepts/nodes/node/#phase The field is never populated, and now is deprecated.
             */
            phase?: pulumi.Input<string>;
            /**
             * The available runtime handlers.
             */
            runtimeHandlers?: pulumi.Input<pulumi.Input<inputs.core.v1.NodeRuntimeHandler>[]>;
            /**
             * List of volumes that are attached to the node.
             */
            volumesAttached?: pulumi.Input<pulumi.Input<inputs.core.v1.AttachedVolume>[]>;
            /**
             * List of attachable volumes in use (mounted) by the node.
             */
            volumesInUse?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * NodeSwapStatus represents swap memory information.
         */
        interface NodeSwapStatus {
            /**
             * Total amount of swap memory in bytes.
             */
            capacity?: pulumi.Input<number>;
        }
        /**
         * NodeSystemInfo is a set of ids/uuids to uniquely identify the node.
         */
        interface NodeSystemInfo {
            /**
             * The Architecture reported by the node
             */
            architecture: pulumi.Input<string>;
            /**
             * Boot ID reported by the node.
             */
            bootID: pulumi.Input<string>;
            /**
             * ContainerRuntime Version reported by the node through runtime remote API (e.g. containerd://1.4.2).
             */
            containerRuntimeVersion: pulumi.Input<string>;
            /**
             * Kernel Version reported by the node from 'uname -r' (e.g. 3.16.0-0.bpo.4-amd64).
             */
            kernelVersion: pulumi.Input<string>;
            /**
             * Deprecated: KubeProxy Version reported by the node.
             */
            kubeProxyVersion: pulumi.Input<string>;
            /**
             * Kubelet Version reported by the node.
             */
            kubeletVersion: pulumi.Input<string>;
            /**
             * MachineID reported by the node. For unique machine identification in the cluster this field is preferred. Learn more from man(5) machine-id: http://man7.org/linux/man-pages/man5/machine-id.5.html
             */
            machineID: pulumi.Input<string>;
            /**
             * The Operating System reported by the node
             */
            operatingSystem: pulumi.Input<string>;
            /**
             * OS Image reported by the node from /etc/os-release (e.g. Debian GNU/Linux 7 (wheezy)).
             */
            osImage: pulumi.Input<string>;
            /**
             * Swap Info reported by the node.
             */
            swap?: pulumi.Input<inputs.core.v1.NodeSwapStatus>;
            /**
             * SystemUUID reported by the node. For unique machine identification MachineID is preferred. This field is specific to Red Hat hosts https://access.redhat.com/documentation/en-us/red_hat_subscription_management/1/html/rhsm/uuid
             */
            systemUUID: pulumi.Input<string>;
        }
        /**
         * ObjectFieldSelector selects an APIVersioned field of an object.
         */
        interface ObjectFieldSelector {
            /**
             * Version of the schema the FieldPath is written in terms of, defaults to "v1".
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * Path of the field to select in the specified API version.
             */
            fieldPath: pulumi.Input<string>;
        }
        /**
         * ObjectFieldSelector selects an APIVersioned field of an object.
         */
        interface ObjectFieldSelectorPatch {
            /**
             * Version of the schema the FieldPath is written in terms of, defaults to "v1".
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * Path of the field to select in the specified API version.
             */
            fieldPath?: pulumi.Input<string>;
        }
        /**
         * ObjectReference contains enough information to let you inspect or modify the referred object.
         */
        interface ObjectReference {
            /**
             * API version of the referent.
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * If referring to a piece of an object instead of an entire object, this string should contain a valid JSON/Go field access statement, such as desiredState.manifest.containers[2]. For example, if the object reference is to a container within a pod, this would take on a value like: "spec.containers{name}" (where "name" refers to the name of the container that triggered the event) or if no container name is specified "spec.containers[2]" (container with index 2 in this pod). This syntax is chosen only to have some well-defined way of referencing a part of an object.
             */
            fieldPath?: pulumi.Input<string>;
            /**
             * Kind of the referent. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<string>;
            /**
             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces/
             */
            namespace?: pulumi.Input<string>;
            /**
             * Specific resourceVersion to which this reference is made, if any. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency
             */
            resourceVersion?: pulumi.Input<string>;
            /**
             * UID of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#uids
             */
            uid?: pulumi.Input<string>;
        }
        /**
         * ObjectReference contains enough information to let you inspect or modify the referred object.
         */
        interface ObjectReferencePatch {
            /**
             * API version of the referent.
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * If referring to a piece of an object instead of an entire object, this string should contain a valid JSON/Go field access statement, such as desiredState.manifest.containers[2]. For example, if the object reference is to a container within a pod, this would take on a value like: "spec.containers{name}" (where "name" refers to the name of the container that triggered the event) or if no container name is specified "spec.containers[2]" (container with index 2 in this pod). This syntax is chosen only to have some well-defined way of referencing a part of an object.
             */
            fieldPath?: pulumi.Input<string>;
            /**
             * Kind of the referent. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<string>;
            /**
             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces/
             */
            namespace?: pulumi.Input<string>;
            /**
             * Specific resourceVersion to which this reference is made, if any. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency
             */
            resourceVersion?: pulumi.Input<string>;
            /**
             * UID of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#uids
             */
            uid?: pulumi.Input<string>;
        }
        /**
         * PersistentVolume (PV) is a storage resource provisioned by an administrator. It is analogous to a node. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes
         */
        interface PersistentVolume {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PersistentVolume">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec defines a specification of a persistent volume owned by the cluster. Provisioned by an administrator. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistent-volumes
             */
            spec?: pulumi.Input<inputs.core.v1.PersistentVolumeSpec>;
            /**
             * status represents the current information/status for the persistent volume. Populated by the system. Read-only. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistent-volumes
             */
            status?: pulumi.Input<inputs.core.v1.PersistentVolumeStatus>;
        }
        /**
         * PersistentVolumeClaim is a user's request for and claim to a persistent volume
         */
        interface PersistentVolumeClaim {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PersistentVolumeClaim">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec defines the desired characteristics of a volume requested by a pod author. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims
             */
            spec?: pulumi.Input<inputs.core.v1.PersistentVolumeClaimSpec>;
            /**
             * status represents the current information/status of a persistent volume claim. Read-only. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims
             */
            status?: pulumi.Input<inputs.core.v1.PersistentVolumeClaimStatus>;
        }
        /**
         * PersistentVolumeClaimCondition contains details about state of pvc
         */
        interface PersistentVolumeClaimCondition {
            /**
             * lastProbeTime is the time we probed the condition.
             */
            lastProbeTime?: pulumi.Input<string>;
            /**
             * lastTransitionTime is the time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * message is the human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * reason is a unique, this should be a short, machine understandable string that gives the reason for condition's last transition. If it reports "Resizing" that means the underlying persistent volume is being resized.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status is the status of the condition. Can be True, False, Unknown. More info: https://kubernetes.io/docs/reference/kubernetes-api/config-and-storage-resources/persistent-volume-claim-v1/#:~:text=state%20of%20pvc-,conditions.status,-(string)%2C%20required
             */
            status: pulumi.Input<string>;
            /**
             * Type is the type of the condition. More info: https://kubernetes.io/docs/reference/kubernetes-api/config-and-storage-resources/persistent-volume-claim-v1/#:~:text=set%20to%20%27ResizeStarted%27.-,PersistentVolumeClaimCondition,-contains%20details%20about
             */
            type: pulumi.Input<string>;
        }
        /**
         * PersistentVolumeClaimCondition contains details about state of pvc
         */
        interface PersistentVolumeClaimConditionPatch {
            /**
             * lastProbeTime is the time we probed the condition.
             */
            lastProbeTime?: pulumi.Input<string>;
            /**
             * lastTransitionTime is the time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * message is the human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * reason is a unique, this should be a short, machine understandable string that gives the reason for condition's last transition. If it reports "Resizing" that means the underlying persistent volume is being resized.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status is the status of the condition. Can be True, False, Unknown. More info: https://kubernetes.io/docs/reference/kubernetes-api/config-and-storage-resources/persistent-volume-claim-v1/#:~:text=state%20of%20pvc-,conditions.status,-(string)%2C%20required
             */
            status?: pulumi.Input<string>;
            /**
             * Type is the type of the condition. More info: https://kubernetes.io/docs/reference/kubernetes-api/config-and-storage-resources/persistent-volume-claim-v1/#:~:text=set%20to%20%27ResizeStarted%27.-,PersistentVolumeClaimCondition,-contains%20details%20about
             */
            type?: pulumi.Input<string>;
        }
        /**
         * PersistentVolumeClaim is a user's request for and claim to a persistent volume
         */
        interface PersistentVolumeClaimPatch {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PersistentVolumeClaim">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMetaPatch>;
            /**
             * spec defines the desired characteristics of a volume requested by a pod author. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims
             */
            spec?: pulumi.Input<inputs.core.v1.PersistentVolumeClaimSpecPatch>;
            /**
             * status represents the current information/status of a persistent volume claim. Read-only. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims
             */
            status?: pulumi.Input<inputs.core.v1.PersistentVolumeClaimStatusPatch>;
        }
        /**
         * PersistentVolumeClaimSpec describes the common attributes of storage devices and allows a Source for provider-specific attributes
         */
        interface PersistentVolumeClaimSpec {
            /**
             * accessModes contains the desired access modes the volume should have. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1
             */
            accessModes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * dataSource field can be used to specify either: * An existing VolumeSnapshot object (snapshot.storage.k8s.io/VolumeSnapshot) * An existing PVC (PersistentVolumeClaim) If the provisioner or an external controller can support the specified data source, it will create a new volume based on the contents of the specified data source. When the AnyVolumeDataSource feature gate is enabled, dataSource contents will be copied to dataSourceRef, and dataSourceRef contents will be copied to dataSource when dataSourceRef.namespace is not specified. If the namespace is specified, then dataSourceRef will not be copied to dataSource.
             */
            dataSource?: pulumi.Input<inputs.core.v1.TypedLocalObjectReference>;
            /**
             * dataSourceRef specifies the object from which to populate the volume with data, if a non-empty volume is desired. This may be any object from a non-empty API group (non core object) or a PersistentVolumeClaim object. When this field is specified, volume binding will only succeed if the type of the specified object matches some installed volume populator or dynamic provisioner. This field will replace the functionality of the dataSource field and as such if both fields are non-empty, they must have the same value. For backwards compatibility, when namespace isn't specified in dataSourceRef, both fields (dataSource and dataSourceRef) will be set to the same value automatically if one of them is empty and the other is non-empty. When namespace is specified in dataSourceRef, dataSource isn't set to the same value and must be empty. There are three important differences between dataSource and dataSourceRef: * While dataSource only allows two specific types of objects, dataSourceRef
             *   allows any non-core object, as well as PersistentVolumeClaim objects.
             * * While dataSource ignores disallowed values (dropping them), dataSourceRef
             *   preserves all values, and generates an error if a disallowed value is
             *   specified.
             * * While dataSource only allows local objects, dataSourceRef allows objects
             *   in any namespaces.
             * (Beta) Using this field requires the AnyVolumeDataSource feature gate to be enabled. (Alpha) Using the namespace field of dataSourceRef requires the CrossNamespaceVolumeDataSource feature gate to be enabled.
             */
            dataSourceRef?: pulumi.Input<inputs.core.v1.TypedObjectReference>;
            /**
             * resources represents the minimum resources the volume should have. If RecoverVolumeExpansionFailure feature is enabled users are allowed to specify resource requirements that are lower than previous value but must still be higher than capacity recorded in the status field of the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#resources
             */
            resources?: pulumi.Input<inputs.core.v1.VolumeResourceRequirements>;
            /**
             * selector is a label query over volumes to consider for binding.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * storageClassName is the name of the StorageClass required by the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#class-1
             */
            storageClassName?: pulumi.Input<string>;
            /**
             * volumeAttributesClassName may be used to set the VolumeAttributesClass used by this claim. If specified, the CSI driver will create or update the volume with the attributes defined in the corresponding VolumeAttributesClass. This has a different purpose than storageClassName, it can be changed after the claim is created. An empty string value means that no VolumeAttributesClass will be applied to the claim but it's not allowed to reset this field to empty string once it is set. If unspecified and the PersistentVolumeClaim is unbound, the default VolumeAttributesClass will be set by the persistentvolume controller if it exists. If the resource referred to by volumeAttributesClass does not exist, this PersistentVolumeClaim will be set to a Pending state, as reflected by the modifyVolumeStatus field, until such as a resource exists. More info: https://kubernetes.io/docs/concepts/storage/volume-attributes-classes/ (Beta) Using this field requires the VolumeAttributesClass feature gate to be enabled (off by default).
             */
            volumeAttributesClassName?: pulumi.Input<string>;
            /**
             * volumeMode defines what type of volume is required by the claim. Value of Filesystem is implied when not included in claim spec.
             */
            volumeMode?: pulumi.Input<string>;
            /**
             * volumeName is the binding reference to the PersistentVolume backing this claim.
             */
            volumeName?: pulumi.Input<string>;
        }
        /**
         * PersistentVolumeClaimSpec describes the common attributes of storage devices and allows a Source for provider-specific attributes
         */
        interface PersistentVolumeClaimSpecPatch {
            /**
             * accessModes contains the desired access modes the volume should have. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1
             */
            accessModes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * dataSource field can be used to specify either: * An existing VolumeSnapshot object (snapshot.storage.k8s.io/VolumeSnapshot) * An existing PVC (PersistentVolumeClaim) If the provisioner or an external controller can support the specified data source, it will create a new volume based on the contents of the specified data source. When the AnyVolumeDataSource feature gate is enabled, dataSource contents will be copied to dataSourceRef, and dataSourceRef contents will be copied to dataSource when dataSourceRef.namespace is not specified. If the namespace is specified, then dataSourceRef will not be copied to dataSource.
             */
            dataSource?: pulumi.Input<inputs.core.v1.TypedLocalObjectReferencePatch>;
            /**
             * dataSourceRef specifies the object from which to populate the volume with data, if a non-empty volume is desired. This may be any object from a non-empty API group (non core object) or a PersistentVolumeClaim object. When this field is specified, volume binding will only succeed if the type of the specified object matches some installed volume populator or dynamic provisioner. This field will replace the functionality of the dataSource field and as such if both fields are non-empty, they must have the same value. For backwards compatibility, when namespace isn't specified in dataSourceRef, both fields (dataSource and dataSourceRef) will be set to the same value automatically if one of them is empty and the other is non-empty. When namespace is specified in dataSourceRef, dataSource isn't set to the same value and must be empty. There are three important differences between dataSource and dataSourceRef: * While dataSource only allows two specific types of objects, dataSourceRef
             *   allows any non-core object, as well as PersistentVolumeClaim objects.
             * * While dataSource ignores disallowed values (dropping them), dataSourceRef
             *   preserves all values, and generates an error if a disallowed value is
             *   specified.
             * * While dataSource only allows local objects, dataSourceRef allows objects
             *   in any namespaces.
             * (Beta) Using this field requires the AnyVolumeDataSource feature gate to be enabled. (Alpha) Using the namespace field of dataSourceRef requires the CrossNamespaceVolumeDataSource feature gate to be enabled.
             */
            dataSourceRef?: pulumi.Input<inputs.core.v1.TypedObjectReferencePatch>;
            /**
             * resources represents the minimum resources the volume should have. If RecoverVolumeExpansionFailure feature is enabled users are allowed to specify resource requirements that are lower than previous value but must still be higher than capacity recorded in the status field of the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#resources
             */
            resources?: pulumi.Input<inputs.core.v1.VolumeResourceRequirementsPatch>;
            /**
             * selector is a label query over volumes to consider for binding.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * storageClassName is the name of the StorageClass required by the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#class-1
             */
            storageClassName?: pulumi.Input<string>;
            /**
             * volumeAttributesClassName may be used to set the VolumeAttributesClass used by this claim. If specified, the CSI driver will create or update the volume with the attributes defined in the corresponding VolumeAttributesClass. This has a different purpose than storageClassName, it can be changed after the claim is created. An empty string value means that no VolumeAttributesClass will be applied to the claim but it's not allowed to reset this field to empty string once it is set. If unspecified and the PersistentVolumeClaim is unbound, the default VolumeAttributesClass will be set by the persistentvolume controller if it exists. If the resource referred to by volumeAttributesClass does not exist, this PersistentVolumeClaim will be set to a Pending state, as reflected by the modifyVolumeStatus field, until such as a resource exists. More info: https://kubernetes.io/docs/concepts/storage/volume-attributes-classes/ (Beta) Using this field requires the VolumeAttributesClass feature gate to be enabled (off by default).
             */
            volumeAttributesClassName?: pulumi.Input<string>;
            /**
             * volumeMode defines what type of volume is required by the claim. Value of Filesystem is implied when not included in claim spec.
             */
            volumeMode?: pulumi.Input<string>;
            /**
             * volumeName is the binding reference to the PersistentVolume backing this claim.
             */
            volumeName?: pulumi.Input<string>;
        }
        /**
         * PersistentVolumeClaimStatus is the current status of a persistent volume claim.
         */
        interface PersistentVolumeClaimStatus {
            /**
             * accessModes contains the actual access modes the volume backing the PVC has. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1
             */
            accessModes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * allocatedResourceStatuses stores status of resource being resized for the given PVC. Key names follow standard Kubernetes label syntax. Valid values are either:
             * 	* Un-prefixed keys:
             * 		- storage - the capacity of the volume.
             * 	* Custom resources must use implementation-defined prefixed names such as "example.com/my-custom-resource"
             * Apart from above values - keys that are unprefixed or have kubernetes.io prefix are considered reserved and hence may not be used.
             *
             * ClaimResourceStatus can be in any of following states:
             * 	- ControllerResizeInProgress:
             * 		State set when resize controller starts resizing the volume in control-plane.
             * 	- ControllerResizeFailed:
             * 		State set when resize has failed in resize controller with a terminal error.
             * 	- NodeResizePending:
             * 		State set when resize controller has finished resizing the volume but further resizing of
             * 		volume is needed on the node.
             * 	- NodeResizeInProgress:
             * 		State set when kubelet starts resizing the volume.
             * 	- NodeResizeFailed:
             * 		State set when resizing has failed in kubelet with a terminal error. Transient errors don't set
             * 		NodeResizeFailed.
             * For example: if expanding a PVC for more capacity - this field can be one of the following states:
             * 	- pvc.status.allocatedResourceStatus['storage'] = "ControllerResizeInProgress"
             *      - pvc.status.allocatedResourceStatus['storage'] = "ControllerResizeFailed"
             *      - pvc.status.allocatedResourceStatus['storage'] = "NodeResizePending"
             *      - pvc.status.allocatedResourceStatus['storage'] = "NodeResizeInProgress"
             *      - pvc.status.allocatedResourceStatus['storage'] = "NodeResizeFailed"
             * When this field is not set, it means that no resize operation is in progress for the given PVC.
             *
             * A controller that receives PVC update with previously unknown resourceName or ClaimResourceStatus should ignore the update for the purpose it was designed. For example - a controller that only is responsible for resizing capacity of the volume, should ignore PVC updates that change other valid resources associated with PVC.
             *
             * This is an alpha field and requires enabling RecoverVolumeExpansionFailure feature.
             */
            allocatedResourceStatuses?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * allocatedResources tracks the resources allocated to a PVC including its capacity. Key names follow standard Kubernetes label syntax. Valid values are either:
             * 	* Un-prefixed keys:
             * 		- storage - the capacity of the volume.
             * 	* Custom resources must use implementation-defined prefixed names such as "example.com/my-custom-resource"
             * Apart from above values - keys that are unprefixed or have kubernetes.io prefix are considered reserved and hence may not be used.
             *
             * Capacity reported here may be larger than the actual capacity when a volume expansion operation is requested. For storage quota, the larger value from allocatedResources and PVC.spec.resources is used. If allocatedResources is not set, PVC.spec.resources alone is used for quota calculation. If a volume expansion capacity request is lowered, allocatedResources is only lowered if there are no expansion operations in progress and if the actual volume capacity is equal or lower than the requested capacity.
             *
             * A controller that receives PVC update with previously unknown resourceName should ignore the update for the purpose it was designed. For example - a controller that only is responsible for resizing capacity of the volume, should ignore PVC updates that change other valid resources associated with PVC.
             *
             * This is an alpha field and requires enabling RecoverVolumeExpansionFailure feature.
             */
            allocatedResources?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * capacity represents the actual resources of the underlying volume.
             */
            capacity?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * conditions is the current Condition of persistent volume claim. If underlying persistent volume is being resized then the Condition will be set to 'Resizing'.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.core.v1.PersistentVolumeClaimCondition>[]>;
            /**
             * currentVolumeAttributesClassName is the current name of the VolumeAttributesClass the PVC is using. When unset, there is no VolumeAttributeClass applied to this PersistentVolumeClaim This is a beta field and requires enabling VolumeAttributesClass feature (off by default).
             */
            currentVolumeAttributesClassName?: pulumi.Input<string>;
            /**
             * ModifyVolumeStatus represents the status object of ControllerModifyVolume operation. When this is unset, there is no ModifyVolume operation being attempted. This is a beta field and requires enabling VolumeAttributesClass feature (off by default).
             */
            modifyVolumeStatus?: pulumi.Input<inputs.core.v1.ModifyVolumeStatus>;
            /**
             * phase represents the current phase of PersistentVolumeClaim.
             */
            phase?: pulumi.Input<string>;
            /**
             * resizeStatus stores status of resize operation. ResizeStatus is not set by default but when expansion is complete resizeStatus is set to empty string by resize controller or kubelet. This is an alpha field and requires enabling RecoverVolumeExpansionFailure feature.
             */
            resizeStatus?: pulumi.Input<string>;
        }
        /**
         * PersistentVolumeClaimStatus is the current status of a persistent volume claim.
         */
        interface PersistentVolumeClaimStatusPatch {
            /**
             * accessModes contains the actual access modes the volume backing the PVC has. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1
             */
            accessModes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * allocatedResourceStatuses stores status of resource being resized for the given PVC. Key names follow standard Kubernetes label syntax. Valid values are either:
             * 	* Un-prefixed keys:
             * 		- storage - the capacity of the volume.
             * 	* Custom resources must use implementation-defined prefixed names such as "example.com/my-custom-resource"
             * Apart from above values - keys that are unprefixed or have kubernetes.io prefix are considered reserved and hence may not be used.
             *
             * ClaimResourceStatus can be in any of following states:
             * 	- ControllerResizeInProgress:
             * 		State set when resize controller starts resizing the volume in control-plane.
             * 	- ControllerResizeFailed:
             * 		State set when resize has failed in resize controller with a terminal error.
             * 	- NodeResizePending:
             * 		State set when resize controller has finished resizing the volume but further resizing of
             * 		volume is needed on the node.
             * 	- NodeResizeInProgress:
             * 		State set when kubelet starts resizing the volume.
             * 	- NodeResizeFailed:
             * 		State set when resizing has failed in kubelet with a terminal error. Transient errors don't set
             * 		NodeResizeFailed.
             * For example: if expanding a PVC for more capacity - this field can be one of the following states:
             * 	- pvc.status.allocatedResourceStatus['storage'] = "ControllerResizeInProgress"
             *      - pvc.status.allocatedResourceStatus['storage'] = "ControllerResizeFailed"
             *      - pvc.status.allocatedResourceStatus['storage'] = "NodeResizePending"
             *      - pvc.status.allocatedResourceStatus['storage'] = "NodeResizeInProgress"
             *      - pvc.status.allocatedResourceStatus['storage'] = "NodeResizeFailed"
             * When this field is not set, it means that no resize operation is in progress for the given PVC.
             *
             * A controller that receives PVC update with previously unknown resourceName or ClaimResourceStatus should ignore the update for the purpose it was designed. For example - a controller that only is responsible for resizing capacity of the volume, should ignore PVC updates that change other valid resources associated with PVC.
             *
             * This is an alpha field and requires enabling RecoverVolumeExpansionFailure feature.
             */
            allocatedResourceStatuses?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * allocatedResources tracks the resources allocated to a PVC including its capacity. Key names follow standard Kubernetes label syntax. Valid values are either:
             * 	* Un-prefixed keys:
             * 		- storage - the capacity of the volume.
             * 	* Custom resources must use implementation-defined prefixed names such as "example.com/my-custom-resource"
             * Apart from above values - keys that are unprefixed or have kubernetes.io prefix are considered reserved and hence may not be used.
             *
             * Capacity reported here may be larger than the actual capacity when a volume expansion operation is requested. For storage quota, the larger value from allocatedResources and PVC.spec.resources is used. If allocatedResources is not set, PVC.spec.resources alone is used for quota calculation. If a volume expansion capacity request is lowered, allocatedResources is only lowered if there are no expansion operations in progress and if the actual volume capacity is equal or lower than the requested capacity.
             *
             * A controller that receives PVC update with previously unknown resourceName should ignore the update for the purpose it was designed. For example - a controller that only is responsible for resizing capacity of the volume, should ignore PVC updates that change other valid resources associated with PVC.
             *
             * This is an alpha field and requires enabling RecoverVolumeExpansionFailure feature.
             */
            allocatedResources?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * capacity represents the actual resources of the underlying volume.
             */
            capacity?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * conditions is the current Condition of persistent volume claim. If underlying persistent volume is being resized then the Condition will be set to 'Resizing'.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.core.v1.PersistentVolumeClaimConditionPatch>[]>;
            /**
             * currentVolumeAttributesClassName is the current name of the VolumeAttributesClass the PVC is using. When unset, there is no VolumeAttributeClass applied to this PersistentVolumeClaim This is a beta field and requires enabling VolumeAttributesClass feature (off by default).
             */
            currentVolumeAttributesClassName?: pulumi.Input<string>;
            /**
             * ModifyVolumeStatus represents the status object of ControllerModifyVolume operation. When this is unset, there is no ModifyVolume operation being attempted. This is a beta field and requires enabling VolumeAttributesClass feature (off by default).
             */
            modifyVolumeStatus?: pulumi.Input<inputs.core.v1.ModifyVolumeStatusPatch>;
            /**
             * phase represents the current phase of PersistentVolumeClaim.
             */
            phase?: pulumi.Input<string>;
            /**
             * resizeStatus stores status of resize operation. ResizeStatus is not set by default but when expansion is complete resizeStatus is set to empty string by resize controller or kubelet. This is an alpha field and requires enabling RecoverVolumeExpansionFailure feature.
             */
            resizeStatus?: pulumi.Input<string>;
        }
        /**
         * PersistentVolumeClaimTemplate is used to produce PersistentVolumeClaim objects as part of an EphemeralVolumeSource.
         */
        interface PersistentVolumeClaimTemplate {
            /**
             * May contain labels and annotations that will be copied into the PVC when creating it. No other fields are allowed and will be rejected during validation.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * The specification for the PersistentVolumeClaim. The entire content is copied unchanged into the PVC that gets created from this template. The same fields as in a PersistentVolumeClaim are also valid here.
             */
            spec: pulumi.Input<inputs.core.v1.PersistentVolumeClaimSpec>;
        }
        /**
         * PersistentVolumeClaimTemplate is used to produce PersistentVolumeClaim objects as part of an EphemeralVolumeSource.
         */
        interface PersistentVolumeClaimTemplatePatch {
            /**
             * May contain labels and annotations that will be copied into the PVC when creating it. No other fields are allowed and will be rejected during validation.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMetaPatch>;
            /**
             * The specification for the PersistentVolumeClaim. The entire content is copied unchanged into the PVC that gets created from this template. The same fields as in a PersistentVolumeClaim are also valid here.
             */
            spec?: pulumi.Input<inputs.core.v1.PersistentVolumeClaimSpecPatch>;
        }
        /**
         * PersistentVolumeClaimVolumeSource references the user's PVC in the same namespace. This volume finds the bound PV and mounts that volume for the pod. A PersistentVolumeClaimVolumeSource is, essentially, a wrapper around another type of volume that is owned by someone else (the system).
         */
        interface PersistentVolumeClaimVolumeSource {
            /**
             * claimName is the name of a PersistentVolumeClaim in the same namespace as the pod using this volume. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims
             */
            claimName: pulumi.Input<string>;
            /**
             * readOnly Will force the ReadOnly setting in VolumeMounts. Default false.
             */
            readOnly?: pulumi.Input<boolean>;
        }
        /**
         * PersistentVolumeClaimVolumeSource references the user's PVC in the same namespace. This volume finds the bound PV and mounts that volume for the pod. A PersistentVolumeClaimVolumeSource is, essentially, a wrapper around another type of volume that is owned by someone else (the system).
         */
        interface PersistentVolumeClaimVolumeSourcePatch {
            /**
             * claimName is the name of a PersistentVolumeClaim in the same namespace as the pod using this volume. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims
             */
            claimName?: pulumi.Input<string>;
            /**
             * readOnly Will force the ReadOnly setting in VolumeMounts. Default false.
             */
            readOnly?: pulumi.Input<boolean>;
        }
        /**
         * PersistentVolumeSpec is the specification of a persistent volume.
         */
        interface PersistentVolumeSpec {
            /**
             * accessModes contains all ways the volume can be mounted. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes
             */
            accessModes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * awsElasticBlockStore represents an AWS Disk resource that is attached to a kubelet's host machine and then exposed to the pod. Deprecated: AWSElasticBlockStore is deprecated. All operations for the in-tree awsElasticBlockStore type are redirected to the ebs.csi.aws.com CSI driver. More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore
             */
            awsElasticBlockStore?: pulumi.Input<inputs.core.v1.AWSElasticBlockStoreVolumeSource>;
            /**
             * azureDisk represents an Azure Data Disk mount on the host and bind mount to the pod. Deprecated: AzureDisk is deprecated. All operations for the in-tree azureDisk type are redirected to the disk.csi.azure.com CSI driver.
             */
            azureDisk?: pulumi.Input<inputs.core.v1.AzureDiskVolumeSource>;
            /**
             * azureFile represents an Azure File Service mount on the host and bind mount to the pod. Deprecated: AzureFile is deprecated. All operations for the in-tree azureFile type are redirected to the file.csi.azure.com CSI driver.
             */
            azureFile?: pulumi.Input<inputs.core.v1.AzureFilePersistentVolumeSource>;
            /**
             * capacity is the description of the persistent volume's resources and capacity. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#capacity
             */
            capacity?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * cephFS represents a Ceph FS mount on the host that shares a pod's lifetime. Deprecated: CephFS is deprecated and the in-tree cephfs type is no longer supported.
             */
            cephfs?: pulumi.Input<inputs.core.v1.CephFSPersistentVolumeSource>;
            /**
             * cinder represents a cinder volume attached and mounted on kubelets host machine. Deprecated: Cinder is deprecated. All operations for the in-tree cinder type are redirected to the cinder.csi.openstack.org CSI driver. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            cinder?: pulumi.Input<inputs.core.v1.CinderPersistentVolumeSource>;
            /**
             * claimRef is part of a bi-directional binding between PersistentVolume and PersistentVolumeClaim. Expected to be non-nil when bound. claim.VolumeName is the authoritative bind between PV and PVC. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#binding
             */
            claimRef?: pulumi.Input<inputs.core.v1.ObjectReference>;
            /**
             * csi represents storage that is handled by an external CSI driver.
             */
            csi?: pulumi.Input<inputs.core.v1.CSIPersistentVolumeSource>;
            /**
             * fc represents a Fibre Channel resource that is attached to a kubelet's host machine and then exposed to the pod.
             */
            fc?: pulumi.Input<inputs.core.v1.FCVolumeSource>;
            /**
             * flexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin. Deprecated: FlexVolume is deprecated. Consider using a CSIDriver instead.
             */
            flexVolume?: pulumi.Input<inputs.core.v1.FlexPersistentVolumeSource>;
            /**
             * flocker represents a Flocker volume attached to a kubelet's host machine and exposed to the pod for its usage. This depends on the Flocker control service being running. Deprecated: Flocker is deprecated and the in-tree flocker type is no longer supported.
             */
            flocker?: pulumi.Input<inputs.core.v1.FlockerVolumeSource>;
            /**
             * gcePersistentDisk represents a GCE Disk resource that is attached to a kubelet's host machine and then exposed to the pod. Provisioned by an admin. Deprecated: GCEPersistentDisk is deprecated. All operations for the in-tree gcePersistentDisk type are redirected to the pd.csi.storage.gke.io CSI driver. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk
             */
            gcePersistentDisk?: pulumi.Input<inputs.core.v1.GCEPersistentDiskVolumeSource>;
            /**
             * glusterfs represents a Glusterfs volume that is attached to a host and exposed to the pod. Provisioned by an admin. Deprecated: Glusterfs is deprecated and the in-tree glusterfs type is no longer supported. More info: https://examples.k8s.io/volumes/glusterfs/README.md
             */
            glusterfs?: pulumi.Input<inputs.core.v1.GlusterfsPersistentVolumeSource>;
            /**
             * hostPath represents a directory on the host. Provisioned by a developer or tester. This is useful for single-node development and testing only! On-host storage is not supported in any way and WILL NOT WORK in a multi-node cluster. More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath
             */
            hostPath?: pulumi.Input<inputs.core.v1.HostPathVolumeSource>;
            /**
             * iscsi represents an ISCSI Disk resource that is attached to a kubelet's host machine and then exposed to the pod. Provisioned by an admin.
             */
            iscsi?: pulumi.Input<inputs.core.v1.ISCSIPersistentVolumeSource>;
            /**
             * local represents directly-attached storage with node affinity
             */
            local?: pulumi.Input<inputs.core.v1.LocalVolumeSource>;
            /**
             * mountOptions is the list of mount options, e.g. ["ro", "soft"]. Not validated - mount will simply fail if one is invalid. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes/#mount-options
             */
            mountOptions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * nfs represents an NFS mount on the host. Provisioned by an admin. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs
             */
            nfs?: pulumi.Input<inputs.core.v1.NFSVolumeSource>;
            /**
             * nodeAffinity defines constraints that limit what nodes this volume can be accessed from. This field influences the scheduling of pods that use this volume.
             */
            nodeAffinity?: pulumi.Input<inputs.core.v1.VolumeNodeAffinity>;
            /**
             * persistentVolumeReclaimPolicy defines what happens to a persistent volume when released from its claim. Valid options are Retain (default for manually created PersistentVolumes), Delete (default for dynamically provisioned PersistentVolumes), and Recycle (deprecated). Recycle must be supported by the volume plugin underlying this PersistentVolume. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#reclaiming
             */
            persistentVolumeReclaimPolicy?: pulumi.Input<string>;
            /**
             * photonPersistentDisk represents a PhotonController persistent disk attached and mounted on kubelets host machine. Deprecated: PhotonPersistentDisk is deprecated and the in-tree photonPersistentDisk type is no longer supported.
             */
            photonPersistentDisk?: pulumi.Input<inputs.core.v1.PhotonPersistentDiskVolumeSource>;
            /**
             * portworxVolume represents a portworx volume attached and mounted on kubelets host machine. Deprecated: PortworxVolume is deprecated. All operations for the in-tree portworxVolume type are redirected to the pxd.portworx.com CSI driver when the CSIMigrationPortworx feature-gate is on.
             */
            portworxVolume?: pulumi.Input<inputs.core.v1.PortworxVolumeSource>;
            /**
             * quobyte represents a Quobyte mount on the host that shares a pod's lifetime. Deprecated: Quobyte is deprecated and the in-tree quobyte type is no longer supported.
             */
            quobyte?: pulumi.Input<inputs.core.v1.QuobyteVolumeSource>;
            /**
             * rbd represents a Rados Block Device mount on the host that shares a pod's lifetime. Deprecated: RBD is deprecated and the in-tree rbd type is no longer supported. More info: https://examples.k8s.io/volumes/rbd/README.md
             */
            rbd?: pulumi.Input<inputs.core.v1.RBDPersistentVolumeSource>;
            /**
             * scaleIO represents a ScaleIO persistent volume attached and mounted on Kubernetes nodes. Deprecated: ScaleIO is deprecated and the in-tree scaleIO type is no longer supported.
             */
            scaleIO?: pulumi.Input<inputs.core.v1.ScaleIOPersistentVolumeSource>;
            /**
             * storageClassName is the name of StorageClass to which this persistent volume belongs. Empty value means that this volume does not belong to any StorageClass.
             */
            storageClassName?: pulumi.Input<string>;
            /**
             * storageOS represents a StorageOS volume that is attached to the kubelet's host machine and mounted into the pod. Deprecated: StorageOS is deprecated and the in-tree storageos type is no longer supported. More info: https://examples.k8s.io/volumes/storageos/README.md
             */
            storageos?: pulumi.Input<inputs.core.v1.StorageOSPersistentVolumeSource>;
            /**
             * Name of VolumeAttributesClass to which this persistent volume belongs. Empty value is not allowed. When this field is not set, it indicates that this volume does not belong to any VolumeAttributesClass. This field is mutable and can be changed by the CSI driver after a volume has been updated successfully to a new class. For an unbound PersistentVolume, the volumeAttributesClassName will be matched with unbound PersistentVolumeClaims during the binding process. This is a beta field and requires enabling VolumeAttributesClass feature (off by default).
             */
            volumeAttributesClassName?: pulumi.Input<string>;
            /**
             * volumeMode defines if a volume is intended to be used with a formatted filesystem or to remain in raw block state. Value of Filesystem is implied when not included in spec.
             */
            volumeMode?: pulumi.Input<string>;
            /**
             * vsphereVolume represents a vSphere volume attached and mounted on kubelets host machine. Deprecated: VsphereVolume is deprecated. All operations for the in-tree vsphereVolume type are redirected to the csi.vsphere.vmware.com CSI driver.
             */
            vsphereVolume?: pulumi.Input<inputs.core.v1.VsphereVirtualDiskVolumeSource>;
        }
        /**
         * PersistentVolumeSpec is the specification of a persistent volume.
         */
        interface PersistentVolumeSpecPatch {
            /**
             * accessModes contains all ways the volume can be mounted. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes
             */
            accessModes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * awsElasticBlockStore represents an AWS Disk resource that is attached to a kubelet's host machine and then exposed to the pod. Deprecated: AWSElasticBlockStore is deprecated. All operations for the in-tree awsElasticBlockStore type are redirected to the ebs.csi.aws.com CSI driver. More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore
             */
            awsElasticBlockStore?: pulumi.Input<inputs.core.v1.AWSElasticBlockStoreVolumeSourcePatch>;
            /**
             * azureDisk represents an Azure Data Disk mount on the host and bind mount to the pod. Deprecated: AzureDisk is deprecated. All operations for the in-tree azureDisk type are redirected to the disk.csi.azure.com CSI driver.
             */
            azureDisk?: pulumi.Input<inputs.core.v1.AzureDiskVolumeSourcePatch>;
            /**
             * azureFile represents an Azure File Service mount on the host and bind mount to the pod. Deprecated: AzureFile is deprecated. All operations for the in-tree azureFile type are redirected to the file.csi.azure.com CSI driver.
             */
            azureFile?: pulumi.Input<inputs.core.v1.AzureFilePersistentVolumeSourcePatch>;
            /**
             * capacity is the description of the persistent volume's resources and capacity. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#capacity
             */
            capacity?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * cephFS represents a Ceph FS mount on the host that shares a pod's lifetime. Deprecated: CephFS is deprecated and the in-tree cephfs type is no longer supported.
             */
            cephfs?: pulumi.Input<inputs.core.v1.CephFSPersistentVolumeSourcePatch>;
            /**
             * cinder represents a cinder volume attached and mounted on kubelets host machine. Deprecated: Cinder is deprecated. All operations for the in-tree cinder type are redirected to the cinder.csi.openstack.org CSI driver. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            cinder?: pulumi.Input<inputs.core.v1.CinderPersistentVolumeSourcePatch>;
            /**
             * claimRef is part of a bi-directional binding between PersistentVolume and PersistentVolumeClaim. Expected to be non-nil when bound. claim.VolumeName is the authoritative bind between PV and PVC. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#binding
             */
            claimRef?: pulumi.Input<inputs.core.v1.ObjectReferencePatch>;
            /**
             * csi represents storage that is handled by an external CSI driver.
             */
            csi?: pulumi.Input<inputs.core.v1.CSIPersistentVolumeSourcePatch>;
            /**
             * fc represents a Fibre Channel resource that is attached to a kubelet's host machine and then exposed to the pod.
             */
            fc?: pulumi.Input<inputs.core.v1.FCVolumeSourcePatch>;
            /**
             * flexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin. Deprecated: FlexVolume is deprecated. Consider using a CSIDriver instead.
             */
            flexVolume?: pulumi.Input<inputs.core.v1.FlexPersistentVolumeSourcePatch>;
            /**
             * flocker represents a Flocker volume attached to a kubelet's host machine and exposed to the pod for its usage. This depends on the Flocker control service being running. Deprecated: Flocker is deprecated and the in-tree flocker type is no longer supported.
             */
            flocker?: pulumi.Input<inputs.core.v1.FlockerVolumeSourcePatch>;
            /**
             * gcePersistentDisk represents a GCE Disk resource that is attached to a kubelet's host machine and then exposed to the pod. Provisioned by an admin. Deprecated: GCEPersistentDisk is deprecated. All operations for the in-tree gcePersistentDisk type are redirected to the pd.csi.storage.gke.io CSI driver. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk
             */
            gcePersistentDisk?: pulumi.Input<inputs.core.v1.GCEPersistentDiskVolumeSourcePatch>;
            /**
             * glusterfs represents a Glusterfs volume that is attached to a host and exposed to the pod. Provisioned by an admin. Deprecated: Glusterfs is deprecated and the in-tree glusterfs type is no longer supported. More info: https://examples.k8s.io/volumes/glusterfs/README.md
             */
            glusterfs?: pulumi.Input<inputs.core.v1.GlusterfsPersistentVolumeSourcePatch>;
            /**
             * hostPath represents a directory on the host. Provisioned by a developer or tester. This is useful for single-node development and testing only! On-host storage is not supported in any way and WILL NOT WORK in a multi-node cluster. More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath
             */
            hostPath?: pulumi.Input<inputs.core.v1.HostPathVolumeSourcePatch>;
            /**
             * iscsi represents an ISCSI Disk resource that is attached to a kubelet's host machine and then exposed to the pod. Provisioned by an admin.
             */
            iscsi?: pulumi.Input<inputs.core.v1.ISCSIPersistentVolumeSourcePatch>;
            /**
             * local represents directly-attached storage with node affinity
             */
            local?: pulumi.Input<inputs.core.v1.LocalVolumeSourcePatch>;
            /**
             * mountOptions is the list of mount options, e.g. ["ro", "soft"]. Not validated - mount will simply fail if one is invalid. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes/#mount-options
             */
            mountOptions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * nfs represents an NFS mount on the host. Provisioned by an admin. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs
             */
            nfs?: pulumi.Input<inputs.core.v1.NFSVolumeSourcePatch>;
            /**
             * nodeAffinity defines constraints that limit what nodes this volume can be accessed from. This field influences the scheduling of pods that use this volume.
             */
            nodeAffinity?: pulumi.Input<inputs.core.v1.VolumeNodeAffinityPatch>;
            /**
             * persistentVolumeReclaimPolicy defines what happens to a persistent volume when released from its claim. Valid options are Retain (default for manually created PersistentVolumes), Delete (default for dynamically provisioned PersistentVolumes), and Recycle (deprecated). Recycle must be supported by the volume plugin underlying this PersistentVolume. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#reclaiming
             */
            persistentVolumeReclaimPolicy?: pulumi.Input<string>;
            /**
             * photonPersistentDisk represents a PhotonController persistent disk attached and mounted on kubelets host machine. Deprecated: PhotonPersistentDisk is deprecated and the in-tree photonPersistentDisk type is no longer supported.
             */
            photonPersistentDisk?: pulumi.Input<inputs.core.v1.PhotonPersistentDiskVolumeSourcePatch>;
            /**
             * portworxVolume represents a portworx volume attached and mounted on kubelets host machine. Deprecated: PortworxVolume is deprecated. All operations for the in-tree portworxVolume type are redirected to the pxd.portworx.com CSI driver when the CSIMigrationPortworx feature-gate is on.
             */
            portworxVolume?: pulumi.Input<inputs.core.v1.PortworxVolumeSourcePatch>;
            /**
             * quobyte represents a Quobyte mount on the host that shares a pod's lifetime. Deprecated: Quobyte is deprecated and the in-tree quobyte type is no longer supported.
             */
            quobyte?: pulumi.Input<inputs.core.v1.QuobyteVolumeSourcePatch>;
            /**
             * rbd represents a Rados Block Device mount on the host that shares a pod's lifetime. Deprecated: RBD is deprecated and the in-tree rbd type is no longer supported. More info: https://examples.k8s.io/volumes/rbd/README.md
             */
            rbd?: pulumi.Input<inputs.core.v1.RBDPersistentVolumeSourcePatch>;
            /**
             * scaleIO represents a ScaleIO persistent volume attached and mounted on Kubernetes nodes. Deprecated: ScaleIO is deprecated and the in-tree scaleIO type is no longer supported.
             */
            scaleIO?: pulumi.Input<inputs.core.v1.ScaleIOPersistentVolumeSourcePatch>;
            /**
             * storageClassName is the name of StorageClass to which this persistent volume belongs. Empty value means that this volume does not belong to any StorageClass.
             */
            storageClassName?: pulumi.Input<string>;
            /**
             * storageOS represents a StorageOS volume that is attached to the kubelet's host machine and mounted into the pod. Deprecated: StorageOS is deprecated and the in-tree storageos type is no longer supported. More info: https://examples.k8s.io/volumes/storageos/README.md
             */
            storageos?: pulumi.Input<inputs.core.v1.StorageOSPersistentVolumeSourcePatch>;
            /**
             * Name of VolumeAttributesClass to which this persistent volume belongs. Empty value is not allowed. When this field is not set, it indicates that this volume does not belong to any VolumeAttributesClass. This field is mutable and can be changed by the CSI driver after a volume has been updated successfully to a new class. For an unbound PersistentVolume, the volumeAttributesClassName will be matched with unbound PersistentVolumeClaims during the binding process. This is a beta field and requires enabling VolumeAttributesClass feature (off by default).
             */
            volumeAttributesClassName?: pulumi.Input<string>;
            /**
             * volumeMode defines if a volume is intended to be used with a formatted filesystem or to remain in raw block state. Value of Filesystem is implied when not included in spec.
             */
            volumeMode?: pulumi.Input<string>;
            /**
             * vsphereVolume represents a vSphere volume attached and mounted on kubelets host machine. Deprecated: VsphereVolume is deprecated. All operations for the in-tree vsphereVolume type are redirected to the csi.vsphere.vmware.com CSI driver.
             */
            vsphereVolume?: pulumi.Input<inputs.core.v1.VsphereVirtualDiskVolumeSourcePatch>;
        }
        /**
         * PersistentVolumeStatus is the current status of a persistent volume.
         */
        interface PersistentVolumeStatus {
            /**
             * lastPhaseTransitionTime is the time the phase transitioned from one to another and automatically resets to current time everytime a volume phase transitions.
             */
            lastPhaseTransitionTime?: pulumi.Input<string>;
            /**
             * message is a human-readable message indicating details about why the volume is in this state.
             */
            message?: pulumi.Input<string>;
            /**
             * phase indicates if a volume is available, bound to a claim, or released by a claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#phase
             */
            phase?: pulumi.Input<string>;
            /**
             * reason is a brief CamelCase string that describes any failure and is meant for machine parsing and tidy display in the CLI.
             */
            reason?: pulumi.Input<string>;
        }
        /**
         * Represents a Photon Controller persistent disk resource.
         */
        interface PhotonPersistentDiskVolumeSource {
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * pdID is the ID that identifies Photon Controller persistent disk
             */
            pdID: pulumi.Input<string>;
        }
        /**
         * Represents a Photon Controller persistent disk resource.
         */
        interface PhotonPersistentDiskVolumeSourcePatch {
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * pdID is the ID that identifies Photon Controller persistent disk
             */
            pdID?: pulumi.Input<string>;
        }
        /**
         * Pod is a collection of containers that can run on a host. This resource is created by clients and scheduled onto hosts.
         *
         * This resource waits until its status is ready before registering success
         * for create/update, and populating output properties from the current state of the resource.
         * The following conditions are used to determine whether the resource creation has
         * succeeded or failed:
         *
         * 1. The Pod is scheduled ("PodScheduled"" '.status.condition' is true).
         * 2. The Pod is initialized ("Initialized" '.status.condition' is true).
         * 3. The Pod is ready ("Ready" '.status.condition' is true) and the '.status.phase' is
         *    set to "Running".
         * Or (for Jobs): The Pod succeeded ('.status.phase' set to "Succeeded").
         *
         * If the Pod has not reached a Ready state after 10 minutes, it will
         * time out and mark the resource update as Failed. You can override the default timeout value
         * by setting the 'customTimeouts' option on the resource.
         */
        interface Pod {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Pod">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the pod. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.core.v1.PodSpec>;
            /**
             * Most recently observed status of the pod. This data may not be up to date. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.core.v1.PodStatus>;
        }
        /**
         * Pod affinity is a group of inter pod affinity scheduling rules.
         */
        interface PodAffinity {
            /**
             * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
             */
            preferredDuringSchedulingIgnoredDuringExecution?: pulumi.Input<pulumi.Input<inputs.core.v1.WeightedPodAffinityTerm>[]>;
            /**
             * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
             */
            requiredDuringSchedulingIgnoredDuringExecution?: pulumi.Input<pulumi.Input<inputs.core.v1.PodAffinityTerm>[]>;
        }
        /**
         * Pod affinity is a group of inter pod affinity scheduling rules.
         */
        interface PodAffinityPatch {
            /**
             * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
             */
            preferredDuringSchedulingIgnoredDuringExecution?: pulumi.Input<pulumi.Input<inputs.core.v1.WeightedPodAffinityTermPatch>[]>;
            /**
             * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
             */
            requiredDuringSchedulingIgnoredDuringExecution?: pulumi.Input<pulumi.Input<inputs.core.v1.PodAffinityTermPatch>[]>;
        }
        /**
         * Defines a set of pods (namely those matching the labelSelector relative to the given namespace(s)) that this pod should be co-located (affinity) or not co-located (anti-affinity) with, where co-located is defined as running on a node whose value of the label with key <topologyKey> matches that of any node on which a pod of the set of pods is running
         */
        interface PodAffinityTerm {
            /**
             * A label query over a set of resources, in this case pods. If it's null, this PodAffinityTerm matches with no Pods.
             */
            labelSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * MatchLabelKeys is a set of pod label keys to select which pods will be taken into consideration. The keys are used to lookup values from the incoming pod labels, those key-value labels are merged with `labelSelector` as `key in (value)` to select the group of existing pods which pods will be taken into consideration for the incoming pod's pod (anti) affinity. Keys that don't exist in the incoming pod labels will be ignored. The default value is empty. The same key is forbidden to exist in both matchLabelKeys and labelSelector. Also, matchLabelKeys cannot be set when labelSelector isn't set.
             */
            matchLabelKeys?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * MismatchLabelKeys is a set of pod label keys to select which pods will be taken into consideration. The keys are used to lookup values from the incoming pod labels, those key-value labels are merged with `labelSelector` as `key notin (value)` to select the group of existing pods which pods will be taken into consideration for the incoming pod's pod (anti) affinity. Keys that don't exist in the incoming pod labels will be ignored. The default value is empty. The same key is forbidden to exist in both mismatchLabelKeys and labelSelector. Also, mismatchLabelKeys cannot be set when labelSelector isn't set.
             */
            mismatchLabelKeys?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
             */
            namespaces?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
             */
            topologyKey: pulumi.Input<string>;
        }
        /**
         * Defines a set of pods (namely those matching the labelSelector relative to the given namespace(s)) that this pod should be co-located (affinity) or not co-located (anti-affinity) with, where co-located is defined as running on a node whose value of the label with key <topologyKey> matches that of any node on which a pod of the set of pods is running
         */
        interface PodAffinityTermPatch {
            /**
             * A label query over a set of resources, in this case pods. If it's null, this PodAffinityTerm matches with no Pods.
             */
            labelSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * MatchLabelKeys is a set of pod label keys to select which pods will be taken into consideration. The keys are used to lookup values from the incoming pod labels, those key-value labels are merged with `labelSelector` as `key in (value)` to select the group of existing pods which pods will be taken into consideration for the incoming pod's pod (anti) affinity. Keys that don't exist in the incoming pod labels will be ignored. The default value is empty. The same key is forbidden to exist in both matchLabelKeys and labelSelector. Also, matchLabelKeys cannot be set when labelSelector isn't set.
             */
            matchLabelKeys?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * MismatchLabelKeys is a set of pod label keys to select which pods will be taken into consideration. The keys are used to lookup values from the incoming pod labels, those key-value labels are merged with `labelSelector` as `key notin (value)` to select the group of existing pods which pods will be taken into consideration for the incoming pod's pod (anti) affinity. Keys that don't exist in the incoming pod labels will be ignored. The default value is empty. The same key is forbidden to exist in both mismatchLabelKeys and labelSelector. Also, mismatchLabelKeys cannot be set when labelSelector isn't set.
             */
            mismatchLabelKeys?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
             */
            namespaces?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
             */
            topologyKey?: pulumi.Input<string>;
        }
        /**
         * Pod anti affinity is a group of inter pod anti affinity scheduling rules.
         */
        interface PodAntiAffinity {
            /**
             * The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
             */
            preferredDuringSchedulingIgnoredDuringExecution?: pulumi.Input<pulumi.Input<inputs.core.v1.WeightedPodAffinityTerm>[]>;
            /**
             * If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
             */
            requiredDuringSchedulingIgnoredDuringExecution?: pulumi.Input<pulumi.Input<inputs.core.v1.PodAffinityTerm>[]>;
        }
        /**
         * Pod anti affinity is a group of inter pod anti affinity scheduling rules.
         */
        interface PodAntiAffinityPatch {
            /**
             * The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
             */
            preferredDuringSchedulingIgnoredDuringExecution?: pulumi.Input<pulumi.Input<inputs.core.v1.WeightedPodAffinityTermPatch>[]>;
            /**
             * If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
             */
            requiredDuringSchedulingIgnoredDuringExecution?: pulumi.Input<pulumi.Input<inputs.core.v1.PodAffinityTermPatch>[]>;
        }
        /**
         * PodCondition contains details for the current condition of this pod.
         */
        interface PodCondition {
            /**
             * Last time we probed the condition.
             */
            lastProbeTime?: pulumi.Input<string>;
            /**
             * Last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * Human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * If set, this represents the .metadata.generation that the pod condition was set based upon. This is an alpha field. Enable PodObservedGenerationTracking to be able to use this field.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * Unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status is the status of the condition. Can be True, False, Unknown. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-conditions
             */
            status: pulumi.Input<string>;
            /**
             * Type is the type of the condition. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-conditions
             */
            type: pulumi.Input<string>;
        }
        /**
         * PodDNSConfig defines the DNS parameters of a pod in addition to those generated from DNSPolicy.
         */
        interface PodDNSConfig {
            /**
             * A list of DNS name server IP addresses. This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed.
             */
            nameservers?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * A list of DNS resolver options. This will be merged with the base options generated from DNSPolicy. Duplicated entries will be removed. Resolution options given in Options will override those that appear in the base DNSPolicy.
             */
            options?: pulumi.Input<pulumi.Input<inputs.core.v1.PodDNSConfigOption>[]>;
            /**
             * A list of DNS search domains for host-name lookup. This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed.
             */
            searches?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * PodDNSConfigOption defines DNS resolver options of a pod.
         */
        interface PodDNSConfigOption {
            /**
             * Name is this DNS resolver option's name. Required.
             */
            name?: pulumi.Input<string>;
            /**
             * Value is this DNS resolver option's value.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * PodDNSConfigOption defines DNS resolver options of a pod.
         */
        interface PodDNSConfigOptionPatch {
            /**
             * Name is this DNS resolver option's name. Required.
             */
            name?: pulumi.Input<string>;
            /**
             * Value is this DNS resolver option's value.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * PodDNSConfig defines the DNS parameters of a pod in addition to those generated from DNSPolicy.
         */
        interface PodDNSConfigPatch {
            /**
             * A list of DNS name server IP addresses. This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed.
             */
            nameservers?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * A list of DNS resolver options. This will be merged with the base options generated from DNSPolicy. Duplicated entries will be removed. Resolution options given in Options will override those that appear in the base DNSPolicy.
             */
            options?: pulumi.Input<pulumi.Input<inputs.core.v1.PodDNSConfigOptionPatch>[]>;
            /**
             * A list of DNS search domains for host-name lookup. This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed.
             */
            searches?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * PodIP represents a single IP address allocated to the pod.
         */
        interface PodIP {
            /**
             * IP is the IP address assigned to the pod
             */
            ip: pulumi.Input<string>;
        }
        /**
         * PodOS defines the OS parameters of a pod.
         */
        interface PodOS {
            /**
             * Name is the name of the operating system. The currently supported values are linux and windows. Additional value may be defined in future and can be one of: https://github.com/opencontainers/runtime-spec/blob/master/config.md#platform-specific-configuration Clients should expect to handle additional values and treat unrecognized values in this field as os: null
             */
            name: pulumi.Input<string>;
        }
        /**
         * PodOS defines the OS parameters of a pod.
         */
        interface PodOSPatch {
            /**
             * Name is the name of the operating system. The currently supported values are linux and windows. Additional value may be defined in future and can be one of: https://github.com/opencontainers/runtime-spec/blob/master/config.md#platform-specific-configuration Clients should expect to handle additional values and treat unrecognized values in this field as os: null
             */
            name?: pulumi.Input<string>;
        }
        /**
         * PodReadinessGate contains the reference to a pod condition
         */
        interface PodReadinessGate {
            /**
             * ConditionType refers to a condition in the pod's condition list with matching type.
             */
            conditionType: pulumi.Input<string>;
        }
        /**
         * PodReadinessGate contains the reference to a pod condition
         */
        interface PodReadinessGatePatch {
            /**
             * ConditionType refers to a condition in the pod's condition list with matching type.
             */
            conditionType?: pulumi.Input<string>;
        }
        /**
         * PodResourceClaim references exactly one ResourceClaim, either directly or by naming a ResourceClaimTemplate which is then turned into a ResourceClaim for the pod.
         *
         * It adds a name to it that uniquely identifies the ResourceClaim inside the Pod. Containers that need access to the ResourceClaim reference it with this name.
         */
        interface PodResourceClaim {
            /**
             * Name uniquely identifies this resource claim inside the pod. This must be a DNS_LABEL.
             */
            name: pulumi.Input<string>;
            /**
             * ResourceClaimName is the name of a ResourceClaim object in the same namespace as this pod.
             *
             * Exactly one of ResourceClaimName and ResourceClaimTemplateName must be set.
             */
            resourceClaimName?: pulumi.Input<string>;
            /**
             * ResourceClaimTemplateName is the name of a ResourceClaimTemplate object in the same namespace as this pod.
             *
             * The template will be used to create a new ResourceClaim, which will be bound to this pod. When this pod is deleted, the ResourceClaim will also be deleted. The pod name and resource name, along with a generated component, will be used to form a unique name for the ResourceClaim, which will be recorded in pod.status.resourceClaimStatuses.
             *
             * This field is immutable and no changes will be made to the corresponding ResourceClaim by the control plane after creating the ResourceClaim.
             *
             * Exactly one of ResourceClaimName and ResourceClaimTemplateName must be set.
             */
            resourceClaimTemplateName?: pulumi.Input<string>;
            /**
             * Source describes where to find the ResourceClaim.
             */
            source?: pulumi.Input<inputs.core.v1.ClaimSource>;
        }
        /**
         * PodResourceClaim references exactly one ResourceClaim, either directly or by naming a ResourceClaimTemplate which is then turned into a ResourceClaim for the pod.
         *
         * It adds a name to it that uniquely identifies the ResourceClaim inside the Pod. Containers that need access to the ResourceClaim reference it with this name.
         */
        interface PodResourceClaimPatch {
            /**
             * Name uniquely identifies this resource claim inside the pod. This must be a DNS_LABEL.
             */
            name?: pulumi.Input<string>;
            /**
             * ResourceClaimName is the name of a ResourceClaim object in the same namespace as this pod.
             *
             * Exactly one of ResourceClaimName and ResourceClaimTemplateName must be set.
             */
            resourceClaimName?: pulumi.Input<string>;
            /**
             * ResourceClaimTemplateName is the name of a ResourceClaimTemplate object in the same namespace as this pod.
             *
             * The template will be used to create a new ResourceClaim, which will be bound to this pod. When this pod is deleted, the ResourceClaim will also be deleted. The pod name and resource name, along with a generated component, will be used to form a unique name for the ResourceClaim, which will be recorded in pod.status.resourceClaimStatuses.
             *
             * This field is immutable and no changes will be made to the corresponding ResourceClaim by the control plane after creating the ResourceClaim.
             *
             * Exactly one of ResourceClaimName and ResourceClaimTemplateName must be set.
             */
            resourceClaimTemplateName?: pulumi.Input<string>;
            /**
             * Source describes where to find the ResourceClaim.
             */
            source?: pulumi.Input<inputs.core.v1.ClaimSourcePatch>;
        }
        /**
         * PodResourceClaimStatus is stored in the PodStatus for each PodResourceClaim which references a ResourceClaimTemplate. It stores the generated name for the corresponding ResourceClaim.
         */
        interface PodResourceClaimStatus {
            /**
             * Name uniquely identifies this resource claim inside the pod. This must match the name of an entry in pod.spec.resourceClaims, which implies that the string must be a DNS_LABEL.
             */
            name: pulumi.Input<string>;
            /**
             * ResourceClaimName is the name of the ResourceClaim that was generated for the Pod in the namespace of the Pod. If this is unset, then generating a ResourceClaim was not necessary. The pod.spec.resourceClaims entry can be ignored in this case.
             */
            resourceClaimName?: pulumi.Input<string>;
        }
        /**
         * PodSchedulingGate is associated to a Pod to guard its scheduling.
         */
        interface PodSchedulingGate {
            /**
             * Name of the scheduling gate. Each scheduling gate must have a unique name field.
             */
            name: pulumi.Input<string>;
        }
        /**
         * PodSchedulingGate is associated to a Pod to guard its scheduling.
         */
        interface PodSchedulingGatePatch {
            /**
             * Name of the scheduling gate. Each scheduling gate must have a unique name field.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * PodSecurityContext holds pod-level security attributes and common container settings. Some fields are also present in container.securityContext.  Field values of container.securityContext take precedence over field values of PodSecurityContext.
         */
        interface PodSecurityContext {
            /**
             * appArmorProfile is the AppArmor options to use by the containers in this pod. Note that this field cannot be set when spec.os.name is windows.
             */
            appArmorProfile?: pulumi.Input<inputs.core.v1.AppArmorProfile>;
            /**
             * A special supplemental group that applies to all containers in a pod. Some volume types allow the Kubelet to change the ownership of that volume to be owned by the pod:
             *
             * 1. The owning GID will be the FSGroup 2. The setgid bit is set (new files created in the volume will be owned by FSGroup) 3. The permission bits are OR'd with rw-rw----
             *
             * If unset, the Kubelet will not modify the ownership and permissions of any volume. Note that this field cannot be set when spec.os.name is windows.
             */
            fsGroup?: pulumi.Input<number>;
            /**
             * fsGroupChangePolicy defines behavior of changing ownership and permission of the volume before being exposed inside Pod. This field will only apply to volume types which support fsGroup based ownership(and permissions). It will have no effect on ephemeral volume types such as: secret, configmaps and emptydir. Valid values are "OnRootMismatch" and "Always". If not specified, "Always" is used. Note that this field cannot be set when spec.os.name is windows.
             */
            fsGroupChangePolicy?: pulumi.Input<string>;
            /**
             * The GID to run the entrypoint of the container process. Uses runtime default if unset. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container. Note that this field cannot be set when spec.os.name is windows.
             */
            runAsGroup?: pulumi.Input<number>;
            /**
             * Indicates that the container must run as a non-root user. If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
             */
            runAsNonRoot?: pulumi.Input<boolean>;
            /**
             * The UID to run the entrypoint of the container process. Defaults to user specified in image metadata if unspecified. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container. Note that this field cannot be set when spec.os.name is windows.
             */
            runAsUser?: pulumi.Input<number>;
            /**
             * seLinuxChangePolicy defines how the container's SELinux label is applied to all volumes used by the Pod. It has no effect on nodes that do not support SELinux or to volumes does not support SELinux. Valid values are "MountOption" and "Recursive".
             *
             * "Recursive" means relabeling of all files on all Pod volumes by the container runtime. This may be slow for large volumes, but allows mixing privileged and unprivileged Pods sharing the same volume on the same node.
             *
             * "MountOption" mounts all eligible Pod volumes with `-o context` mount option. This requires all Pods that share the same volume to use the same SELinux label. It is not possible to share the same volume among privileged and unprivileged Pods. Eligible volumes are in-tree FibreChannel and iSCSI volumes, and all CSI volumes whose CSI driver announces SELinux support by setting spec.seLinuxMount: true in their CSIDriver instance. Other volumes are always re-labelled recursively. "MountOption" value is allowed only when SELinuxMount feature gate is enabled.
             *
             * If not specified and SELinuxMount feature gate is enabled, "MountOption" is used. If not specified and SELinuxMount feature gate is disabled, "MountOption" is used for ReadWriteOncePod volumes and "Recursive" for all other volumes.
             *
             * This field affects only Pods that have SELinux label set, either in PodSecurityContext or in SecurityContext of all containers.
             *
             * All Pods that use the same volume should use the same seLinuxChangePolicy, otherwise some pods can get stuck in ContainerCreating state. Note that this field cannot be set when spec.os.name is windows.
             */
            seLinuxChangePolicy?: pulumi.Input<string>;
            /**
             * The SELinux context to be applied to all containers. If unspecified, the container runtime will allocate a random SELinux context for each container.  May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container. Note that this field cannot be set when spec.os.name is windows.
             */
            seLinuxOptions?: pulumi.Input<inputs.core.v1.SELinuxOptions>;
            /**
             * The seccomp options to use by the containers in this pod. Note that this field cannot be set when spec.os.name is windows.
             */
            seccompProfile?: pulumi.Input<inputs.core.v1.SeccompProfile>;
            /**
             * A list of groups applied to the first process run in each container, in addition to the container's primary GID and fsGroup (if specified).  If the SupplementalGroupsPolicy feature is enabled, the supplementalGroupsPolicy field determines whether these are in addition to or instead of any group memberships defined in the container image. If unspecified, no additional groups are added, though group memberships defined in the container image may still be used, depending on the supplementalGroupsPolicy field. Note that this field cannot be set when spec.os.name is windows.
             */
            supplementalGroups?: pulumi.Input<pulumi.Input<number>[]>;
            /**
             * Defines how supplemental groups of the first container processes are calculated. Valid values are "Merge" and "Strict". If not specified, "Merge" is used. (Alpha) Using the field requires the SupplementalGroupsPolicy feature gate to be enabled and the container runtime must implement support for this feature. Note that this field cannot be set when spec.os.name is windows.
             */
            supplementalGroupsPolicy?: pulumi.Input<string>;
            /**
             * Sysctls hold a list of namespaced sysctls used for the pod. Pods with unsupported sysctls (by the container runtime) might fail to launch. Note that this field cannot be set when spec.os.name is windows.
             */
            sysctls?: pulumi.Input<pulumi.Input<inputs.core.v1.Sysctl>[]>;
            /**
             * The Windows specific settings applied to all containers. If unspecified, the options within a container's SecurityContext will be used. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is linux.
             */
            windowsOptions?: pulumi.Input<inputs.core.v1.WindowsSecurityContextOptions>;
        }
        /**
         * PodSecurityContext holds pod-level security attributes and common container settings. Some fields are also present in container.securityContext.  Field values of container.securityContext take precedence over field values of PodSecurityContext.
         */
        interface PodSecurityContextPatch {
            /**
             * appArmorProfile is the AppArmor options to use by the containers in this pod. Note that this field cannot be set when spec.os.name is windows.
             */
            appArmorProfile?: pulumi.Input<inputs.core.v1.AppArmorProfilePatch>;
            /**
             * A special supplemental group that applies to all containers in a pod. Some volume types allow the Kubelet to change the ownership of that volume to be owned by the pod:
             *
             * 1. The owning GID will be the FSGroup 2. The setgid bit is set (new files created in the volume will be owned by FSGroup) 3. The permission bits are OR'd with rw-rw----
             *
             * If unset, the Kubelet will not modify the ownership and permissions of any volume. Note that this field cannot be set when spec.os.name is windows.
             */
            fsGroup?: pulumi.Input<number>;
            /**
             * fsGroupChangePolicy defines behavior of changing ownership and permission of the volume before being exposed inside Pod. This field will only apply to volume types which support fsGroup based ownership(and permissions). It will have no effect on ephemeral volume types such as: secret, configmaps and emptydir. Valid values are "OnRootMismatch" and "Always". If not specified, "Always" is used. Note that this field cannot be set when spec.os.name is windows.
             */
            fsGroupChangePolicy?: pulumi.Input<string>;
            /**
             * The GID to run the entrypoint of the container process. Uses runtime default if unset. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container. Note that this field cannot be set when spec.os.name is windows.
             */
            runAsGroup?: pulumi.Input<number>;
            /**
             * Indicates that the container must run as a non-root user. If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
             */
            runAsNonRoot?: pulumi.Input<boolean>;
            /**
             * The UID to run the entrypoint of the container process. Defaults to user specified in image metadata if unspecified. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container. Note that this field cannot be set when spec.os.name is windows.
             */
            runAsUser?: pulumi.Input<number>;
            /**
             * seLinuxChangePolicy defines how the container's SELinux label is applied to all volumes used by the Pod. It has no effect on nodes that do not support SELinux or to volumes does not support SELinux. Valid values are "MountOption" and "Recursive".
             *
             * "Recursive" means relabeling of all files on all Pod volumes by the container runtime. This may be slow for large volumes, but allows mixing privileged and unprivileged Pods sharing the same volume on the same node.
             *
             * "MountOption" mounts all eligible Pod volumes with `-o context` mount option. This requires all Pods that share the same volume to use the same SELinux label. It is not possible to share the same volume among privileged and unprivileged Pods. Eligible volumes are in-tree FibreChannel and iSCSI volumes, and all CSI volumes whose CSI driver announces SELinux support by setting spec.seLinuxMount: true in their CSIDriver instance. Other volumes are always re-labelled recursively. "MountOption" value is allowed only when SELinuxMount feature gate is enabled.
             *
             * If not specified and SELinuxMount feature gate is enabled, "MountOption" is used. If not specified and SELinuxMount feature gate is disabled, "MountOption" is used for ReadWriteOncePod volumes and "Recursive" for all other volumes.
             *
             * This field affects only Pods that have SELinux label set, either in PodSecurityContext or in SecurityContext of all containers.
             *
             * All Pods that use the same volume should use the same seLinuxChangePolicy, otherwise some pods can get stuck in ContainerCreating state. Note that this field cannot be set when spec.os.name is windows.
             */
            seLinuxChangePolicy?: pulumi.Input<string>;
            /**
             * The SELinux context to be applied to all containers. If unspecified, the container runtime will allocate a random SELinux context for each container.  May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container. Note that this field cannot be set when spec.os.name is windows.
             */
            seLinuxOptions?: pulumi.Input<inputs.core.v1.SELinuxOptionsPatch>;
            /**
             * The seccomp options to use by the containers in this pod. Note that this field cannot be set when spec.os.name is windows.
             */
            seccompProfile?: pulumi.Input<inputs.core.v1.SeccompProfilePatch>;
            /**
             * A list of groups applied to the first process run in each container, in addition to the container's primary GID and fsGroup (if specified).  If the SupplementalGroupsPolicy feature is enabled, the supplementalGroupsPolicy field determines whether these are in addition to or instead of any group memberships defined in the container image. If unspecified, no additional groups are added, though group memberships defined in the container image may still be used, depending on the supplementalGroupsPolicy field. Note that this field cannot be set when spec.os.name is windows.
             */
            supplementalGroups?: pulumi.Input<pulumi.Input<number>[]>;
            /**
             * Defines how supplemental groups of the first container processes are calculated. Valid values are "Merge" and "Strict". If not specified, "Merge" is used. (Alpha) Using the field requires the SupplementalGroupsPolicy feature gate to be enabled and the container runtime must implement support for this feature. Note that this field cannot be set when spec.os.name is windows.
             */
            supplementalGroupsPolicy?: pulumi.Input<string>;
            /**
             * Sysctls hold a list of namespaced sysctls used for the pod. Pods with unsupported sysctls (by the container runtime) might fail to launch. Note that this field cannot be set when spec.os.name is windows.
             */
            sysctls?: pulumi.Input<pulumi.Input<inputs.core.v1.SysctlPatch>[]>;
            /**
             * The Windows specific settings applied to all containers. If unspecified, the options within a container's SecurityContext will be used. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is linux.
             */
            windowsOptions?: pulumi.Input<inputs.core.v1.WindowsSecurityContextOptionsPatch>;
        }
        /**
         * PodSpec is a description of a pod.
         */
        interface PodSpec {
            /**
             * Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers. Value must be a positive integer.
             */
            activeDeadlineSeconds?: pulumi.Input<number>;
            /**
             * If specified, the pod's scheduling constraints
             */
            affinity?: pulumi.Input<inputs.core.v1.Affinity>;
            /**
             * AutomountServiceAccountToken indicates whether a service account token should be automatically mounted.
             */
            automountServiceAccountToken?: pulumi.Input<boolean>;
            /**
             * List of containers belonging to the pod. Containers cannot currently be added or removed. There must be at least one container in a Pod. Cannot be updated.
             */
            containers: pulumi.Input<pulumi.Input<inputs.core.v1.Container>[]>;
            /**
             * Specifies the DNS parameters of a pod. Parameters specified here will be merged to the generated DNS configuration based on DNSPolicy.
             */
            dnsConfig?: pulumi.Input<inputs.core.v1.PodDNSConfig>;
            /**
             * Set DNS policy for the pod. Defaults to "ClusterFirst". Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'.
             */
            dnsPolicy?: pulumi.Input<string>;
            /**
             * EnableServiceLinks indicates whether information about services should be injected into pod's environment variables, matching the syntax of Docker links. Optional: Defaults to true.
             */
            enableServiceLinks?: pulumi.Input<boolean>;
            /**
             * List of ephemeral containers run in this pod. Ephemeral containers may be run in an existing pod to perform user-initiated actions such as debugging. This list cannot be specified when creating a pod, and it cannot be modified by updating the pod spec. In order to add an ephemeral container to an existing pod, use the pod's ephemeralcontainers subresource.
             */
            ephemeralContainers?: pulumi.Input<pulumi.Input<inputs.core.v1.EphemeralContainer>[]>;
            /**
             * HostAliases is an optional list of hosts and IPs that will be injected into the pod's hosts file if specified.
             */
            hostAliases?: pulumi.Input<pulumi.Input<inputs.core.v1.HostAlias>[]>;
            /**
             * Use the host's ipc namespace. Optional: Default to false.
             */
            hostIPC?: pulumi.Input<boolean>;
            /**
             * Host networking requested for this pod. Use the host's network namespace. If this option is set, the ports that will be used must be specified. Default to false.
             */
            hostNetwork?: pulumi.Input<boolean>;
            /**
             * Use the host's pid namespace. Optional: Default to false.
             */
            hostPID?: pulumi.Input<boolean>;
            /**
             * Use the host's user namespace. Optional: Default to true. If set to true or not present, the pod will be run in the host user namespace, useful for when the pod needs a feature only available to the host user namespace, such as loading a kernel module with CAP_SYS_MODULE. When set to false, a new userns is created for the pod. Setting false is useful for mitigating container breakout vulnerabilities even allowing users to run their containers as root without actually having root privileges on the host. This field is alpha-level and is only honored by servers that enable the UserNamespacesSupport feature.
             */
            hostUsers?: pulumi.Input<boolean>;
            /**
             * Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value.
             */
            hostname?: pulumi.Input<string>;
            /**
             * ImagePullSecrets is an optional list of references to secrets in the same namespace to use for pulling any of the images used by this PodSpec. If specified, these secrets will be passed to individual puller implementations for them to use. More info: https://kubernetes.io/docs/concepts/containers/images#specifying-imagepullsecrets-on-a-pod
             */
            imagePullSecrets?: pulumi.Input<pulumi.Input<inputs.core.v1.LocalObjectReference>[]>;
            /**
             * List of initialization containers belonging to the pod. Init containers are executed in order prior to containers being started. If any init container fails, the pod is considered to have failed and is handled according to its restartPolicy. The name for an init container or normal container must be unique among all containers. Init containers may not have Lifecycle actions, Readiness probes, Liveness probes, or Startup probes. The resourceRequirements of an init container are taken into account during scheduling by finding the highest request/limit for each resource type, and then using the max of that value or the sum of the normal containers. Limits are applied to init containers in a similar fashion. Init containers cannot currently be added or removed. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/init-containers/
             */
            initContainers?: pulumi.Input<pulumi.Input<inputs.core.v1.Container>[]>;
            /**
             * NodeName indicates in which node this pod is scheduled. If empty, this pod is a candidate for scheduling by the scheduler defined in schedulerName. Once this field is set, the kubelet for this node becomes responsible for the lifecycle of this pod. This field should not be used to express a desire for the pod to be scheduled on a specific node. https://kubernetes.io/docs/concepts/scheduling-eviction/assign-pod-node/#nodename
             */
            nodeName?: pulumi.Input<string>;
            /**
             * NodeSelector is a selector which must be true for the pod to fit on a node. Selector which must match a node's labels for the pod to be scheduled on that node. More info: https://kubernetes.io/docs/concepts/configuration/assign-pod-node/
             */
            nodeSelector?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Specifies the OS of the containers in the pod. Some pod and container fields are restricted if this is set.
             *
             * If the OS field is set to linux, the following fields must be unset: -securityContext.windowsOptions
             *
             * If the OS field is set to windows, following fields must be unset: - spec.hostPID - spec.hostIPC - spec.hostUsers - spec.securityContext.appArmorProfile - spec.securityContext.seLinuxOptions - spec.securityContext.seccompProfile - spec.securityContext.fsGroup - spec.securityContext.fsGroupChangePolicy - spec.securityContext.sysctls - spec.shareProcessNamespace - spec.securityContext.runAsUser - spec.securityContext.runAsGroup - spec.securityContext.supplementalGroups - spec.securityContext.supplementalGroupsPolicy - spec.containers[*].securityContext.appArmorProfile - spec.containers[*].securityContext.seLinuxOptions - spec.containers[*].securityContext.seccompProfile - spec.containers[*].securityContext.capabilities - spec.containers[*].securityContext.readOnlyRootFilesystem - spec.containers[*].securityContext.privileged - spec.containers[*].securityContext.allowPrivilegeEscalation - spec.containers[*].securityContext.procMount - spec.containers[*].securityContext.runAsUser - spec.containers[*].securityContext.runAsGroup
             */
            os?: pulumi.Input<inputs.core.v1.PodOS>;
            /**
             * Overhead represents the resource overhead associated with running a pod for a given RuntimeClass. This field will be autopopulated at admission time by the RuntimeClass admission controller. If the RuntimeClass admission controller is enabled, overhead must not be set in Pod create requests. The RuntimeClass admission controller will reject Pod create requests which have the overhead already set. If RuntimeClass is configured and selected in the PodSpec, Overhead will be set to the value defined in the corresponding RuntimeClass, otherwise it will remain unset and treated as zero. More info: https://git.k8s.io/enhancements/keps/sig-node/688-pod-overhead/README.md
             */
            overhead?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * PreemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset.
             */
            preemptionPolicy?: pulumi.Input<string>;
            /**
             * The priority value. Various system components use this field to find the priority of the pod. When Priority Admission Controller is enabled, it prevents users from setting this field. The admission controller populates this field from PriorityClassName. The higher the value, the higher the priority.
             */
            priority?: pulumi.Input<number>;
            /**
             * If specified, indicates the pod's priority. "system-node-critical" and "system-cluster-critical" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default.
             */
            priorityClassName?: pulumi.Input<string>;
            /**
             * If specified, all readiness gates will be evaluated for pod readiness. A pod is ready when all its containers are ready AND all conditions specified in the readiness gates have status equal to "True" More info: https://git.k8s.io/enhancements/keps/sig-network/580-pod-readiness-gates
             */
            readinessGates?: pulumi.Input<pulumi.Input<inputs.core.v1.PodReadinessGate>[]>;
            /**
             * ResourceClaims defines which ResourceClaims must be allocated and reserved before the Pod is allowed to start. The resources will be made available to those containers which consume them by name.
             *
             * This is an alpha field and requires enabling the DynamicResourceAllocation feature gate.
             *
             * This field is immutable.
             */
            resourceClaims?: pulumi.Input<pulumi.Input<inputs.core.v1.PodResourceClaim>[]>;
            /**
             * Resources is the total amount of CPU and Memory resources required by all containers in the pod. It supports specifying Requests and Limits for "cpu" and "memory" resource names only. ResourceClaims are not supported.
             *
             * This field enables fine-grained control over resource allocation for the entire pod, allowing resource sharing among containers in a pod.
             *
             * This is an alpha field and requires enabling the PodLevelResources feature gate.
             */
            resources?: pulumi.Input<inputs.core.v1.ResourceRequirements>;
            /**
             * Restart policy for all containers within the pod. One of Always, OnFailure, Never. In some contexts, only a subset of those values may be permitted. Default to Always. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#restart-policy
             */
            restartPolicy?: pulumi.Input<string>;
            /**
             * RuntimeClassName refers to a RuntimeClass object in the node.k8s.io group, which should be used to run this pod.  If no RuntimeClass resource matches the named class, the pod will not be run. If unset or empty, the "legacy" RuntimeClass will be used, which is an implicit class with an empty definition that uses the default runtime handler. More info: https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class
             */
            runtimeClassName?: pulumi.Input<string>;
            /**
             * If specified, the pod will be dispatched by specified scheduler. If not specified, the pod will be dispatched by default scheduler.
             */
            schedulerName?: pulumi.Input<string>;
            /**
             * SchedulingGates is an opaque list of values that if specified will block scheduling the pod. If schedulingGates is not empty, the pod will stay in the SchedulingGated state and the scheduler will not attempt to schedule the pod.
             *
             * SchedulingGates can only be set at pod creation time, and be removed only afterwards.
             */
            schedulingGates?: pulumi.Input<pulumi.Input<inputs.core.v1.PodSchedulingGate>[]>;
            /**
             * SecurityContext holds pod-level security attributes and common container settings. Optional: Defaults to empty.  See type description for default values of each field.
             */
            securityContext?: pulumi.Input<inputs.core.v1.PodSecurityContext>;
            /**
             * DeprecatedServiceAccount is a deprecated alias for ServiceAccountName. Deprecated: Use serviceAccountName instead.
             */
            serviceAccount?: pulumi.Input<string>;
            /**
             * ServiceAccountName is the name of the ServiceAccount to use to run this pod. More info: https://kubernetes.io/docs/tasks/configure-pod-container/configure-service-account/
             */
            serviceAccountName?: pulumi.Input<string>;
            /**
             * If true the pod's hostname will be configured as the pod's FQDN, rather than the leaf name (the default). In Linux containers, this means setting the FQDN in the hostname field of the kernel (the nodename field of struct utsname). In Windows containers, this means setting the registry value of hostname for the registry key HKEY_LOCAL_MACHINE\\SYSTEM\\CurrentControlSet\\Services\\Tcpip\\Parameters to FQDN. If a pod does not have FQDN, this has no effect. Default to false.
             */
            setHostnameAsFQDN?: pulumi.Input<boolean>;
            /**
             * Share a single process namespace between all of the containers in a pod. When this is set containers will be able to view and signal processes from other containers in the same pod, and the first process in each container will not be assigned PID 1. HostPID and ShareProcessNamespace cannot both be set. Optional: Default to false.
             */
            shareProcessNamespace?: pulumi.Input<boolean>;
            /**
             * If specified, the fully qualified Pod hostname will be "<hostname>.<subdomain>.<pod namespace>.svc.<cluster domain>". If not specified, the pod will not have a domainname at all.
             */
            subdomain?: pulumi.Input<string>;
            /**
             * Optional duration in seconds the pod needs to terminate gracefully. May be decreased in delete request. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). If this value is nil, the default grace period will be used instead. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. Defaults to 30 seconds.
             */
            terminationGracePeriodSeconds?: pulumi.Input<number>;
            /**
             * If specified, the pod's tolerations.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.core.v1.Toleration>[]>;
            /**
             * TopologySpreadConstraints describes how a group of pods ought to spread across topology domains. Scheduler will schedule pods in a way which abides by the constraints. All topologySpreadConstraints are ANDed.
             */
            topologySpreadConstraints?: pulumi.Input<pulumi.Input<inputs.core.v1.TopologySpreadConstraint>[]>;
            /**
             * List of volumes that can be mounted by containers belonging to the pod. More info: https://kubernetes.io/docs/concepts/storage/volumes
             */
            volumes?: pulumi.Input<pulumi.Input<inputs.core.v1.Volume>[]>;
        }
        /**
         * PodSpec is a description of a pod.
         */
        interface PodSpecPatch {
            /**
             * Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers. Value must be a positive integer.
             */
            activeDeadlineSeconds?: pulumi.Input<number>;
            /**
             * If specified, the pod's scheduling constraints
             */
            affinity?: pulumi.Input<inputs.core.v1.AffinityPatch>;
            /**
             * AutomountServiceAccountToken indicates whether a service account token should be automatically mounted.
             */
            automountServiceAccountToken?: pulumi.Input<boolean>;
            /**
             * List of containers belonging to the pod. Containers cannot currently be added or removed. There must be at least one container in a Pod. Cannot be updated.
             */
            containers?: pulumi.Input<pulumi.Input<inputs.core.v1.ContainerPatch>[]>;
            /**
             * Specifies the DNS parameters of a pod. Parameters specified here will be merged to the generated DNS configuration based on DNSPolicy.
             */
            dnsConfig?: pulumi.Input<inputs.core.v1.PodDNSConfigPatch>;
            /**
             * Set DNS policy for the pod. Defaults to "ClusterFirst". Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'.
             */
            dnsPolicy?: pulumi.Input<string>;
            /**
             * EnableServiceLinks indicates whether information about services should be injected into pod's environment variables, matching the syntax of Docker links. Optional: Defaults to true.
             */
            enableServiceLinks?: pulumi.Input<boolean>;
            /**
             * List of ephemeral containers run in this pod. Ephemeral containers may be run in an existing pod to perform user-initiated actions such as debugging. This list cannot be specified when creating a pod, and it cannot be modified by updating the pod spec. In order to add an ephemeral container to an existing pod, use the pod's ephemeralcontainers subresource.
             */
            ephemeralContainers?: pulumi.Input<pulumi.Input<inputs.core.v1.EphemeralContainerPatch>[]>;
            /**
             * HostAliases is an optional list of hosts and IPs that will be injected into the pod's hosts file if specified.
             */
            hostAliases?: pulumi.Input<pulumi.Input<inputs.core.v1.HostAliasPatch>[]>;
            /**
             * Use the host's ipc namespace. Optional: Default to false.
             */
            hostIPC?: pulumi.Input<boolean>;
            /**
             * Host networking requested for this pod. Use the host's network namespace. If this option is set, the ports that will be used must be specified. Default to false.
             */
            hostNetwork?: pulumi.Input<boolean>;
            /**
             * Use the host's pid namespace. Optional: Default to false.
             */
            hostPID?: pulumi.Input<boolean>;
            /**
             * Use the host's user namespace. Optional: Default to true. If set to true or not present, the pod will be run in the host user namespace, useful for when the pod needs a feature only available to the host user namespace, such as loading a kernel module with CAP_SYS_MODULE. When set to false, a new userns is created for the pod. Setting false is useful for mitigating container breakout vulnerabilities even allowing users to run their containers as root without actually having root privileges on the host. This field is alpha-level and is only honored by servers that enable the UserNamespacesSupport feature.
             */
            hostUsers?: pulumi.Input<boolean>;
            /**
             * Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value.
             */
            hostname?: pulumi.Input<string>;
            /**
             * ImagePullSecrets is an optional list of references to secrets in the same namespace to use for pulling any of the images used by this PodSpec. If specified, these secrets will be passed to individual puller implementations for them to use. More info: https://kubernetes.io/docs/concepts/containers/images#specifying-imagepullsecrets-on-a-pod
             */
            imagePullSecrets?: pulumi.Input<pulumi.Input<inputs.core.v1.LocalObjectReferencePatch>[]>;
            /**
             * List of initialization containers belonging to the pod. Init containers are executed in order prior to containers being started. If any init container fails, the pod is considered to have failed and is handled according to its restartPolicy. The name for an init container or normal container must be unique among all containers. Init containers may not have Lifecycle actions, Readiness probes, Liveness probes, or Startup probes. The resourceRequirements of an init container are taken into account during scheduling by finding the highest request/limit for each resource type, and then using the max of that value or the sum of the normal containers. Limits are applied to init containers in a similar fashion. Init containers cannot currently be added or removed. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/init-containers/
             */
            initContainers?: pulumi.Input<pulumi.Input<inputs.core.v1.ContainerPatch>[]>;
            /**
             * NodeName indicates in which node this pod is scheduled. If empty, this pod is a candidate for scheduling by the scheduler defined in schedulerName. Once this field is set, the kubelet for this node becomes responsible for the lifecycle of this pod. This field should not be used to express a desire for the pod to be scheduled on a specific node. https://kubernetes.io/docs/concepts/scheduling-eviction/assign-pod-node/#nodename
             */
            nodeName?: pulumi.Input<string>;
            /**
             * NodeSelector is a selector which must be true for the pod to fit on a node. Selector which must match a node's labels for the pod to be scheduled on that node. More info: https://kubernetes.io/docs/concepts/configuration/assign-pod-node/
             */
            nodeSelector?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Specifies the OS of the containers in the pod. Some pod and container fields are restricted if this is set.
             *
             * If the OS field is set to linux, the following fields must be unset: -securityContext.windowsOptions
             *
             * If the OS field is set to windows, following fields must be unset: - spec.hostPID - spec.hostIPC - spec.hostUsers - spec.securityContext.appArmorProfile - spec.securityContext.seLinuxOptions - spec.securityContext.seccompProfile - spec.securityContext.fsGroup - spec.securityContext.fsGroupChangePolicy - spec.securityContext.sysctls - spec.shareProcessNamespace - spec.securityContext.runAsUser - spec.securityContext.runAsGroup - spec.securityContext.supplementalGroups - spec.securityContext.supplementalGroupsPolicy - spec.containers[*].securityContext.appArmorProfile - spec.containers[*].securityContext.seLinuxOptions - spec.containers[*].securityContext.seccompProfile - spec.containers[*].securityContext.capabilities - spec.containers[*].securityContext.readOnlyRootFilesystem - spec.containers[*].securityContext.privileged - spec.containers[*].securityContext.allowPrivilegeEscalation - spec.containers[*].securityContext.procMount - spec.containers[*].securityContext.runAsUser - spec.containers[*].securityContext.runAsGroup
             */
            os?: pulumi.Input<inputs.core.v1.PodOSPatch>;
            /**
             * Overhead represents the resource overhead associated with running a pod for a given RuntimeClass. This field will be autopopulated at admission time by the RuntimeClass admission controller. If the RuntimeClass admission controller is enabled, overhead must not be set in Pod create requests. The RuntimeClass admission controller will reject Pod create requests which have the overhead already set. If RuntimeClass is configured and selected in the PodSpec, Overhead will be set to the value defined in the corresponding RuntimeClass, otherwise it will remain unset and treated as zero. More info: https://git.k8s.io/enhancements/keps/sig-node/688-pod-overhead/README.md
             */
            overhead?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * PreemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset.
             */
            preemptionPolicy?: pulumi.Input<string>;
            /**
             * The priority value. Various system components use this field to find the priority of the pod. When Priority Admission Controller is enabled, it prevents users from setting this field. The admission controller populates this field from PriorityClassName. The higher the value, the higher the priority.
             */
            priority?: pulumi.Input<number>;
            /**
             * If specified, indicates the pod's priority. "system-node-critical" and "system-cluster-critical" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default.
             */
            priorityClassName?: pulumi.Input<string>;
            /**
             * If specified, all readiness gates will be evaluated for pod readiness. A pod is ready when all its containers are ready AND all conditions specified in the readiness gates have status equal to "True" More info: https://git.k8s.io/enhancements/keps/sig-network/580-pod-readiness-gates
             */
            readinessGates?: pulumi.Input<pulumi.Input<inputs.core.v1.PodReadinessGatePatch>[]>;
            /**
             * ResourceClaims defines which ResourceClaims must be allocated and reserved before the Pod is allowed to start. The resources will be made available to those containers which consume them by name.
             *
             * This is an alpha field and requires enabling the DynamicResourceAllocation feature gate.
             *
             * This field is immutable.
             */
            resourceClaims?: pulumi.Input<pulumi.Input<inputs.core.v1.PodResourceClaimPatch>[]>;
            /**
             * Resources is the total amount of CPU and Memory resources required by all containers in the pod. It supports specifying Requests and Limits for "cpu" and "memory" resource names only. ResourceClaims are not supported.
             *
             * This field enables fine-grained control over resource allocation for the entire pod, allowing resource sharing among containers in a pod.
             *
             * This is an alpha field and requires enabling the PodLevelResources feature gate.
             */
            resources?: pulumi.Input<inputs.core.v1.ResourceRequirementsPatch>;
            /**
             * Restart policy for all containers within the pod. One of Always, OnFailure, Never. In some contexts, only a subset of those values may be permitted. Default to Always. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#restart-policy
             */
            restartPolicy?: pulumi.Input<string>;
            /**
             * RuntimeClassName refers to a RuntimeClass object in the node.k8s.io group, which should be used to run this pod.  If no RuntimeClass resource matches the named class, the pod will not be run. If unset or empty, the "legacy" RuntimeClass will be used, which is an implicit class with an empty definition that uses the default runtime handler. More info: https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class
             */
            runtimeClassName?: pulumi.Input<string>;
            /**
             * If specified, the pod will be dispatched by specified scheduler. If not specified, the pod will be dispatched by default scheduler.
             */
            schedulerName?: pulumi.Input<string>;
            /**
             * SchedulingGates is an opaque list of values that if specified will block scheduling the pod. If schedulingGates is not empty, the pod will stay in the SchedulingGated state and the scheduler will not attempt to schedule the pod.
             *
             * SchedulingGates can only be set at pod creation time, and be removed only afterwards.
             */
            schedulingGates?: pulumi.Input<pulumi.Input<inputs.core.v1.PodSchedulingGatePatch>[]>;
            /**
             * SecurityContext holds pod-level security attributes and common container settings. Optional: Defaults to empty.  See type description for default values of each field.
             */
            securityContext?: pulumi.Input<inputs.core.v1.PodSecurityContextPatch>;
            /**
             * DeprecatedServiceAccount is a deprecated alias for ServiceAccountName. Deprecated: Use serviceAccountName instead.
             */
            serviceAccount?: pulumi.Input<string>;
            /**
             * ServiceAccountName is the name of the ServiceAccount to use to run this pod. More info: https://kubernetes.io/docs/tasks/configure-pod-container/configure-service-account/
             */
            serviceAccountName?: pulumi.Input<string>;
            /**
             * If true the pod's hostname will be configured as the pod's FQDN, rather than the leaf name (the default). In Linux containers, this means setting the FQDN in the hostname field of the kernel (the nodename field of struct utsname). In Windows containers, this means setting the registry value of hostname for the registry key HKEY_LOCAL_MACHINE\\SYSTEM\\CurrentControlSet\\Services\\Tcpip\\Parameters to FQDN. If a pod does not have FQDN, this has no effect. Default to false.
             */
            setHostnameAsFQDN?: pulumi.Input<boolean>;
            /**
             * Share a single process namespace between all of the containers in a pod. When this is set containers will be able to view and signal processes from other containers in the same pod, and the first process in each container will not be assigned PID 1. HostPID and ShareProcessNamespace cannot both be set. Optional: Default to false.
             */
            shareProcessNamespace?: pulumi.Input<boolean>;
            /**
             * If specified, the fully qualified Pod hostname will be "<hostname>.<subdomain>.<pod namespace>.svc.<cluster domain>". If not specified, the pod will not have a domainname at all.
             */
            subdomain?: pulumi.Input<string>;
            /**
             * Optional duration in seconds the pod needs to terminate gracefully. May be decreased in delete request. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). If this value is nil, the default grace period will be used instead. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. Defaults to 30 seconds.
             */
            terminationGracePeriodSeconds?: pulumi.Input<number>;
            /**
             * If specified, the pod's tolerations.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.core.v1.TolerationPatch>[]>;
            /**
             * TopologySpreadConstraints describes how a group of pods ought to spread across topology domains. Scheduler will schedule pods in a way which abides by the constraints. All topologySpreadConstraints are ANDed.
             */
            topologySpreadConstraints?: pulumi.Input<pulumi.Input<inputs.core.v1.TopologySpreadConstraintPatch>[]>;
            /**
             * List of volumes that can be mounted by containers belonging to the pod. More info: https://kubernetes.io/docs/concepts/storage/volumes
             */
            volumes?: pulumi.Input<pulumi.Input<inputs.core.v1.VolumePatch>[]>;
        }
        /**
         * PodStatus represents information about the status of a pod. Status may trail the actual state of a system, especially if the node that hosts the pod cannot contact the control plane.
         */
        interface PodStatus {
            /**
             * Current service state of pod. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-conditions
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.core.v1.PodCondition>[]>;
            /**
             * Statuses of containers in this pod. Each container in the pod should have at most one status in this list, and all statuses should be for containers in the pod. However this is not enforced. If a status for a non-existent container is present in the list, or the list has duplicate names, the behavior of various Kubernetes components is not defined and those statuses might be ignored. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-and-container-status
             */
            containerStatuses?: pulumi.Input<pulumi.Input<inputs.core.v1.ContainerStatus>[]>;
            /**
             * Statuses for any ephemeral containers that have run in this pod. Each ephemeral container in the pod should have at most one status in this list, and all statuses should be for containers in the pod. However this is not enforced. If a status for a non-existent container is present in the list, or the list has duplicate names, the behavior of various Kubernetes components is not defined and those statuses might be ignored. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-and-container-status
             */
            ephemeralContainerStatuses?: pulumi.Input<pulumi.Input<inputs.core.v1.ContainerStatus>[]>;
            /**
             * hostIP holds the IP address of the host to which the pod is assigned. Empty if the pod has not started yet. A pod can be assigned to a node that has a problem in kubelet which in turns mean that HostIP will not be updated even if there is a node is assigned to pod
             */
            hostIP?: pulumi.Input<string>;
            /**
             * hostIPs holds the IP addresses allocated to the host. If this field is specified, the first entry must match the hostIP field. This list is empty if the pod has not started yet. A pod can be assigned to a node that has a problem in kubelet which in turns means that HostIPs will not be updated even if there is a node is assigned to this pod.
             */
            hostIPs?: pulumi.Input<pulumi.Input<inputs.core.v1.HostIP>[]>;
            /**
             * Statuses of init containers in this pod. The most recent successful non-restartable init container will have ready = true, the most recently started container will have startTime set. Each init container in the pod should have at most one status in this list, and all statuses should be for containers in the pod. However this is not enforced. If a status for a non-existent container is present in the list, or the list has duplicate names, the behavior of various Kubernetes components is not defined and those statuses might be ignored. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#pod-and-container-status
             */
            initContainerStatuses?: pulumi.Input<pulumi.Input<inputs.core.v1.ContainerStatus>[]>;
            /**
             * A human readable message indicating details about why the pod is in this condition.
             */
            message?: pulumi.Input<string>;
            /**
             * nominatedNodeName is set only when this pod preempts other pods on the node, but it cannot be scheduled right away as preemption victims receive their graceful termination periods. This field does not guarantee that the pod will be scheduled on this node. Scheduler may decide to place the pod elsewhere if other nodes become available sooner. Scheduler may also decide to give the resources on this node to a higher priority pod that is created after preemption. As a result, this field may be different than PodSpec.nodeName when the pod is scheduled.
             */
            nominatedNodeName?: pulumi.Input<string>;
            /**
             * If set, this represents the .metadata.generation that the pod status was set based upon. This is an alpha field. Enable PodObservedGenerationTracking to be able to use this field.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * The phase of a Pod is a simple, high-level summary of where the Pod is in its lifecycle. The conditions array, the reason and message fields, and the individual container status arrays contain more detail about the pod's status. There are five possible phase values:
             *
             * Pending: The pod has been accepted by the Kubernetes system, but one or more of the container images has not been created. This includes time before being scheduled as well as time spent downloading images over the network, which could take a while. Running: The pod has been bound to a node, and all of the containers have been created. At least one container is still running, or is in the process of starting or restarting. Succeeded: All containers in the pod have terminated in success, and will not be restarted. Failed: All containers in the pod have terminated, and at least one container has terminated in failure. The container either exited with non-zero status or was terminated by the system. Unknown: For some reason the state of the pod could not be obtained, typically due to an error in communicating with the host of the pod.
             *
             * More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-phase
             */
            phase?: pulumi.Input<string>;
            /**
             * podIP address allocated to the pod. Routable at least within the cluster. Empty if not yet allocated.
             */
            podIP?: pulumi.Input<string>;
            /**
             * podIPs holds the IP addresses allocated to the pod. If this field is specified, the 0th entry must match the podIP field. Pods may be allocated at most 1 value for each of IPv4 and IPv6. This list is empty if no IPs have been allocated yet.
             */
            podIPs?: pulumi.Input<pulumi.Input<inputs.core.v1.PodIP>[]>;
            /**
             * The Quality of Service (QOS) classification assigned to the pod based on resource requirements See PodQOSClass type for available QOS classes More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-qos/#quality-of-service-classes
             */
            qosClass?: pulumi.Input<string>;
            /**
             * A brief CamelCase message indicating details about why the pod is in this state. e.g. 'Evicted'
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of resources resize desired for pod's containers. It is empty if no resources resize is pending. Any changes to container resources will automatically set this to "Proposed" Deprecated: Resize status is moved to two pod conditions PodResizePending and PodResizeInProgress. PodResizePending will track states where the spec has been resized, but the Kubelet has not yet allocated the resources. PodResizeInProgress will track in-progress resizes, and should be present whenever allocated resources != acknowledged resources.
             */
            resize?: pulumi.Input<string>;
            /**
             * Status of resource claims.
             */
            resourceClaimStatuses?: pulumi.Input<pulumi.Input<inputs.core.v1.PodResourceClaimStatus>[]>;
            /**
             * RFC 3339 date and time at which the object was acknowledged by the Kubelet. This is before the Kubelet pulled the container image(s) for the pod.
             */
            startTime?: pulumi.Input<string>;
        }
        /**
         * PodTemplate describes a template for creating copies of a predefined pod.
         */
        interface PodTemplate {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PodTemplate">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Template defines the pods that will be created from this pod template. https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
        }
        /**
         * PodTemplateSpec describes the data a pod should have when created from a template
         */
        interface PodTemplateSpec {
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the pod. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.core.v1.PodSpec>;
        }
        /**
         * PodTemplateSpec describes the data a pod should have when created from a template
         */
        interface PodTemplateSpecPatch {
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMetaPatch>;
            /**
             * Specification of the desired behavior of the pod. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.core.v1.PodSpecPatch>;
        }
        /**
         * PortStatus represents the error condition of a service port
         */
        interface PortStatus {
            /**
             * Error is to record the problem with the service port The format of the error shall comply with the following rules: - built-in error values shall be specified in this file and those shall use
             *   CamelCase names
             * - cloud provider specific error values must have names that comply with the
             *   format foo.example.com/CamelCase.
             */
            error?: pulumi.Input<string>;
            /**
             * Port is the port number of the service port of which status is recorded here
             */
            port: pulumi.Input<number>;
            /**
             * Protocol is the protocol of the service port of which status is recorded here The supported values are: "TCP", "UDP", "SCTP"
             */
            protocol: pulumi.Input<string>;
        }
        /**
         * PortworxVolumeSource represents a Portworx volume resource.
         */
        interface PortworxVolumeSource {
            /**
             * fSType represents the filesystem type to mount Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs". Implicitly inferred to be "ext4" if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * volumeID uniquely identifies a Portworx volume
             */
            volumeID: pulumi.Input<string>;
        }
        /**
         * PortworxVolumeSource represents a Portworx volume resource.
         */
        interface PortworxVolumeSourcePatch {
            /**
             * fSType represents the filesystem type to mount Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs". Implicitly inferred to be "ext4" if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * volumeID uniquely identifies a Portworx volume
             */
            volumeID?: pulumi.Input<string>;
        }
        /**
         * An empty preferred scheduling term matches all objects with implicit weight 0 (i.e. it's a no-op). A null preferred scheduling term matches no objects (i.e. is also a no-op).
         */
        interface PreferredSchedulingTerm {
            /**
             * A node selector term, associated with the corresponding weight.
             */
            preference: pulumi.Input<inputs.core.v1.NodeSelectorTerm>;
            /**
             * Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.
             */
            weight: pulumi.Input<number>;
        }
        /**
         * An empty preferred scheduling term matches all objects with implicit weight 0 (i.e. it's a no-op). A null preferred scheduling term matches no objects (i.e. is also a no-op).
         */
        interface PreferredSchedulingTermPatch {
            /**
             * A node selector term, associated with the corresponding weight.
             */
            preference?: pulumi.Input<inputs.core.v1.NodeSelectorTermPatch>;
            /**
             * Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.
             */
            weight?: pulumi.Input<number>;
        }
        /**
         * Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.
         */
        interface Probe {
            /**
             * Exec specifies a command to execute in the container.
             */
            exec?: pulumi.Input<inputs.core.v1.ExecAction>;
            /**
             * Minimum consecutive failures for the probe to be considered failed after having succeeded. Defaults to 3. Minimum value is 1.
             */
            failureThreshold?: pulumi.Input<number>;
            /**
             * GRPC specifies a GRPC HealthCheckRequest.
             */
            grpc?: pulumi.Input<inputs.core.v1.GRPCAction>;
            /**
             * HTTPGet specifies an HTTP GET request to perform.
             */
            httpGet?: pulumi.Input<inputs.core.v1.HTTPGetAction>;
            /**
             * Number of seconds after the container has started before liveness probes are initiated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
             */
            initialDelaySeconds?: pulumi.Input<number>;
            /**
             * How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1.
             */
            periodSeconds?: pulumi.Input<number>;
            /**
             * Minimum consecutive successes for the probe to be considered successful after having failed. Defaults to 1. Must be 1 for liveness and startup. Minimum value is 1.
             */
            successThreshold?: pulumi.Input<number>;
            /**
             * TCPSocket specifies a connection to a TCP port.
             */
            tcpSocket?: pulumi.Input<inputs.core.v1.TCPSocketAction>;
            /**
             * Optional duration in seconds the pod needs to terminate gracefully upon probe failure. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. If this value is nil, the pod's terminationGracePeriodSeconds will be used. Otherwise, this value overrides the value provided by the pod spec. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). This is a beta field and requires enabling ProbeTerminationGracePeriod feature gate. Minimum value is 1. spec.terminationGracePeriodSeconds is used if unset.
             */
            terminationGracePeriodSeconds?: pulumi.Input<number>;
            /**
             * Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
             */
            timeoutSeconds?: pulumi.Input<number>;
        }
        /**
         * Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.
         */
        interface ProbePatch {
            /**
             * Exec specifies a command to execute in the container.
             */
            exec?: pulumi.Input<inputs.core.v1.ExecActionPatch>;
            /**
             * Minimum consecutive failures for the probe to be considered failed after having succeeded. Defaults to 3. Minimum value is 1.
             */
            failureThreshold?: pulumi.Input<number>;
            /**
             * GRPC specifies a GRPC HealthCheckRequest.
             */
            grpc?: pulumi.Input<inputs.core.v1.GRPCActionPatch>;
            /**
             * HTTPGet specifies an HTTP GET request to perform.
             */
            httpGet?: pulumi.Input<inputs.core.v1.HTTPGetActionPatch>;
            /**
             * Number of seconds after the container has started before liveness probes are initiated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
             */
            initialDelaySeconds?: pulumi.Input<number>;
            /**
             * How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1.
             */
            periodSeconds?: pulumi.Input<number>;
            /**
             * Minimum consecutive successes for the probe to be considered successful after having failed. Defaults to 1. Must be 1 for liveness and startup. Minimum value is 1.
             */
            successThreshold?: pulumi.Input<number>;
            /**
             * TCPSocket specifies a connection to a TCP port.
             */
            tcpSocket?: pulumi.Input<inputs.core.v1.TCPSocketActionPatch>;
            /**
             * Optional duration in seconds the pod needs to terminate gracefully upon probe failure. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. If this value is nil, the pod's terminationGracePeriodSeconds will be used. Otherwise, this value overrides the value provided by the pod spec. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). This is a beta field and requires enabling ProbeTerminationGracePeriod feature gate. Minimum value is 1. spec.terminationGracePeriodSeconds is used if unset.
             */
            terminationGracePeriodSeconds?: pulumi.Input<number>;
            /**
             * Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
             */
            timeoutSeconds?: pulumi.Input<number>;
        }
        /**
         * Represents a projected volume source
         */
        interface ProjectedVolumeSource {
            /**
             * defaultMode are the mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
             */
            defaultMode?: pulumi.Input<number>;
            /**
             * sources is the list of volume projections. Each entry in this list handles one source.
             */
            sources: pulumi.Input<pulumi.Input<inputs.core.v1.VolumeProjection>[]>;
        }
        /**
         * Represents a projected volume source
         */
        interface ProjectedVolumeSourcePatch {
            /**
             * defaultMode are the mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
             */
            defaultMode?: pulumi.Input<number>;
            /**
             * sources is the list of volume projections. Each entry in this list handles one source.
             */
            sources?: pulumi.Input<pulumi.Input<inputs.core.v1.VolumeProjectionPatch>[]>;
        }
        /**
         * Represents a Quobyte mount that lasts the lifetime of a pod. Quobyte volumes do not support ownership management or SELinux relabeling.
         */
        interface QuobyteVolumeSource {
            /**
             * group to map volume access to Default is no group
             */
            group?: pulumi.Input<string>;
            /**
             * readOnly here will force the Quobyte volume to be mounted with read-only permissions. Defaults to false.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes
             */
            registry: pulumi.Input<string>;
            /**
             * tenant owning the given Quobyte volume in the Backend Used with dynamically provisioned Quobyte volumes, value is set by the plugin
             */
            tenant?: pulumi.Input<string>;
            /**
             * user to map volume access to Defaults to serivceaccount user
             */
            user?: pulumi.Input<string>;
            /**
             * volume is a string that references an already created Quobyte volume by name.
             */
            volume: pulumi.Input<string>;
        }
        /**
         * Represents a Quobyte mount that lasts the lifetime of a pod. Quobyte volumes do not support ownership management or SELinux relabeling.
         */
        interface QuobyteVolumeSourcePatch {
            /**
             * group to map volume access to Default is no group
             */
            group?: pulumi.Input<string>;
            /**
             * readOnly here will force the Quobyte volume to be mounted with read-only permissions. Defaults to false.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes
             */
            registry?: pulumi.Input<string>;
            /**
             * tenant owning the given Quobyte volume in the Backend Used with dynamically provisioned Quobyte volumes, value is set by the plugin
             */
            tenant?: pulumi.Input<string>;
            /**
             * user to map volume access to Defaults to serivceaccount user
             */
            user?: pulumi.Input<string>;
            /**
             * volume is a string that references an already created Quobyte volume by name.
             */
            volume?: pulumi.Input<string>;
        }
        /**
         * Represents a Rados Block Device mount that lasts the lifetime of a pod. RBD volumes support ownership management and SELinux relabeling.
         */
        interface RBDPersistentVolumeSource {
            /**
             * fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#rbd
             */
            fsType?: pulumi.Input<string>;
            /**
             * image is the rados image name. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            image: pulumi.Input<string>;
            /**
             * keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            keyring?: pulumi.Input<string>;
            /**
             * monitors is a collection of Ceph monitors. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            monitors: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * pool is the rados pool name. Default is rbd. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            pool?: pulumi.Input<string>;
            /**
             * readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is name of the authentication secret for RBDUser. If provided overrides keyring. Default is nil. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            secretRef?: pulumi.Input<inputs.core.v1.SecretReference>;
            /**
             * user is the rados user name. Default is admin. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            user?: pulumi.Input<string>;
        }
        /**
         * Represents a Rados Block Device mount that lasts the lifetime of a pod. RBD volumes support ownership management and SELinux relabeling.
         */
        interface RBDPersistentVolumeSourcePatch {
            /**
             * fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#rbd
             */
            fsType?: pulumi.Input<string>;
            /**
             * image is the rados image name. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            image?: pulumi.Input<string>;
            /**
             * keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            keyring?: pulumi.Input<string>;
            /**
             * monitors is a collection of Ceph monitors. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            monitors?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * pool is the rados pool name. Default is rbd. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            pool?: pulumi.Input<string>;
            /**
             * readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is name of the authentication secret for RBDUser. If provided overrides keyring. Default is nil. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            secretRef?: pulumi.Input<inputs.core.v1.SecretReferencePatch>;
            /**
             * user is the rados user name. Default is admin. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            user?: pulumi.Input<string>;
        }
        /**
         * Represents a Rados Block Device mount that lasts the lifetime of a pod. RBD volumes support ownership management and SELinux relabeling.
         */
        interface RBDVolumeSource {
            /**
             * fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#rbd
             */
            fsType?: pulumi.Input<string>;
            /**
             * image is the rados image name. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            image: pulumi.Input<string>;
            /**
             * keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            keyring?: pulumi.Input<string>;
            /**
             * monitors is a collection of Ceph monitors. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            monitors: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * pool is the rados pool name. Default is rbd. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            pool?: pulumi.Input<string>;
            /**
             * readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is name of the authentication secret for RBDUser. If provided overrides keyring. Default is nil. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            secretRef?: pulumi.Input<inputs.core.v1.LocalObjectReference>;
            /**
             * user is the rados user name. Default is admin. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            user?: pulumi.Input<string>;
        }
        /**
         * Represents a Rados Block Device mount that lasts the lifetime of a pod. RBD volumes support ownership management and SELinux relabeling.
         */
        interface RBDVolumeSourcePatch {
            /**
             * fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#rbd
             */
            fsType?: pulumi.Input<string>;
            /**
             * image is the rados image name. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            image?: pulumi.Input<string>;
            /**
             * keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            keyring?: pulumi.Input<string>;
            /**
             * monitors is a collection of Ceph monitors. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            monitors?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * pool is the rados pool name. Default is rbd. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            pool?: pulumi.Input<string>;
            /**
             * readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef is name of the authentication secret for RBDUser. If provided overrides keyring. Default is nil. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            secretRef?: pulumi.Input<inputs.core.v1.LocalObjectReferencePatch>;
            /**
             * user is the rados user name. Default is admin. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it
             */
            user?: pulumi.Input<string>;
        }
        /**
         * ReplicationController represents the configuration of a replication controller.
         */
        interface ReplicationController {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ReplicationController">;
            /**
             * If the Labels of a ReplicationController are empty, they are defaulted to be the same as the Pod(s) that the replication controller manages. Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines the specification of the desired behavior of the replication controller. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.core.v1.ReplicationControllerSpec>;
            /**
             * Status is the most recently observed status of the replication controller. This data may be out of date by some window of time. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.core.v1.ReplicationControllerStatus>;
        }
        /**
         * ReplicationControllerCondition describes the state of a replication controller at a certain point.
         */
        interface ReplicationControllerCondition {
            /**
             * The last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of replication controller condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * ReplicationControllerSpec is the specification of a replication controller.
         */
        interface ReplicationControllerSpec {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Replicas is the number of desired replicas. This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#what-is-a-replicationcontroller
             */
            replicas?: pulumi.Input<number>;
            /**
             * Selector is a label query over pods that should match the Replicas count. If Selector is empty, it is defaulted to the labels present on the Pod template. Label keys and values that must match in order to be controlled by this replication controller, if empty defaulted to labels on Pod template. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Template is the object that describes the pod that will be created if insufficient replicas are detected. This takes precedence over a TemplateRef. The only allowed template.spec.restartPolicy value is "Always". More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
        }
        /**
         * ReplicationControllerSpec is the specification of a replication controller.
         */
        interface ReplicationControllerSpecPatch {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Replicas is the number of desired replicas. This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#what-is-a-replicationcontroller
             */
            replicas?: pulumi.Input<number>;
            /**
             * Selector is a label query over pods that should match the Replicas count. If Selector is empty, it is defaulted to the labels present on the Pod template. Label keys and values that must match in order to be controlled by this replication controller, if empty defaulted to labels on Pod template. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Template is the object that describes the pod that will be created if insufficient replicas are detected. This takes precedence over a TemplateRef. The only allowed template.spec.restartPolicy value is "Always". More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
        }
        /**
         * ReplicationControllerStatus represents the current status of a replication controller.
         */
        interface ReplicationControllerStatus {
            /**
             * The number of available replicas (ready for at least minReadySeconds) for this replication controller.
             */
            availableReplicas?: pulumi.Input<number>;
            /**
             * Represents the latest available observations of a replication controller's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.core.v1.ReplicationControllerCondition>[]>;
            /**
             * The number of pods that have labels matching the labels of the pod template of the replication controller.
             */
            fullyLabeledReplicas?: pulumi.Input<number>;
            /**
             * ObservedGeneration reflects the generation of the most recently observed replication controller.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * The number of ready replicas for this replication controller.
             */
            readyReplicas?: pulumi.Input<number>;
            /**
             * Replicas is the most recently observed number of replicas. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#what-is-a-replicationcontroller
             */
            replicas: pulumi.Input<number>;
        }
        /**
         * ResourceClaim references one entry in PodSpec.ResourceClaims.
         */
        interface ResourceClaim {
            /**
             * Name must match the name of one entry in pod.spec.resourceClaims of the Pod where this field is used. It makes that resource available inside a container.
             */
            name: pulumi.Input<string>;
            /**
             * Request is the name chosen for a request in the referenced claim. If empty, everything from the claim is made available, otherwise only the result of this request.
             */
            request?: pulumi.Input<string>;
        }
        /**
         * ResourceClaim references one entry in PodSpec.ResourceClaims.
         */
        interface ResourceClaimPatch {
            /**
             * Name must match the name of one entry in pod.spec.resourceClaims of the Pod where this field is used. It makes that resource available inside a container.
             */
            name?: pulumi.Input<string>;
            /**
             * Request is the name chosen for a request in the referenced claim. If empty, everything from the claim is made available, otherwise only the result of this request.
             */
            request?: pulumi.Input<string>;
        }
        /**
         * ResourceFieldSelector represents container resources (cpu, memory) and their output format
         */
        interface ResourceFieldSelector {
            /**
             * Container name: required for volumes, optional for env vars
             */
            containerName?: pulumi.Input<string>;
            /**
             * Specifies the output format of the exposed resources, defaults to "1"
             */
            divisor?: pulumi.Input<string>;
            /**
             * Required: resource to select
             */
            resource: pulumi.Input<string>;
        }
        /**
         * ResourceFieldSelector represents container resources (cpu, memory) and their output format
         */
        interface ResourceFieldSelectorPatch {
            /**
             * Container name: required for volumes, optional for env vars
             */
            containerName?: pulumi.Input<string>;
            /**
             * Specifies the output format of the exposed resources, defaults to "1"
             */
            divisor?: pulumi.Input<string>;
            /**
             * Required: resource to select
             */
            resource?: pulumi.Input<string>;
        }
        /**
         * ResourceHealth represents the health of a resource. It has the latest device health information. This is a part of KEP https://kep.k8s.io/4680.
         */
        interface ResourceHealth {
            /**
             * Health of the resource. can be one of:
             *  - Healthy: operates as normal
             *  - Unhealthy: reported unhealthy. We consider this a temporary health issue
             *               since we do not have a mechanism today to distinguish
             *               temporary and permanent issues.
             *  - Unknown: The status cannot be determined.
             *             For example, Device Plugin got unregistered and hasn't been re-registered since.
             *
             * In future we may want to introduce the PermanentlyUnhealthy Status.
             */
            health?: pulumi.Input<string>;
            /**
             * ResourceID is the unique identifier of the resource. See the ResourceID type for more information.
             */
            resourceID: pulumi.Input<string>;
        }
        /**
         * ResourceQuota sets aggregate quota restrictions enforced per namespace
         */
        interface ResourceQuota {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceQuota">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines the desired quota. https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.core.v1.ResourceQuotaSpec>;
            /**
             * Status defines the actual enforced quota and its current usage. https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.core.v1.ResourceQuotaStatus>;
        }
        /**
         * ResourceQuotaSpec defines the desired hard limits to enforce for Quota.
         */
        interface ResourceQuotaSpec {
            /**
             * hard is the set of desired hard limits for each named resource. More info: https://kubernetes.io/docs/concepts/policy/resource-quotas/
             */
            hard?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * scopeSelector is also a collection of filters like scopes that must match each object tracked by a quota but expressed using ScopeSelectorOperator in combination with possible values. For a resource to match, both scopes AND scopeSelector (if specified in spec), must be matched.
             */
            scopeSelector?: pulumi.Input<inputs.core.v1.ScopeSelector>;
            /**
             * A collection of filters that must match each object tracked by a quota. If not specified, the quota matches all objects.
             */
            scopes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ResourceQuotaSpec defines the desired hard limits to enforce for Quota.
         */
        interface ResourceQuotaSpecPatch {
            /**
             * hard is the set of desired hard limits for each named resource. More info: https://kubernetes.io/docs/concepts/policy/resource-quotas/
             */
            hard?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * scopeSelector is also a collection of filters like scopes that must match each object tracked by a quota but expressed using ScopeSelectorOperator in combination with possible values. For a resource to match, both scopes AND scopeSelector (if specified in spec), must be matched.
             */
            scopeSelector?: pulumi.Input<inputs.core.v1.ScopeSelectorPatch>;
            /**
             * A collection of filters that must match each object tracked by a quota. If not specified, the quota matches all objects.
             */
            scopes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ResourceQuotaStatus defines the enforced hard limits and observed use.
         */
        interface ResourceQuotaStatus {
            /**
             * Hard is the set of enforced hard limits for each named resource. More info: https://kubernetes.io/docs/concepts/policy/resource-quotas/
             */
            hard?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Used is the current observed total usage of the resource in the namespace.
             */
            used?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * ResourceRequirements describes the compute resource requirements.
         */
        interface ResourceRequirements {
            /**
             * Claims lists the names of resources, defined in spec.resourceClaims, that are used by this container.
             *
             * This is an alpha field and requires enabling the DynamicResourceAllocation feature gate.
             *
             * This field is immutable. It can only be set for containers.
             */
            claims?: pulumi.Input<pulumi.Input<inputs.core.v1.ResourceClaim>[]>;
            /**
             * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
             */
            limits?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. Requests cannot exceed Limits. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
             */
            requests?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * ResourceRequirements describes the compute resource requirements.
         */
        interface ResourceRequirementsPatch {
            /**
             * Claims lists the names of resources, defined in spec.resourceClaims, that are used by this container.
             *
             * This is an alpha field and requires enabling the DynamicResourceAllocation feature gate.
             *
             * This field is immutable. It can only be set for containers.
             */
            claims?: pulumi.Input<pulumi.Input<inputs.core.v1.ResourceClaimPatch>[]>;
            /**
             * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
             */
            limits?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. Requests cannot exceed Limits. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
             */
            requests?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * ResourceStatus represents the status of a single resource allocated to a Pod.
         */
        interface ResourceStatus {
            /**
             * Name of the resource. Must be unique within the pod and in case of non-DRA resource, match one of the resources from the pod spec. For DRA resources, the value must be "claim:<claim_name>/<request>". When this status is reported about a container, the "claim_name" and "request" must match one of the claims of this container.
             */
            name: pulumi.Input<string>;
            /**
             * List of unique resources health. Each element in the list contains an unique resource ID and its health. At a minimum, for the lifetime of a Pod, resource ID must uniquely identify the resource allocated to the Pod on the Node. If other Pod on the same Node reports the status with the same resource ID, it must be the same resource they share. See ResourceID type definition for a specific format it has in various use cases.
             */
            resources?: pulumi.Input<pulumi.Input<inputs.core.v1.ResourceHealth>[]>;
        }
        /**
         * SELinuxOptions are the labels to be applied to the container
         */
        interface SELinuxOptions {
            /**
             * Level is SELinux level label that applies to the container.
             */
            level?: pulumi.Input<string>;
            /**
             * Role is a SELinux role label that applies to the container.
             */
            role?: pulumi.Input<string>;
            /**
             * Type is a SELinux type label that applies to the container.
             */
            type?: pulumi.Input<string>;
            /**
             * User is a SELinux user label that applies to the container.
             */
            user?: pulumi.Input<string>;
        }
        /**
         * SELinuxOptions are the labels to be applied to the container
         */
        interface SELinuxOptionsPatch {
            /**
             * Level is SELinux level label that applies to the container.
             */
            level?: pulumi.Input<string>;
            /**
             * Role is a SELinux role label that applies to the container.
             */
            role?: pulumi.Input<string>;
            /**
             * Type is a SELinux type label that applies to the container.
             */
            type?: pulumi.Input<string>;
            /**
             * User is a SELinux user label that applies to the container.
             */
            user?: pulumi.Input<string>;
        }
        /**
         * ScaleIOPersistentVolumeSource represents a persistent ScaleIO volume
         */
        interface ScaleIOPersistentVolumeSource {
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Default is "xfs"
             */
            fsType?: pulumi.Input<string>;
            /**
             * gateway is the host address of the ScaleIO API Gateway.
             */
            gateway: pulumi.Input<string>;
            /**
             * protectionDomain is the name of the ScaleIO Protection Domain for the configured storage.
             */
            protectionDomain?: pulumi.Input<string>;
            /**
             * readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef references to the secret for ScaleIO user and other sensitive information. If this is not provided, Login operation will fail.
             */
            secretRef: pulumi.Input<inputs.core.v1.SecretReference>;
            /**
             * sslEnabled is the flag to enable/disable SSL communication with Gateway, default false
             */
            sslEnabled?: pulumi.Input<boolean>;
            /**
             * storageMode indicates whether the storage for a volume should be ThickProvisioned or ThinProvisioned. Default is ThinProvisioned.
             */
            storageMode?: pulumi.Input<string>;
            /**
             * storagePool is the ScaleIO Storage Pool associated with the protection domain.
             */
            storagePool?: pulumi.Input<string>;
            /**
             * system is the name of the storage system as configured in ScaleIO.
             */
            system: pulumi.Input<string>;
            /**
             * volumeName is the name of a volume already created in the ScaleIO system that is associated with this volume source.
             */
            volumeName?: pulumi.Input<string>;
        }
        /**
         * ScaleIOPersistentVolumeSource represents a persistent ScaleIO volume
         */
        interface ScaleIOPersistentVolumeSourcePatch {
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Default is "xfs"
             */
            fsType?: pulumi.Input<string>;
            /**
             * gateway is the host address of the ScaleIO API Gateway.
             */
            gateway?: pulumi.Input<string>;
            /**
             * protectionDomain is the name of the ScaleIO Protection Domain for the configured storage.
             */
            protectionDomain?: pulumi.Input<string>;
            /**
             * readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef references to the secret for ScaleIO user and other sensitive information. If this is not provided, Login operation will fail.
             */
            secretRef?: pulumi.Input<inputs.core.v1.SecretReferencePatch>;
            /**
             * sslEnabled is the flag to enable/disable SSL communication with Gateway, default false
             */
            sslEnabled?: pulumi.Input<boolean>;
            /**
             * storageMode indicates whether the storage for a volume should be ThickProvisioned or ThinProvisioned. Default is ThinProvisioned.
             */
            storageMode?: pulumi.Input<string>;
            /**
             * storagePool is the ScaleIO Storage Pool associated with the protection domain.
             */
            storagePool?: pulumi.Input<string>;
            /**
             * system is the name of the storage system as configured in ScaleIO.
             */
            system?: pulumi.Input<string>;
            /**
             * volumeName is the name of a volume already created in the ScaleIO system that is associated with this volume source.
             */
            volumeName?: pulumi.Input<string>;
        }
        /**
         * ScaleIOVolumeSource represents a persistent ScaleIO volume
         */
        interface ScaleIOVolumeSource {
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Default is "xfs".
             */
            fsType?: pulumi.Input<string>;
            /**
             * gateway is the host address of the ScaleIO API Gateway.
             */
            gateway: pulumi.Input<string>;
            /**
             * protectionDomain is the name of the ScaleIO Protection Domain for the configured storage.
             */
            protectionDomain?: pulumi.Input<string>;
            /**
             * readOnly Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef references to the secret for ScaleIO user and other sensitive information. If this is not provided, Login operation will fail.
             */
            secretRef: pulumi.Input<inputs.core.v1.LocalObjectReference>;
            /**
             * sslEnabled Flag enable/disable SSL communication with Gateway, default false
             */
            sslEnabled?: pulumi.Input<boolean>;
            /**
             * storageMode indicates whether the storage for a volume should be ThickProvisioned or ThinProvisioned. Default is ThinProvisioned.
             */
            storageMode?: pulumi.Input<string>;
            /**
             * storagePool is the ScaleIO Storage Pool associated with the protection domain.
             */
            storagePool?: pulumi.Input<string>;
            /**
             * system is the name of the storage system as configured in ScaleIO.
             */
            system: pulumi.Input<string>;
            /**
             * volumeName is the name of a volume already created in the ScaleIO system that is associated with this volume source.
             */
            volumeName?: pulumi.Input<string>;
        }
        /**
         * ScaleIOVolumeSource represents a persistent ScaleIO volume
         */
        interface ScaleIOVolumeSourcePatch {
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Default is "xfs".
             */
            fsType?: pulumi.Input<string>;
            /**
             * gateway is the host address of the ScaleIO API Gateway.
             */
            gateway?: pulumi.Input<string>;
            /**
             * protectionDomain is the name of the ScaleIO Protection Domain for the configured storage.
             */
            protectionDomain?: pulumi.Input<string>;
            /**
             * readOnly Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef references to the secret for ScaleIO user and other sensitive information. If this is not provided, Login operation will fail.
             */
            secretRef?: pulumi.Input<inputs.core.v1.LocalObjectReferencePatch>;
            /**
             * sslEnabled Flag enable/disable SSL communication with Gateway, default false
             */
            sslEnabled?: pulumi.Input<boolean>;
            /**
             * storageMode indicates whether the storage for a volume should be ThickProvisioned or ThinProvisioned. Default is ThinProvisioned.
             */
            storageMode?: pulumi.Input<string>;
            /**
             * storagePool is the ScaleIO Storage Pool associated with the protection domain.
             */
            storagePool?: pulumi.Input<string>;
            /**
             * system is the name of the storage system as configured in ScaleIO.
             */
            system?: pulumi.Input<string>;
            /**
             * volumeName is the name of a volume already created in the ScaleIO system that is associated with this volume source.
             */
            volumeName?: pulumi.Input<string>;
        }
        /**
         * A scope selector represents the AND of the selectors represented by the scoped-resource selector requirements.
         */
        interface ScopeSelector {
            /**
             * A list of scope selector requirements by scope of the resources.
             */
            matchExpressions?: pulumi.Input<pulumi.Input<inputs.core.v1.ScopedResourceSelectorRequirement>[]>;
        }
        /**
         * A scope selector represents the AND of the selectors represented by the scoped-resource selector requirements.
         */
        interface ScopeSelectorPatch {
            /**
             * A list of scope selector requirements by scope of the resources.
             */
            matchExpressions?: pulumi.Input<pulumi.Input<inputs.core.v1.ScopedResourceSelectorRequirementPatch>[]>;
        }
        /**
         * A scoped-resource selector requirement is a selector that contains values, a scope name, and an operator that relates the scope name and values.
         */
        interface ScopedResourceSelectorRequirement {
            /**
             * Represents a scope's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist.
             */
            operator: pulumi.Input<string>;
            /**
             * The name of the scope that the selector applies to.
             */
            scopeName: pulumi.Input<string>;
            /**
             * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
             */
            values?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * A scoped-resource selector requirement is a selector that contains values, a scope name, and an operator that relates the scope name and values.
         */
        interface ScopedResourceSelectorRequirementPatch {
            /**
             * Represents a scope's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist.
             */
            operator?: pulumi.Input<string>;
            /**
             * The name of the scope that the selector applies to.
             */
            scopeName?: pulumi.Input<string>;
            /**
             * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
             */
            values?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * SeccompProfile defines a pod/container's seccomp profile settings. Only one profile source may be set.
         */
        interface SeccompProfile {
            /**
             * localhostProfile indicates a profile defined in a file on the node should be used. The profile must be preconfigured on the node to work. Must be a descending path, relative to the kubelet's configured seccomp profile location. Must be set if type is "Localhost". Must NOT be set for any other type.
             */
            localhostProfile?: pulumi.Input<string>;
            /**
             * type indicates which kind of seccomp profile will be applied. Valid options are:
             *
             * Localhost - a profile defined in a file on the node should be used. RuntimeDefault - the container runtime default profile should be used. Unconfined - no profile should be applied.
             */
            type: pulumi.Input<string>;
        }
        /**
         * SeccompProfile defines a pod/container's seccomp profile settings. Only one profile source may be set.
         */
        interface SeccompProfilePatch {
            /**
             * localhostProfile indicates a profile defined in a file on the node should be used. The profile must be preconfigured on the node to work. Must be a descending path, relative to the kubelet's configured seccomp profile location. Must be set if type is "Localhost". Must NOT be set for any other type.
             */
            localhostProfile?: pulumi.Input<string>;
            /**
             * type indicates which kind of seccomp profile will be applied. Valid options are:
             *
             * Localhost - a profile defined in a file on the node should be used. RuntimeDefault - the container runtime default profile should be used. Unconfined - no profile should be applied.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * Secret holds secret data of a certain type. The total bytes of the values in the Data field must be less than MaxSecretSize bytes.
         *
         * Note: While Pulumi automatically encrypts the 'data' and 'stringData'
         * fields, this encryption only applies to Pulumi's context, including the state file,
         * the Service, the CLI, etc. Kubernetes does not encrypt Secret resources by default,
         * and the contents are visible to users with access to the Secret in Kubernetes using
         * tools like 'kubectl'.
         *
         * For more information on securing Kubernetes Secrets, see the following links:
         * https://kubernetes.io/docs/concepts/configuration/secret/#security-properties
         * https://kubernetes.io/docs/concepts/configuration/secret/#risks
         */
        interface Secret {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * Data contains the secret data. Each key must consist of alphanumeric characters, '-', '_' or '.'. The serialized form of the secret data is a base64 encoded string, representing the arbitrary (possibly non-string) data value here. Described in https://tools.ietf.org/html/rfc4648#section-4
             */
            data?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Immutable, if set to true, ensures that data stored in the Secret cannot be updated (only object metadata can be modified). If not set to true, the field can be modified at any time. Defaulted to nil.
             */
            immutable?: pulumi.Input<boolean>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Secret">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * stringData allows specifying non-binary secret data in string form. It is provided as a write-only input field for convenience. All keys and values are merged into the data field on write, overwriting any existing values. The stringData field is never output when reading from the API.
             */
            stringData?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Used to facilitate programmatic handling of secret data. More info: https://kubernetes.io/docs/concepts/configuration/secret/#secret-types
             */
            type?: pulumi.Input<string>;
        }
        /**
         * SecretEnvSource selects a Secret to populate the environment variables with.
         *
         * The contents of the target Secret's Data field will represent the key-value pairs as environment variables.
         */
        interface SecretEnvSource {
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * Specify whether the Secret must be defined
             */
            optional?: pulumi.Input<boolean>;
        }
        /**
         * SecretEnvSource selects a Secret to populate the environment variables with.
         *
         * The contents of the target Secret's Data field will represent the key-value pairs as environment variables.
         */
        interface SecretEnvSourcePatch {
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * Specify whether the Secret must be defined
             */
            optional?: pulumi.Input<boolean>;
        }
        /**
         * SecretKeySelector selects a key of a Secret.
         */
        interface SecretKeySelector {
            /**
             * The key of the secret to select from.  Must be a valid secret key.
             */
            key: pulumi.Input<string>;
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * Specify whether the Secret or its key must be defined
             */
            optional?: pulumi.Input<boolean>;
        }
        /**
         * SecretKeySelector selects a key of a Secret.
         */
        interface SecretKeySelectorPatch {
            /**
             * The key of the secret to select from.  Must be a valid secret key.
             */
            key?: pulumi.Input<string>;
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * Specify whether the Secret or its key must be defined
             */
            optional?: pulumi.Input<boolean>;
        }
        /**
         * Adapts a secret into a projected volume.
         *
         * The contents of the target Secret's Data field will be presented in a projected volume as files using the keys in the Data field as the file names. Note that this is identical to a secret volume source without the default mode.
         */
        interface SecretProjection {
            /**
             * items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
             */
            items?: pulumi.Input<pulumi.Input<inputs.core.v1.KeyToPath>[]>;
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * optional field specify whether the Secret or its key must be defined
             */
            optional?: pulumi.Input<boolean>;
        }
        /**
         * Adapts a secret into a projected volume.
         *
         * The contents of the target Secret's Data field will be presented in a projected volume as files using the keys in the Data field as the file names. Note that this is identical to a secret volume source without the default mode.
         */
        interface SecretProjectionPatch {
            /**
             * items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
             */
            items?: pulumi.Input<pulumi.Input<inputs.core.v1.KeyToPathPatch>[]>;
            /**
             * Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * optional field specify whether the Secret or its key must be defined
             */
            optional?: pulumi.Input<boolean>;
        }
        /**
         * SecretReference represents a Secret Reference. It has enough information to retrieve secret in any namespace
         */
        interface SecretReference {
            /**
             * name is unique within a namespace to reference a secret resource.
             */
            name?: pulumi.Input<string>;
            /**
             * namespace defines the space within which the secret name must be unique.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * SecretReference represents a Secret Reference. It has enough information to retrieve secret in any namespace
         */
        interface SecretReferencePatch {
            /**
             * name is unique within a namespace to reference a secret resource.
             */
            name?: pulumi.Input<string>;
            /**
             * namespace defines the space within which the secret name must be unique.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * Adapts a Secret into a volume.
         *
         * The contents of the target Secret's Data field will be presented in a volume as files using the keys in the Data field as the file names. Secret volumes support ownership management and SELinux relabeling.
         */
        interface SecretVolumeSource {
            /**
             * defaultMode is Optional: mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
             */
            defaultMode?: pulumi.Input<number>;
            /**
             * items If unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
             */
            items?: pulumi.Input<pulumi.Input<inputs.core.v1.KeyToPath>[]>;
            /**
             * optional field specify whether the Secret or its keys must be defined
             */
            optional?: pulumi.Input<boolean>;
            /**
             * secretName is the name of the secret in the pod's namespace to use. More info: https://kubernetes.io/docs/concepts/storage/volumes#secret
             */
            secretName?: pulumi.Input<string>;
        }
        /**
         * Adapts a Secret into a volume.
         *
         * The contents of the target Secret's Data field will be presented in a volume as files using the keys in the Data field as the file names. Secret volumes support ownership management and SELinux relabeling.
         */
        interface SecretVolumeSourcePatch {
            /**
             * defaultMode is Optional: mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
             */
            defaultMode?: pulumi.Input<number>;
            /**
             * items If unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
             */
            items?: pulumi.Input<pulumi.Input<inputs.core.v1.KeyToPathPatch>[]>;
            /**
             * optional field specify whether the Secret or its keys must be defined
             */
            optional?: pulumi.Input<boolean>;
            /**
             * secretName is the name of the secret in the pod's namespace to use. More info: https://kubernetes.io/docs/concepts/storage/volumes#secret
             */
            secretName?: pulumi.Input<string>;
        }
        /**
         * SecurityContext holds security configuration that will be applied to a container. Some fields are present in both SecurityContext and PodSecurityContext.  When both are set, the values in SecurityContext take precedence.
         */
        interface SecurityContext {
            /**
             * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process. This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN Note that this field cannot be set when spec.os.name is windows.
             */
            allowPrivilegeEscalation?: pulumi.Input<boolean>;
            /**
             * appArmorProfile is the AppArmor options to use by this container. If set, this profile overrides the pod's appArmorProfile. Note that this field cannot be set when spec.os.name is windows.
             */
            appArmorProfile?: pulumi.Input<inputs.core.v1.AppArmorProfile>;
            /**
             * The capabilities to add/drop when running containers. Defaults to the default set of capabilities granted by the container runtime. Note that this field cannot be set when spec.os.name is windows.
             */
            capabilities?: pulumi.Input<inputs.core.v1.Capabilities>;
            /**
             * Run container in privileged mode. Processes in privileged containers are essentially equivalent to root on the host. Defaults to false. Note that this field cannot be set when spec.os.name is windows.
             */
            privileged?: pulumi.Input<boolean>;
            /**
             * procMount denotes the type of proc mount to use for the containers. The default value is Default which uses the container runtime defaults for readonly paths and masked paths. This requires the ProcMountType feature flag to be enabled. Note that this field cannot be set when spec.os.name is windows.
             */
            procMount?: pulumi.Input<string>;
            /**
             * Whether this container has a read-only root filesystem. Default is false. Note that this field cannot be set when spec.os.name is windows.
             */
            readOnlyRootFilesystem?: pulumi.Input<boolean>;
            /**
             * The GID to run the entrypoint of the container process. Uses runtime default if unset. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
             */
            runAsGroup?: pulumi.Input<number>;
            /**
             * Indicates that the container must run as a non-root user. If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
             */
            runAsNonRoot?: pulumi.Input<boolean>;
            /**
             * The UID to run the entrypoint of the container process. Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
             */
            runAsUser?: pulumi.Input<number>;
            /**
             * The SELinux context to be applied to the container. If unspecified, the container runtime will allocate a random SELinux context for each container.  May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
             */
            seLinuxOptions?: pulumi.Input<inputs.core.v1.SELinuxOptions>;
            /**
             * The seccomp options to use by this container. If seccomp options are provided at both the pod & container level, the container options override the pod options. Note that this field cannot be set when spec.os.name is windows.
             */
            seccompProfile?: pulumi.Input<inputs.core.v1.SeccompProfile>;
            /**
             * The Windows specific settings applied to all containers. If unspecified, the options from the PodSecurityContext will be used. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is linux.
             */
            windowsOptions?: pulumi.Input<inputs.core.v1.WindowsSecurityContextOptions>;
        }
        /**
         * SecurityContext holds security configuration that will be applied to a container. Some fields are present in both SecurityContext and PodSecurityContext.  When both are set, the values in SecurityContext take precedence.
         */
        interface SecurityContextPatch {
            /**
             * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process. This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN Note that this field cannot be set when spec.os.name is windows.
             */
            allowPrivilegeEscalation?: pulumi.Input<boolean>;
            /**
             * appArmorProfile is the AppArmor options to use by this container. If set, this profile overrides the pod's appArmorProfile. Note that this field cannot be set when spec.os.name is windows.
             */
            appArmorProfile?: pulumi.Input<inputs.core.v1.AppArmorProfilePatch>;
            /**
             * The capabilities to add/drop when running containers. Defaults to the default set of capabilities granted by the container runtime. Note that this field cannot be set when spec.os.name is windows.
             */
            capabilities?: pulumi.Input<inputs.core.v1.CapabilitiesPatch>;
            /**
             * Run container in privileged mode. Processes in privileged containers are essentially equivalent to root on the host. Defaults to false. Note that this field cannot be set when spec.os.name is windows.
             */
            privileged?: pulumi.Input<boolean>;
            /**
             * procMount denotes the type of proc mount to use for the containers. The default value is Default which uses the container runtime defaults for readonly paths and masked paths. This requires the ProcMountType feature flag to be enabled. Note that this field cannot be set when spec.os.name is windows.
             */
            procMount?: pulumi.Input<string>;
            /**
             * Whether this container has a read-only root filesystem. Default is false. Note that this field cannot be set when spec.os.name is windows.
             */
            readOnlyRootFilesystem?: pulumi.Input<boolean>;
            /**
             * The GID to run the entrypoint of the container process. Uses runtime default if unset. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
             */
            runAsGroup?: pulumi.Input<number>;
            /**
             * Indicates that the container must run as a non-root user. If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
             */
            runAsNonRoot?: pulumi.Input<boolean>;
            /**
             * The UID to run the entrypoint of the container process. Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
             */
            runAsUser?: pulumi.Input<number>;
            /**
             * The SELinux context to be applied to the container. If unspecified, the container runtime will allocate a random SELinux context for each container.  May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
             */
            seLinuxOptions?: pulumi.Input<inputs.core.v1.SELinuxOptionsPatch>;
            /**
             * The seccomp options to use by this container. If seccomp options are provided at both the pod & container level, the container options override the pod options. Note that this field cannot be set when spec.os.name is windows.
             */
            seccompProfile?: pulumi.Input<inputs.core.v1.SeccompProfilePatch>;
            /**
             * The Windows specific settings applied to all containers. If unspecified, the options from the PodSecurityContext will be used. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is linux.
             */
            windowsOptions?: pulumi.Input<inputs.core.v1.WindowsSecurityContextOptionsPatch>;
        }
        /**
         * Service is a named abstraction of software service (for example, mysql) consisting of local port (for example 3306) that the proxy listens on, and the selector that determines which pods will answer requests sent through the proxy.
         *
         * This resource waits until its status is ready before registering success
         * for create/update, and populating output properties from the current state of the resource.
         * The following conditions are used to determine whether the resource creation has
         * succeeded or failed:
         *
         * 1. Service object exists.
         * 2. Related Endpoint objects are created. Each time we get an update, wait 10 seconds
         *    for any stragglers.
         * 3. There are no "not ready" endpoints -- unless the Service is an "empty
         *    headless" Service [1], a Service with '.spec.type: ExternalName', or a Service
         *    without a selector.
         * 4. External IP address is allocated (if Service has '.spec.type: LoadBalancer').
         *
         * If the Service has not reached a Ready state after 10 minutes, it will
         * time out and mark the resource update as Failed. You can override the default timeout value
         * by setting the 'customTimeouts' option on the resource.
         */
        interface Service {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Service">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines the behavior of a service. https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.core.v1.ServiceSpec>;
            /**
             * Most recently observed status of the service. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.core.v1.ServiceStatus>;
        }
        /**
         * ServiceAccount binds together: * a name, understood by users, and perhaps by peripheral systems, for an identity * a principal that can be authenticated and authorized * a set of secrets
         */
        interface ServiceAccount {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"v1">;
            /**
             * AutomountServiceAccountToken indicates whether pods running as this service account should have an API token automatically mounted. Can be overridden at the pod level.
             */
            automountServiceAccountToken?: pulumi.Input<boolean>;
            /**
             * ImagePullSecrets is a list of references to secrets in the same namespace to use for pulling any images in pods that reference this ServiceAccount. ImagePullSecrets are distinct from Secrets because Secrets can be mounted in the pod, but ImagePullSecrets are only accessed by the kubelet. More info: https://kubernetes.io/docs/concepts/containers/images/#specifying-imagepullsecrets-on-a-pod
             */
            imagePullSecrets?: pulumi.Input<pulumi.Input<inputs.core.v1.LocalObjectReference>[]>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ServiceAccount">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Secrets is a list of the secrets in the same namespace that pods running using this ServiceAccount are allowed to use. Pods are only limited to this list if this service account has a "kubernetes.io/enforce-mountable-secrets" annotation set to "true". The "kubernetes.io/enforce-mountable-secrets" annotation is deprecated since v1.32. Prefer separate namespaces to isolate access to mounted secrets. This field should not be used to find auto-generated service account token secrets for use outside of pods. Instead, tokens can be requested directly using the TokenRequest API, or service account token secrets can be manually created. More info: https://kubernetes.io/docs/concepts/configuration/secret
             */
            secrets?: pulumi.Input<pulumi.Input<inputs.core.v1.ObjectReference>[]>;
        }
        /**
         * ServiceAccountTokenProjection represents a projected service account token volume. This projection can be used to insert a service account token into the pods runtime filesystem for use against APIs (Kubernetes API Server or otherwise).
         */
        interface ServiceAccountTokenProjection {
            /**
             * audience is the intended audience of the token. A recipient of a token must identify itself with an identifier specified in the audience of the token, and otherwise should reject the token. The audience defaults to the identifier of the apiserver.
             */
            audience?: pulumi.Input<string>;
            /**
             * expirationSeconds is the requested duration of validity of the service account token. As the token approaches expiration, the kubelet volume plugin will proactively rotate the service account token. The kubelet will start trying to rotate the token if the token is older than 80 percent of its time to live or if the token is older than 24 hours.Defaults to 1 hour and must be at least 10 minutes.
             */
            expirationSeconds?: pulumi.Input<number>;
            /**
             * path is the path relative to the mount point of the file to project the token into.
             */
            path: pulumi.Input<string>;
        }
        /**
         * ServiceAccountTokenProjection represents a projected service account token volume. This projection can be used to insert a service account token into the pods runtime filesystem for use against APIs (Kubernetes API Server or otherwise).
         */
        interface ServiceAccountTokenProjectionPatch {
            /**
             * audience is the intended audience of the token. A recipient of a token must identify itself with an identifier specified in the audience of the token, and otherwise should reject the token. The audience defaults to the identifier of the apiserver.
             */
            audience?: pulumi.Input<string>;
            /**
             * expirationSeconds is the requested duration of validity of the service account token. As the token approaches expiration, the kubelet volume plugin will proactively rotate the service account token. The kubelet will start trying to rotate the token if the token is older than 80 percent of its time to live or if the token is older than 24 hours.Defaults to 1 hour and must be at least 10 minutes.
             */
            expirationSeconds?: pulumi.Input<number>;
            /**
             * path is the path relative to the mount point of the file to project the token into.
             */
            path?: pulumi.Input<string>;
        }
        /**
         * ServicePort contains information on service's port.
         */
        interface ServicePort {
            /**
             * The application protocol for this port. This is used as a hint for implementations to offer richer behavior for protocols that they understand. This field follows standard Kubernetes label syntax. Valid values are either:
             *
             * * Un-prefixed protocol names - reserved for IANA standard service names (as per RFC-6335 and https://www.iana.org/assignments/service-names).
             *
             * * Kubernetes-defined prefixed names:
             *   * 'kubernetes.io/h2c' - HTTP/2 prior knowledge over cleartext as described in https://www.rfc-editor.org/rfc/rfc9113.html#name-starting-http-2-with-prior-
             *   * 'kubernetes.io/ws'  - WebSocket over cleartext as described in https://www.rfc-editor.org/rfc/rfc6455
             *   * 'kubernetes.io/wss' - WebSocket over TLS as described in https://www.rfc-editor.org/rfc/rfc6455
             *
             * * Other protocols should use implementation-defined prefixed names such as mycompany.com/my-custom-protocol.
             */
            appProtocol?: pulumi.Input<string>;
            /**
             * The name of this port within the service. This must be a DNS_LABEL. All ports within a ServiceSpec must have unique names. When considering the endpoints for a Service, this must match the 'name' field in the EndpointPort. Optional if only one ServicePort is defined on this service.
             */
            name?: pulumi.Input<string>;
            /**
             * The port on each node on which this service is exposed when type is NodePort or LoadBalancer.  Usually assigned by the system. If a value is specified, in-range, and not in use it will be used, otherwise the operation will fail.  If not specified, a port will be allocated if this Service requires one.  If this field is specified when creating a Service which does not need it, creation will fail. This field will be wiped when updating a Service to no longer need it (e.g. changing type from NodePort to ClusterIP). More info: https://kubernetes.io/docs/concepts/services-networking/service/#type-nodeport
             */
            nodePort?: pulumi.Input<number>;
            /**
             * The port that will be exposed by this service.
             */
            port: pulumi.Input<number>;
            /**
             * The IP protocol for this port. Supports "TCP", "UDP", and "SCTP". Default is TCP.
             */
            protocol?: pulumi.Input<string>;
            /**
             * Number or name of the port to access on the pods targeted by the service. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME. If this is a string, it will be looked up as a named port in the target Pod's container ports. If this is not specified, the value of the 'port' field is used (an identity map). This field is ignored for services with clusterIP=None, and should be omitted or set equal to the 'port' field. More info: https://kubernetes.io/docs/concepts/services-networking/service/#defining-a-service
             */
            targetPort?: pulumi.Input<number | string>;
        }
        /**
         * ServicePort contains information on service's port.
         */
        interface ServicePortPatch {
            /**
             * The application protocol for this port. This is used as a hint for implementations to offer richer behavior for protocols that they understand. This field follows standard Kubernetes label syntax. Valid values are either:
             *
             * * Un-prefixed protocol names - reserved for IANA standard service names (as per RFC-6335 and https://www.iana.org/assignments/service-names).
             *
             * * Kubernetes-defined prefixed names:
             *   * 'kubernetes.io/h2c' - HTTP/2 prior knowledge over cleartext as described in https://www.rfc-editor.org/rfc/rfc9113.html#name-starting-http-2-with-prior-
             *   * 'kubernetes.io/ws'  - WebSocket over cleartext as described in https://www.rfc-editor.org/rfc/rfc6455
             *   * 'kubernetes.io/wss' - WebSocket over TLS as described in https://www.rfc-editor.org/rfc/rfc6455
             *
             * * Other protocols should use implementation-defined prefixed names such as mycompany.com/my-custom-protocol.
             */
            appProtocol?: pulumi.Input<string>;
            /**
             * The name of this port within the service. This must be a DNS_LABEL. All ports within a ServiceSpec must have unique names. When considering the endpoints for a Service, this must match the 'name' field in the EndpointPort. Optional if only one ServicePort is defined on this service.
             */
            name?: pulumi.Input<string>;
            /**
             * The port on each node on which this service is exposed when type is NodePort or LoadBalancer.  Usually assigned by the system. If a value is specified, in-range, and not in use it will be used, otherwise the operation will fail.  If not specified, a port will be allocated if this Service requires one.  If this field is specified when creating a Service which does not need it, creation will fail. This field will be wiped when updating a Service to no longer need it (e.g. changing type from NodePort to ClusterIP). More info: https://kubernetes.io/docs/concepts/services-networking/service/#type-nodeport
             */
            nodePort?: pulumi.Input<number>;
            /**
             * The port that will be exposed by this service.
             */
            port?: pulumi.Input<number>;
            /**
             * The IP protocol for this port. Supports "TCP", "UDP", and "SCTP". Default is TCP.
             */
            protocol?: pulumi.Input<string>;
            /**
             * Number or name of the port to access on the pods targeted by the service. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME. If this is a string, it will be looked up as a named port in the target Pod's container ports. If this is not specified, the value of the 'port' field is used (an identity map). This field is ignored for services with clusterIP=None, and should be omitted or set equal to the 'port' field. More info: https://kubernetes.io/docs/concepts/services-networking/service/#defining-a-service
             */
            targetPort?: pulumi.Input<number | string>;
        }
        /**
         * ServiceSpec describes the attributes that a user creates on a service.
         */
        interface ServiceSpec {
            /**
             * allocateLoadBalancerNodePorts defines if NodePorts will be automatically allocated for services with type LoadBalancer.  Default is "true". It may be set to "false" if the cluster load-balancer does not rely on NodePorts.  If the caller requests specific NodePorts (by specifying a value), those requests will be respected, regardless of this field. This field may only be set for services with type LoadBalancer and will be cleared if the type is changed to any other type.
             */
            allocateLoadBalancerNodePorts?: pulumi.Input<boolean>;
            /**
             * clusterIP is the IP address of the service and is usually assigned randomly. If an address is specified manually, is in-range (as per system configuration), and is not in use, it will be allocated to the service; otherwise creation of the service will fail. This field may not be changed through updates unless the type field is also being changed to ExternalName (which requires this field to be blank) or the type field is being changed from ExternalName (in which case this field may optionally be specified, as describe above).  Valid values are "None", empty string (""), or a valid IP address. Setting this to "None" makes a "headless service" (no virtual IP), which is useful when direct endpoint connections are preferred and proxying is not required.  Only applies to types ClusterIP, NodePort, and LoadBalancer. If this field is specified when creating a Service of type ExternalName, creation will fail. This field will be wiped when updating a Service to type ExternalName. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
             */
            clusterIP?: pulumi.Input<string>;
            /**
             * ClusterIPs is a list of IP addresses assigned to this service, and are usually assigned randomly.  If an address is specified manually, is in-range (as per system configuration), and is not in use, it will be allocated to the service; otherwise creation of the service will fail. This field may not be changed through updates unless the type field is also being changed to ExternalName (which requires this field to be empty) or the type field is being changed from ExternalName (in which case this field may optionally be specified, as describe above).  Valid values are "None", empty string (""), or a valid IP address.  Setting this to "None" makes a "headless service" (no virtual IP), which is useful when direct endpoint connections are preferred and proxying is not required.  Only applies to types ClusterIP, NodePort, and LoadBalancer. If this field is specified when creating a Service of type ExternalName, creation will fail. This field will be wiped when updating a Service to type ExternalName.  If this field is not specified, it will be initialized from the clusterIP field.  If this field is specified, clients must ensure that clusterIPs[0] and clusterIP have the same value.
             *
             * This field may hold a maximum of two entries (dual-stack IPs, in either order). These IPs must correspond to the values of the ipFamilies field. Both clusterIPs and ipFamilies are governed by the ipFamilyPolicy field. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
             */
            clusterIPs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * externalIPs is a list of IP addresses for which nodes in the cluster will also accept traffic for this service.  These IPs are not managed by Kubernetes.  The user is responsible for ensuring that traffic arrives at a node with this IP.  A common example is external load-balancers that are not part of the Kubernetes system.
             */
            externalIPs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * externalName is the external reference that discovery mechanisms will return as an alias for this service (e.g. a DNS CNAME record). No proxying will be involved.  Must be a lowercase RFC-1123 hostname (https://tools.ietf.org/html/rfc1123) and requires `type` to be "ExternalName".
             */
            externalName?: pulumi.Input<string>;
            /**
             * externalTrafficPolicy describes how nodes distribute service traffic they receive on one of the Service's "externally-facing" addresses (NodePorts, ExternalIPs, and LoadBalancer IPs). If set to "Local", the proxy will configure the service in a way that assumes that external load balancers will take care of balancing the service traffic between nodes, and so each node will deliver traffic only to the node-local endpoints of the service, without masquerading the client source IP. (Traffic mistakenly sent to a node with no endpoints will be dropped.) The default value, "Cluster", uses the standard behavior of routing to all endpoints evenly (possibly modified by topology and other features). Note that traffic sent to an External IP or LoadBalancer IP from within the cluster will always get "Cluster" semantics, but clients sending to a NodePort from within the cluster may need to take traffic policy into account when picking a node.
             */
            externalTrafficPolicy?: pulumi.Input<string>;
            /**
             * healthCheckNodePort specifies the healthcheck nodePort for the service. This only applies when type is set to LoadBalancer and externalTrafficPolicy is set to Local. If a value is specified, is in-range, and is not in use, it will be used.  If not specified, a value will be automatically allocated.  External systems (e.g. load-balancers) can use this port to determine if a given node holds endpoints for this service or not.  If this field is specified when creating a Service which does not need it, creation will fail. This field will be wiped when updating a Service to no longer need it (e.g. changing type). This field cannot be updated once set.
             */
            healthCheckNodePort?: pulumi.Input<number>;
            /**
             * InternalTrafficPolicy describes how nodes distribute service traffic they receive on the ClusterIP. If set to "Local", the proxy will assume that pods only want to talk to endpoints of the service on the same node as the pod, dropping the traffic if there are no local endpoints. The default value, "Cluster", uses the standard behavior of routing to all endpoints evenly (possibly modified by topology and other features).
             */
            internalTrafficPolicy?: pulumi.Input<string>;
            /**
             * IPFamilies is a list of IP families (e.g. IPv4, IPv6) assigned to this service. This field is usually assigned automatically based on cluster configuration and the ipFamilyPolicy field. If this field is specified manually, the requested family is available in the cluster, and ipFamilyPolicy allows it, it will be used; otherwise creation of the service will fail. This field is conditionally mutable: it allows for adding or removing a secondary IP family, but it does not allow changing the primary IP family of the Service. Valid values are "IPv4" and "IPv6".  This field only applies to Services of types ClusterIP, NodePort, and LoadBalancer, and does apply to "headless" services. This field will be wiped when updating a Service to type ExternalName.
             *
             * This field may hold a maximum of two entries (dual-stack families, in either order).  These families must correspond to the values of the clusterIPs field, if specified. Both clusterIPs and ipFamilies are governed by the ipFamilyPolicy field.
             */
            ipFamilies?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ipFamily specifies whether this Service has a preference for a particular IP family (e.g. IPv4 vs. IPv6).  If a specific IP family is requested, the clusterIP field will be allocated from that family, if it is available in the cluster.  If no IP family is requested, the cluster's primary IP family will be used. Other IP fields (loadBalancerIP, loadBalancerSourceRanges, externalIPs) and controllers which allocate external load-balancers should use the same IP family.  Endpoints for this Service will be of this family.  This field is immutable after creation. Assigning a ServiceIPFamily not available in the cluster (e.g. IPv6 in IPv4 only cluster) is an error condition and will fail during clusterIP assignment.
             */
            ipFamily?: pulumi.Input<string>;
            /**
             * IPFamilyPolicy represents the dual-stack-ness requested or required by this Service. If there is no value provided, then this field will be set to SingleStack. Services can be "SingleStack" (a single IP family), "PreferDualStack" (two IP families on dual-stack configured clusters or a single IP family on single-stack clusters), or "RequireDualStack" (two IP families on dual-stack configured clusters, otherwise fail). The ipFamilies and clusterIPs fields depend on the value of this field. This field will be wiped when updating a service to type ExternalName.
             */
            ipFamilyPolicy?: pulumi.Input<string>;
            /**
             * loadBalancerClass is the class of the load balancer implementation this Service belongs to. If specified, the value of this field must be a label-style identifier, with an optional prefix, e.g. "internal-vip" or "example.com/internal-vip". Unprefixed names are reserved for end-users. This field can only be set when the Service type is 'LoadBalancer'. If not set, the default load balancer implementation is used, today this is typically done through the cloud provider integration, but should apply for any default implementation. If set, it is assumed that a load balancer implementation is watching for Services with a matching class. Any default load balancer implementation (e.g. cloud providers) should ignore Services that set this field. This field can only be set when creating or updating a Service to type 'LoadBalancer'. Once set, it can not be changed. This field will be wiped when a service is updated to a non 'LoadBalancer' type.
             */
            loadBalancerClass?: pulumi.Input<string>;
            /**
             * Only applies to Service Type: LoadBalancer. This feature depends on whether the underlying cloud-provider supports specifying the loadBalancerIP when a load balancer is created. This field will be ignored if the cloud-provider does not support the feature. Deprecated: This field was under-specified and its meaning varies across implementations. Using it is non-portable and it may not support dual-stack. Users are encouraged to use implementation-specific annotations when available.
             */
            loadBalancerIP?: pulumi.Input<string>;
            /**
             * If specified and supported by the platform, this will restrict traffic through the cloud-provider load-balancer will be restricted to the specified client IPs. This field will be ignored if the cloud-provider does not support the feature." More info: https://kubernetes.io/docs/tasks/access-application-cluster/create-external-load-balancer/
             */
            loadBalancerSourceRanges?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * The list of ports that are exposed by this service. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
             */
            ports?: pulumi.Input<pulumi.Input<inputs.core.v1.ServicePort>[]>;
            /**
             * publishNotReadyAddresses indicates that any agent which deals with endpoints for this Service should disregard any indications of ready/not-ready. The primary use case for setting this field is for a StatefulSet's Headless Service to propagate SRV DNS records for its Pods for the purpose of peer discovery. The Kubernetes controllers that generate Endpoints and EndpointSlice resources for Services interpret this to mean that all endpoints are considered "ready" even if the Pods themselves are not. Agents which consume only Kubernetes generated endpoints through the Endpoints or EndpointSlice resources can safely assume this behavior.
             */
            publishNotReadyAddresses?: pulumi.Input<boolean>;
            /**
             * Route service traffic to pods with label keys and values matching this selector. If empty or not present, the service is assumed to have an external process managing its endpoints, which Kubernetes will not modify. Only applies to types ClusterIP, NodePort, and LoadBalancer. Ignored if type is ExternalName. More info: https://kubernetes.io/docs/concepts/services-networking/service/
             */
            selector?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Supports "ClientIP" and "None". Used to maintain session affinity. Enable client IP based session affinity. Must be ClientIP or None. Defaults to None. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
             */
            sessionAffinity?: pulumi.Input<string>;
            /**
             * sessionAffinityConfig contains the configurations of session affinity.
             */
            sessionAffinityConfig?: pulumi.Input<inputs.core.v1.SessionAffinityConfig>;
            /**
             * topologyKeys is a preference-order list of topology keys which implementations of services should use to preferentially sort endpoints when accessing this Service, it can not be used at the same time as externalTrafficPolicy=Local. Topology keys must be valid label keys and at most 16 keys may be specified. Endpoints are chosen based on the first topology key with available backends. If this field is specified and all entries have no backends that match the topology of the client, the service has no backends for that client and connections should fail. The special value "*" may be used to mean "any topology". This catch-all value, if used, only makes sense as the last value in the list. If this is not specified or empty, no topology constraints will be applied.
             */
            topologyKeys?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * TrafficDistribution offers a way to express preferences for how traffic is distributed to Service endpoints. Implementations can use this field as a hint, but are not required to guarantee strict adherence. If the field is not set, the implementation will apply its default routing strategy. If set to "PreferClose", implementations should prioritize endpoints that are in the same zone.
             */
            trafficDistribution?: pulumi.Input<string>;
            /**
             * type determines how the Service is exposed. Defaults to ClusterIP. Valid options are ExternalName, ClusterIP, NodePort, and LoadBalancer. "ClusterIP" allocates a cluster-internal IP address for load-balancing to endpoints. Endpoints are determined by the selector or if that is not specified, by manual construction of an Endpoints object or EndpointSlice objects. If clusterIP is "None", no virtual IP is allocated and the endpoints are published as a set of endpoints rather than a virtual IP. "NodePort" builds on ClusterIP and allocates a port on every node which routes to the same endpoints as the clusterIP. "LoadBalancer" builds on NodePort and creates an external load-balancer (if supported in the current cloud) which routes to the same endpoints as the clusterIP. "ExternalName" aliases this service to the specified externalName. Several other fields do not apply to ExternalName services. More info: https://kubernetes.io/docs/concepts/services-networking/service/#publishing-services-service-types
             */
            type?: pulumi.Input<string | enums.core.v1.ServiceSpecType>;
        }
        /**
         * ServiceSpec describes the attributes that a user creates on a service.
         */
        interface ServiceSpecPatch {
            /**
             * allocateLoadBalancerNodePorts defines if NodePorts will be automatically allocated for services with type LoadBalancer.  Default is "true". It may be set to "false" if the cluster load-balancer does not rely on NodePorts.  If the caller requests specific NodePorts (by specifying a value), those requests will be respected, regardless of this field. This field may only be set for services with type LoadBalancer and will be cleared if the type is changed to any other type.
             */
            allocateLoadBalancerNodePorts?: pulumi.Input<boolean>;
            /**
             * clusterIP is the IP address of the service and is usually assigned randomly. If an address is specified manually, is in-range (as per system configuration), and is not in use, it will be allocated to the service; otherwise creation of the service will fail. This field may not be changed through updates unless the type field is also being changed to ExternalName (which requires this field to be blank) or the type field is being changed from ExternalName (in which case this field may optionally be specified, as describe above).  Valid values are "None", empty string (""), or a valid IP address. Setting this to "None" makes a "headless service" (no virtual IP), which is useful when direct endpoint connections are preferred and proxying is not required.  Only applies to types ClusterIP, NodePort, and LoadBalancer. If this field is specified when creating a Service of type ExternalName, creation will fail. This field will be wiped when updating a Service to type ExternalName. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
             */
            clusterIP?: pulumi.Input<string>;
            /**
             * ClusterIPs is a list of IP addresses assigned to this service, and are usually assigned randomly.  If an address is specified manually, is in-range (as per system configuration), and is not in use, it will be allocated to the service; otherwise creation of the service will fail. This field may not be changed through updates unless the type field is also being changed to ExternalName (which requires this field to be empty) or the type field is being changed from ExternalName (in which case this field may optionally be specified, as describe above).  Valid values are "None", empty string (""), or a valid IP address.  Setting this to "None" makes a "headless service" (no virtual IP), which is useful when direct endpoint connections are preferred and proxying is not required.  Only applies to types ClusterIP, NodePort, and LoadBalancer. If this field is specified when creating a Service of type ExternalName, creation will fail. This field will be wiped when updating a Service to type ExternalName.  If this field is not specified, it will be initialized from the clusterIP field.  If this field is specified, clients must ensure that clusterIPs[0] and clusterIP have the same value.
             *
             * This field may hold a maximum of two entries (dual-stack IPs, in either order). These IPs must correspond to the values of the ipFamilies field. Both clusterIPs and ipFamilies are governed by the ipFamilyPolicy field. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
             */
            clusterIPs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * externalIPs is a list of IP addresses for which nodes in the cluster will also accept traffic for this service.  These IPs are not managed by Kubernetes.  The user is responsible for ensuring that traffic arrives at a node with this IP.  A common example is external load-balancers that are not part of the Kubernetes system.
             */
            externalIPs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * externalName is the external reference that discovery mechanisms will return as an alias for this service (e.g. a DNS CNAME record). No proxying will be involved.  Must be a lowercase RFC-1123 hostname (https://tools.ietf.org/html/rfc1123) and requires `type` to be "ExternalName".
             */
            externalName?: pulumi.Input<string>;
            /**
             * externalTrafficPolicy describes how nodes distribute service traffic they receive on one of the Service's "externally-facing" addresses (NodePorts, ExternalIPs, and LoadBalancer IPs). If set to "Local", the proxy will configure the service in a way that assumes that external load balancers will take care of balancing the service traffic between nodes, and so each node will deliver traffic only to the node-local endpoints of the service, without masquerading the client source IP. (Traffic mistakenly sent to a node with no endpoints will be dropped.) The default value, "Cluster", uses the standard behavior of routing to all endpoints evenly (possibly modified by topology and other features). Note that traffic sent to an External IP or LoadBalancer IP from within the cluster will always get "Cluster" semantics, but clients sending to a NodePort from within the cluster may need to take traffic policy into account when picking a node.
             */
            externalTrafficPolicy?: pulumi.Input<string>;
            /**
             * healthCheckNodePort specifies the healthcheck nodePort for the service. This only applies when type is set to LoadBalancer and externalTrafficPolicy is set to Local. If a value is specified, is in-range, and is not in use, it will be used.  If not specified, a value will be automatically allocated.  External systems (e.g. load-balancers) can use this port to determine if a given node holds endpoints for this service or not.  If this field is specified when creating a Service which does not need it, creation will fail. This field will be wiped when updating a Service to no longer need it (e.g. changing type). This field cannot be updated once set.
             */
            healthCheckNodePort?: pulumi.Input<number>;
            /**
             * InternalTrafficPolicy describes how nodes distribute service traffic they receive on the ClusterIP. If set to "Local", the proxy will assume that pods only want to talk to endpoints of the service on the same node as the pod, dropping the traffic if there are no local endpoints. The default value, "Cluster", uses the standard behavior of routing to all endpoints evenly (possibly modified by topology and other features).
             */
            internalTrafficPolicy?: pulumi.Input<string>;
            /**
             * IPFamilies is a list of IP families (e.g. IPv4, IPv6) assigned to this service. This field is usually assigned automatically based on cluster configuration and the ipFamilyPolicy field. If this field is specified manually, the requested family is available in the cluster, and ipFamilyPolicy allows it, it will be used; otherwise creation of the service will fail. This field is conditionally mutable: it allows for adding or removing a secondary IP family, but it does not allow changing the primary IP family of the Service. Valid values are "IPv4" and "IPv6".  This field only applies to Services of types ClusterIP, NodePort, and LoadBalancer, and does apply to "headless" services. This field will be wiped when updating a Service to type ExternalName.
             *
             * This field may hold a maximum of two entries (dual-stack families, in either order).  These families must correspond to the values of the clusterIPs field, if specified. Both clusterIPs and ipFamilies are governed by the ipFamilyPolicy field.
             */
            ipFamilies?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ipFamily specifies whether this Service has a preference for a particular IP family (e.g. IPv4 vs. IPv6).  If a specific IP family is requested, the clusterIP field will be allocated from that family, if it is available in the cluster.  If no IP family is requested, the cluster's primary IP family will be used. Other IP fields (loadBalancerIP, loadBalancerSourceRanges, externalIPs) and controllers which allocate external load-balancers should use the same IP family.  Endpoints for this Service will be of this family.  This field is immutable after creation. Assigning a ServiceIPFamily not available in the cluster (e.g. IPv6 in IPv4 only cluster) is an error condition and will fail during clusterIP assignment.
             */
            ipFamily?: pulumi.Input<string>;
            /**
             * IPFamilyPolicy represents the dual-stack-ness requested or required by this Service. If there is no value provided, then this field will be set to SingleStack. Services can be "SingleStack" (a single IP family), "PreferDualStack" (two IP families on dual-stack configured clusters or a single IP family on single-stack clusters), or "RequireDualStack" (two IP families on dual-stack configured clusters, otherwise fail). The ipFamilies and clusterIPs fields depend on the value of this field. This field will be wiped when updating a service to type ExternalName.
             */
            ipFamilyPolicy?: pulumi.Input<string>;
            /**
             * loadBalancerClass is the class of the load balancer implementation this Service belongs to. If specified, the value of this field must be a label-style identifier, with an optional prefix, e.g. "internal-vip" or "example.com/internal-vip". Unprefixed names are reserved for end-users. This field can only be set when the Service type is 'LoadBalancer'. If not set, the default load balancer implementation is used, today this is typically done through the cloud provider integration, but should apply for any default implementation. If set, it is assumed that a load balancer implementation is watching for Services with a matching class. Any default load balancer implementation (e.g. cloud providers) should ignore Services that set this field. This field can only be set when creating or updating a Service to type 'LoadBalancer'. Once set, it can not be changed. This field will be wiped when a service is updated to a non 'LoadBalancer' type.
             */
            loadBalancerClass?: pulumi.Input<string>;
            /**
             * Only applies to Service Type: LoadBalancer. This feature depends on whether the underlying cloud-provider supports specifying the loadBalancerIP when a load balancer is created. This field will be ignored if the cloud-provider does not support the feature. Deprecated: This field was under-specified and its meaning varies across implementations. Using it is non-portable and it may not support dual-stack. Users are encouraged to use implementation-specific annotations when available.
             */
            loadBalancerIP?: pulumi.Input<string>;
            /**
             * If specified and supported by the platform, this will restrict traffic through the cloud-provider load-balancer will be restricted to the specified client IPs. This field will be ignored if the cloud-provider does not support the feature." More info: https://kubernetes.io/docs/tasks/access-application-cluster/create-external-load-balancer/
             */
            loadBalancerSourceRanges?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * The list of ports that are exposed by this service. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
             */
            ports?: pulumi.Input<pulumi.Input<inputs.core.v1.ServicePortPatch>[]>;
            /**
             * publishNotReadyAddresses indicates that any agent which deals with endpoints for this Service should disregard any indications of ready/not-ready. The primary use case for setting this field is for a StatefulSet's Headless Service to propagate SRV DNS records for its Pods for the purpose of peer discovery. The Kubernetes controllers that generate Endpoints and EndpointSlice resources for Services interpret this to mean that all endpoints are considered "ready" even if the Pods themselves are not. Agents which consume only Kubernetes generated endpoints through the Endpoints or EndpointSlice resources can safely assume this behavior.
             */
            publishNotReadyAddresses?: pulumi.Input<boolean>;
            /**
             * Route service traffic to pods with label keys and values matching this selector. If empty or not present, the service is assumed to have an external process managing its endpoints, which Kubernetes will not modify. Only applies to types ClusterIP, NodePort, and LoadBalancer. Ignored if type is ExternalName. More info: https://kubernetes.io/docs/concepts/services-networking/service/
             */
            selector?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Supports "ClientIP" and "None". Used to maintain session affinity. Enable client IP based session affinity. Must be ClientIP or None. Defaults to None. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
             */
            sessionAffinity?: pulumi.Input<string>;
            /**
             * sessionAffinityConfig contains the configurations of session affinity.
             */
            sessionAffinityConfig?: pulumi.Input<inputs.core.v1.SessionAffinityConfigPatch>;
            /**
             * topologyKeys is a preference-order list of topology keys which implementations of services should use to preferentially sort endpoints when accessing this Service, it can not be used at the same time as externalTrafficPolicy=Local. Topology keys must be valid label keys and at most 16 keys may be specified. Endpoints are chosen based on the first topology key with available backends. If this field is specified and all entries have no backends that match the topology of the client, the service has no backends for that client and connections should fail. The special value "*" may be used to mean "any topology". This catch-all value, if used, only makes sense as the last value in the list. If this is not specified or empty, no topology constraints will be applied.
             */
            topologyKeys?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * TrafficDistribution offers a way to express preferences for how traffic is distributed to Service endpoints. Implementations can use this field as a hint, but are not required to guarantee strict adherence. If the field is not set, the implementation will apply its default routing strategy. If set to "PreferClose", implementations should prioritize endpoints that are in the same zone.
             */
            trafficDistribution?: pulumi.Input<string>;
            /**
             * type determines how the Service is exposed. Defaults to ClusterIP. Valid options are ExternalName, ClusterIP, NodePort, and LoadBalancer. "ClusterIP" allocates a cluster-internal IP address for load-balancing to endpoints. Endpoints are determined by the selector or if that is not specified, by manual construction of an Endpoints object or EndpointSlice objects. If clusterIP is "None", no virtual IP is allocated and the endpoints are published as a set of endpoints rather than a virtual IP. "NodePort" builds on ClusterIP and allocates a port on every node which routes to the same endpoints as the clusterIP. "LoadBalancer" builds on NodePort and creates an external load-balancer (if supported in the current cloud) which routes to the same endpoints as the clusterIP. "ExternalName" aliases this service to the specified externalName. Several other fields do not apply to ExternalName services. More info: https://kubernetes.io/docs/concepts/services-networking/service/#publishing-services-service-types
             */
            type?: pulumi.Input<string | enums.core.v1.ServiceSpecType>;
        }
        /**
         * ServiceStatus represents the current status of a service.
         */
        interface ServiceStatus {
            /**
             * Current service state
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.meta.v1.Condition>[]>;
            /**
             * LoadBalancer contains the current status of the load-balancer, if one is present.
             */
            loadBalancer?: pulumi.Input<inputs.core.v1.LoadBalancerStatus>;
        }
        /**
         * SessionAffinityConfig represents the configurations of session affinity.
         */
        interface SessionAffinityConfig {
            /**
             * clientIP contains the configurations of Client IP based session affinity.
             */
            clientIP?: pulumi.Input<inputs.core.v1.ClientIPConfig>;
        }
        /**
         * SessionAffinityConfig represents the configurations of session affinity.
         */
        interface SessionAffinityConfigPatch {
            /**
             * clientIP contains the configurations of Client IP based session affinity.
             */
            clientIP?: pulumi.Input<inputs.core.v1.ClientIPConfigPatch>;
        }
        /**
         * SleepAction describes a "sleep" action.
         */
        interface SleepAction {
            /**
             * Seconds is the number of seconds to sleep.
             */
            seconds: pulumi.Input<number>;
        }
        /**
         * SleepAction describes a "sleep" action.
         */
        interface SleepActionPatch {
            /**
             * Seconds is the number of seconds to sleep.
             */
            seconds?: pulumi.Input<number>;
        }
        /**
         * Represents a StorageOS persistent volume resource.
         */
        interface StorageOSPersistentVolumeSource {
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef specifies the secret to use for obtaining the StorageOS API credentials.  If not specified, default values will be attempted.
             */
            secretRef?: pulumi.Input<inputs.core.v1.ObjectReference>;
            /**
             * volumeName is the human-readable name of the StorageOS volume.  Volume names are only unique within a namespace.
             */
            volumeName?: pulumi.Input<string>;
            /**
             * volumeNamespace specifies the scope of the volume within StorageOS.  If no namespace is specified then the Pod's namespace will be used.  This allows the Kubernetes name scoping to be mirrored within StorageOS for tighter integration. Set VolumeName to any name to override the default behaviour. Set to "default" if you are not using namespaces within StorageOS. Namespaces that do not pre-exist within StorageOS will be created.
             */
            volumeNamespace?: pulumi.Input<string>;
        }
        /**
         * Represents a StorageOS persistent volume resource.
         */
        interface StorageOSPersistentVolumeSourcePatch {
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef specifies the secret to use for obtaining the StorageOS API credentials.  If not specified, default values will be attempted.
             */
            secretRef?: pulumi.Input<inputs.core.v1.ObjectReferencePatch>;
            /**
             * volumeName is the human-readable name of the StorageOS volume.  Volume names are only unique within a namespace.
             */
            volumeName?: pulumi.Input<string>;
            /**
             * volumeNamespace specifies the scope of the volume within StorageOS.  If no namespace is specified then the Pod's namespace will be used.  This allows the Kubernetes name scoping to be mirrored within StorageOS for tighter integration. Set VolumeName to any name to override the default behaviour. Set to "default" if you are not using namespaces within StorageOS. Namespaces that do not pre-exist within StorageOS will be created.
             */
            volumeNamespace?: pulumi.Input<string>;
        }
        /**
         * Represents a StorageOS persistent volume resource.
         */
        interface StorageOSVolumeSource {
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef specifies the secret to use for obtaining the StorageOS API credentials.  If not specified, default values will be attempted.
             */
            secretRef?: pulumi.Input<inputs.core.v1.LocalObjectReference>;
            /**
             * volumeName is the human-readable name of the StorageOS volume.  Volume names are only unique within a namespace.
             */
            volumeName?: pulumi.Input<string>;
            /**
             * volumeNamespace specifies the scope of the volume within StorageOS.  If no namespace is specified then the Pod's namespace will be used.  This allows the Kubernetes name scoping to be mirrored within StorageOS for tighter integration. Set VolumeName to any name to override the default behaviour. Set to "default" if you are not using namespaces within StorageOS. Namespaces that do not pre-exist within StorageOS will be created.
             */
            volumeNamespace?: pulumi.Input<string>;
        }
        /**
         * Represents a StorageOS persistent volume resource.
         */
        interface StorageOSVolumeSourcePatch {
            /**
             * fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * secretRef specifies the secret to use for obtaining the StorageOS API credentials.  If not specified, default values will be attempted.
             */
            secretRef?: pulumi.Input<inputs.core.v1.LocalObjectReferencePatch>;
            /**
             * volumeName is the human-readable name of the StorageOS volume.  Volume names are only unique within a namespace.
             */
            volumeName?: pulumi.Input<string>;
            /**
             * volumeNamespace specifies the scope of the volume within StorageOS.  If no namespace is specified then the Pod's namespace will be used.  This allows the Kubernetes name scoping to be mirrored within StorageOS for tighter integration. Set VolumeName to any name to override the default behaviour. Set to "default" if you are not using namespaces within StorageOS. Namespaces that do not pre-exist within StorageOS will be created.
             */
            volumeNamespace?: pulumi.Input<string>;
        }
        /**
         * Sysctl defines a kernel parameter to be set
         */
        interface Sysctl {
            /**
             * Name of a property to set
             */
            name: pulumi.Input<string>;
            /**
             * Value of a property to set
             */
            value: pulumi.Input<string>;
        }
        /**
         * Sysctl defines a kernel parameter to be set
         */
        interface SysctlPatch {
            /**
             * Name of a property to set
             */
            name?: pulumi.Input<string>;
            /**
             * Value of a property to set
             */
            value?: pulumi.Input<string>;
        }
        /**
         * TCPSocketAction describes an action based on opening a socket
         */
        interface TCPSocketAction {
            /**
             * Optional: Host name to connect to, defaults to the pod IP.
             */
            host?: pulumi.Input<string>;
            /**
             * Number or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
             */
            port: pulumi.Input<number | string>;
        }
        /**
         * TCPSocketAction describes an action based on opening a socket
         */
        interface TCPSocketActionPatch {
            /**
             * Optional: Host name to connect to, defaults to the pod IP.
             */
            host?: pulumi.Input<string>;
            /**
             * Number or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
             */
            port?: pulumi.Input<number | string>;
        }
        /**
         * The node this Taint is attached to has the "effect" on any pod that does not tolerate the Taint.
         */
        interface Taint {
            /**
             * Required. The effect of the taint on pods that do not tolerate the taint. Valid effects are NoSchedule, PreferNoSchedule and NoExecute.
             */
            effect: pulumi.Input<string>;
            /**
             * Required. The taint key to be applied to a node.
             */
            key: pulumi.Input<string>;
            /**
             * TimeAdded represents the time at which the taint was added. It is only written for NoExecute taints.
             */
            timeAdded?: pulumi.Input<string>;
            /**
             * The taint value corresponding to the taint key.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * The node this Taint is attached to has the "effect" on any pod that does not tolerate the Taint.
         */
        interface TaintPatch {
            /**
             * Required. The effect of the taint on pods that do not tolerate the taint. Valid effects are NoSchedule, PreferNoSchedule and NoExecute.
             */
            effect?: pulumi.Input<string>;
            /**
             * Required. The taint key to be applied to a node.
             */
            key?: pulumi.Input<string>;
            /**
             * TimeAdded represents the time at which the taint was added. It is only written for NoExecute taints.
             */
            timeAdded?: pulumi.Input<string>;
            /**
             * The taint value corresponding to the taint key.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * The pod this Toleration is attached to tolerates any taint that matches the triple <key,value,effect> using the matching operator <operator>.
         */
        interface Toleration {
            /**
             * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
             */
            effect?: pulumi.Input<string>;
            /**
             * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
             */
            key?: pulumi.Input<string>;
            /**
             * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
             */
            operator?: pulumi.Input<string>;
            /**
             * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
             */
            tolerationSeconds?: pulumi.Input<number>;
            /**
             * Value is the taint value the toleration matches to. If the operator is Exists, the value should be empty, otherwise just a regular string.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * The pod this Toleration is attached to tolerates any taint that matches the triple <key,value,effect> using the matching operator <operator>.
         */
        interface TolerationPatch {
            /**
             * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
             */
            effect?: pulumi.Input<string>;
            /**
             * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
             */
            key?: pulumi.Input<string>;
            /**
             * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
             */
            operator?: pulumi.Input<string>;
            /**
             * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
             */
            tolerationSeconds?: pulumi.Input<number>;
            /**
             * Value is the taint value the toleration matches to. If the operator is Exists, the value should be empty, otherwise just a regular string.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * A topology selector requirement is a selector that matches given label. This is an alpha feature and may change in the future.
         */
        interface TopologySelectorLabelRequirement {
            /**
             * The label key that the selector applies to.
             */
            key: pulumi.Input<string>;
            /**
             * An array of string values. One value must match the label to be selected. Each entry in Values is ORed.
             */
            values: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * A topology selector requirement is a selector that matches given label. This is an alpha feature and may change in the future.
         */
        interface TopologySelectorLabelRequirementPatch {
            /**
             * The label key that the selector applies to.
             */
            key?: pulumi.Input<string>;
            /**
             * An array of string values. One value must match the label to be selected. Each entry in Values is ORed.
             */
            values?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * A topology selector term represents the result of label queries. A null or empty topology selector term matches no objects. The requirements of them are ANDed. It provides a subset of functionality as NodeSelectorTerm. This is an alpha feature and may change in the future.
         */
        interface TopologySelectorTerm {
            /**
             * A list of topology selector requirements by labels.
             */
            matchLabelExpressions?: pulumi.Input<pulumi.Input<inputs.core.v1.TopologySelectorLabelRequirement>[]>;
        }
        /**
         * A topology selector term represents the result of label queries. A null or empty topology selector term matches no objects. The requirements of them are ANDed. It provides a subset of functionality as NodeSelectorTerm. This is an alpha feature and may change in the future.
         */
        interface TopologySelectorTermPatch {
            /**
             * A list of topology selector requirements by labels.
             */
            matchLabelExpressions?: pulumi.Input<pulumi.Input<inputs.core.v1.TopologySelectorLabelRequirementPatch>[]>;
        }
        /**
         * TopologySpreadConstraint specifies how to spread matching pods among the given topology.
         */
        interface TopologySpreadConstraint {
            /**
             * LabelSelector is used to find matching pods. Pods that match this label selector are counted to determine the number of pods in their corresponding topology domain.
             */
            labelSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * MatchLabelKeys is a set of pod label keys to select the pods over which spreading will be calculated. The keys are used to lookup values from the incoming pod labels, those key-value labels are ANDed with labelSelector to select the group of existing pods over which spreading will be calculated for the incoming pod. The same key is forbidden to exist in both MatchLabelKeys and LabelSelector. MatchLabelKeys cannot be set when LabelSelector isn't set. Keys that don't exist in the incoming pod labels will be ignored. A null or empty list means only match against labelSelector.
             *
             * This is a beta field and requires the MatchLabelKeysInPodTopologySpread feature gate to be enabled (enabled by default).
             */
            matchLabelKeys?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * MaxSkew describes the degree to which pods may be unevenly distributed. When `whenUnsatisfiable=DoNotSchedule`, it is the maximum permitted difference between the number of matching pods in the target topology and the global minimum. The global minimum is the minimum number of matching pods in an eligible domain or zero if the number of eligible domains is less than MinDomains. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 2/2/1: In this case, the global minimum is 1. | zone1 | zone2 | zone3 | |  P P  |  P P  |   P   | - if MaxSkew is 1, incoming pod can only be scheduled to zone3 to become 2/2/2; scheduling it onto zone1(zone2) would make the ActualSkew(3-1) on zone1(zone2) violate MaxSkew(1). - if MaxSkew is 2, incoming pod can be scheduled onto any zone. When `whenUnsatisfiable=ScheduleAnyway`, it is used to give higher precedence to topologies that satisfy it. It's a required field. Default value is 1 and 0 is not allowed.
             */
            maxSkew: pulumi.Input<number>;
            /**
             * MinDomains indicates a minimum number of eligible domains. When the number of eligible domains with matching topology keys is less than minDomains, Pod Topology Spread treats "global minimum" as 0, and then the calculation of Skew is performed. And when the number of eligible domains with matching topology keys equals or greater than minDomains, this value has no effect on scheduling. As a result, when the number of eligible domains is less than minDomains, scheduler won't schedule more than maxSkew Pods to those domains. If value is nil, the constraint behaves as if MinDomains is equal to 1. Valid values are integers greater than 0. When value is not nil, WhenUnsatisfiable must be DoNotSchedule.
             *
             * For example, in a 3-zone cluster, MaxSkew is set to 2, MinDomains is set to 5 and pods with the same labelSelector spread as 2/2/2: | zone1 | zone2 | zone3 | |  P P  |  P P  |  P P  | The number of domains is less than 5(MinDomains), so "global minimum" is treated as 0. In this situation, new pod with the same labelSelector cannot be scheduled, because computed skew will be 3(3 - 0) if new Pod is scheduled to any of the three zones, it will violate MaxSkew.
             */
            minDomains?: pulumi.Input<number>;
            /**
             * NodeAffinityPolicy indicates how we will treat Pod's nodeAffinity/nodeSelector when calculating pod topology spread skew. Options are: - Honor: only nodes matching nodeAffinity/nodeSelector are included in the calculations. - Ignore: nodeAffinity/nodeSelector are ignored. All nodes are included in the calculations.
             *
             * If this value is nil, the behavior is equivalent to the Honor policy.
             */
            nodeAffinityPolicy?: pulumi.Input<string>;
            /**
             * NodeTaintsPolicy indicates how we will treat node taints when calculating pod topology spread skew. Options are: - Honor: nodes without taints, along with tainted nodes for which the incoming pod has a toleration, are included. - Ignore: node taints are ignored. All nodes are included.
             *
             * If this value is nil, the behavior is equivalent to the Ignore policy.
             */
            nodeTaintsPolicy?: pulumi.Input<string>;
            /**
             * TopologyKey is the key of node labels. Nodes that have a label with this key and identical values are considered to be in the same topology. We consider each <key, value> as a "bucket", and try to put balanced number of pods into each bucket. We define a domain as a particular instance of a topology. Also, we define an eligible domain as a domain whose nodes meet the requirements of nodeAffinityPolicy and nodeTaintsPolicy. e.g. If TopologyKey is "kubernetes.io/hostname", each Node is a domain of that topology. And, if TopologyKey is "topology.kubernetes.io/zone", each zone is a domain of that topology. It's a required field.
             */
            topologyKey: pulumi.Input<string>;
            /**
             * WhenUnsatisfiable indicates how to deal with a pod if it doesn't satisfy the spread constraint. - DoNotSchedule (default) tells the scheduler not to schedule it. - ScheduleAnyway tells the scheduler to schedule the pod in any location,
             *   but giving higher precedence to topologies that would help reduce the
             *   skew.
             * A constraint is considered "Unsatisfiable" for an incoming pod if and only if every possible node assignment for that pod would violate "MaxSkew" on some topology. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 3/1/1: | zone1 | zone2 | zone3 | | P P P |   P   |   P   | If WhenUnsatisfiable is set to DoNotSchedule, incoming pod can only be scheduled to zone2(zone3) to become 3/2/1(3/1/2) as ActualSkew(2-1) on zone2(zone3) satisfies MaxSkew(1). In other words, the cluster can still be imbalanced, but scheduler won't make it *more* imbalanced. It's a required field.
             */
            whenUnsatisfiable: pulumi.Input<string>;
        }
        /**
         * TopologySpreadConstraint specifies how to spread matching pods among the given topology.
         */
        interface TopologySpreadConstraintPatch {
            /**
             * LabelSelector is used to find matching pods. Pods that match this label selector are counted to determine the number of pods in their corresponding topology domain.
             */
            labelSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * MatchLabelKeys is a set of pod label keys to select the pods over which spreading will be calculated. The keys are used to lookup values from the incoming pod labels, those key-value labels are ANDed with labelSelector to select the group of existing pods over which spreading will be calculated for the incoming pod. The same key is forbidden to exist in both MatchLabelKeys and LabelSelector. MatchLabelKeys cannot be set when LabelSelector isn't set. Keys that don't exist in the incoming pod labels will be ignored. A null or empty list means only match against labelSelector.
             *
             * This is a beta field and requires the MatchLabelKeysInPodTopologySpread feature gate to be enabled (enabled by default).
             */
            matchLabelKeys?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * MaxSkew describes the degree to which pods may be unevenly distributed. When `whenUnsatisfiable=DoNotSchedule`, it is the maximum permitted difference between the number of matching pods in the target topology and the global minimum. The global minimum is the minimum number of matching pods in an eligible domain or zero if the number of eligible domains is less than MinDomains. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 2/2/1: In this case, the global minimum is 1. | zone1 | zone2 | zone3 | |  P P  |  P P  |   P   | - if MaxSkew is 1, incoming pod can only be scheduled to zone3 to become 2/2/2; scheduling it onto zone1(zone2) would make the ActualSkew(3-1) on zone1(zone2) violate MaxSkew(1). - if MaxSkew is 2, incoming pod can be scheduled onto any zone. When `whenUnsatisfiable=ScheduleAnyway`, it is used to give higher precedence to topologies that satisfy it. It's a required field. Default value is 1 and 0 is not allowed.
             */
            maxSkew?: pulumi.Input<number>;
            /**
             * MinDomains indicates a minimum number of eligible domains. When the number of eligible domains with matching topology keys is less than minDomains, Pod Topology Spread treats "global minimum" as 0, and then the calculation of Skew is performed. And when the number of eligible domains with matching topology keys equals or greater than minDomains, this value has no effect on scheduling. As a result, when the number of eligible domains is less than minDomains, scheduler won't schedule more than maxSkew Pods to those domains. If value is nil, the constraint behaves as if MinDomains is equal to 1. Valid values are integers greater than 0. When value is not nil, WhenUnsatisfiable must be DoNotSchedule.
             *
             * For example, in a 3-zone cluster, MaxSkew is set to 2, MinDomains is set to 5 and pods with the same labelSelector spread as 2/2/2: | zone1 | zone2 | zone3 | |  P P  |  P P  |  P P  | The number of domains is less than 5(MinDomains), so "global minimum" is treated as 0. In this situation, new pod with the same labelSelector cannot be scheduled, because computed skew will be 3(3 - 0) if new Pod is scheduled to any of the three zones, it will violate MaxSkew.
             */
            minDomains?: pulumi.Input<number>;
            /**
             * NodeAffinityPolicy indicates how we will treat Pod's nodeAffinity/nodeSelector when calculating pod topology spread skew. Options are: - Honor: only nodes matching nodeAffinity/nodeSelector are included in the calculations. - Ignore: nodeAffinity/nodeSelector are ignored. All nodes are included in the calculations.
             *
             * If this value is nil, the behavior is equivalent to the Honor policy.
             */
            nodeAffinityPolicy?: pulumi.Input<string>;
            /**
             * NodeTaintsPolicy indicates how we will treat node taints when calculating pod topology spread skew. Options are: - Honor: nodes without taints, along with tainted nodes for which the incoming pod has a toleration, are included. - Ignore: node taints are ignored. All nodes are included.
             *
             * If this value is nil, the behavior is equivalent to the Ignore policy.
             */
            nodeTaintsPolicy?: pulumi.Input<string>;
            /**
             * TopologyKey is the key of node labels. Nodes that have a label with this key and identical values are considered to be in the same topology. We consider each <key, value> as a "bucket", and try to put balanced number of pods into each bucket. We define a domain as a particular instance of a topology. Also, we define an eligible domain as a domain whose nodes meet the requirements of nodeAffinityPolicy and nodeTaintsPolicy. e.g. If TopologyKey is "kubernetes.io/hostname", each Node is a domain of that topology. And, if TopologyKey is "topology.kubernetes.io/zone", each zone is a domain of that topology. It's a required field.
             */
            topologyKey?: pulumi.Input<string>;
            /**
             * WhenUnsatisfiable indicates how to deal with a pod if it doesn't satisfy the spread constraint. - DoNotSchedule (default) tells the scheduler not to schedule it. - ScheduleAnyway tells the scheduler to schedule the pod in any location,
             *   but giving higher precedence to topologies that would help reduce the
             *   skew.
             * A constraint is considered "Unsatisfiable" for an incoming pod if and only if every possible node assignment for that pod would violate "MaxSkew" on some topology. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 3/1/1: | zone1 | zone2 | zone3 | | P P P |   P   |   P   | If WhenUnsatisfiable is set to DoNotSchedule, incoming pod can only be scheduled to zone2(zone3) to become 3/2/1(3/1/2) as ActualSkew(2-1) on zone2(zone3) satisfies MaxSkew(1). In other words, the cluster can still be imbalanced, but scheduler won't make it *more* imbalanced. It's a required field.
             */
            whenUnsatisfiable?: pulumi.Input<string>;
        }
        /**
         * TypedLocalObjectReference contains enough information to let you locate the typed referenced object inside the same namespace.
         */
        interface TypedLocalObjectReference {
            /**
             * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced
             */
            kind: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced
             */
            name: pulumi.Input<string>;
        }
        /**
         * TypedLocalObjectReference contains enough information to let you locate the typed referenced object inside the same namespace.
         */
        interface TypedLocalObjectReferencePatch {
            /**
             * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced
             */
            kind?: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced
             */
            name?: pulumi.Input<string>;
        }
        /**
         * TypedObjectReference contains enough information to let you locate the typed referenced object
         */
        interface TypedObjectReference {
            /**
             * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced
             */
            kind: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced
             */
            name: pulumi.Input<string>;
            /**
             * Namespace is the namespace of resource being referenced Note that when a namespace is specified, a gateway.networking.k8s.io/ReferenceGrant object is required in the referent namespace to allow that namespace's owner to accept the reference. See the ReferenceGrant documentation for details. (Alpha) This field requires the CrossNamespaceVolumeDataSource feature gate to be enabled.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * TypedObjectReference contains enough information to let you locate the typed referenced object
         */
        interface TypedObjectReferencePatch {
            /**
             * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced
             */
            kind?: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace is the namespace of resource being referenced Note that when a namespace is specified, a gateway.networking.k8s.io/ReferenceGrant object is required in the referent namespace to allow that namespace's owner to accept the reference. See the ReferenceGrant documentation for details. (Alpha) This field requires the CrossNamespaceVolumeDataSource feature gate to be enabled.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * Volume represents a named volume in a pod that may be accessed by any container in the pod.
         */
        interface Volume {
            /**
             * awsElasticBlockStore represents an AWS Disk resource that is attached to a kubelet's host machine and then exposed to the pod. Deprecated: AWSElasticBlockStore is deprecated. All operations for the in-tree awsElasticBlockStore type are redirected to the ebs.csi.aws.com CSI driver. More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore
             */
            awsElasticBlockStore?: pulumi.Input<inputs.core.v1.AWSElasticBlockStoreVolumeSource>;
            /**
             * azureDisk represents an Azure Data Disk mount on the host and bind mount to the pod. Deprecated: AzureDisk is deprecated. All operations for the in-tree azureDisk type are redirected to the disk.csi.azure.com CSI driver.
             */
            azureDisk?: pulumi.Input<inputs.core.v1.AzureDiskVolumeSource>;
            /**
             * azureFile represents an Azure File Service mount on the host and bind mount to the pod. Deprecated: AzureFile is deprecated. All operations for the in-tree azureFile type are redirected to the file.csi.azure.com CSI driver.
             */
            azureFile?: pulumi.Input<inputs.core.v1.AzureFileVolumeSource>;
            /**
             * cephFS represents a Ceph FS mount on the host that shares a pod's lifetime. Deprecated: CephFS is deprecated and the in-tree cephfs type is no longer supported.
             */
            cephfs?: pulumi.Input<inputs.core.v1.CephFSVolumeSource>;
            /**
             * cinder represents a cinder volume attached and mounted on kubelets host machine. Deprecated: Cinder is deprecated. All operations for the in-tree cinder type are redirected to the cinder.csi.openstack.org CSI driver. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            cinder?: pulumi.Input<inputs.core.v1.CinderVolumeSource>;
            /**
             * configMap represents a configMap that should populate this volume
             */
            configMap?: pulumi.Input<inputs.core.v1.ConfigMapVolumeSource>;
            /**
             * csi (Container Storage Interface) represents ephemeral storage that is handled by certain external CSI drivers.
             */
            csi?: pulumi.Input<inputs.core.v1.CSIVolumeSource>;
            /**
             * downwardAPI represents downward API about the pod that should populate this volume
             */
            downwardAPI?: pulumi.Input<inputs.core.v1.DownwardAPIVolumeSource>;
            /**
             * emptyDir represents a temporary directory that shares a pod's lifetime. More info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir
             */
            emptyDir?: pulumi.Input<inputs.core.v1.EmptyDirVolumeSource>;
            /**
             * ephemeral represents a volume that is handled by a cluster storage driver. The volume's lifecycle is tied to the pod that defines it - it will be created before the pod starts, and deleted when the pod is removed.
             *
             * Use this if: a) the volume is only needed while the pod runs, b) features of normal volumes like restoring from snapshot or capacity
             *    tracking are needed,
             * c) the storage driver is specified through a storage class, and d) the storage driver supports dynamic volume provisioning through
             *    a PersistentVolumeClaim (see EphemeralVolumeSource for more
             *    information on the connection between this volume type
             *    and PersistentVolumeClaim).
             *
             * Use PersistentVolumeClaim or one of the vendor-specific APIs for volumes that persist for longer than the lifecycle of an individual pod.
             *
             * Use CSI for light-weight local ephemeral volumes if the CSI driver is meant to be used that way - see the documentation of the driver for more information.
             *
             * A pod can use both types of ephemeral volumes and persistent volumes at the same time.
             */
            ephemeral?: pulumi.Input<inputs.core.v1.EphemeralVolumeSource>;
            /**
             * fc represents a Fibre Channel resource that is attached to a kubelet's host machine and then exposed to the pod.
             */
            fc?: pulumi.Input<inputs.core.v1.FCVolumeSource>;
            /**
             * flexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin. Deprecated: FlexVolume is deprecated. Consider using a CSIDriver instead.
             */
            flexVolume?: pulumi.Input<inputs.core.v1.FlexVolumeSource>;
            /**
             * flocker represents a Flocker volume attached to a kubelet's host machine. This depends on the Flocker control service being running. Deprecated: Flocker is deprecated and the in-tree flocker type is no longer supported.
             */
            flocker?: pulumi.Input<inputs.core.v1.FlockerVolumeSource>;
            /**
             * gcePersistentDisk represents a GCE Disk resource that is attached to a kubelet's host machine and then exposed to the pod. Deprecated: GCEPersistentDisk is deprecated. All operations for the in-tree gcePersistentDisk type are redirected to the pd.csi.storage.gke.io CSI driver. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk
             */
            gcePersistentDisk?: pulumi.Input<inputs.core.v1.GCEPersistentDiskVolumeSource>;
            /**
             * gitRepo represents a git repository at a particular revision. Deprecated: GitRepo is deprecated. To provision a container with a git repo, mount an EmptyDir into an InitContainer that clones the repo using git, then mount the EmptyDir into the Pod's container.
             */
            gitRepo?: pulumi.Input<inputs.core.v1.GitRepoVolumeSource>;
            /**
             * glusterfs represents a Glusterfs mount on the host that shares a pod's lifetime. Deprecated: Glusterfs is deprecated and the in-tree glusterfs type is no longer supported. More info: https://examples.k8s.io/volumes/glusterfs/README.md
             */
            glusterfs?: pulumi.Input<inputs.core.v1.GlusterfsVolumeSource>;
            /**
             * hostPath represents a pre-existing file or directory on the host machine that is directly exposed to the container. This is generally used for system agents or other privileged things that are allowed to see the host machine. Most containers will NOT need this. More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath
             */
            hostPath?: pulumi.Input<inputs.core.v1.HostPathVolumeSource>;
            /**
             * image represents an OCI object (a container image or artifact) pulled and mounted on the kubelet's host machine. The volume is resolved at pod startup depending on which PullPolicy value is provided:
             *
             * - Always: the kubelet always attempts to pull the reference. Container creation will fail If the pull fails. - Never: the kubelet never pulls the reference and only uses a local image or artifact. Container creation will fail if the reference isn't present. - IfNotPresent: the kubelet pulls if the reference isn't already present on disk. Container creation will fail if the reference isn't present and the pull fails.
             *
             * The volume gets re-resolved if the pod gets deleted and recreated, which means that new remote content will become available on pod recreation. A failure to resolve or pull the image during pod startup will block containers from starting and may add significant latency. Failures will be retried using normal volume backoff and will be reported on the pod reason and message. The types of objects that may be mounted by this volume are defined by the container runtime implementation on a host machine and at minimum must include all valid types supported by the container image field. The OCI object gets mounted in a single directory (spec.containers[*].volumeMounts.mountPath) by merging the manifest layers in the same way as for container images. The volume will be mounted read-only (ro) and non-executable files (noexec). Sub path mounts for containers are not supported (spec.containers[*].volumeMounts.subpath) before 1.33. The field spec.securityContext.fsGroupChangePolicy has no effect on this volume type.
             */
            image?: pulumi.Input<inputs.core.v1.ImageVolumeSource>;
            /**
             * iscsi represents an ISCSI Disk resource that is attached to a kubelet's host machine and then exposed to the pod. More info: https://examples.k8s.io/volumes/iscsi/README.md
             */
            iscsi?: pulumi.Input<inputs.core.v1.ISCSIVolumeSource>;
            /**
             * name of the volume. Must be a DNS_LABEL and unique within the pod. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name: pulumi.Input<string>;
            /**
             * nfs represents an NFS mount on the host that shares a pod's lifetime More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs
             */
            nfs?: pulumi.Input<inputs.core.v1.NFSVolumeSource>;
            /**
             * persistentVolumeClaimVolumeSource represents a reference to a PersistentVolumeClaim in the same namespace. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims
             */
            persistentVolumeClaim?: pulumi.Input<inputs.core.v1.PersistentVolumeClaimVolumeSource>;
            /**
             * photonPersistentDisk represents a PhotonController persistent disk attached and mounted on kubelets host machine. Deprecated: PhotonPersistentDisk is deprecated and the in-tree photonPersistentDisk type is no longer supported.
             */
            photonPersistentDisk?: pulumi.Input<inputs.core.v1.PhotonPersistentDiskVolumeSource>;
            /**
             * portworxVolume represents a portworx volume attached and mounted on kubelets host machine. Deprecated: PortworxVolume is deprecated. All operations for the in-tree portworxVolume type are redirected to the pxd.portworx.com CSI driver when the CSIMigrationPortworx feature-gate is on.
             */
            portworxVolume?: pulumi.Input<inputs.core.v1.PortworxVolumeSource>;
            /**
             * projected items for all in one resources secrets, configmaps, and downward API
             */
            projected?: pulumi.Input<inputs.core.v1.ProjectedVolumeSource>;
            /**
             * quobyte represents a Quobyte mount on the host that shares a pod's lifetime. Deprecated: Quobyte is deprecated and the in-tree quobyte type is no longer supported.
             */
            quobyte?: pulumi.Input<inputs.core.v1.QuobyteVolumeSource>;
            /**
             * rbd represents a Rados Block Device mount on the host that shares a pod's lifetime. Deprecated: RBD is deprecated and the in-tree rbd type is no longer supported. More info: https://examples.k8s.io/volumes/rbd/README.md
             */
            rbd?: pulumi.Input<inputs.core.v1.RBDVolumeSource>;
            /**
             * scaleIO represents a ScaleIO persistent volume attached and mounted on Kubernetes nodes. Deprecated: ScaleIO is deprecated and the in-tree scaleIO type is no longer supported.
             */
            scaleIO?: pulumi.Input<inputs.core.v1.ScaleIOVolumeSource>;
            /**
             * secret represents a secret that should populate this volume. More info: https://kubernetes.io/docs/concepts/storage/volumes#secret
             */
            secret?: pulumi.Input<inputs.core.v1.SecretVolumeSource>;
            /**
             * storageOS represents a StorageOS volume attached and mounted on Kubernetes nodes. Deprecated: StorageOS is deprecated and the in-tree storageos type is no longer supported.
             */
            storageos?: pulumi.Input<inputs.core.v1.StorageOSVolumeSource>;
            /**
             * vsphereVolume represents a vSphere volume attached and mounted on kubelets host machine. Deprecated: VsphereVolume is deprecated. All operations for the in-tree vsphereVolume type are redirected to the csi.vsphere.vmware.com CSI driver.
             */
            vsphereVolume?: pulumi.Input<inputs.core.v1.VsphereVirtualDiskVolumeSource>;
        }
        /**
         * volumeDevice describes a mapping of a raw block device within a container.
         */
        interface VolumeDevice {
            /**
             * devicePath is the path inside of the container that the device will be mapped to.
             */
            devicePath: pulumi.Input<string>;
            /**
             * name must match the name of a persistentVolumeClaim in the pod
             */
            name: pulumi.Input<string>;
        }
        /**
         * volumeDevice describes a mapping of a raw block device within a container.
         */
        interface VolumeDevicePatch {
            /**
             * devicePath is the path inside of the container that the device will be mapped to.
             */
            devicePath?: pulumi.Input<string>;
            /**
             * name must match the name of a persistentVolumeClaim in the pod
             */
            name?: pulumi.Input<string>;
        }
        /**
         * VolumeMount describes a mounting of a Volume within a container.
         */
        interface VolumeMount {
            /**
             * Path within the container at which the volume should be mounted.  Must not contain ':'.
             */
            mountPath: pulumi.Input<string>;
            /**
             * mountPropagation determines how mounts are propagated from the host to container and the other way around. When not set, MountPropagationNone is used. This field is beta in 1.10. When RecursiveReadOnly is set to IfPossible or to Enabled, MountPropagation must be None or unspecified (which defaults to None).
             */
            mountPropagation?: pulumi.Input<string>;
            /**
             * This must match the Name of a Volume.
             */
            name: pulumi.Input<string>;
            /**
             * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * RecursiveReadOnly specifies whether read-only mounts should be handled recursively.
             *
             * If ReadOnly is false, this field has no meaning and must be unspecified.
             *
             * If ReadOnly is true, and this field is set to Disabled, the mount is not made recursively read-only.  If this field is set to IfPossible, the mount is made recursively read-only, if it is supported by the container runtime.  If this field is set to Enabled, the mount is made recursively read-only if it is supported by the container runtime, otherwise the pod will not be started and an error will be generated to indicate the reason.
             *
             * If this field is set to IfPossible or Enabled, MountPropagation must be set to None (or be unspecified, which defaults to None).
             *
             * If this field is not specified, it is treated as an equivalent of Disabled.
             */
            recursiveReadOnly?: pulumi.Input<string>;
            /**
             * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
             */
            subPath?: pulumi.Input<string>;
            /**
             * Expanded path within the volume from which the container's volume should be mounted. Behaves similarly to SubPath but environment variable references $(VAR_NAME) are expanded using the container's environment. Defaults to "" (volume's root). SubPathExpr and SubPath are mutually exclusive.
             */
            subPathExpr?: pulumi.Input<string>;
        }
        /**
         * VolumeMount describes a mounting of a Volume within a container.
         */
        interface VolumeMountPatch {
            /**
             * Path within the container at which the volume should be mounted.  Must not contain ':'.
             */
            mountPath?: pulumi.Input<string>;
            /**
             * mountPropagation determines how mounts are propagated from the host to container and the other way around. When not set, MountPropagationNone is used. This field is beta in 1.10. When RecursiveReadOnly is set to IfPossible or to Enabled, MountPropagation must be None or unspecified (which defaults to None).
             */
            mountPropagation?: pulumi.Input<string>;
            /**
             * This must match the Name of a Volume.
             */
            name?: pulumi.Input<string>;
            /**
             * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * RecursiveReadOnly specifies whether read-only mounts should be handled recursively.
             *
             * If ReadOnly is false, this field has no meaning and must be unspecified.
             *
             * If ReadOnly is true, and this field is set to Disabled, the mount is not made recursively read-only.  If this field is set to IfPossible, the mount is made recursively read-only, if it is supported by the container runtime.  If this field is set to Enabled, the mount is made recursively read-only if it is supported by the container runtime, otherwise the pod will not be started and an error will be generated to indicate the reason.
             *
             * If this field is set to IfPossible or Enabled, MountPropagation must be set to None (or be unspecified, which defaults to None).
             *
             * If this field is not specified, it is treated as an equivalent of Disabled.
             */
            recursiveReadOnly?: pulumi.Input<string>;
            /**
             * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
             */
            subPath?: pulumi.Input<string>;
            /**
             * Expanded path within the volume from which the container's volume should be mounted. Behaves similarly to SubPath but environment variable references $(VAR_NAME) are expanded using the container's environment. Defaults to "" (volume's root). SubPathExpr and SubPath are mutually exclusive.
             */
            subPathExpr?: pulumi.Input<string>;
        }
        /**
         * VolumeMountStatus shows status of volume mounts.
         */
        interface VolumeMountStatus {
            /**
             * MountPath corresponds to the original VolumeMount.
             */
            mountPath: pulumi.Input<string>;
            /**
             * Name corresponds to the name of the original VolumeMount.
             */
            name: pulumi.Input<string>;
            /**
             * ReadOnly corresponds to the original VolumeMount.
             */
            readOnly?: pulumi.Input<boolean>;
            /**
             * RecursiveReadOnly must be set to Disabled, Enabled, or unspecified (for non-readonly mounts). An IfPossible value in the original VolumeMount must be translated to Disabled or Enabled, depending on the mount result.
             */
            recursiveReadOnly?: pulumi.Input<string>;
        }
        /**
         * VolumeNodeAffinity defines constraints that limit what nodes this volume can be accessed from.
         */
        interface VolumeNodeAffinity {
            /**
             * required specifies hard node constraints that must be met.
             */
            required?: pulumi.Input<inputs.core.v1.NodeSelector>;
        }
        /**
         * VolumeNodeAffinity defines constraints that limit what nodes this volume can be accessed from.
         */
        interface VolumeNodeAffinityPatch {
            /**
             * required specifies hard node constraints that must be met.
             */
            required?: pulumi.Input<inputs.core.v1.NodeSelectorPatch>;
        }
        /**
         * Volume represents a named volume in a pod that may be accessed by any container in the pod.
         */
        interface VolumePatch {
            /**
             * awsElasticBlockStore represents an AWS Disk resource that is attached to a kubelet's host machine and then exposed to the pod. Deprecated: AWSElasticBlockStore is deprecated. All operations for the in-tree awsElasticBlockStore type are redirected to the ebs.csi.aws.com CSI driver. More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore
             */
            awsElasticBlockStore?: pulumi.Input<inputs.core.v1.AWSElasticBlockStoreVolumeSourcePatch>;
            /**
             * azureDisk represents an Azure Data Disk mount on the host and bind mount to the pod. Deprecated: AzureDisk is deprecated. All operations for the in-tree azureDisk type are redirected to the disk.csi.azure.com CSI driver.
             */
            azureDisk?: pulumi.Input<inputs.core.v1.AzureDiskVolumeSourcePatch>;
            /**
             * azureFile represents an Azure File Service mount on the host and bind mount to the pod. Deprecated: AzureFile is deprecated. All operations for the in-tree azureFile type are redirected to the file.csi.azure.com CSI driver.
             */
            azureFile?: pulumi.Input<inputs.core.v1.AzureFileVolumeSourcePatch>;
            /**
             * cephFS represents a Ceph FS mount on the host that shares a pod's lifetime. Deprecated: CephFS is deprecated and the in-tree cephfs type is no longer supported.
             */
            cephfs?: pulumi.Input<inputs.core.v1.CephFSVolumeSourcePatch>;
            /**
             * cinder represents a cinder volume attached and mounted on kubelets host machine. Deprecated: Cinder is deprecated. All operations for the in-tree cinder type are redirected to the cinder.csi.openstack.org CSI driver. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
             */
            cinder?: pulumi.Input<inputs.core.v1.CinderVolumeSourcePatch>;
            /**
             * configMap represents a configMap that should populate this volume
             */
            configMap?: pulumi.Input<inputs.core.v1.ConfigMapVolumeSourcePatch>;
            /**
             * csi (Container Storage Interface) represents ephemeral storage that is handled by certain external CSI drivers.
             */
            csi?: pulumi.Input<inputs.core.v1.CSIVolumeSourcePatch>;
            /**
             * downwardAPI represents downward API about the pod that should populate this volume
             */
            downwardAPI?: pulumi.Input<inputs.core.v1.DownwardAPIVolumeSourcePatch>;
            /**
             * emptyDir represents a temporary directory that shares a pod's lifetime. More info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir
             */
            emptyDir?: pulumi.Input<inputs.core.v1.EmptyDirVolumeSourcePatch>;
            /**
             * ephemeral represents a volume that is handled by a cluster storage driver. The volume's lifecycle is tied to the pod that defines it - it will be created before the pod starts, and deleted when the pod is removed.
             *
             * Use this if: a) the volume is only needed while the pod runs, b) features of normal volumes like restoring from snapshot or capacity
             *    tracking are needed,
             * c) the storage driver is specified through a storage class, and d) the storage driver supports dynamic volume provisioning through
             *    a PersistentVolumeClaim (see EphemeralVolumeSource for more
             *    information on the connection between this volume type
             *    and PersistentVolumeClaim).
             *
             * Use PersistentVolumeClaim or one of the vendor-specific APIs for volumes that persist for longer than the lifecycle of an individual pod.
             *
             * Use CSI for light-weight local ephemeral volumes if the CSI driver is meant to be used that way - see the documentation of the driver for more information.
             *
             * A pod can use both types of ephemeral volumes and persistent volumes at the same time.
             */
            ephemeral?: pulumi.Input<inputs.core.v1.EphemeralVolumeSourcePatch>;
            /**
             * fc represents a Fibre Channel resource that is attached to a kubelet's host machine and then exposed to the pod.
             */
            fc?: pulumi.Input<inputs.core.v1.FCVolumeSourcePatch>;
            /**
             * flexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin. Deprecated: FlexVolume is deprecated. Consider using a CSIDriver instead.
             */
            flexVolume?: pulumi.Input<inputs.core.v1.FlexVolumeSourcePatch>;
            /**
             * flocker represents a Flocker volume attached to a kubelet's host machine. This depends on the Flocker control service being running. Deprecated: Flocker is deprecated and the in-tree flocker type is no longer supported.
             */
            flocker?: pulumi.Input<inputs.core.v1.FlockerVolumeSourcePatch>;
            /**
             * gcePersistentDisk represents a GCE Disk resource that is attached to a kubelet's host machine and then exposed to the pod. Deprecated: GCEPersistentDisk is deprecated. All operations for the in-tree gcePersistentDisk type are redirected to the pd.csi.storage.gke.io CSI driver. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk
             */
            gcePersistentDisk?: pulumi.Input<inputs.core.v1.GCEPersistentDiskVolumeSourcePatch>;
            /**
             * gitRepo represents a git repository at a particular revision. Deprecated: GitRepo is deprecated. To provision a container with a git repo, mount an EmptyDir into an InitContainer that clones the repo using git, then mount the EmptyDir into the Pod's container.
             */
            gitRepo?: pulumi.Input<inputs.core.v1.GitRepoVolumeSourcePatch>;
            /**
             * glusterfs represents a Glusterfs mount on the host that shares a pod's lifetime. Deprecated: Glusterfs is deprecated and the in-tree glusterfs type is no longer supported. More info: https://examples.k8s.io/volumes/glusterfs/README.md
             */
            glusterfs?: pulumi.Input<inputs.core.v1.GlusterfsVolumeSourcePatch>;
            /**
             * hostPath represents a pre-existing file or directory on the host machine that is directly exposed to the container. This is generally used for system agents or other privileged things that are allowed to see the host machine. Most containers will NOT need this. More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath
             */
            hostPath?: pulumi.Input<inputs.core.v1.HostPathVolumeSourcePatch>;
            /**
             * image represents an OCI object (a container image or artifact) pulled and mounted on the kubelet's host machine. The volume is resolved at pod startup depending on which PullPolicy value is provided:
             *
             * - Always: the kubelet always attempts to pull the reference. Container creation will fail If the pull fails. - Never: the kubelet never pulls the reference and only uses a local image or artifact. Container creation will fail if the reference isn't present. - IfNotPresent: the kubelet pulls if the reference isn't already present on disk. Container creation will fail if the reference isn't present and the pull fails.
             *
             * The volume gets re-resolved if the pod gets deleted and recreated, which means that new remote content will become available on pod recreation. A failure to resolve or pull the image during pod startup will block containers from starting and may add significant latency. Failures will be retried using normal volume backoff and will be reported on the pod reason and message. The types of objects that may be mounted by this volume are defined by the container runtime implementation on a host machine and at minimum must include all valid types supported by the container image field. The OCI object gets mounted in a single directory (spec.containers[*].volumeMounts.mountPath) by merging the manifest layers in the same way as for container images. The volume will be mounted read-only (ro) and non-executable files (noexec). Sub path mounts for containers are not supported (spec.containers[*].volumeMounts.subpath) before 1.33. The field spec.securityContext.fsGroupChangePolicy has no effect on this volume type.
             */
            image?: pulumi.Input<inputs.core.v1.ImageVolumeSourcePatch>;
            /**
             * iscsi represents an ISCSI Disk resource that is attached to a kubelet's host machine and then exposed to the pod. More info: https://examples.k8s.io/volumes/iscsi/README.md
             */
            iscsi?: pulumi.Input<inputs.core.v1.ISCSIVolumeSourcePatch>;
            /**
             * name of the volume. Must be a DNS_LABEL and unique within the pod. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name?: pulumi.Input<string>;
            /**
             * nfs represents an NFS mount on the host that shares a pod's lifetime More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs
             */
            nfs?: pulumi.Input<inputs.core.v1.NFSVolumeSourcePatch>;
            /**
             * persistentVolumeClaimVolumeSource represents a reference to a PersistentVolumeClaim in the same namespace. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims
             */
            persistentVolumeClaim?: pulumi.Input<inputs.core.v1.PersistentVolumeClaimVolumeSourcePatch>;
            /**
             * photonPersistentDisk represents a PhotonController persistent disk attached and mounted on kubelets host machine. Deprecated: PhotonPersistentDisk is deprecated and the in-tree photonPersistentDisk type is no longer supported.
             */
            photonPersistentDisk?: pulumi.Input<inputs.core.v1.PhotonPersistentDiskVolumeSourcePatch>;
            /**
             * portworxVolume represents a portworx volume attached and mounted on kubelets host machine. Deprecated: PortworxVolume is deprecated. All operations for the in-tree portworxVolume type are redirected to the pxd.portworx.com CSI driver when the CSIMigrationPortworx feature-gate is on.
             */
            portworxVolume?: pulumi.Input<inputs.core.v1.PortworxVolumeSourcePatch>;
            /**
             * projected items for all in one resources secrets, configmaps, and downward API
             */
            projected?: pulumi.Input<inputs.core.v1.ProjectedVolumeSourcePatch>;
            /**
             * quobyte represents a Quobyte mount on the host that shares a pod's lifetime. Deprecated: Quobyte is deprecated and the in-tree quobyte type is no longer supported.
             */
            quobyte?: pulumi.Input<inputs.core.v1.QuobyteVolumeSourcePatch>;
            /**
             * rbd represents a Rados Block Device mount on the host that shares a pod's lifetime. Deprecated: RBD is deprecated and the in-tree rbd type is no longer supported. More info: https://examples.k8s.io/volumes/rbd/README.md
             */
            rbd?: pulumi.Input<inputs.core.v1.RBDVolumeSourcePatch>;
            /**
             * scaleIO represents a ScaleIO persistent volume attached and mounted on Kubernetes nodes. Deprecated: ScaleIO is deprecated and the in-tree scaleIO type is no longer supported.
             */
            scaleIO?: pulumi.Input<inputs.core.v1.ScaleIOVolumeSourcePatch>;
            /**
             * secret represents a secret that should populate this volume. More info: https://kubernetes.io/docs/concepts/storage/volumes#secret
             */
            secret?: pulumi.Input<inputs.core.v1.SecretVolumeSourcePatch>;
            /**
             * storageOS represents a StorageOS volume attached and mounted on Kubernetes nodes. Deprecated: StorageOS is deprecated and the in-tree storageos type is no longer supported.
             */
            storageos?: pulumi.Input<inputs.core.v1.StorageOSVolumeSourcePatch>;
            /**
             * vsphereVolume represents a vSphere volume attached and mounted on kubelets host machine. Deprecated: VsphereVolume is deprecated. All operations for the in-tree vsphereVolume type are redirected to the csi.vsphere.vmware.com CSI driver.
             */
            vsphereVolume?: pulumi.Input<inputs.core.v1.VsphereVirtualDiskVolumeSourcePatch>;
        }
        /**
         * Projection that may be projected along with other supported volume types. Exactly one of these fields must be set.
         */
        interface VolumeProjection {
            /**
             * ClusterTrustBundle allows a pod to access the `.spec.trustBundle` field of ClusterTrustBundle objects in an auto-updating file.
             *
             * Alpha, gated by the ClusterTrustBundleProjection feature gate.
             *
             * ClusterTrustBundle objects can either be selected by name, or by the combination of signer name and a label selector.
             *
             * Kubelet performs aggressive normalization of the PEM contents written into the pod filesystem.  Esoteric PEM features such as inter-block comments and block headers are stripped.  Certificates are deduplicated. The ordering of certificates within the file is arbitrary, and Kubelet may change the order over time.
             */
            clusterTrustBundle?: pulumi.Input<inputs.core.v1.ClusterTrustBundleProjection>;
            /**
             * configMap information about the configMap data to project
             */
            configMap?: pulumi.Input<inputs.core.v1.ConfigMapProjection>;
            /**
             * downwardAPI information about the downwardAPI data to project
             */
            downwardAPI?: pulumi.Input<inputs.core.v1.DownwardAPIProjection>;
            /**
             * secret information about the secret data to project
             */
            secret?: pulumi.Input<inputs.core.v1.SecretProjection>;
            /**
             * serviceAccountToken is information about the serviceAccountToken data to project
             */
            serviceAccountToken?: pulumi.Input<inputs.core.v1.ServiceAccountTokenProjection>;
        }
        /**
         * Projection that may be projected along with other supported volume types. Exactly one of these fields must be set.
         */
        interface VolumeProjectionPatch {
            /**
             * ClusterTrustBundle allows a pod to access the `.spec.trustBundle` field of ClusterTrustBundle objects in an auto-updating file.
             *
             * Alpha, gated by the ClusterTrustBundleProjection feature gate.
             *
             * ClusterTrustBundle objects can either be selected by name, or by the combination of signer name and a label selector.
             *
             * Kubelet performs aggressive normalization of the PEM contents written into the pod filesystem.  Esoteric PEM features such as inter-block comments and block headers are stripped.  Certificates are deduplicated. The ordering of certificates within the file is arbitrary, and Kubelet may change the order over time.
             */
            clusterTrustBundle?: pulumi.Input<inputs.core.v1.ClusterTrustBundleProjectionPatch>;
            /**
             * configMap information about the configMap data to project
             */
            configMap?: pulumi.Input<inputs.core.v1.ConfigMapProjectionPatch>;
            /**
             * downwardAPI information about the downwardAPI data to project
             */
            downwardAPI?: pulumi.Input<inputs.core.v1.DownwardAPIProjectionPatch>;
            /**
             * secret information about the secret data to project
             */
            secret?: pulumi.Input<inputs.core.v1.SecretProjectionPatch>;
            /**
             * serviceAccountToken is information about the serviceAccountToken data to project
             */
            serviceAccountToken?: pulumi.Input<inputs.core.v1.ServiceAccountTokenProjectionPatch>;
        }
        /**
         * VolumeResourceRequirements describes the storage resource requirements for a volume.
         */
        interface VolumeResourceRequirements {
            /**
             * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
             */
            limits?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. Requests cannot exceed Limits. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
             */
            requests?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * VolumeResourceRequirements describes the storage resource requirements for a volume.
         */
        interface VolumeResourceRequirementsPatch {
            /**
             * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
             */
            limits?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. Requests cannot exceed Limits. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
             */
            requests?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * Represents a vSphere volume resource.
         */
        interface VsphereVirtualDiskVolumeSource {
            /**
             * fsType is filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * storagePolicyID is the storage Policy Based Management (SPBM) profile ID associated with the StoragePolicyName.
             */
            storagePolicyID?: pulumi.Input<string>;
            /**
             * storagePolicyName is the storage Policy Based Management (SPBM) profile name.
             */
            storagePolicyName?: pulumi.Input<string>;
            /**
             * volumePath is the path that identifies vSphere volume vmdk
             */
            volumePath: pulumi.Input<string>;
        }
        /**
         * Represents a vSphere volume resource.
         */
        interface VsphereVirtualDiskVolumeSourcePatch {
            /**
             * fsType is filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
             */
            fsType?: pulumi.Input<string>;
            /**
             * storagePolicyID is the storage Policy Based Management (SPBM) profile ID associated with the StoragePolicyName.
             */
            storagePolicyID?: pulumi.Input<string>;
            /**
             * storagePolicyName is the storage Policy Based Management (SPBM) profile name.
             */
            storagePolicyName?: pulumi.Input<string>;
            /**
             * volumePath is the path that identifies vSphere volume vmdk
             */
            volumePath?: pulumi.Input<string>;
        }
        /**
         * The weights of all of the matched WeightedPodAffinityTerm fields are added per-node to find the most preferred node(s)
         */
        interface WeightedPodAffinityTerm {
            /**
             * Required. A pod affinity term, associated with the corresponding weight.
             */
            podAffinityTerm: pulumi.Input<inputs.core.v1.PodAffinityTerm>;
            /**
             * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
             */
            weight: pulumi.Input<number>;
        }
        /**
         * The weights of all of the matched WeightedPodAffinityTerm fields are added per-node to find the most preferred node(s)
         */
        interface WeightedPodAffinityTermPatch {
            /**
             * Required. A pod affinity term, associated with the corresponding weight.
             */
            podAffinityTerm?: pulumi.Input<inputs.core.v1.PodAffinityTermPatch>;
            /**
             * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
             */
            weight?: pulumi.Input<number>;
        }
        /**
         * WindowsSecurityContextOptions contain Windows-specific options and credentials.
         */
        interface WindowsSecurityContextOptions {
            /**
             * GMSACredentialSpec is where the GMSA admission webhook (https://github.com/kubernetes-sigs/windows-gmsa) inlines the contents of the GMSA credential spec named by the GMSACredentialSpecName field.
             */
            gmsaCredentialSpec?: pulumi.Input<string>;
            /**
             * GMSACredentialSpecName is the name of the GMSA credential spec to use.
             */
            gmsaCredentialSpecName?: pulumi.Input<string>;
            /**
             * HostProcess determines if a container should be run as a 'Host Process' container. All of a Pod's containers must have the same effective HostProcess value (it is not allowed to have a mix of HostProcess containers and non-HostProcess containers). In addition, if HostProcess is true then HostNetwork must also be set to true.
             */
            hostProcess?: pulumi.Input<boolean>;
            /**
             * The UserName in Windows to run the entrypoint of the container process. Defaults to the user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
             */
            runAsUserName?: pulumi.Input<string>;
        }
        /**
         * WindowsSecurityContextOptions contain Windows-specific options and credentials.
         */
        interface WindowsSecurityContextOptionsPatch {
            /**
             * GMSACredentialSpec is where the GMSA admission webhook (https://github.com/kubernetes-sigs/windows-gmsa) inlines the contents of the GMSA credential spec named by the GMSACredentialSpecName field.
             */
            gmsaCredentialSpec?: pulumi.Input<string>;
            /**
             * GMSACredentialSpecName is the name of the GMSA credential spec to use.
             */
            gmsaCredentialSpecName?: pulumi.Input<string>;
            /**
             * HostProcess determines if a container should be run as a 'Host Process' container. All of a Pod's containers must have the same effective HostProcess value (it is not allowed to have a mix of HostProcess containers and non-HostProcess containers). In addition, if HostProcess is true then HostNetwork must also be set to true.
             */
            hostProcess?: pulumi.Input<boolean>;
            /**
             * The UserName in Windows to run the entrypoint of the container process. Defaults to the user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
             */
            runAsUserName?: pulumi.Input<string>;
        }
    }
}
export declare namespace discovery {
    namespace v1 {
        /**
         * Endpoint represents a single logical "backend" implementing a service.
         */
        interface Endpoint {
            /**
             * addresses of this endpoint. For EndpointSlices of addressType "IPv4" or "IPv6", the values are IP addresses in canonical form. The syntax and semantics of other addressType values are not defined. This must contain at least one address but no more than 100. EndpointSlices generated by the EndpointSlice controller will always have exactly 1 address. No semantics are defined for additional addresses beyond the first, and kube-proxy does not look at them.
             */
            addresses: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * conditions contains information about the current status of the endpoint.
             */
            conditions?: pulumi.Input<inputs.discovery.v1.EndpointConditions>;
            /**
             * deprecatedTopology contains topology information part of the v1beta1 API. This field is deprecated, and will be removed when the v1beta1 API is removed (no sooner than kubernetes v1.24).  While this field can hold values, it is not writable through the v1 API, and any attempts to write to it will be silently ignored. Topology information can be found in the zone and nodeName fields instead.
             */
            deprecatedTopology?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * hints contains information associated with how an endpoint should be consumed.
             */
            hints?: pulumi.Input<inputs.discovery.v1.EndpointHints>;
            /**
             * hostname of this endpoint. This field may be used by consumers of endpoints to distinguish endpoints from each other (e.g. in DNS names). Multiple endpoints which use the same hostname should be considered fungible (e.g. multiple A values in DNS). Must be lowercase and pass DNS Label (RFC 1123) validation.
             */
            hostname?: pulumi.Input<string>;
            /**
             * nodeName represents the name of the Node hosting this endpoint. This can be used to determine endpoints local to a Node.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * targetRef is a reference to a Kubernetes object that represents this endpoint.
             */
            targetRef?: pulumi.Input<inputs.core.v1.ObjectReference>;
            /**
             * zone is the name of the Zone this endpoint exists in.
             */
            zone?: pulumi.Input<string>;
        }
        /**
         * EndpointConditions represents the current condition of an endpoint.
         */
        interface EndpointConditions {
            /**
             * ready indicates that this endpoint is ready to receive traffic, according to whatever system is managing the endpoint. A nil value should be interpreted as "true". In general, an endpoint should be marked ready if it is serving and not terminating, though this can be overridden in some cases, such as when the associated Service has set the publishNotReadyAddresses flag.
             */
            ready?: pulumi.Input<boolean>;
            /**
             * serving indicates that this endpoint is able to receive traffic, according to whatever system is managing the endpoint. For endpoints backed by pods, the EndpointSlice controller will mark the endpoint as serving if the pod's Ready condition is True. A nil value should be interpreted as "true".
             */
            serving?: pulumi.Input<boolean>;
            /**
             * terminating indicates that this endpoint is terminating. A nil value should be interpreted as "false".
             */
            terminating?: pulumi.Input<boolean>;
        }
        /**
         * EndpointConditions represents the current condition of an endpoint.
         */
        interface EndpointConditionsPatch {
            /**
             * ready indicates that this endpoint is ready to receive traffic, according to whatever system is managing the endpoint. A nil value should be interpreted as "true". In general, an endpoint should be marked ready if it is serving and not terminating, though this can be overridden in some cases, such as when the associated Service has set the publishNotReadyAddresses flag.
             */
            ready?: pulumi.Input<boolean>;
            /**
             * serving indicates that this endpoint is able to receive traffic, according to whatever system is managing the endpoint. For endpoints backed by pods, the EndpointSlice controller will mark the endpoint as serving if the pod's Ready condition is True. A nil value should be interpreted as "true".
             */
            serving?: pulumi.Input<boolean>;
            /**
             * terminating indicates that this endpoint is terminating. A nil value should be interpreted as "false".
             */
            terminating?: pulumi.Input<boolean>;
        }
        /**
         * EndpointHints provides hints describing how an endpoint should be consumed.
         */
        interface EndpointHints {
            /**
             * forNodes indicates the node(s) this endpoint should be consumed by when using topology aware routing. May contain a maximum of 8 entries. This is an Alpha feature and is only used when the PreferSameTrafficDistribution feature gate is enabled.
             */
            forNodes?: pulumi.Input<pulumi.Input<inputs.discovery.v1.ForNode>[]>;
            /**
             * forZones indicates the zone(s) this endpoint should be consumed by when using topology aware routing. May contain a maximum of 8 entries.
             */
            forZones?: pulumi.Input<pulumi.Input<inputs.discovery.v1.ForZone>[]>;
        }
        /**
         * EndpointHints provides hints describing how an endpoint should be consumed.
         */
        interface EndpointHintsPatch {
            /**
             * forNodes indicates the node(s) this endpoint should be consumed by when using topology aware routing. May contain a maximum of 8 entries. This is an Alpha feature and is only used when the PreferSameTrafficDistribution feature gate is enabled.
             */
            forNodes?: pulumi.Input<pulumi.Input<inputs.discovery.v1.ForNodePatch>[]>;
            /**
             * forZones indicates the zone(s) this endpoint should be consumed by when using topology aware routing. May contain a maximum of 8 entries.
             */
            forZones?: pulumi.Input<pulumi.Input<inputs.discovery.v1.ForZonePatch>[]>;
        }
        /**
         * Endpoint represents a single logical "backend" implementing a service.
         */
        interface EndpointPatch {
            /**
             * addresses of this endpoint. For EndpointSlices of addressType "IPv4" or "IPv6", the values are IP addresses in canonical form. The syntax and semantics of other addressType values are not defined. This must contain at least one address but no more than 100. EndpointSlices generated by the EndpointSlice controller will always have exactly 1 address. No semantics are defined for additional addresses beyond the first, and kube-proxy does not look at them.
             */
            addresses?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * conditions contains information about the current status of the endpoint.
             */
            conditions?: pulumi.Input<inputs.discovery.v1.EndpointConditionsPatch>;
            /**
             * deprecatedTopology contains topology information part of the v1beta1 API. This field is deprecated, and will be removed when the v1beta1 API is removed (no sooner than kubernetes v1.24).  While this field can hold values, it is not writable through the v1 API, and any attempts to write to it will be silently ignored. Topology information can be found in the zone and nodeName fields instead.
             */
            deprecatedTopology?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * hints contains information associated with how an endpoint should be consumed.
             */
            hints?: pulumi.Input<inputs.discovery.v1.EndpointHintsPatch>;
            /**
             * hostname of this endpoint. This field may be used by consumers of endpoints to distinguish endpoints from each other (e.g. in DNS names). Multiple endpoints which use the same hostname should be considered fungible (e.g. multiple A values in DNS). Must be lowercase and pass DNS Label (RFC 1123) validation.
             */
            hostname?: pulumi.Input<string>;
            /**
             * nodeName represents the name of the Node hosting this endpoint. This can be used to determine endpoints local to a Node.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * targetRef is a reference to a Kubernetes object that represents this endpoint.
             */
            targetRef?: pulumi.Input<inputs.core.v1.ObjectReferencePatch>;
            /**
             * zone is the name of the Zone this endpoint exists in.
             */
            zone?: pulumi.Input<string>;
        }
        /**
         * EndpointPort represents a Port used by an EndpointSlice
         */
        interface EndpointPort {
            /**
             * The application protocol for this port. This is used as a hint for implementations to offer richer behavior for protocols that they understand. This field follows standard Kubernetes label syntax. Valid values are either:
             *
             * * Un-prefixed protocol names - reserved for IANA standard service names (as per RFC-6335 and https://www.iana.org/assignments/service-names).
             *
             * * Kubernetes-defined prefixed names:
             *   * 'kubernetes.io/h2c' - HTTP/2 prior knowledge over cleartext as described in https://www.rfc-editor.org/rfc/rfc9113.html#name-starting-http-2-with-prior-
             *   * 'kubernetes.io/ws'  - WebSocket over cleartext as described in https://www.rfc-editor.org/rfc/rfc6455
             *   * 'kubernetes.io/wss' - WebSocket over TLS as described in https://www.rfc-editor.org/rfc/rfc6455
             *
             * * Other protocols should use implementation-defined prefixed names such as mycompany.com/my-custom-protocol.
             */
            appProtocol?: pulumi.Input<string>;
            /**
             * name represents the name of this port. All ports in an EndpointSlice must have a unique name. If the EndpointSlice is derived from a Kubernetes service, this corresponds to the Service.ports[].name. Name must either be an empty string or pass DNS_LABEL validation: * must be no more than 63 characters long. * must consist of lower case alphanumeric characters or '-'. * must start and end with an alphanumeric character. Default is empty string.
             */
            name?: pulumi.Input<string>;
            /**
             * port represents the port number of the endpoint. If the EndpointSlice is derived from a Kubernetes service, this must be set to the service's target port. EndpointSlices used for other purposes may have a nil port.
             */
            port?: pulumi.Input<number>;
            /**
             * protocol represents the IP protocol for this port. Must be UDP, TCP, or SCTP. Default is TCP.
             */
            protocol?: pulumi.Input<string>;
        }
        /**
         * EndpointPort represents a Port used by an EndpointSlice
         */
        interface EndpointPortPatch {
            /**
             * The application protocol for this port. This is used as a hint for implementations to offer richer behavior for protocols that they understand. This field follows standard Kubernetes label syntax. Valid values are either:
             *
             * * Un-prefixed protocol names - reserved for IANA standard service names (as per RFC-6335 and https://www.iana.org/assignments/service-names).
             *
             * * Kubernetes-defined prefixed names:
             *   * 'kubernetes.io/h2c' - HTTP/2 prior knowledge over cleartext as described in https://www.rfc-editor.org/rfc/rfc9113.html#name-starting-http-2-with-prior-
             *   * 'kubernetes.io/ws'  - WebSocket over cleartext as described in https://www.rfc-editor.org/rfc/rfc6455
             *   * 'kubernetes.io/wss' - WebSocket over TLS as described in https://www.rfc-editor.org/rfc/rfc6455
             *
             * * Other protocols should use implementation-defined prefixed names such as mycompany.com/my-custom-protocol.
             */
            appProtocol?: pulumi.Input<string>;
            /**
             * name represents the name of this port. All ports in an EndpointSlice must have a unique name. If the EndpointSlice is derived from a Kubernetes service, this corresponds to the Service.ports[].name. Name must either be an empty string or pass DNS_LABEL validation: * must be no more than 63 characters long. * must consist of lower case alphanumeric characters or '-'. * must start and end with an alphanumeric character. Default is empty string.
             */
            name?: pulumi.Input<string>;
            /**
             * port represents the port number of the endpoint. If the EndpointSlice is derived from a Kubernetes service, this must be set to the service's target port. EndpointSlices used for other purposes may have a nil port.
             */
            port?: pulumi.Input<number>;
            /**
             * protocol represents the IP protocol for this port. Must be UDP, TCP, or SCTP. Default is TCP.
             */
            protocol?: pulumi.Input<string>;
        }
        /**
         * EndpointSlice represents a set of service endpoints. Most EndpointSlices are created by the EndpointSlice controller to represent the Pods selected by Service objects. For a given service there may be multiple EndpointSlice objects which must be joined to produce the full set of endpoints; you can find all of the slices for a given service by listing EndpointSlices in the service's namespace whose `kubernetes.io/service-name` label contains the service's name.
         */
        interface EndpointSlice {
            /**
             * addressType specifies the type of address carried by this EndpointSlice. All addresses in this slice must be the same type. This field is immutable after creation. The following address types are currently supported: * IPv4: Represents an IPv4 Address. * IPv6: Represents an IPv6 Address. * FQDN: Represents a Fully Qualified Domain Name. (Deprecated) The EndpointSlice controller only generates, and kube-proxy only processes, slices of addressType "IPv4" and "IPv6". No semantics are defined for the "FQDN" type.
             */
            addressType: pulumi.Input<string>;
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"discovery.k8s.io/v1">;
            /**
             * endpoints is a list of unique endpoints in this slice. Each slice may include a maximum of 1000 endpoints.
             */
            endpoints: pulumi.Input<pulumi.Input<inputs.discovery.v1.Endpoint>[]>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"EndpointSlice">;
            /**
             * Standard object's metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * ports specifies the list of network ports exposed by each endpoint in this slice. Each port must have a unique name. Each slice may include a maximum of 100 ports. Services always have at least 1 port, so EndpointSlices generated by the EndpointSlice controller will likewise always have at least 1 port. EndpointSlices used for other purposes may have an empty ports list.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.discovery.v1.EndpointPort>[]>;
        }
        /**
         * ForNode provides information about which nodes should consume this endpoint.
         */
        interface ForNode {
            /**
             * name represents the name of the node.
             */
            name: pulumi.Input<string>;
        }
        /**
         * ForNode provides information about which nodes should consume this endpoint.
         */
        interface ForNodePatch {
            /**
             * name represents the name of the node.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * ForZone provides information about which zones should consume this endpoint.
         */
        interface ForZone {
            /**
             * name represents the name of the zone.
             */
            name: pulumi.Input<string>;
        }
        /**
         * ForZone provides information about which zones should consume this endpoint.
         */
        interface ForZonePatch {
            /**
             * name represents the name of the zone.
             */
            name?: pulumi.Input<string>;
        }
    }
    namespace v1beta1 {
        /**
         * Endpoint represents a single logical "backend" implementing a service.
         */
        interface Endpoint {
            /**
             * addresses of this endpoint. The contents of this field are interpreted according to the corresponding EndpointSlice addressType field. Consumers must handle different types of addresses in the context of their own capabilities. This must contain at least one address but no more than 100.
             */
            addresses: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * conditions contains information about the current status of the endpoint.
             */
            conditions?: pulumi.Input<inputs.discovery.v1beta1.EndpointConditions>;
            /**
             * hostname of this endpoint. This field may be used by consumers of endpoints to distinguish endpoints from each other (e.g. in DNS names). Multiple endpoints which use the same hostname should be considered fungible (e.g. multiple A values in DNS). Must pass DNS Label (RFC 1123) validation.
             */
            hostname?: pulumi.Input<string>;
            /**
             * nodeName represents the name of the Node hosting this endpoint. This can be used to determine endpoints local to a Node. This field can be enabled with the EndpointSliceNodeName feature gate.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * targetRef is a reference to a Kubernetes object that represents this endpoint.
             */
            targetRef?: pulumi.Input<inputs.core.v1.ObjectReference>;
            /**
             * topology contains arbitrary topology information associated with the endpoint. These key/value pairs must conform with the label format. https://kubernetes.io/docs/concepts/overview/working-with-objects/labels Topology may include a maximum of 16 key/value pairs. This includes, but is not limited to the following well known keys: * kubernetes.io/hostname: the value indicates the hostname of the node
             *   where the endpoint is located. This should match the corresponding
             *   node label.
             * * topology.kubernetes.io/zone: the value indicates the zone where the
             *   endpoint is located. This should match the corresponding node label.
             * * topology.kubernetes.io/region: the value indicates the region where the
             *   endpoint is located. This should match the corresponding node label.
             */
            topology?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * EndpointConditions represents the current condition of an endpoint.
         */
        interface EndpointConditions {
            /**
             * ready indicates that this endpoint is prepared to receive traffic, according to whatever system is managing the endpoint. A nil value indicates an unknown state. In most cases consumers should interpret this unknown state as ready.
             */
            ready?: pulumi.Input<boolean>;
            /**
             * serving is identical to ready except that it is set regardless of the terminating state of endpoints. This condition should be set to true for a ready endpoint that is terminating. If nil, consumers should defer to the ready condition. This field can be enabled with the EndpointSliceTerminatingCondition feature gate.
             */
            serving?: pulumi.Input<boolean>;
            /**
             * terminating indicates that this endpoint is terminating. A nil value indicates an unknown state. Consumers should interpret this unknown state to mean that the endpoint is not terminating. This field can be enabled with the EndpointSliceTerminatingCondition feature gate.
             */
            terminating?: pulumi.Input<boolean>;
        }
        /**
         * EndpointConditions represents the current condition of an endpoint.
         */
        interface EndpointConditionsPatch {
            /**
             * ready indicates that this endpoint is prepared to receive traffic, according to whatever system is managing the endpoint. A nil value indicates an unknown state. In most cases consumers should interpret this unknown state as ready.
             */
            ready?: pulumi.Input<boolean>;
            /**
             * serving is identical to ready except that it is set regardless of the terminating state of endpoints. This condition should be set to true for a ready endpoint that is terminating. If nil, consumers should defer to the ready condition. This field can be enabled with the EndpointSliceTerminatingCondition feature gate.
             */
            serving?: pulumi.Input<boolean>;
            /**
             * terminating indicates that this endpoint is terminating. A nil value indicates an unknown state. Consumers should interpret this unknown state to mean that the endpoint is not terminating. This field can be enabled with the EndpointSliceTerminatingCondition feature gate.
             */
            terminating?: pulumi.Input<boolean>;
        }
        /**
         * Endpoint represents a single logical "backend" implementing a service.
         */
        interface EndpointPatch {
            /**
             * addresses of this endpoint. The contents of this field are interpreted according to the corresponding EndpointSlice addressType field. Consumers must handle different types of addresses in the context of their own capabilities. This must contain at least one address but no more than 100.
             */
            addresses?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * conditions contains information about the current status of the endpoint.
             */
            conditions?: pulumi.Input<inputs.discovery.v1beta1.EndpointConditionsPatch>;
            /**
             * hostname of this endpoint. This field may be used by consumers of endpoints to distinguish endpoints from each other (e.g. in DNS names). Multiple endpoints which use the same hostname should be considered fungible (e.g. multiple A values in DNS). Must pass DNS Label (RFC 1123) validation.
             */
            hostname?: pulumi.Input<string>;
            /**
             * nodeName represents the name of the Node hosting this endpoint. This can be used to determine endpoints local to a Node. This field can be enabled with the EndpointSliceNodeName feature gate.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * targetRef is a reference to a Kubernetes object that represents this endpoint.
             */
            targetRef?: pulumi.Input<inputs.core.v1.ObjectReferencePatch>;
            /**
             * topology contains arbitrary topology information associated with the endpoint. These key/value pairs must conform with the label format. https://kubernetes.io/docs/concepts/overview/working-with-objects/labels Topology may include a maximum of 16 key/value pairs. This includes, but is not limited to the following well known keys: * kubernetes.io/hostname: the value indicates the hostname of the node
             *   where the endpoint is located. This should match the corresponding
             *   node label.
             * * topology.kubernetes.io/zone: the value indicates the zone where the
             *   endpoint is located. This should match the corresponding node label.
             * * topology.kubernetes.io/region: the value indicates the region where the
             *   endpoint is located. This should match the corresponding node label.
             */
            topology?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * EndpointPort represents a Port used by an EndpointSlice
         */
        interface EndpointPort {
            /**
             * The application protocol for this port. This field follows standard Kubernetes label syntax. Un-prefixed names are reserved for IANA standard service names (as per RFC-6335 and http://www.iana.org/assignments/service-names). Non-standard protocols should use prefixed names. Default is empty string.
             */
            appProtocol?: pulumi.Input<string>;
            /**
             * The name of this port. All ports in an EndpointSlice must have a unique name. If the EndpointSlice is dervied from a Kubernetes service, this corresponds to the Service.ports[].name. Name must either be an empty string or pass DNS_LABEL validation: * must be no more than 63 characters long. * must consist of lower case alphanumeric characters or '-'. * must start and end with an alphanumeric character. Default is empty string.
             */
            name?: pulumi.Input<string>;
            /**
             * The port number of the endpoint. If this is not specified, ports are not restricted and must be interpreted in the context of the specific consumer.
             */
            port?: pulumi.Input<number>;
            /**
             * The IP protocol for this port. Must be UDP, TCP, or SCTP. Default is TCP.
             */
            protocol?: pulumi.Input<string>;
        }
        /**
         * EndpointPort represents a Port used by an EndpointSlice
         */
        interface EndpointPortPatch {
            /**
             * The application protocol for this port. This field follows standard Kubernetes label syntax. Un-prefixed names are reserved for IANA standard service names (as per RFC-6335 and http://www.iana.org/assignments/service-names). Non-standard protocols should use prefixed names. Default is empty string.
             */
            appProtocol?: pulumi.Input<string>;
            /**
             * The name of this port. All ports in an EndpointSlice must have a unique name. If the EndpointSlice is dervied from a Kubernetes service, this corresponds to the Service.ports[].name. Name must either be an empty string or pass DNS_LABEL validation: * must be no more than 63 characters long. * must consist of lower case alphanumeric characters or '-'. * must start and end with an alphanumeric character. Default is empty string.
             */
            name?: pulumi.Input<string>;
            /**
             * The port number of the endpoint. If this is not specified, ports are not restricted and must be interpreted in the context of the specific consumer.
             */
            port?: pulumi.Input<number>;
            /**
             * The IP protocol for this port. Must be UDP, TCP, or SCTP. Default is TCP.
             */
            protocol?: pulumi.Input<string>;
        }
        /**
         * EndpointSlice represents a subset of the endpoints that implement a service. For a given service there may be multiple EndpointSlice objects, selected by labels, which must be joined to produce the full set of endpoints.
         */
        interface EndpointSlice {
            /**
             * addressType specifies the type of address carried by this EndpointSlice. All addresses in this slice must be the same type. This field is immutable after creation. The following address types are currently supported: * IPv4: Represents an IPv4 Address. * IPv6: Represents an IPv6 Address. * FQDN: Represents a Fully Qualified Domain Name.
             */
            addressType: pulumi.Input<string>;
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"discovery.k8s.io/v1beta1">;
            /**
             * endpoints is a list of unique endpoints in this slice. Each slice may include a maximum of 1000 endpoints.
             */
            endpoints: pulumi.Input<pulumi.Input<inputs.discovery.v1beta1.Endpoint>[]>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"EndpointSlice">;
            /**
             * Standard object's metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * ports specifies the list of network ports exposed by each endpoint in this slice. Each port must have a unique name. When ports is empty, it indicates that there are no defined ports. When a port is defined with a nil port value, it indicates "all ports". Each slice may include a maximum of 100 ports.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.discovery.v1beta1.EndpointPort>[]>;
        }
    }
}
export declare namespace events {
    namespace v1 {
        /**
         * Event is a report of an event somewhere in the cluster. It generally denotes some state change in the system. Events have a limited retention time and triggers and messages may evolve with time.  Event consumers should not rely on the timing of an event with a given Reason reflecting a consistent underlying trigger, or the continued existence of events with that Reason.  Events should be treated as informative, best-effort, supplemental data.
         */
        interface Event {
            /**
             * action is what action was taken/failed regarding to the regarding object. It is machine-readable. This field cannot be empty for new Events and it can have at most 128 characters.
             */
            action?: pulumi.Input<string>;
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"events.k8s.io/v1">;
            /**
             * deprecatedCount is the deprecated field assuring backward compatibility with core.v1 Event type.
             */
            deprecatedCount?: pulumi.Input<number>;
            /**
             * deprecatedFirstTimestamp is the deprecated field assuring backward compatibility with core.v1 Event type.
             */
            deprecatedFirstTimestamp?: pulumi.Input<string>;
            /**
             * deprecatedLastTimestamp is the deprecated field assuring backward compatibility with core.v1 Event type.
             */
            deprecatedLastTimestamp?: pulumi.Input<string>;
            /**
             * deprecatedSource is the deprecated field assuring backward compatibility with core.v1 Event type.
             */
            deprecatedSource?: pulumi.Input<inputs.core.v1.EventSource>;
            /**
             * eventTime is the time when this Event was first observed. It is required.
             */
            eventTime: pulumi.Input<string>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Event">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * note is a human-readable description of the status of this operation. Maximal length of the note is 1kB, but libraries should be prepared to handle values up to 64kB.
             */
            note?: pulumi.Input<string>;
            /**
             * reason is why the action was taken. It is human-readable. This field cannot be empty for new Events and it can have at most 128 characters.
             */
            reason?: pulumi.Input<string>;
            /**
             * regarding contains the object this Event is about. In most cases it's an Object reporting controller implements, e.g. ReplicaSetController implements ReplicaSets and this event is emitted because it acts on some changes in a ReplicaSet object.
             */
            regarding?: pulumi.Input<inputs.core.v1.ObjectReference>;
            /**
             * related is the optional secondary object for more complex actions. E.g. when regarding object triggers a creation or deletion of related object.
             */
            related?: pulumi.Input<inputs.core.v1.ObjectReference>;
            /**
             * reportingController is the name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`. This field cannot be empty for new Events.
             */
            reportingController?: pulumi.Input<string>;
            /**
             * reportingInstance is the ID of the controller instance, e.g. `kubelet-xyzf`. This field cannot be empty for new Events and it can have at most 128 characters.
             */
            reportingInstance?: pulumi.Input<string>;
            /**
             * series is data about the Event series this event represents or nil if it's a singleton Event.
             */
            series?: pulumi.Input<inputs.events.v1.EventSeries>;
            /**
             * type is the type of this event (Normal, Warning), new types could be added in the future. It is machine-readable. This field cannot be empty for new Events.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * EventSeries contain information on series of events, i.e. thing that was/is happening continuously for some time. How often to update the EventSeries is up to the event reporters. The default event reporter in "k8s.io/client-go/tools/events/event_broadcaster.go" shows how this struct is updated on heartbeats and can guide customized reporter implementations.
         */
        interface EventSeries {
            /**
             * count is the number of occurrences in this series up to the last heartbeat time.
             */
            count: pulumi.Input<number>;
            /**
             * lastObservedTime is the time when last Event from the series was seen before last heartbeat.
             */
            lastObservedTime: pulumi.Input<string>;
        }
        /**
         * EventSeries contain information on series of events, i.e. thing that was/is happening continuously for some time. How often to update the EventSeries is up to the event reporters. The default event reporter in "k8s.io/client-go/tools/events/event_broadcaster.go" shows how this struct is updated on heartbeats and can guide customized reporter implementations.
         */
        interface EventSeriesPatch {
            /**
             * count is the number of occurrences in this series up to the last heartbeat time.
             */
            count?: pulumi.Input<number>;
            /**
             * lastObservedTime is the time when last Event from the series was seen before last heartbeat.
             */
            lastObservedTime?: pulumi.Input<string>;
        }
    }
    namespace v1beta1 {
        /**
         * Event is a report of an event somewhere in the cluster. It generally denotes some state change in the system.
         */
        interface Event {
            /**
             * What action was taken/failed regarding to the regarding object.
             */
            action?: pulumi.Input<string>;
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"events.k8s.io/v1beta1">;
            /**
             * Deprecated field assuring backward compatibility with core.v1 Event type
             */
            deprecatedCount?: pulumi.Input<number>;
            /**
             * Deprecated field assuring backward compatibility with core.v1 Event type
             */
            deprecatedFirstTimestamp?: pulumi.Input<string>;
            /**
             * Deprecated field assuring backward compatibility with core.v1 Event type
             */
            deprecatedLastTimestamp?: pulumi.Input<string>;
            /**
             * Deprecated field assuring backward compatibility with core.v1 Event type
             */
            deprecatedSource?: pulumi.Input<inputs.core.v1.EventSource>;
            /**
             * Required. Time when this Event was first observed.
             */
            eventTime: pulumi.Input<string>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Event">;
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Optional. A human-readable description of the status of this operation. Maximal length of the note is 1kB, but libraries should be prepared to handle values up to 64kB.
             */
            note?: pulumi.Input<string>;
            /**
             * Why the action was taken.
             */
            reason?: pulumi.Input<string>;
            /**
             * The object this Event is about. In most cases it's an Object reporting controller implements. E.g. ReplicaSetController implements ReplicaSets and this event is emitted because it acts on some changes in a ReplicaSet object.
             */
            regarding?: pulumi.Input<inputs.core.v1.ObjectReference>;
            /**
             * Optional secondary object for more complex actions. E.g. when regarding object triggers a creation or deletion of related object.
             */
            related?: pulumi.Input<inputs.core.v1.ObjectReference>;
            /**
             * Name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`.
             */
            reportingController?: pulumi.Input<string>;
            /**
             * ID of the controller instance, e.g. `kubelet-xyzf`.
             */
            reportingInstance?: pulumi.Input<string>;
            /**
             * Data about the Event series this event represents or nil if it's a singleton Event.
             */
            series?: pulumi.Input<inputs.events.v1beta1.EventSeries>;
            /**
             * Type of this event (Normal, Warning), new types could be added in the future.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * EventSeries contain information on series of events, i.e. thing that was/is happening continuously for some time.
         */
        interface EventSeries {
            /**
             * Number of occurrences in this series up to the last heartbeat time
             */
            count: pulumi.Input<number>;
            /**
             * Time when last Event from the series was seen before last heartbeat.
             */
            lastObservedTime: pulumi.Input<string>;
            /**
             * Information whether this series is ongoing or finished. Deprecated. Planned removal for 1.18
             */
            state: pulumi.Input<string>;
        }
        /**
         * EventSeries contain information on series of events, i.e. thing that was/is happening continuously for some time.
         */
        interface EventSeriesPatch {
            /**
             * Number of occurrences in this series up to the last heartbeat time
             */
            count?: pulumi.Input<number>;
            /**
             * Time when last Event from the series was seen before last heartbeat.
             */
            lastObservedTime?: pulumi.Input<string>;
            /**
             * Information whether this series is ongoing or finished. Deprecated. Planned removal for 1.18
             */
            state?: pulumi.Input<string>;
        }
    }
}
export declare namespace extensions {
    namespace v1beta1 {
        /**
         * AllowedCSIDriver represents a single inline CSI Driver that is allowed to be used.
         */
        interface AllowedCSIDriver {
            /**
             * Name is the registered name of the CSI driver
             */
            name: pulumi.Input<string>;
        }
        /**
         * AllowedCSIDriver represents a single inline CSI Driver that is allowed to be used.
         */
        interface AllowedCSIDriverPatch {
            /**
             * Name is the registered name of the CSI driver
             */
            name?: pulumi.Input<string>;
        }
        /**
         * AllowedFlexVolume represents a single Flexvolume that is allowed to be used. Deprecated: use AllowedFlexVolume from policy API Group instead.
         */
        interface AllowedFlexVolume {
            /**
             * driver is the name of the Flexvolume driver.
             */
            driver: pulumi.Input<string>;
        }
        /**
         * AllowedFlexVolume represents a single Flexvolume that is allowed to be used. Deprecated: use AllowedFlexVolume from policy API Group instead.
         */
        interface AllowedFlexVolumePatch {
            /**
             * driver is the name of the Flexvolume driver.
             */
            driver?: pulumi.Input<string>;
        }
        /**
         * AllowedHostPath defines the host volume conditions that will be enabled by a policy for pods to use. It requires the path prefix to be defined. Deprecated: use AllowedHostPath from policy API Group instead.
         */
        interface AllowedHostPath {
            /**
             * pathPrefix is the path prefix that the host volume must match. It does not support `*`. Trailing slashes are trimmed when validating the path prefix with a host path.
             *
             * Examples: `/foo` would allow `/foo`, `/foo/` and `/foo/bar` `/foo` would not allow `/food` or `/etc/foo`
             */
            pathPrefix?: pulumi.Input<string>;
            /**
             * when set to true, will allow host volumes matching the pathPrefix only if all volume mounts are readOnly.
             */
            readOnly?: pulumi.Input<boolean>;
        }
        /**
         * AllowedHostPath defines the host volume conditions that will be enabled by a policy for pods to use. It requires the path prefix to be defined. Deprecated: use AllowedHostPath from policy API Group instead.
         */
        interface AllowedHostPathPatch {
            /**
             * pathPrefix is the path prefix that the host volume must match. It does not support `*`. Trailing slashes are trimmed when validating the path prefix with a host path.
             *
             * Examples: `/foo` would allow `/foo`, `/foo/` and `/foo/bar` `/foo` would not allow `/food` or `/etc/foo`
             */
            pathPrefix?: pulumi.Input<string>;
            /**
             * when set to true, will allow host volumes matching the pathPrefix only if all volume mounts are readOnly.
             */
            readOnly?: pulumi.Input<boolean>;
        }
        /**
         * DaemonSet represents the configuration of a daemon set.
         */
        interface DaemonSet {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"extensions/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"DaemonSet">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * The desired behavior of this daemon set. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.extensions.v1beta1.DaemonSetSpec>;
            /**
             * The current status of this daemon set. This data may be out of date by some window of time. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.extensions.v1beta1.DaemonSetStatus>;
        }
        /**
         * DaemonSetCondition describes the state of a DaemonSet at a certain point.
         */
        interface DaemonSetCondition {
            /**
             * Last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of DaemonSet condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * DaemonSetSpec is the specification of a daemon set.
         */
        interface DaemonSetSpec {
            /**
             * The minimum number of seconds for which a newly created DaemonSet pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready).
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * The number of old history to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * A label query over pods that are managed by the daemon set. Must match in order to be controlled. If empty, defaulted to labels on Pod template. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * An object that describes the pod that will be created. The DaemonSet will create exactly one copy of this pod on every node that matches the template's node selector (or on every node if no node selector is specified). More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
             */
            template: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
            /**
             * DEPRECATED. A sequence number representing a specific generation of the template. Populated by the system. It can be set only during the creation.
             */
            templateGeneration?: pulumi.Input<number>;
            /**
             * An update strategy to replace existing DaemonSet pods with new pods.
             */
            updateStrategy?: pulumi.Input<inputs.extensions.v1beta1.DaemonSetUpdateStrategy>;
        }
        /**
         * DaemonSetSpec is the specification of a daemon set.
         */
        interface DaemonSetSpecPatch {
            /**
             * The minimum number of seconds for which a newly created DaemonSet pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready).
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * The number of old history to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * A label query over pods that are managed by the daemon set. Must match in order to be controlled. If empty, defaulted to labels on Pod template. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * An object that describes the pod that will be created. The DaemonSet will create exactly one copy of this pod on every node that matches the template's node selector (or on every node if no node selector is specified). More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
            /**
             * DEPRECATED. A sequence number representing a specific generation of the template. Populated by the system. It can be set only during the creation.
             */
            templateGeneration?: pulumi.Input<number>;
            /**
             * An update strategy to replace existing DaemonSet pods with new pods.
             */
            updateStrategy?: pulumi.Input<inputs.extensions.v1beta1.DaemonSetUpdateStrategyPatch>;
        }
        /**
         * DaemonSetStatus represents the current status of a daemon set.
         */
        interface DaemonSetStatus {
            /**
             * Count of hash collisions for the DaemonSet. The DaemonSet controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ControllerRevision.
             */
            collisionCount?: pulumi.Input<number>;
            /**
             * Represents the latest available observations of a DaemonSet's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.DaemonSetCondition>[]>;
            /**
             * The number of nodes that are running at least 1 daemon pod and are supposed to run the daemon pod. More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
             */
            currentNumberScheduled: pulumi.Input<number>;
            /**
             * The total number of nodes that should be running the daemon pod (including nodes correctly running the daemon pod). More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
             */
            desiredNumberScheduled: pulumi.Input<number>;
            /**
             * The number of nodes that should be running the daemon pod and have one or more of the daemon pod running and available (ready for at least spec.minReadySeconds)
             */
            numberAvailable?: pulumi.Input<number>;
            /**
             * The number of nodes that are running the daemon pod, but are not supposed to run the daemon pod. More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
             */
            numberMisscheduled: pulumi.Input<number>;
            /**
             * The number of nodes that should be running the daemon pod and have one or more of the daemon pod running and ready.
             */
            numberReady: pulumi.Input<number>;
            /**
             * The number of nodes that should be running the daemon pod and have none of the daemon pod running and available (ready for at least spec.minReadySeconds)
             */
            numberUnavailable?: pulumi.Input<number>;
            /**
             * The most recent generation observed by the daemon set controller.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * The total number of nodes that are running updated daemon pod
             */
            updatedNumberScheduled?: pulumi.Input<number>;
        }
        interface DaemonSetUpdateStrategy {
            /**
             * Rolling update config params. Present only if type = "RollingUpdate".
             */
            rollingUpdate?: pulumi.Input<inputs.extensions.v1beta1.RollingUpdateDaemonSet>;
            /**
             * Type of daemon set update. Can be "RollingUpdate" or "OnDelete". Default is OnDelete.
             */
            type?: pulumi.Input<string>;
        }
        interface DaemonSetUpdateStrategyPatch {
            /**
             * Rolling update config params. Present only if type = "RollingUpdate".
             */
            rollingUpdate?: pulumi.Input<inputs.extensions.v1beta1.RollingUpdateDaemonSetPatch>;
            /**
             * Type of daemon set update. Can be "RollingUpdate" or "OnDelete". Default is OnDelete.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * Deployment enables declarative updates for Pods and ReplicaSets.
         *
         * This resource waits until its status is ready before registering success
         * for create/update, and populating output properties from the current state of the resource.
         * The following conditions are used to determine whether the resource creation has
         * succeeded or failed:
         *
         * 1. The Deployment has begun to be updated by the Deployment controller. If the current
         *    generation of the Deployment is > 1, then this means that the current generation must
         *    be different from the generation reported by the last outputs.
         * 2. There exists a ReplicaSet whose revision is equal to the current revision of the
         *    Deployment.
         * 3. The Deployment's '.status.conditions' has a status of type 'Available' whose 'status'
         *    member is set to 'True'.
         * 4. If the Deployment has generation > 1, then '.status.conditions' has a status of type
         *    'Progressing', whose 'status' member is set to 'True', and whose 'reason' is
         *    'NewReplicaSetAvailable'. For generation <= 1, this status field does not exist,
         *    because it doesn't do a rollout (i.e., it simply creates the Deployment and
         *    corresponding ReplicaSet), and therefore there is no rollout to mark as 'Progressing'.
         *
         * If the Deployment has not reached a Ready state after 10 minutes, it will
         * time out and mark the resource update as Failed. You can override the default timeout value
         * by setting the 'customTimeouts' option on the resource.
         */
        interface Deployment {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"extensions/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Deployment">;
            /**
             * Standard object metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the Deployment.
             */
            spec?: pulumi.Input<inputs.extensions.v1beta1.DeploymentSpec>;
            /**
             * Most recently observed status of the Deployment.
             */
            status?: pulumi.Input<inputs.extensions.v1beta1.DeploymentStatus>;
        }
        /**
         * DeploymentCondition describes the state of a deployment at a certain point.
         */
        interface DeploymentCondition {
            /**
             * Last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * The last time this condition was updated.
             */
            lastUpdateTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of deployment condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * DeploymentSpec is the specification of the desired behavior of the Deployment.
         */
        interface DeploymentSpec {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Indicates that the deployment is paused and will not be processed by the deployment controller.
             */
            paused?: pulumi.Input<boolean>;
            /**
             * The maximum time in seconds for a deployment to make progress before it is considered to be failed. The deployment controller will continue to process failed deployments and a condition with a ProgressDeadlineExceeded reason will be surfaced in the deployment status. Note that progress will not be estimated during the time a deployment is paused. This is set to the max value of int32 (i.e. 2147483647) by default, which means "no deadline".
             */
            progressDeadlineSeconds?: pulumi.Input<number>;
            /**
             * Number of desired pods. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1.
             */
            replicas?: pulumi.Input<number>;
            /**
             * The number of old ReplicaSets to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. This is set to the max value of int32 (i.e. 2147483647) by default, which means "retaining all old RelicaSets".
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * DEPRECATED. The config this deployment is rolling back to. Will be cleared after rollback is done.
             */
            rollbackTo?: pulumi.Input<inputs.extensions.v1beta1.RollbackConfig>;
            /**
             * Label selector for pods. Existing ReplicaSets whose pods are selected by this will be the ones affected by this deployment.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * The deployment strategy to use to replace existing pods with new ones.
             */
            strategy?: pulumi.Input<inputs.extensions.v1beta1.DeploymentStrategy>;
            /**
             * Template describes the pods that will be created.
             */
            template: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
        }
        /**
         * DeploymentSpec is the specification of the desired behavior of the Deployment.
         */
        interface DeploymentSpecPatch {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Indicates that the deployment is paused and will not be processed by the deployment controller.
             */
            paused?: pulumi.Input<boolean>;
            /**
             * The maximum time in seconds for a deployment to make progress before it is considered to be failed. The deployment controller will continue to process failed deployments and a condition with a ProgressDeadlineExceeded reason will be surfaced in the deployment status. Note that progress will not be estimated during the time a deployment is paused. This is set to the max value of int32 (i.e. 2147483647) by default, which means "no deadline".
             */
            progressDeadlineSeconds?: pulumi.Input<number>;
            /**
             * Number of desired pods. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1.
             */
            replicas?: pulumi.Input<number>;
            /**
             * The number of old ReplicaSets to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. This is set to the max value of int32 (i.e. 2147483647) by default, which means "retaining all old RelicaSets".
             */
            revisionHistoryLimit?: pulumi.Input<number>;
            /**
             * DEPRECATED. The config this deployment is rolling back to. Will be cleared after rollback is done.
             */
            rollbackTo?: pulumi.Input<inputs.extensions.v1beta1.RollbackConfigPatch>;
            /**
             * Label selector for pods. Existing ReplicaSets whose pods are selected by this will be the ones affected by this deployment.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * The deployment strategy to use to replace existing pods with new ones.
             */
            strategy?: pulumi.Input<inputs.extensions.v1beta1.DeploymentStrategyPatch>;
            /**
             * Template describes the pods that will be created.
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
        }
        /**
         * DeploymentStatus is the most recently observed status of the Deployment.
         */
        interface DeploymentStatus {
            /**
             * Total number of available pods (ready for at least minReadySeconds) targeted by this deployment.
             */
            availableReplicas?: pulumi.Input<number>;
            /**
             * Count of hash collisions for the Deployment. The Deployment controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ReplicaSet.
             */
            collisionCount?: pulumi.Input<number>;
            /**
             * Represents the latest available observations of a deployment's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.DeploymentCondition>[]>;
            /**
             * The generation observed by the deployment controller.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * Total number of ready pods targeted by this deployment.
             */
            readyReplicas?: pulumi.Input<number>;
            /**
             * Total number of non-terminated pods targeted by this deployment (their labels match the selector).
             */
            replicas?: pulumi.Input<number>;
            /**
             * Total number of unavailable pods targeted by this deployment. This is the total number of pods that are still required for the deployment to have 100% available capacity. They may either be pods that are running but not yet available or pods that still have not been created.
             */
            unavailableReplicas?: pulumi.Input<number>;
            /**
             * Total number of non-terminated pods targeted by this deployment that have the desired template spec.
             */
            updatedReplicas?: pulumi.Input<number>;
        }
        /**
         * DeploymentStrategy describes how to replace existing pods with new ones.
         */
        interface DeploymentStrategy {
            /**
             * Rolling update config params. Present only if DeploymentStrategyType = RollingUpdate.
             */
            rollingUpdate?: pulumi.Input<inputs.extensions.v1beta1.RollingUpdateDeployment>;
            /**
             * Type of deployment. Can be "Recreate" or "RollingUpdate". Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * DeploymentStrategy describes how to replace existing pods with new ones.
         */
        interface DeploymentStrategyPatch {
            /**
             * Rolling update config params. Present only if DeploymentStrategyType = RollingUpdate.
             */
            rollingUpdate?: pulumi.Input<inputs.extensions.v1beta1.RollingUpdateDeploymentPatch>;
            /**
             * Type of deployment. Can be "Recreate" or "RollingUpdate". Default is RollingUpdate.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * FSGroupStrategyOptions defines the strategy type and options used to create the strategy. Deprecated: use FSGroupStrategyOptions from policy API Group instead.
         */
        interface FSGroupStrategyOptions {
            /**
             * ranges are the allowed ranges of fs groups.  If you would like to force a single fs group then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.IDRange>[]>;
            /**
             * rule is the strategy that will dictate what FSGroup is used in the SecurityContext.
             */
            rule?: pulumi.Input<string>;
        }
        /**
         * FSGroupStrategyOptions defines the strategy type and options used to create the strategy. Deprecated: use FSGroupStrategyOptions from policy API Group instead.
         */
        interface FSGroupStrategyOptionsPatch {
            /**
             * ranges are the allowed ranges of fs groups.  If you would like to force a single fs group then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.IDRangePatch>[]>;
            /**
             * rule is the strategy that will dictate what FSGroup is used in the SecurityContext.
             */
            rule?: pulumi.Input<string>;
        }
        /**
         * HTTPIngressPath associates a path regex with a backend. Incoming urls matching the path are forwarded to the backend.
         */
        interface HTTPIngressPath {
            /**
             * Backend defines the referenced service endpoint to which the traffic will be forwarded to.
             */
            backend: pulumi.Input<inputs.extensions.v1beta1.IngressBackend>;
            /**
             * Path is an extended POSIX regex as defined by IEEE Std 1003.1, (i.e this follows the egrep/unix syntax, not the perl syntax) matched against the path of an incoming request. Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/'. If unspecified, the path defaults to a catch all sending traffic to the backend.
             */
            path?: pulumi.Input<string>;
            /**
             * PathType determines the interpretation of the Path matching. PathType can be one of the following values: * Exact: Matches the URL path exactly. * Prefix: Matches based on a URL path prefix split by '/'. Matching is
             *   done on a path element by element basis. A path element refers is the
             *   list of labels in the path split by the '/' separator. A request is a
             *   match for path p if every p is an element-wise prefix of p of the
             *   request path. Note that if the last element of the path is a substring
             *   of the last element in request path, it is not a match (e.g. /foo/bar
             *   matches /foo/bar/baz, but does not match /foo/barbaz).
             * * ImplementationSpecific: Interpretation of the Path matching is up to
             *   the IngressClass. Implementations can treat this as a separate PathType
             *   or treat it identically to Prefix or Exact path types.
             * Implementations are required to support all path types. Defaults to ImplementationSpecific.
             */
            pathType?: pulumi.Input<string>;
        }
        /**
         * HTTPIngressPath associates a path regex with a backend. Incoming urls matching the path are forwarded to the backend.
         */
        interface HTTPIngressPathPatch {
            /**
             * Backend defines the referenced service endpoint to which the traffic will be forwarded to.
             */
            backend?: pulumi.Input<inputs.extensions.v1beta1.IngressBackendPatch>;
            /**
             * Path is an extended POSIX regex as defined by IEEE Std 1003.1, (i.e this follows the egrep/unix syntax, not the perl syntax) matched against the path of an incoming request. Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/'. If unspecified, the path defaults to a catch all sending traffic to the backend.
             */
            path?: pulumi.Input<string>;
            /**
             * PathType determines the interpretation of the Path matching. PathType can be one of the following values: * Exact: Matches the URL path exactly. * Prefix: Matches based on a URL path prefix split by '/'. Matching is
             *   done on a path element by element basis. A path element refers is the
             *   list of labels in the path split by the '/' separator. A request is a
             *   match for path p if every p is an element-wise prefix of p of the
             *   request path. Note that if the last element of the path is a substring
             *   of the last element in request path, it is not a match (e.g. /foo/bar
             *   matches /foo/bar/baz, but does not match /foo/barbaz).
             * * ImplementationSpecific: Interpretation of the Path matching is up to
             *   the IngressClass. Implementations can treat this as a separate PathType
             *   or treat it identically to Prefix or Exact path types.
             * Implementations are required to support all path types. Defaults to ImplementationSpecific.
             */
            pathType?: pulumi.Input<string>;
        }
        /**
         * HTTPIngressRuleValue is a list of http selectors pointing to backends. In the example: http://<host>/<path>?<searchpart> -> backend where where parts of the url correspond to RFC 3986, this resource will be used to match against everything after the last '/' and before the first '?' or '#'.
         */
        interface HTTPIngressRuleValue {
            /**
             * A collection of paths that map requests to backends.
             */
            paths: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.HTTPIngressPath>[]>;
        }
        /**
         * HTTPIngressRuleValue is a list of http selectors pointing to backends. In the example: http://<host>/<path>?<searchpart> -> backend where where parts of the url correspond to RFC 3986, this resource will be used to match against everything after the last '/' and before the first '?' or '#'.
         */
        interface HTTPIngressRuleValuePatch {
            /**
             * A collection of paths that map requests to backends.
             */
            paths?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.HTTPIngressPathPatch>[]>;
        }
        /**
         * HostPortRange defines a range of host ports that will be enabled by a policy for pods to use.  It requires both the start and end to be defined. Deprecated: use HostPortRange from policy API Group instead.
         */
        interface HostPortRange {
            /**
             * max is the end of the range, inclusive.
             */
            max: pulumi.Input<number>;
            /**
             * min is the start of the range, inclusive.
             */
            min: pulumi.Input<number>;
        }
        /**
         * HostPortRange defines a range of host ports that will be enabled by a policy for pods to use.  It requires both the start and end to be defined. Deprecated: use HostPortRange from policy API Group instead.
         */
        interface HostPortRangePatch {
            /**
             * max is the end of the range, inclusive.
             */
            max?: pulumi.Input<number>;
            /**
             * min is the start of the range, inclusive.
             */
            min?: pulumi.Input<number>;
        }
        /**
         * IDRange provides a min/max of an allowed range of IDs. Deprecated: use IDRange from policy API Group instead.
         */
        interface IDRange {
            /**
             * max is the end of the range, inclusive.
             */
            max: pulumi.Input<number>;
            /**
             * min is the start of the range, inclusive.
             */
            min: pulumi.Input<number>;
        }
        /**
         * IDRange provides a min/max of an allowed range of IDs. Deprecated: use IDRange from policy API Group instead.
         */
        interface IDRangePatch {
            /**
             * max is the end of the range, inclusive.
             */
            max?: pulumi.Input<number>;
            /**
             * min is the start of the range, inclusive.
             */
            min?: pulumi.Input<number>;
        }
        /**
         * DEPRECATED 1.9 - This group version of IPBlock is deprecated by networking/v1/IPBlock. IPBlock describes a particular CIDR (Ex. "192.168.1.1/24") that is allowed to the pods matched by a NetworkPolicySpec's podSelector. The except entry describes CIDRs that should not be included within this rule.
         */
        interface IPBlock {
            /**
             * CIDR is a string representing the IP Block Valid examples are "192.168.1.1/24"
             */
            cidr: pulumi.Input<string>;
            /**
             * Except is a slice of CIDRs that should not be included within an IP Block Valid examples are "192.168.1.1/24" Except values will be rejected if they are outside the CIDR range
             */
            except?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * DEPRECATED 1.9 - This group version of IPBlock is deprecated by networking/v1/IPBlock. IPBlock describes a particular CIDR (Ex. "192.168.1.1/24") that is allowed to the pods matched by a NetworkPolicySpec's podSelector. The except entry describes CIDRs that should not be included within this rule.
         */
        interface IPBlockPatch {
            /**
             * CIDR is a string representing the IP Block Valid examples are "192.168.1.1/24"
             */
            cidr?: pulumi.Input<string>;
            /**
             * Except is a slice of CIDRs that should not be included within an IP Block Valid examples are "192.168.1.1/24" Except values will be rejected if they are outside the CIDR range
             */
            except?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * Ingress is a collection of rules that allow inbound connections to reach the endpoints defined by a backend. An Ingress can be configured to give services externally-reachable urls, load balance traffic, terminate SSL, offer name based virtual hosting etc.
         *
         * This resource waits until its status is ready before registering success
         * for create/update, and populating output properties from the current state of the resource.
         * The following conditions are used to determine whether the resource creation has
         * succeeded or failed:
         *
         * 1.  Ingress object exists.
         * 2.  Endpoint objects exist with matching names for each Ingress path (except when Service
         *     type is ExternalName).
         * 3.  Ingress entry exists for '.status.loadBalancer.ingress'.
         *
         * If the Ingress has not reached a Ready state after 10 minutes, it will
         * time out and mark the resource update as Failed. You can override the default timeout value
         * by setting the 'customTimeouts' option on the resource.
         */
        interface Ingress {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"extensions/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Ingress">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec is the desired state of the Ingress. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.extensions.v1beta1.IngressSpec>;
            /**
             * Status is the current state of the Ingress. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.extensions.v1beta1.IngressStatus>;
        }
        /**
         * IngressBackend describes all endpoints for a given service and port.
         */
        interface IngressBackend {
            /**
             * Resource is an ObjectRef to another Kubernetes resource in the namespace of the Ingress object. If resource is specified, serviceName and servicePort must not be specified.
             */
            resource?: pulumi.Input<inputs.core.v1.TypedLocalObjectReference>;
            /**
             * Specifies the name of the referenced service.
             */
            serviceName: pulumi.Input<string>;
            /**
             * Specifies the port of the referenced service.
             */
            servicePort: pulumi.Input<number | string>;
        }
        /**
         * IngressBackend describes all endpoints for a given service and port.
         */
        interface IngressBackendPatch {
            /**
             * Resource is an ObjectRef to another Kubernetes resource in the namespace of the Ingress object. If resource is specified, serviceName and servicePort must not be specified.
             */
            resource?: pulumi.Input<inputs.core.v1.TypedLocalObjectReferencePatch>;
            /**
             * Specifies the name of the referenced service.
             */
            serviceName?: pulumi.Input<string>;
            /**
             * Specifies the port of the referenced service.
             */
            servicePort?: pulumi.Input<number | string>;
        }
        /**
         * IngressRule represents the rules mapping the paths under a specified host to the related backend services. Incoming requests are first evaluated for a host match, then routed to the backend associated with the matching IngressRuleValue.
         */
        interface IngressRule {
            /**
             * Host is the fully qualified domain name of a network host, as defined by RFC 3986. Note the following deviations from the "host" part of the URI as defined in the RFC: 1. IPs are not allowed. Currently an IngressRuleValue can only apply to the
             * 	  IP in the Spec of the parent Ingress.
             * 2. The `:` delimiter is not respected because ports are not allowed.
             * 	  Currently the port of an Ingress is implicitly :80 for http and
             * 	  :443 for https.
             * Both these may change in the future. Incoming requests are matched against the host before the IngressRuleValue. If the host is unspecified, the Ingress routes all traffic based on the specified IngressRuleValue.
             */
            host?: pulumi.Input<string>;
            http?: pulumi.Input<inputs.extensions.v1beta1.HTTPIngressRuleValue>;
        }
        /**
         * IngressRule represents the rules mapping the paths under a specified host to the related backend services. Incoming requests are first evaluated for a host match, then routed to the backend associated with the matching IngressRuleValue.
         */
        interface IngressRulePatch {
            /**
             * Host is the fully qualified domain name of a network host, as defined by RFC 3986. Note the following deviations from the "host" part of the URI as defined in the RFC: 1. IPs are not allowed. Currently an IngressRuleValue can only apply to the
             * 	  IP in the Spec of the parent Ingress.
             * 2. The `:` delimiter is not respected because ports are not allowed.
             * 	  Currently the port of an Ingress is implicitly :80 for http and
             * 	  :443 for https.
             * Both these may change in the future. Incoming requests are matched against the host before the IngressRuleValue. If the host is unspecified, the Ingress routes all traffic based on the specified IngressRuleValue.
             */
            host?: pulumi.Input<string>;
            http?: pulumi.Input<inputs.extensions.v1beta1.HTTPIngressRuleValuePatch>;
        }
        /**
         * IngressSpec describes the Ingress the user wishes to exist.
         */
        interface IngressSpec {
            /**
             * A default backend capable of servicing requests that don't match any rule. At least one of 'backend' or 'rules' must be specified. This field is optional to allow the loadbalancer controller or defaulting logic to specify a global default.
             */
            backend?: pulumi.Input<inputs.extensions.v1beta1.IngressBackend>;
            /**
             * IngressClassName is the name of the IngressClass cluster resource. The associated IngressClass defines which controller will implement the resource. This replaces the deprecated `kubernetes.io/ingress.class` annotation. For backwards compatibility, when that annotation is set, it must be given precedence over this field. The controller may emit a warning if the field and annotation have different values. Implementations of this API should ignore Ingresses without a class specified. An IngressClass resource may be marked as default, which can be used to set a default value for this field. For more information, refer to the IngressClass documentation.
             */
            ingressClassName?: pulumi.Input<string>;
            /**
             * A list of host rules used to configure the Ingress. If unspecified, or no rule matches, all traffic is sent to the default backend.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.IngressRule>[]>;
            /**
             * TLS configuration. Currently the Ingress only supports a single TLS port, 443. If multiple members of this list specify different hosts, they will be multiplexed on the same port according to the hostname specified through the SNI TLS extension, if the ingress controller fulfilling the ingress supports SNI.
             */
            tls?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.IngressTLS>[]>;
        }
        /**
         * IngressSpec describes the Ingress the user wishes to exist.
         */
        interface IngressSpecPatch {
            /**
             * A default backend capable of servicing requests that don't match any rule. At least one of 'backend' or 'rules' must be specified. This field is optional to allow the loadbalancer controller or defaulting logic to specify a global default.
             */
            backend?: pulumi.Input<inputs.extensions.v1beta1.IngressBackendPatch>;
            /**
             * IngressClassName is the name of the IngressClass cluster resource. The associated IngressClass defines which controller will implement the resource. This replaces the deprecated `kubernetes.io/ingress.class` annotation. For backwards compatibility, when that annotation is set, it must be given precedence over this field. The controller may emit a warning if the field and annotation have different values. Implementations of this API should ignore Ingresses without a class specified. An IngressClass resource may be marked as default, which can be used to set a default value for this field. For more information, refer to the IngressClass documentation.
             */
            ingressClassName?: pulumi.Input<string>;
            /**
             * A list of host rules used to configure the Ingress. If unspecified, or no rule matches, all traffic is sent to the default backend.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.IngressRulePatch>[]>;
            /**
             * TLS configuration. Currently the Ingress only supports a single TLS port, 443. If multiple members of this list specify different hosts, they will be multiplexed on the same port according to the hostname specified through the SNI TLS extension, if the ingress controller fulfilling the ingress supports SNI.
             */
            tls?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.IngressTLSPatch>[]>;
        }
        /**
         * IngressStatus describe the current state of the Ingress.
         */
        interface IngressStatus {
            /**
             * LoadBalancer contains the current status of the load-balancer.
             */
            loadBalancer?: pulumi.Input<inputs.core.v1.LoadBalancerStatus>;
        }
        /**
         * IngressTLS describes the transport layer security associated with an Ingress.
         */
        interface IngressTLS {
            /**
             * Hosts are a list of hosts included in the TLS certificate. The values in this list must match the name/s used in the tlsSecret. Defaults to the wildcard host setting for the loadbalancer controller fulfilling this Ingress, if left unspecified.
             */
            hosts?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * SecretName is the name of the secret used to terminate SSL traffic on 443. Field is left optional to allow SSL routing based on SNI hostname alone. If the SNI host in a listener conflicts with the "Host" header field used by an IngressRule, the SNI host is used for termination and value of the Host header is used for routing.
             */
            secretName?: pulumi.Input<string>;
        }
        /**
         * IngressTLS describes the transport layer security associated with an Ingress.
         */
        interface IngressTLSPatch {
            /**
             * Hosts are a list of hosts included in the TLS certificate. The values in this list must match the name/s used in the tlsSecret. Defaults to the wildcard host setting for the loadbalancer controller fulfilling this Ingress, if left unspecified.
             */
            hosts?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * SecretName is the name of the secret used to terminate SSL traffic on 443. Field is left optional to allow SSL routing based on SNI hostname alone. If the SNI host in a listener conflicts with the "Host" header field used by an IngressRule, the SNI host is used for termination and value of the Host header is used for routing.
             */
            secretName?: pulumi.Input<string>;
        }
        /**
         * DEPRECATED 1.9 - This group version of NetworkPolicy is deprecated by networking/v1/NetworkPolicy. NetworkPolicy describes what network traffic is allowed for a set of Pods
         */
        interface NetworkPolicy {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"extensions/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"NetworkPolicy">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior for this NetworkPolicy.
             */
            spec?: pulumi.Input<inputs.extensions.v1beta1.NetworkPolicySpec>;
        }
        /**
         * DEPRECATED 1.9 - This group version of NetworkPolicyEgressRule is deprecated by networking/v1/NetworkPolicyEgressRule. NetworkPolicyEgressRule describes a particular set of traffic that is allowed out of pods matched by a NetworkPolicySpec's podSelector. The traffic must match both ports and to. This type is beta-level in 1.8
         */
        interface NetworkPolicyEgressRule {
            /**
             * List of destination ports for outgoing traffic. Each item in this list is combined using a logical OR. If this field is empty or missing, this rule matches all ports (traffic not restricted by port). If this field is present and contains at least one item, then this rule allows traffic only if the traffic matches at least one port in the list.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.NetworkPolicyPort>[]>;
            /**
             * List of destinations for outgoing traffic of pods selected for this rule. Items in this list are combined using a logical OR operation. If this field is empty or missing, this rule matches all destinations (traffic not restricted by destination). If this field is present and contains at least one item, this rule allows traffic only if the traffic matches at least one item in the to list.
             */
            to?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.NetworkPolicyPeer>[]>;
        }
        /**
         * DEPRECATED 1.9 - This group version of NetworkPolicyEgressRule is deprecated by networking/v1/NetworkPolicyEgressRule. NetworkPolicyEgressRule describes a particular set of traffic that is allowed out of pods matched by a NetworkPolicySpec's podSelector. The traffic must match both ports and to. This type is beta-level in 1.8
         */
        interface NetworkPolicyEgressRulePatch {
            /**
             * List of destination ports for outgoing traffic. Each item in this list is combined using a logical OR. If this field is empty or missing, this rule matches all ports (traffic not restricted by port). If this field is present and contains at least one item, then this rule allows traffic only if the traffic matches at least one port in the list.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.NetworkPolicyPortPatch>[]>;
            /**
             * List of destinations for outgoing traffic of pods selected for this rule. Items in this list are combined using a logical OR operation. If this field is empty or missing, this rule matches all destinations (traffic not restricted by destination). If this field is present and contains at least one item, this rule allows traffic only if the traffic matches at least one item in the to list.
             */
            to?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.NetworkPolicyPeerPatch>[]>;
        }
        /**
         * DEPRECATED 1.9 - This group version of NetworkPolicyIngressRule is deprecated by networking/v1/NetworkPolicyIngressRule. This NetworkPolicyIngressRule matches traffic if and only if the traffic matches both ports AND from.
         */
        interface NetworkPolicyIngressRule {
            /**
             * List of sources which should be able to access the pods selected for this rule. Items in this list are combined using a logical OR operation. If this field is empty or missing, this rule matches all sources (traffic not restricted by source). If this field is present and contains at least one item, this rule allows traffic only if the traffic matches at least one item in the from list.
             */
            from?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.NetworkPolicyPeer>[]>;
            /**
             * List of ports which should be made accessible on the pods selected for this rule. Each item in this list is combined using a logical OR. If this field is empty or missing, this rule matches all ports (traffic not restricted by port). If this field is present and contains at least one item, then this rule allows traffic only if the traffic matches at least one port in the list.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.NetworkPolicyPort>[]>;
        }
        /**
         * DEPRECATED 1.9 - This group version of NetworkPolicyIngressRule is deprecated by networking/v1/NetworkPolicyIngressRule. This NetworkPolicyIngressRule matches traffic if and only if the traffic matches both ports AND from.
         */
        interface NetworkPolicyIngressRulePatch {
            /**
             * List of sources which should be able to access the pods selected for this rule. Items in this list are combined using a logical OR operation. If this field is empty or missing, this rule matches all sources (traffic not restricted by source). If this field is present and contains at least one item, this rule allows traffic only if the traffic matches at least one item in the from list.
             */
            from?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.NetworkPolicyPeerPatch>[]>;
            /**
             * List of ports which should be made accessible on the pods selected for this rule. Each item in this list is combined using a logical OR. If this field is empty or missing, this rule matches all ports (traffic not restricted by port). If this field is present and contains at least one item, then this rule allows traffic only if the traffic matches at least one port in the list.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.NetworkPolicyPortPatch>[]>;
        }
        /**
         * DEPRECATED 1.9 - This group version of NetworkPolicyPeer is deprecated by networking/v1/NetworkPolicyPeer.
         */
        interface NetworkPolicyPeer {
            /**
             * IPBlock defines policy on a particular IPBlock. If this field is set then neither of the other fields can be.
             */
            ipBlock?: pulumi.Input<inputs.extensions.v1beta1.IPBlock>;
            /**
             * Selects Namespaces using cluster-scoped labels. This field follows standard label selector semantics; if present but empty, it selects all namespaces.
             *
             * If PodSelector is also set, then the NetworkPolicyPeer as a whole selects the Pods matching PodSelector in the Namespaces selected by NamespaceSelector. Otherwise it selects all Pods in the Namespaces selected by NamespaceSelector.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * This is a label selector which selects Pods. This field follows standard label selector semantics; if present but empty, it selects all pods.
             *
             * If NamespaceSelector is also set, then the NetworkPolicyPeer as a whole selects the Pods matching PodSelector in the Namespaces selected by NamespaceSelector. Otherwise it selects the Pods matching PodSelector in the policy's own Namespace.
             */
            podSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
        }
        /**
         * DEPRECATED 1.9 - This group version of NetworkPolicyPeer is deprecated by networking/v1/NetworkPolicyPeer.
         */
        interface NetworkPolicyPeerPatch {
            /**
             * IPBlock defines policy on a particular IPBlock. If this field is set then neither of the other fields can be.
             */
            ipBlock?: pulumi.Input<inputs.extensions.v1beta1.IPBlockPatch>;
            /**
             * Selects Namespaces using cluster-scoped labels. This field follows standard label selector semantics; if present but empty, it selects all namespaces.
             *
             * If PodSelector is also set, then the NetworkPolicyPeer as a whole selects the Pods matching PodSelector in the Namespaces selected by NamespaceSelector. Otherwise it selects all Pods in the Namespaces selected by NamespaceSelector.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * This is a label selector which selects Pods. This field follows standard label selector semantics; if present but empty, it selects all pods.
             *
             * If NamespaceSelector is also set, then the NetworkPolicyPeer as a whole selects the Pods matching PodSelector in the Namespaces selected by NamespaceSelector. Otherwise it selects the Pods matching PodSelector in the policy's own Namespace.
             */
            podSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
        }
        /**
         * DEPRECATED 1.9 - This group version of NetworkPolicyPort is deprecated by networking/v1/NetworkPolicyPort.
         */
        interface NetworkPolicyPort {
            /**
             * If specified, the port on the given protocol.  This can either be a numerical or named port on a pod.  If this field is not provided, this matches all port names and numbers. If present, only traffic on the specified protocol AND port will be matched.
             */
            port?: pulumi.Input<number | string>;
            /**
             * Optional.  The protocol (TCP, UDP, or SCTP) which traffic must match. If not specified, this field defaults to TCP.
             */
            protocol?: pulumi.Input<string>;
        }
        /**
         * DEPRECATED 1.9 - This group version of NetworkPolicyPort is deprecated by networking/v1/NetworkPolicyPort.
         */
        interface NetworkPolicyPortPatch {
            /**
             * If specified, the port on the given protocol.  This can either be a numerical or named port on a pod.  If this field is not provided, this matches all port names and numbers. If present, only traffic on the specified protocol AND port will be matched.
             */
            port?: pulumi.Input<number | string>;
            /**
             * Optional.  The protocol (TCP, UDP, or SCTP) which traffic must match. If not specified, this field defaults to TCP.
             */
            protocol?: pulumi.Input<string>;
        }
        /**
         * DEPRECATED 1.9 - This group version of NetworkPolicySpec is deprecated by networking/v1/NetworkPolicySpec.
         */
        interface NetworkPolicySpec {
            /**
             * List of egress rules to be applied to the selected pods. Outgoing traffic is allowed if there are no NetworkPolicies selecting the pod (and cluster policy otherwise allows the traffic), OR if the traffic matches at least one egress rule across all of the NetworkPolicy objects whose podSelector matches the pod. If this field is empty then this NetworkPolicy limits all outgoing traffic (and serves solely to ensure that the pods it selects are isolated by default). This field is beta-level in 1.8
             */
            egress?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.NetworkPolicyEgressRule>[]>;
            /**
             * List of ingress rules to be applied to the selected pods. Traffic is allowed to a pod if there are no NetworkPolicies selecting the pod OR if the traffic source is the pod's local node, OR if the traffic matches at least one ingress rule across all of the NetworkPolicy objects whose podSelector matches the pod. If this field is empty then this NetworkPolicy does not allow any traffic (and serves solely to ensure that the pods it selects are isolated by default).
             */
            ingress?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.NetworkPolicyIngressRule>[]>;
            /**
             * Selects the pods to which this NetworkPolicy object applies.  The array of ingress rules is applied to any pods selected by this field. Multiple network policies can select the same set of pods.  In this case, the ingress rules for each are combined additively. This field is NOT optional and follows standard label selector semantics. An empty podSelector matches all pods in this namespace.
             */
            podSelector: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * List of rule types that the NetworkPolicy relates to. Valid options are "Ingress", "Egress", or "Ingress,Egress". If this field is not specified, it will default based on the existence of Ingress or Egress rules; policies that contain an Egress section are assumed to affect Egress, and all policies (whether or not they contain an Ingress section) are assumed to affect Ingress. If you want to write an egress-only policy, you must explicitly specify policyTypes [ "Egress" ]. Likewise, if you want to write a policy that specifies that no egress is allowed, you must specify a policyTypes value that include "Egress" (since such a policy would not include an Egress section and would otherwise default to just [ "Ingress" ]). This field is beta-level in 1.8
             */
            policyTypes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * DEPRECATED 1.9 - This group version of NetworkPolicySpec is deprecated by networking/v1/NetworkPolicySpec.
         */
        interface NetworkPolicySpecPatch {
            /**
             * List of egress rules to be applied to the selected pods. Outgoing traffic is allowed if there are no NetworkPolicies selecting the pod (and cluster policy otherwise allows the traffic), OR if the traffic matches at least one egress rule across all of the NetworkPolicy objects whose podSelector matches the pod. If this field is empty then this NetworkPolicy limits all outgoing traffic (and serves solely to ensure that the pods it selects are isolated by default). This field is beta-level in 1.8
             */
            egress?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.NetworkPolicyEgressRulePatch>[]>;
            /**
             * List of ingress rules to be applied to the selected pods. Traffic is allowed to a pod if there are no NetworkPolicies selecting the pod OR if the traffic source is the pod's local node, OR if the traffic matches at least one ingress rule across all of the NetworkPolicy objects whose podSelector matches the pod. If this field is empty then this NetworkPolicy does not allow any traffic (and serves solely to ensure that the pods it selects are isolated by default).
             */
            ingress?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.NetworkPolicyIngressRulePatch>[]>;
            /**
             * Selects the pods to which this NetworkPolicy object applies.  The array of ingress rules is applied to any pods selected by this field. Multiple network policies can select the same set of pods.  In this case, the ingress rules for each are combined additively. This field is NOT optional and follows standard label selector semantics. An empty podSelector matches all pods in this namespace.
             */
            podSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * List of rule types that the NetworkPolicy relates to. Valid options are "Ingress", "Egress", or "Ingress,Egress". If this field is not specified, it will default based on the existence of Ingress or Egress rules; policies that contain an Egress section are assumed to affect Egress, and all policies (whether or not they contain an Ingress section) are assumed to affect Ingress. If you want to write an egress-only policy, you must explicitly specify policyTypes [ "Egress" ]. Likewise, if you want to write a policy that specifies that no egress is allowed, you must specify a policyTypes value that include "Egress" (since such a policy would not include an Egress section and would otherwise default to just [ "Ingress" ]). This field is beta-level in 1.8
             */
            policyTypes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * PodSecurityPolicy governs the ability to make requests that affect the Security Context that will be applied to a pod and container. Deprecated: use PodSecurityPolicy from policy API Group instead.
         */
        interface PodSecurityPolicy {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"extensions/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PodSecurityPolicy">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec defines the policy enforced.
             */
            spec?: pulumi.Input<inputs.extensions.v1beta1.PodSecurityPolicySpec>;
        }
        /**
         * PodSecurityPolicySpec defines the policy enforced. Deprecated: use PodSecurityPolicySpec from policy API Group instead.
         */
        interface PodSecurityPolicySpec {
            /**
             * allowPrivilegeEscalation determines if a pod can request to allow privilege escalation. If unspecified, defaults to true.
             */
            allowPrivilegeEscalation?: pulumi.Input<boolean>;
            /**
             * AllowedCSIDrivers is a whitelist of inline CSI drivers that must be explicitly set to be embedded within a pod spec. An empty value indicates that any CSI driver can be used for inline ephemeral volumes.
             */
            allowedCSIDrivers?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.AllowedCSIDriver>[]>;
            /**
             * allowedCapabilities is a list of capabilities that can be requested to add to the container. Capabilities in this field may be added at the pod author's discretion. You must not list a capability in both allowedCapabilities and requiredDropCapabilities.
             */
            allowedCapabilities?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * allowedFlexVolumes is a whitelist of allowed Flexvolumes.  Empty or nil indicates that all Flexvolumes may be used.  This parameter is effective only when the usage of the Flexvolumes is allowed in the "volumes" field.
             */
            allowedFlexVolumes?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.AllowedFlexVolume>[]>;
            /**
             * allowedHostPaths is a white list of allowed host paths. Empty indicates that all host paths may be used.
             */
            allowedHostPaths?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.AllowedHostPath>[]>;
            /**
             * AllowedProcMountTypes is a whitelist of allowed ProcMountTypes. Empty or nil indicates that only the DefaultProcMountType may be used. This requires the ProcMountType feature flag to be enabled.
             */
            allowedProcMountTypes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * allowedUnsafeSysctls is a list of explicitly allowed unsafe sysctls, defaults to none. Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of allowed sysctls. Single * means all unsafe sysctls are allowed. Kubelet has to whitelist all allowed unsafe sysctls explicitly to avoid rejection.
             *
             * Examples: e.g. "foo/*" allows "foo/bar", "foo/baz", etc. e.g. "foo.*" allows "foo.bar", "foo.baz", etc.
             */
            allowedUnsafeSysctls?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * defaultAddCapabilities is the default set of capabilities that will be added to the container unless the pod spec specifically drops the capability.  You may not list a capability in both defaultAddCapabilities and requiredDropCapabilities. Capabilities added here are implicitly allowed, and need not be included in the allowedCapabilities list.
             */
            defaultAddCapabilities?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * defaultAllowPrivilegeEscalation controls the default setting for whether a process can gain more privileges than its parent process.
             */
            defaultAllowPrivilegeEscalation?: pulumi.Input<boolean>;
            /**
             * forbiddenSysctls is a list of explicitly forbidden sysctls, defaults to none. Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of forbidden sysctls. Single * means all sysctls are forbidden.
             *
             * Examples: e.g. "foo/*" forbids "foo/bar", "foo/baz", etc. e.g. "foo.*" forbids "foo.bar", "foo.baz", etc.
             */
            forbiddenSysctls?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * fsGroup is the strategy that will dictate what fs group is used by the SecurityContext.
             */
            fsGroup: pulumi.Input<inputs.extensions.v1beta1.FSGroupStrategyOptions>;
            /**
             * hostIPC determines if the policy allows the use of HostIPC in the pod spec.
             */
            hostIPC?: pulumi.Input<boolean>;
            /**
             * hostNetwork determines if the policy allows the use of HostNetwork in the pod spec.
             */
            hostNetwork?: pulumi.Input<boolean>;
            /**
             * hostPID determines if the policy allows the use of HostPID in the pod spec.
             */
            hostPID?: pulumi.Input<boolean>;
            /**
             * hostPorts determines which host port ranges are allowed to be exposed.
             */
            hostPorts?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.HostPortRange>[]>;
            /**
             * privileged determines if a pod can request to be run as privileged.
             */
            privileged?: pulumi.Input<boolean>;
            /**
             * readOnlyRootFilesystem when set to true will force containers to run with a read only root file system.  If the container specifically requests to run with a non-read only root file system the PSP should deny the pod. If set to false the container may run with a read only root file system if it wishes but it will not be forced to.
             */
            readOnlyRootFilesystem?: pulumi.Input<boolean>;
            /**
             * requiredDropCapabilities are the capabilities that will be dropped from the container.  These are required to be dropped and cannot be added.
             */
            requiredDropCapabilities?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * RunAsGroup is the strategy that will dictate the allowable RunAsGroup values that may be set. If this field is omitted, the pod's RunAsGroup can take any value. This field requires the RunAsGroup feature gate to be enabled.
             */
            runAsGroup?: pulumi.Input<inputs.extensions.v1beta1.RunAsGroupStrategyOptions>;
            /**
             * runAsUser is the strategy that will dictate the allowable RunAsUser values that may be set.
             */
            runAsUser: pulumi.Input<inputs.extensions.v1beta1.RunAsUserStrategyOptions>;
            /**
             * runtimeClass is the strategy that will dictate the allowable RuntimeClasses for a pod. If this field is omitted, the pod's runtimeClassName field is unrestricted. Enforcement of this field depends on the RuntimeClass feature gate being enabled.
             */
            runtimeClass?: pulumi.Input<inputs.extensions.v1beta1.RuntimeClassStrategyOptions>;
            /**
             * seLinux is the strategy that will dictate the allowable labels that may be set.
             */
            seLinux: pulumi.Input<inputs.extensions.v1beta1.SELinuxStrategyOptions>;
            /**
             * supplementalGroups is the strategy that will dictate what supplemental groups are used by the SecurityContext.
             */
            supplementalGroups: pulumi.Input<inputs.extensions.v1beta1.SupplementalGroupsStrategyOptions>;
            /**
             * volumes is a white list of allowed volume plugins. Empty indicates that no volumes may be used. To allow all volumes you may use '*'.
             */
            volumes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * PodSecurityPolicySpec defines the policy enforced. Deprecated: use PodSecurityPolicySpec from policy API Group instead.
         */
        interface PodSecurityPolicySpecPatch {
            /**
             * allowPrivilegeEscalation determines if a pod can request to allow privilege escalation. If unspecified, defaults to true.
             */
            allowPrivilegeEscalation?: pulumi.Input<boolean>;
            /**
             * AllowedCSIDrivers is a whitelist of inline CSI drivers that must be explicitly set to be embedded within a pod spec. An empty value indicates that any CSI driver can be used for inline ephemeral volumes.
             */
            allowedCSIDrivers?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.AllowedCSIDriverPatch>[]>;
            /**
             * allowedCapabilities is a list of capabilities that can be requested to add to the container. Capabilities in this field may be added at the pod author's discretion. You must not list a capability in both allowedCapabilities and requiredDropCapabilities.
             */
            allowedCapabilities?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * allowedFlexVolumes is a whitelist of allowed Flexvolumes.  Empty or nil indicates that all Flexvolumes may be used.  This parameter is effective only when the usage of the Flexvolumes is allowed in the "volumes" field.
             */
            allowedFlexVolumes?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.AllowedFlexVolumePatch>[]>;
            /**
             * allowedHostPaths is a white list of allowed host paths. Empty indicates that all host paths may be used.
             */
            allowedHostPaths?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.AllowedHostPathPatch>[]>;
            /**
             * AllowedProcMountTypes is a whitelist of allowed ProcMountTypes. Empty or nil indicates that only the DefaultProcMountType may be used. This requires the ProcMountType feature flag to be enabled.
             */
            allowedProcMountTypes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * allowedUnsafeSysctls is a list of explicitly allowed unsafe sysctls, defaults to none. Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of allowed sysctls. Single * means all unsafe sysctls are allowed. Kubelet has to whitelist all allowed unsafe sysctls explicitly to avoid rejection.
             *
             * Examples: e.g. "foo/*" allows "foo/bar", "foo/baz", etc. e.g. "foo.*" allows "foo.bar", "foo.baz", etc.
             */
            allowedUnsafeSysctls?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * defaultAddCapabilities is the default set of capabilities that will be added to the container unless the pod spec specifically drops the capability.  You may not list a capability in both defaultAddCapabilities and requiredDropCapabilities. Capabilities added here are implicitly allowed, and need not be included in the allowedCapabilities list.
             */
            defaultAddCapabilities?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * defaultAllowPrivilegeEscalation controls the default setting for whether a process can gain more privileges than its parent process.
             */
            defaultAllowPrivilegeEscalation?: pulumi.Input<boolean>;
            /**
             * forbiddenSysctls is a list of explicitly forbidden sysctls, defaults to none. Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of forbidden sysctls. Single * means all sysctls are forbidden.
             *
             * Examples: e.g. "foo/*" forbids "foo/bar", "foo/baz", etc. e.g. "foo.*" forbids "foo.bar", "foo.baz", etc.
             */
            forbiddenSysctls?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * fsGroup is the strategy that will dictate what fs group is used by the SecurityContext.
             */
            fsGroup?: pulumi.Input<inputs.extensions.v1beta1.FSGroupStrategyOptionsPatch>;
            /**
             * hostIPC determines if the policy allows the use of HostIPC in the pod spec.
             */
            hostIPC?: pulumi.Input<boolean>;
            /**
             * hostNetwork determines if the policy allows the use of HostNetwork in the pod spec.
             */
            hostNetwork?: pulumi.Input<boolean>;
            /**
             * hostPID determines if the policy allows the use of HostPID in the pod spec.
             */
            hostPID?: pulumi.Input<boolean>;
            /**
             * hostPorts determines which host port ranges are allowed to be exposed.
             */
            hostPorts?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.HostPortRangePatch>[]>;
            /**
             * privileged determines if a pod can request to be run as privileged.
             */
            privileged?: pulumi.Input<boolean>;
            /**
             * readOnlyRootFilesystem when set to true will force containers to run with a read only root file system.  If the container specifically requests to run with a non-read only root file system the PSP should deny the pod. If set to false the container may run with a read only root file system if it wishes but it will not be forced to.
             */
            readOnlyRootFilesystem?: pulumi.Input<boolean>;
            /**
             * requiredDropCapabilities are the capabilities that will be dropped from the container.  These are required to be dropped and cannot be added.
             */
            requiredDropCapabilities?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * RunAsGroup is the strategy that will dictate the allowable RunAsGroup values that may be set. If this field is omitted, the pod's RunAsGroup can take any value. This field requires the RunAsGroup feature gate to be enabled.
             */
            runAsGroup?: pulumi.Input<inputs.extensions.v1beta1.RunAsGroupStrategyOptionsPatch>;
            /**
             * runAsUser is the strategy that will dictate the allowable RunAsUser values that may be set.
             */
            runAsUser?: pulumi.Input<inputs.extensions.v1beta1.RunAsUserStrategyOptionsPatch>;
            /**
             * runtimeClass is the strategy that will dictate the allowable RuntimeClasses for a pod. If this field is omitted, the pod's runtimeClassName field is unrestricted. Enforcement of this field depends on the RuntimeClass feature gate being enabled.
             */
            runtimeClass?: pulumi.Input<inputs.extensions.v1beta1.RuntimeClassStrategyOptionsPatch>;
            /**
             * seLinux is the strategy that will dictate the allowable labels that may be set.
             */
            seLinux?: pulumi.Input<inputs.extensions.v1beta1.SELinuxStrategyOptionsPatch>;
            /**
             * supplementalGroups is the strategy that will dictate what supplemental groups are used by the SecurityContext.
             */
            supplementalGroups?: pulumi.Input<inputs.extensions.v1beta1.SupplementalGroupsStrategyOptionsPatch>;
            /**
             * volumes is a white list of allowed volume plugins. Empty indicates that no volumes may be used. To allow all volumes you may use '*'.
             */
            volumes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ReplicaSet ensures that a specified number of pod replicas are running at any given time.
         */
        interface ReplicaSet {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"extensions/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ReplicaSet">;
            /**
             * If the Labels of a ReplicaSet are empty, they are defaulted to be the same as the Pod(s) that the ReplicaSet manages. Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines the specification of the desired behavior of the ReplicaSet. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.extensions.v1beta1.ReplicaSetSpec>;
            /**
             * Status is the most recently observed status of the ReplicaSet. This data may be out of date by some window of time. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.extensions.v1beta1.ReplicaSetStatus>;
        }
        /**
         * ReplicaSetCondition describes the state of a replica set at a certain point.
         */
        interface ReplicaSetCondition {
            /**
             * The last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of replica set condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * ReplicaSetSpec is the specification of a ReplicaSet.
         */
        interface ReplicaSetSpec {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Replicas is the number of desired replicas. This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller/#what-is-a-replicationcontroller
             */
            replicas?: pulumi.Input<number>;
            /**
             * Selector is a label query over pods that should match the replica count. If the selector is empty, it is defaulted to the labels present on the pod template. Label keys and values that must match in order to be controlled by this replica set. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * Template is the object that describes the pod that will be created if insufficient replicas are detected. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpec>;
        }
        /**
         * ReplicaSetSpec is the specification of a ReplicaSet.
         */
        interface ReplicaSetSpecPatch {
            /**
             * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)
             */
            minReadySeconds?: pulumi.Input<number>;
            /**
             * Replicas is the number of desired replicas. This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller/#what-is-a-replicationcontroller
             */
            replicas?: pulumi.Input<number>;
            /**
             * Selector is a label query over pods that should match the replica count. If the selector is empty, it is defaulted to the labels present on the pod template. Label keys and values that must match in order to be controlled by this replica set. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * Template is the object that describes the pod that will be created if insufficient replicas are detected. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
             */
            template?: pulumi.Input<inputs.core.v1.PodTemplateSpecPatch>;
        }
        /**
         * ReplicaSetStatus represents the current status of a ReplicaSet.
         */
        interface ReplicaSetStatus {
            /**
             * The number of available replicas (ready for at least minReadySeconds) for this replica set.
             */
            availableReplicas?: pulumi.Input<number>;
            /**
             * Represents the latest available observations of a replica set's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.ReplicaSetCondition>[]>;
            /**
             * The number of pods that have labels matching the labels of the pod template of the replicaset.
             */
            fullyLabeledReplicas?: pulumi.Input<number>;
            /**
             * ObservedGeneration reflects the generation of the most recently observed ReplicaSet.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * The number of ready replicas for this replica set.
             */
            readyReplicas?: pulumi.Input<number>;
            /**
             * Replicas is the most recently oberved number of replicas. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller/#what-is-a-replicationcontroller
             */
            replicas: pulumi.Input<number>;
        }
        /**
         * DEPRECATED.
         */
        interface RollbackConfig {
            /**
             * The revision to rollback to. If set to 0, rollback to the last revision.
             */
            revision?: pulumi.Input<number>;
        }
        /**
         * DEPRECATED.
         */
        interface RollbackConfigPatch {
            /**
             * The revision to rollback to. If set to 0, rollback to the last revision.
             */
            revision?: pulumi.Input<number>;
        }
        /**
         * Spec to control the desired behavior of daemon set rolling update.
         */
        interface RollingUpdateDaemonSet {
            /**
             * The maximum number of DaemonSet pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of total number of DaemonSet pods at the start of the update (ex: 10%). Absolute number is calculated from percentage by rounding up. This cannot be 0. Default value is 1. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their pods stopped for an update at any given time. The update starts by stopping at most 30% of those DaemonSet pods and then brings up new DaemonSet pods in their place. Once the new pods are available, it then proceeds onto other DaemonSet pods, thus ensuring that at least 70% of original number of DaemonSet pods are available at all times during the update.
             */
            maxUnavailable?: pulumi.Input<number | string>;
        }
        /**
         * Spec to control the desired behavior of daemon set rolling update.
         */
        interface RollingUpdateDaemonSetPatch {
            /**
             * The maximum number of DaemonSet pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of total number of DaemonSet pods at the start of the update (ex: 10%). Absolute number is calculated from percentage by rounding up. This cannot be 0. Default value is 1. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their pods stopped for an update at any given time. The update starts by stopping at most 30% of those DaemonSet pods and then brings up new DaemonSet pods in their place. Once the new pods are available, it then proceeds onto other DaemonSet pods, thus ensuring that at least 70% of original number of DaemonSet pods are available at all times during the update.
             */
            maxUnavailable?: pulumi.Input<number | string>;
        }
        /**
         * Spec to control the desired behavior of rolling update.
         */
        interface RollingUpdateDeployment {
            /**
             * The maximum number of pods that can be scheduled above the desired number of pods. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). This can not be 0 if MaxUnavailable is 0. Absolute number is calculated from percentage by rounding up. By default, a value of 1 is used. Example: when this is set to 30%, the new RC can be scaled up immediately when the rolling update starts, such that the total number of old and new pods do not exceed 130% of desired pods. Once old pods have been killed, new RC can be scaled up further, ensuring that total number of pods running at any time during the update is at most 130% of desired pods.
             */
            maxSurge?: pulumi.Input<number | string>;
            /**
             * The maximum number of pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). Absolute number is calculated from percentage by rounding down. This can not be 0 if MaxSurge is 0. By default, a fixed value of 1 is used. Example: when this is set to 30%, the old RC can be scaled down to 70% of desired pods immediately when the rolling update starts. Once new pods are ready, old RC can be scaled down further, followed by scaling up the new RC, ensuring that the total number of pods available at all times during the update is at least 70% of desired pods.
             */
            maxUnavailable?: pulumi.Input<number | string>;
        }
        /**
         * Spec to control the desired behavior of rolling update.
         */
        interface RollingUpdateDeploymentPatch {
            /**
             * The maximum number of pods that can be scheduled above the desired number of pods. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). This can not be 0 if MaxUnavailable is 0. Absolute number is calculated from percentage by rounding up. By default, a value of 1 is used. Example: when this is set to 30%, the new RC can be scaled up immediately when the rolling update starts, such that the total number of old and new pods do not exceed 130% of desired pods. Once old pods have been killed, new RC can be scaled up further, ensuring that total number of pods running at any time during the update is at most 130% of desired pods.
             */
            maxSurge?: pulumi.Input<number | string>;
            /**
             * The maximum number of pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). Absolute number is calculated from percentage by rounding down. This can not be 0 if MaxSurge is 0. By default, a fixed value of 1 is used. Example: when this is set to 30%, the old RC can be scaled down to 70% of desired pods immediately when the rolling update starts. Once new pods are ready, old RC can be scaled down further, followed by scaling up the new RC, ensuring that the total number of pods available at all times during the update is at least 70% of desired pods.
             */
            maxUnavailable?: pulumi.Input<number | string>;
        }
        /**
         * RunAsGroupStrategyOptions defines the strategy type and any options used to create the strategy. Deprecated: use RunAsGroupStrategyOptions from policy API Group instead.
         */
        interface RunAsGroupStrategyOptions {
            /**
             * ranges are the allowed ranges of gids that may be used. If you would like to force a single gid then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.IDRange>[]>;
            /**
             * rule is the strategy that will dictate the allowable RunAsGroup values that may be set.
             */
            rule: pulumi.Input<string>;
        }
        /**
         * RunAsGroupStrategyOptions defines the strategy type and any options used to create the strategy. Deprecated: use RunAsGroupStrategyOptions from policy API Group instead.
         */
        interface RunAsGroupStrategyOptionsPatch {
            /**
             * ranges are the allowed ranges of gids that may be used. If you would like to force a single gid then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.IDRangePatch>[]>;
            /**
             * rule is the strategy that will dictate the allowable RunAsGroup values that may be set.
             */
            rule?: pulumi.Input<string>;
        }
        /**
         * RunAsUserStrategyOptions defines the strategy type and any options used to create the strategy. Deprecated: use RunAsUserStrategyOptions from policy API Group instead.
         */
        interface RunAsUserStrategyOptions {
            /**
             * ranges are the allowed ranges of uids that may be used. If you would like to force a single uid then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.IDRange>[]>;
            /**
             * rule is the strategy that will dictate the allowable RunAsUser values that may be set.
             */
            rule: pulumi.Input<string>;
        }
        /**
         * RunAsUserStrategyOptions defines the strategy type and any options used to create the strategy. Deprecated: use RunAsUserStrategyOptions from policy API Group instead.
         */
        interface RunAsUserStrategyOptionsPatch {
            /**
             * ranges are the allowed ranges of uids that may be used. If you would like to force a single uid then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.IDRangePatch>[]>;
            /**
             * rule is the strategy that will dictate the allowable RunAsUser values that may be set.
             */
            rule?: pulumi.Input<string>;
        }
        /**
         * RuntimeClassStrategyOptions define the strategy that will dictate the allowable RuntimeClasses for a pod.
         */
        interface RuntimeClassStrategyOptions {
            /**
             * allowedRuntimeClassNames is a whitelist of RuntimeClass names that may be specified on a pod. A value of "*" means that any RuntimeClass name is allowed, and must be the only item in the list. An empty list requires the RuntimeClassName field to be unset.
             */
            allowedRuntimeClassNames: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * defaultRuntimeClassName is the default RuntimeClassName to set on the pod. The default MUST be allowed by the allowedRuntimeClassNames list. A value of nil does not mutate the Pod.
             */
            defaultRuntimeClassName?: pulumi.Input<string>;
        }
        /**
         * RuntimeClassStrategyOptions define the strategy that will dictate the allowable RuntimeClasses for a pod.
         */
        interface RuntimeClassStrategyOptionsPatch {
            /**
             * allowedRuntimeClassNames is a whitelist of RuntimeClass names that may be specified on a pod. A value of "*" means that any RuntimeClass name is allowed, and must be the only item in the list. An empty list requires the RuntimeClassName field to be unset.
             */
            allowedRuntimeClassNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * defaultRuntimeClassName is the default RuntimeClassName to set on the pod. The default MUST be allowed by the allowedRuntimeClassNames list. A value of nil does not mutate the Pod.
             */
            defaultRuntimeClassName?: pulumi.Input<string>;
        }
        /**
         * SELinuxStrategyOptions defines the strategy type and any options used to create the strategy. Deprecated: use SELinuxStrategyOptions from policy API Group instead.
         */
        interface SELinuxStrategyOptions {
            /**
             * rule is the strategy that will dictate the allowable labels that may be set.
             */
            rule: pulumi.Input<string>;
            /**
             * seLinuxOptions required to run as; required for MustRunAs More info: https://kubernetes.io/docs/tasks/configure-pod-container/security-context/
             */
            seLinuxOptions?: pulumi.Input<inputs.core.v1.SELinuxOptions>;
        }
        /**
         * SELinuxStrategyOptions defines the strategy type and any options used to create the strategy. Deprecated: use SELinuxStrategyOptions from policy API Group instead.
         */
        interface SELinuxStrategyOptionsPatch {
            /**
             * rule is the strategy that will dictate the allowable labels that may be set.
             */
            rule?: pulumi.Input<string>;
            /**
             * seLinuxOptions required to run as; required for MustRunAs More info: https://kubernetes.io/docs/tasks/configure-pod-container/security-context/
             */
            seLinuxOptions?: pulumi.Input<inputs.core.v1.SELinuxOptionsPatch>;
        }
        /**
         * SupplementalGroupsStrategyOptions defines the strategy type and options used to create the strategy. Deprecated: use SupplementalGroupsStrategyOptions from policy API Group instead.
         */
        interface SupplementalGroupsStrategyOptions {
            /**
             * ranges are the allowed ranges of supplemental groups.  If you would like to force a single supplemental group then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.IDRange>[]>;
            /**
             * rule is the strategy that will dictate what supplemental groups is used in the SecurityContext.
             */
            rule?: pulumi.Input<string>;
        }
        /**
         * SupplementalGroupsStrategyOptions defines the strategy type and options used to create the strategy. Deprecated: use SupplementalGroupsStrategyOptions from policy API Group instead.
         */
        interface SupplementalGroupsStrategyOptionsPatch {
            /**
             * ranges are the allowed ranges of supplemental groups.  If you would like to force a single supplemental group then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.extensions.v1beta1.IDRangePatch>[]>;
            /**
             * rule is the strategy that will dictate what supplemental groups is used in the SecurityContext.
             */
            rule?: pulumi.Input<string>;
        }
    }
}
export declare namespace flowcontrol {
    namespace v1 {
        /**
         * ExemptPriorityLevelConfiguration describes the configurable aspects of the handling of exempt requests. In the mandatory exempt configuration object the values in the fields here can be modified by authorized users, unlike the rest of the `spec`.
         */
        interface ExemptPriorityLevelConfiguration {
            /**
             * `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels.  This value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.
             *
             * LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
             */
            lendablePercent?: pulumi.Input<number>;
            /**
             * `nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats nominally reserved for this priority level. This DOES NOT limit the dispatching from this priority level but affects the other priority levels through the borrowing mechanism. The server's concurrency limit (ServerCL) is divided among all the priority levels in proportion to their NCS values:
             *
             * NominalCL(i)  = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[priority level k] NCS(k)
             *
             * Bigger numbers mean a larger nominal concurrency limit, at the expense of every other priority level. This field has a default value of zero.
             */
            nominalConcurrencyShares?: pulumi.Input<number>;
        }
        /**
         * ExemptPriorityLevelConfiguration describes the configurable aspects of the handling of exempt requests. In the mandatory exempt configuration object the values in the fields here can be modified by authorized users, unlike the rest of the `spec`.
         */
        interface ExemptPriorityLevelConfigurationPatch {
            /**
             * `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels.  This value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.
             *
             * LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
             */
            lendablePercent?: pulumi.Input<number>;
            /**
             * `nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats nominally reserved for this priority level. This DOES NOT limit the dispatching from this priority level but affects the other priority levels through the borrowing mechanism. The server's concurrency limit (ServerCL) is divided among all the priority levels in proportion to their NCS values:
             *
             * NominalCL(i)  = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[priority level k] NCS(k)
             *
             * Bigger numbers mean a larger nominal concurrency limit, at the expense of every other priority level. This field has a default value of zero.
             */
            nominalConcurrencyShares?: pulumi.Input<number>;
        }
        /**
         * FlowDistinguisherMethod specifies the method of a flow distinguisher.
         */
        interface FlowDistinguisherMethod {
            /**
             * `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * FlowDistinguisherMethod specifies the method of a flow distinguisher.
         */
        interface FlowDistinguisherMethodPatch {
            /**
             * `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * FlowSchema defines the schema of a group of flows. Note that a flow is made up of a set of inbound API requests with similar attributes and is identified by a pair of strings: the name of the FlowSchema and a "flow distinguisher".
         */
        interface FlowSchema {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"flowcontrol.apiserver.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"FlowSchema">;
            /**
             * `metadata` is the standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * `spec` is the specification of the desired behavior of a FlowSchema. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.flowcontrol.v1.FlowSchemaSpec>;
            /**
             * `status` is the current status of a FlowSchema. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.flowcontrol.v1.FlowSchemaStatus>;
        }
        /**
         * FlowSchemaCondition describes conditions for a FlowSchema.
         */
        interface FlowSchemaCondition {
            /**
             * `lastTransitionTime` is the last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * `message` is a human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * `reason` is a unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * `status` is the status of the condition. Can be True, False, Unknown. Required.
             */
            status?: pulumi.Input<string>;
            /**
             * `type` is the type of the condition. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * FlowSchemaSpec describes how the FlowSchema's specification looks like.
         */
        interface FlowSchemaSpec {
            /**
             * `distinguisherMethod` defines how to compute the flow distinguisher for requests that match this schema. `nil` specifies that the distinguisher is disabled and thus will always be the empty string.
             */
            distinguisherMethod?: pulumi.Input<inputs.flowcontrol.v1.FlowDistinguisherMethod>;
            /**
             * `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default.
             */
            matchingPrecedence?: pulumi.Input<number>;
            /**
             * `priorityLevelConfiguration` should reference a PriorityLevelConfiguration in the cluster. If the reference cannot be resolved, the FlowSchema will be ignored and marked as invalid in its status. Required.
             */
            priorityLevelConfiguration: pulumi.Input<inputs.flowcontrol.v1.PriorityLevelConfigurationReference>;
            /**
             * `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1.PolicyRulesWithSubjects>[]>;
        }
        /**
         * FlowSchemaSpec describes how the FlowSchema's specification looks like.
         */
        interface FlowSchemaSpecPatch {
            /**
             * `distinguisherMethod` defines how to compute the flow distinguisher for requests that match this schema. `nil` specifies that the distinguisher is disabled and thus will always be the empty string.
             */
            distinguisherMethod?: pulumi.Input<inputs.flowcontrol.v1.FlowDistinguisherMethodPatch>;
            /**
             * `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default.
             */
            matchingPrecedence?: pulumi.Input<number>;
            /**
             * `priorityLevelConfiguration` should reference a PriorityLevelConfiguration in the cluster. If the reference cannot be resolved, the FlowSchema will be ignored and marked as invalid in its status. Required.
             */
            priorityLevelConfiguration?: pulumi.Input<inputs.flowcontrol.v1.PriorityLevelConfigurationReferencePatch>;
            /**
             * `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1.PolicyRulesWithSubjectsPatch>[]>;
        }
        /**
         * FlowSchemaStatus represents the current state of a FlowSchema.
         */
        interface FlowSchemaStatus {
            /**
             * `conditions` is a list of the current states of FlowSchema.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1.FlowSchemaCondition>[]>;
        }
        /**
         * GroupSubject holds detailed information for group-kind subject.
         */
        interface GroupSubject {
            /**
             * name is the user group that matches, or "*" to match all user groups. See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * GroupSubject holds detailed information for group-kind subject.
         */
        interface GroupSubjectPatch {
            /**
             * name is the user group that matches, or "*" to match all user groups. See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * LimitResponse defines how to handle requests that can not be executed right now.
         */
        interface LimitResponse {
            /**
             * `queuing` holds the configuration parameters for queuing. This field may be non-empty only if `type` is `"Queue"`.
             */
            queuing?: pulumi.Input<inputs.flowcontrol.v1.QueuingConfiguration>;
            /**
             * `type` is "Queue" or "Reject". "Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * LimitResponse defines how to handle requests that can not be executed right now.
         */
        interface LimitResponsePatch {
            /**
             * `queuing` holds the configuration parameters for queuing. This field may be non-empty only if `type` is `"Queue"`.
             */
            queuing?: pulumi.Input<inputs.flowcontrol.v1.QueuingConfigurationPatch>;
            /**
             * `type` is "Queue" or "Reject". "Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:
         *   - How are requests for this priority level limited?
         *   - What should be done with requests that exceed the limit?
         */
        interface LimitedPriorityLevelConfiguration {
            /**
             * `borrowingLimitPercent`, if present, configures a limit on how many seats this priority level can borrow from other priority levels. The limit is known as this level's BorrowingConcurrencyLimit (BorrowingCL) and is a limit on the total number of seats that this level may borrow at any one time. This field holds the ratio of that limit to the level's nominal concurrency limit. When this field is non-nil, it must hold a non-negative integer and the limit is calculated as follows.
             *
             * BorrowingCL(i) = round( NominalCL(i) * borrowingLimitPercent(i)/100.0 )
             *
             * The value of this field can be more than 100, implying that this priority level can borrow a number of seats that is greater than its own nominal concurrency limit (NominalCL). When this field is left `nil`, the limit is effectively infinite.
             */
            borrowingLimitPercent?: pulumi.Input<number>;
            /**
             * `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels. The value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.
             *
             * LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
             */
            lendablePercent?: pulumi.Input<number>;
            /**
             * `limitResponse` indicates what to do with requests that can not be executed right now
             */
            limitResponse?: pulumi.Input<inputs.flowcontrol.v1.LimitResponse>;
            /**
             * `nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats available at this priority level. This is used both for requests dispatched from this priority level as well as requests dispatched from other priority levels borrowing seats from this level. The server's concurrency limit (ServerCL) is divided among the Limited priority levels in proportion to their NCS values:
             *
             * NominalCL(i)  = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[priority level k] NCS(k)
             *
             * Bigger numbers mean a larger nominal concurrency limit, at the expense of every other priority level.
             *
             * If not specified, this field defaults to a value of 30.
             *
             * Setting this field to zero supports the construction of a "jail" for this priority level that is used to hold some request(s)
             */
            nominalConcurrencyShares?: pulumi.Input<number>;
        }
        /**
         * LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:
         *   - How are requests for this priority level limited?
         *   - What should be done with requests that exceed the limit?
         */
        interface LimitedPriorityLevelConfigurationPatch {
            /**
             * `borrowingLimitPercent`, if present, configures a limit on how many seats this priority level can borrow from other priority levels. The limit is known as this level's BorrowingConcurrencyLimit (BorrowingCL) and is a limit on the total number of seats that this level may borrow at any one time. This field holds the ratio of that limit to the level's nominal concurrency limit. When this field is non-nil, it must hold a non-negative integer and the limit is calculated as follows.
             *
             * BorrowingCL(i) = round( NominalCL(i) * borrowingLimitPercent(i)/100.0 )
             *
             * The value of this field can be more than 100, implying that this priority level can borrow a number of seats that is greater than its own nominal concurrency limit (NominalCL). When this field is left `nil`, the limit is effectively infinite.
             */
            borrowingLimitPercent?: pulumi.Input<number>;
            /**
             * `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels. The value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.
             *
             * LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
             */
            lendablePercent?: pulumi.Input<number>;
            /**
             * `limitResponse` indicates what to do with requests that can not be executed right now
             */
            limitResponse?: pulumi.Input<inputs.flowcontrol.v1.LimitResponsePatch>;
            /**
             * `nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats available at this priority level. This is used both for requests dispatched from this priority level as well as requests dispatched from other priority levels borrowing seats from this level. The server's concurrency limit (ServerCL) is divided among the Limited priority levels in proportion to their NCS values:
             *
             * NominalCL(i)  = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[priority level k] NCS(k)
             *
             * Bigger numbers mean a larger nominal concurrency limit, at the expense of every other priority level.
             *
             * If not specified, this field defaults to a value of 30.
             *
             * Setting this field to zero supports the construction of a "jail" for this priority level that is used to hold some request(s)
             */
            nominalConcurrencyShares?: pulumi.Input<number>;
        }
        /**
         * NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.
         */
        interface NonResourcePolicyRule {
            /**
             * `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. For example:
             *   - "/healthz" is legal
             *   - "/hea*" is illegal
             *   - "/hea" is legal but matches nothing
             *   - "/hea/*" also matches nothing
             *   - "/healthz/*" matches all per-component health checks.
             * "*" matches all non-resource urls. if it is present, it must be the only entry. Required.
             */
            nonResourceURLs: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required.
             */
            verbs: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.
         */
        interface NonResourcePolicyRulePatch {
            /**
             * `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. For example:
             *   - "/healthz" is legal
             *   - "/hea*" is illegal
             *   - "/hea" is legal but matches nothing
             *   - "/hea/*" also matches nothing
             *   - "/healthz/*" matches all per-component health checks.
             * "*" matches all non-resource urls. if it is present, it must be the only entry. Required.
             */
            nonResourceURLs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required.
             */
            verbs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver. The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request.
         */
        interface PolicyRulesWithSubjects {
            /**
             * `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL.
             */
            nonResourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1.NonResourcePolicyRule>[]>;
            /**
             * `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. At least one of `resourceRules` and `nonResourceRules` has to be non-empty.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1.ResourcePolicyRule>[]>;
            /**
             * subjects is the list of normal user, serviceaccount, or group that this rule cares about. There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required.
             */
            subjects: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1.Subject>[]>;
        }
        /**
         * PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver. The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request.
         */
        interface PolicyRulesWithSubjectsPatch {
            /**
             * `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL.
             */
            nonResourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1.NonResourcePolicyRulePatch>[]>;
            /**
             * `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. At least one of `resourceRules` and `nonResourceRules` has to be non-empty.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1.ResourcePolicyRulePatch>[]>;
            /**
             * subjects is the list of normal user, serviceaccount, or group that this rule cares about. There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required.
             */
            subjects?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1.SubjectPatch>[]>;
        }
        /**
         * PriorityLevelConfiguration represents the configuration of a priority level.
         */
        interface PriorityLevelConfiguration {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"flowcontrol.apiserver.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PriorityLevelConfiguration">;
            /**
             * `metadata` is the standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * `spec` is the specification of the desired behavior of a "request-priority". More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.flowcontrol.v1.PriorityLevelConfigurationSpec>;
            /**
             * `status` is the current status of a "request-priority". More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.flowcontrol.v1.PriorityLevelConfigurationStatus>;
        }
        /**
         * PriorityLevelConfigurationCondition defines the condition of priority level.
         */
        interface PriorityLevelConfigurationCondition {
            /**
             * `lastTransitionTime` is the last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * `message` is a human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * `reason` is a unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * `status` is the status of the condition. Can be True, False, Unknown. Required.
             */
            status?: pulumi.Input<string>;
            /**
             * `type` is the type of the condition. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationReference contains information that points to the "request-priority" being used.
         */
        interface PriorityLevelConfigurationReference {
            /**
             * `name` is the name of the priority level configuration being referenced Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationReference contains information that points to the "request-priority" being used.
         */
        interface PriorityLevelConfigurationReferencePatch {
            /**
             * `name` is the name of the priority level configuration being referenced Required.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationSpec specifies the configuration of a priority level.
         */
        interface PriorityLevelConfigurationSpec {
            /**
             * `exempt` specifies how requests are handled for an exempt priority level. This field MUST be empty if `type` is `"Limited"`. This field MAY be non-empty if `type` is `"Exempt"`. If empty and `type` is `"Exempt"` then the default values for `ExemptPriorityLevelConfiguration` apply.
             */
            exempt?: pulumi.Input<inputs.flowcontrol.v1.ExemptPriorityLevelConfiguration>;
            /**
             * `limited` specifies how requests are handled for a Limited priority level. This field must be non-empty if and only if `type` is `"Limited"`.
             */
            limited?: pulumi.Input<inputs.flowcontrol.v1.LimitedPriorityLevelConfiguration>;
            /**
             * `type` indicates whether this priority level is subject to limitation on request execution.  A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationSpec specifies the configuration of a priority level.
         */
        interface PriorityLevelConfigurationSpecPatch {
            /**
             * `exempt` specifies how requests are handled for an exempt priority level. This field MUST be empty if `type` is `"Limited"`. This field MAY be non-empty if `type` is `"Exempt"`. If empty and `type` is `"Exempt"` then the default values for `ExemptPriorityLevelConfiguration` apply.
             */
            exempt?: pulumi.Input<inputs.flowcontrol.v1.ExemptPriorityLevelConfigurationPatch>;
            /**
             * `limited` specifies how requests are handled for a Limited priority level. This field must be non-empty if and only if `type` is `"Limited"`.
             */
            limited?: pulumi.Input<inputs.flowcontrol.v1.LimitedPriorityLevelConfigurationPatch>;
            /**
             * `type` indicates whether this priority level is subject to limitation on request execution.  A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationStatus represents the current state of a "request-priority".
         */
        interface PriorityLevelConfigurationStatus {
            /**
             * `conditions` is the current state of "request-priority".
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1.PriorityLevelConfigurationCondition>[]>;
        }
        /**
         * QueuingConfiguration holds the configuration parameters for queuing
         */
        interface QueuingConfiguration {
            /**
             * `handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8.
             */
            handSize?: pulumi.Input<number>;
            /**
             * `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50.
             */
            queueLengthLimit?: pulumi.Input<number>;
            /**
             * `queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64.
             */
            queues?: pulumi.Input<number>;
        }
        /**
         * QueuingConfiguration holds the configuration parameters for queuing
         */
        interface QueuingConfigurationPatch {
            /**
             * `handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8.
             */
            handSize?: pulumi.Input<number>;
            /**
             * `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50.
             */
            queueLengthLimit?: pulumi.Input<number>;
            /**
             * `queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64.
             */
            queues?: pulumi.Input<number>;
        }
        /**
         * ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource. A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) either (d1) the request does not specify a namespace (i.e., `Namespace==""`) and clusterScope is true or (d2) the request specifies a namespace and least one member of namespaces matches the request's namespace.
         */
        interface ResourcePolicyRule {
            /**
             * `apiGroups` is a list of matching API groups and may not be empty. "*" matches all API groups and, if present, must be the only entry. Required.
             */
            apiGroups: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). If this field is omitted or false then the `namespaces` field must contain a non-empty list.
             */
            clusterScope?: pulumi.Input<boolean>;
            /**
             * `namespaces` is a list of target namespaces that restricts matches.  A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true.
             */
            namespaces?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required.
             */
            resources: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs and, if present, must be the only entry. Required.
             */
            verbs: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource. A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) either (d1) the request does not specify a namespace (i.e., `Namespace==""`) and clusterScope is true or (d2) the request specifies a namespace and least one member of namespaces matches the request's namespace.
         */
        interface ResourcePolicyRulePatch {
            /**
             * `apiGroups` is a list of matching API groups and may not be empty. "*" matches all API groups and, if present, must be the only entry. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). If this field is omitted or false then the `namespaces` field must contain a non-empty list.
             */
            clusterScope?: pulumi.Input<boolean>;
            /**
             * `namespaces` is a list of target namespaces that restricts matches.  A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true.
             */
            namespaces?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs and, if present, must be the only entry. Required.
             */
            verbs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ServiceAccountSubject holds detailed information for service-account-kind subject.
         */
        interface ServiceAccountSubject {
            /**
             * `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. Required.
             */
            name: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of matching ServiceAccount objects. Required.
             */
            namespace: pulumi.Input<string>;
        }
        /**
         * ServiceAccountSubject holds detailed information for service-account-kind subject.
         */
        interface ServiceAccountSubjectPatch {
            /**
             * `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. Required.
             */
            name?: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of matching ServiceAccount objects. Required.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account.
         */
        interface Subject {
            /**
             * `group` matches based on user group name.
             */
            group?: pulumi.Input<inputs.flowcontrol.v1.GroupSubject>;
            /**
             * `kind` indicates which one of the other fields is non-empty. Required
             */
            kind: pulumi.Input<string>;
            /**
             * `serviceAccount` matches ServiceAccounts.
             */
            serviceAccount?: pulumi.Input<inputs.flowcontrol.v1.ServiceAccountSubject>;
            /**
             * `user` matches based on username.
             */
            user?: pulumi.Input<inputs.flowcontrol.v1.UserSubject>;
        }
        /**
         * Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account.
         */
        interface SubjectPatch {
            /**
             * `group` matches based on user group name.
             */
            group?: pulumi.Input<inputs.flowcontrol.v1.GroupSubjectPatch>;
            /**
             * `kind` indicates which one of the other fields is non-empty. Required
             */
            kind?: pulumi.Input<string>;
            /**
             * `serviceAccount` matches ServiceAccounts.
             */
            serviceAccount?: pulumi.Input<inputs.flowcontrol.v1.ServiceAccountSubjectPatch>;
            /**
             * `user` matches based on username.
             */
            user?: pulumi.Input<inputs.flowcontrol.v1.UserSubjectPatch>;
        }
        /**
         * UserSubject holds detailed information for user-kind subject.
         */
        interface UserSubject {
            /**
             * `name` is the username that matches, or "*" to match all usernames. Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * UserSubject holds detailed information for user-kind subject.
         */
        interface UserSubjectPatch {
            /**
             * `name` is the username that matches, or "*" to match all usernames. Required.
             */
            name?: pulumi.Input<string>;
        }
    }
    namespace v1alpha1 {
        /**
         * FlowDistinguisherMethod specifies the method of a flow distinguisher.
         */
        interface FlowDistinguisherMethod {
            /**
             * `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * FlowDistinguisherMethod specifies the method of a flow distinguisher.
         */
        interface FlowDistinguisherMethodPatch {
            /**
             * `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * FlowSchema defines the schema of a group of flows. Note that a flow is made up of a set of inbound API requests with similar attributes and is identified by a pair of strings: the name of the FlowSchema and a "flow distinguisher".
         */
        interface FlowSchema {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"flowcontrol.apiserver.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"FlowSchema">;
            /**
             * `metadata` is the standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * `spec` is the specification of the desired behavior of a FlowSchema. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.flowcontrol.v1alpha1.FlowSchemaSpec>;
            /**
             * `status` is the current status of a FlowSchema. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.flowcontrol.v1alpha1.FlowSchemaStatus>;
        }
        /**
         * FlowSchemaCondition describes conditions for a FlowSchema.
         */
        interface FlowSchemaCondition {
            /**
             * `lastTransitionTime` is the last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * `message` is a human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * `reason` is a unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * `status` is the status of the condition. Can be True, False, Unknown. Required.
             */
            status?: pulumi.Input<string>;
            /**
             * `type` is the type of the condition. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * FlowSchemaSpec describes how the FlowSchema's specification looks like.
         */
        interface FlowSchemaSpec {
            /**
             * `distinguisherMethod` defines how to compute the flow distinguisher for requests that match this schema. `nil` specifies that the distinguisher is disabled and thus will always be the empty string.
             */
            distinguisherMethod?: pulumi.Input<inputs.flowcontrol.v1alpha1.FlowDistinguisherMethod>;
            /**
             * `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be non-negative. Note that if the precedence is not specified or zero, it will be set to 1000 as default.
             */
            matchingPrecedence?: pulumi.Input<number>;
            /**
             * `priorityLevelConfiguration` should reference a PriorityLevelConfiguration in the cluster. If the reference cannot be resolved, the FlowSchema will be ignored and marked as invalid in its status. Required.
             */
            priorityLevelConfiguration: pulumi.Input<inputs.flowcontrol.v1alpha1.PriorityLevelConfigurationReference>;
            /**
             * `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1alpha1.PolicyRulesWithSubjects>[]>;
        }
        /**
         * FlowSchemaSpec describes how the FlowSchema's specification looks like.
         */
        interface FlowSchemaSpecPatch {
            /**
             * `distinguisherMethod` defines how to compute the flow distinguisher for requests that match this schema. `nil` specifies that the distinguisher is disabled and thus will always be the empty string.
             */
            distinguisherMethod?: pulumi.Input<inputs.flowcontrol.v1alpha1.FlowDistinguisherMethodPatch>;
            /**
             * `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be non-negative. Note that if the precedence is not specified or zero, it will be set to 1000 as default.
             */
            matchingPrecedence?: pulumi.Input<number>;
            /**
             * `priorityLevelConfiguration` should reference a PriorityLevelConfiguration in the cluster. If the reference cannot be resolved, the FlowSchema will be ignored and marked as invalid in its status. Required.
             */
            priorityLevelConfiguration?: pulumi.Input<inputs.flowcontrol.v1alpha1.PriorityLevelConfigurationReferencePatch>;
            /**
             * `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1alpha1.PolicyRulesWithSubjectsPatch>[]>;
        }
        /**
         * FlowSchemaStatus represents the current state of a FlowSchema.
         */
        interface FlowSchemaStatus {
            /**
             * `conditions` is a list of the current states of FlowSchema.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1alpha1.FlowSchemaCondition>[]>;
        }
        /**
         * GroupSubject holds detailed information for group-kind subject.
         */
        interface GroupSubject {
            /**
             * name is the user group that matches, or "*" to match all user groups. See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * GroupSubject holds detailed information for group-kind subject.
         */
        interface GroupSubjectPatch {
            /**
             * name is the user group that matches, or "*" to match all user groups. See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * LimitResponse defines how to handle requests that can not be executed right now.
         */
        interface LimitResponse {
            /**
             * `queuing` holds the configuration parameters for queuing. This field may be non-empty only if `type` is `"Queue"`.
             */
            queuing?: pulumi.Input<inputs.flowcontrol.v1alpha1.QueuingConfiguration>;
            /**
             * `type` is "Queue" or "Reject". "Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * LimitResponse defines how to handle requests that can not be executed right now.
         */
        interface LimitResponsePatch {
            /**
             * `queuing` holds the configuration parameters for queuing. This field may be non-empty only if `type` is `"Queue"`.
             */
            queuing?: pulumi.Input<inputs.flowcontrol.v1alpha1.QueuingConfigurationPatch>;
            /**
             * `type` is "Queue" or "Reject". "Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:
         *  * How are requests for this priority level limited?
         *  * What should be done with requests that exceed the limit?
         */
        interface LimitedPriorityLevelConfiguration {
            /**
             * `assuredConcurrencyShares` (ACS) configures the execution limit, which is a limit on the number of requests of this priority level that may be exeucting at a given time.  ACS must be a positive number. The server's concurrency limit (SCL) is divided among the concurrency-controlled priority levels in proportion to their assured concurrency shares. This produces the assured concurrency value (ACV) --- the number of requests that may be executing at a time --- for each such priority level:
             *
             *             ACV(l) = ceil( SCL * ACS(l) / ( sum[priority levels k] ACS(k) ) )
             *
             * bigger numbers of ACS mean more reserved concurrent requests (at the expense of every other PL). This field has a default value of 30.
             */
            assuredConcurrencyShares?: pulumi.Input<number>;
            /**
             * `limitResponse` indicates what to do with requests that can not be executed right now
             */
            limitResponse?: pulumi.Input<inputs.flowcontrol.v1alpha1.LimitResponse>;
        }
        /**
         * LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:
         *  * How are requests for this priority level limited?
         *  * What should be done with requests that exceed the limit?
         */
        interface LimitedPriorityLevelConfigurationPatch {
            /**
             * `assuredConcurrencyShares` (ACS) configures the execution limit, which is a limit on the number of requests of this priority level that may be exeucting at a given time.  ACS must be a positive number. The server's concurrency limit (SCL) is divided among the concurrency-controlled priority levels in proportion to their assured concurrency shares. This produces the assured concurrency value (ACV) --- the number of requests that may be executing at a time --- for each such priority level:
             *
             *             ACV(l) = ceil( SCL * ACS(l) / ( sum[priority levels k] ACS(k) ) )
             *
             * bigger numbers of ACS mean more reserved concurrent requests (at the expense of every other PL). This field has a default value of 30.
             */
            assuredConcurrencyShares?: pulumi.Input<number>;
            /**
             * `limitResponse` indicates what to do with requests that can not be executed right now
             */
            limitResponse?: pulumi.Input<inputs.flowcontrol.v1alpha1.LimitResponsePatch>;
        }
        /**
         * NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.
         */
        interface NonResourcePolicyRule {
            /**
             * `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. For example:
             *   - "/healthz" is legal
             *   - "/hea*" is illegal
             *   - "/hea" is legal but matches nothing
             *   - "/hea/*" also matches nothing
             *   - "/healthz/*" matches all per-component health checks.
             * "*" matches all non-resource urls. if it is present, it must be the only entry. Required.
             */
            nonResourceURLs: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required.
             */
            verbs: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.
         */
        interface NonResourcePolicyRulePatch {
            /**
             * `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. For example:
             *   - "/healthz" is legal
             *   - "/hea*" is illegal
             *   - "/hea" is legal but matches nothing
             *   - "/hea/*" also matches nothing
             *   - "/healthz/*" matches all per-component health checks.
             * "*" matches all non-resource urls. if it is present, it must be the only entry. Required.
             */
            nonResourceURLs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required.
             */
            verbs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver. The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request.
         */
        interface PolicyRulesWithSubjects {
            /**
             * `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL.
             */
            nonResourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1alpha1.NonResourcePolicyRule>[]>;
            /**
             * `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. At least one of `resourceRules` and `nonResourceRules` has to be non-empty.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1alpha1.ResourcePolicyRule>[]>;
            /**
             * subjects is the list of normal user, serviceaccount, or group that this rule cares about. There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required.
             */
            subjects: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1alpha1.Subject>[]>;
        }
        /**
         * PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver. The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request.
         */
        interface PolicyRulesWithSubjectsPatch {
            /**
             * `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL.
             */
            nonResourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1alpha1.NonResourcePolicyRulePatch>[]>;
            /**
             * `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. At least one of `resourceRules` and `nonResourceRules` has to be non-empty.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1alpha1.ResourcePolicyRulePatch>[]>;
            /**
             * subjects is the list of normal user, serviceaccount, or group that this rule cares about. There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required.
             */
            subjects?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1alpha1.SubjectPatch>[]>;
        }
        /**
         * PriorityLevelConfiguration represents the configuration of a priority level.
         */
        interface PriorityLevelConfiguration {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"flowcontrol.apiserver.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PriorityLevelConfiguration">;
            /**
             * `metadata` is the standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * `spec` is the specification of the desired behavior of a "request-priority". More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.flowcontrol.v1alpha1.PriorityLevelConfigurationSpec>;
            /**
             * `status` is the current status of a "request-priority". More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.flowcontrol.v1alpha1.PriorityLevelConfigurationStatus>;
        }
        /**
         * PriorityLevelConfigurationCondition defines the condition of priority level.
         */
        interface PriorityLevelConfigurationCondition {
            /**
             * `lastTransitionTime` is the last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * `message` is a human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * `reason` is a unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * `status` is the status of the condition. Can be True, False, Unknown. Required.
             */
            status?: pulumi.Input<string>;
            /**
             * `type` is the type of the condition. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationReference contains information that points to the "request-priority" being used.
         */
        interface PriorityLevelConfigurationReference {
            /**
             * `name` is the name of the priority level configuration being referenced Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationReference contains information that points to the "request-priority" being used.
         */
        interface PriorityLevelConfigurationReferencePatch {
            /**
             * `name` is the name of the priority level configuration being referenced Required.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationSpec specifies the configuration of a priority level.
         */
        interface PriorityLevelConfigurationSpec {
            /**
             * `limited` specifies how requests are handled for a Limited priority level. This field must be non-empty if and only if `type` is `"Limited"`.
             */
            limited?: pulumi.Input<inputs.flowcontrol.v1alpha1.LimitedPriorityLevelConfiguration>;
            /**
             * `type` indicates whether this priority level is subject to limitation on request execution.  A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationSpec specifies the configuration of a priority level.
         */
        interface PriorityLevelConfigurationSpecPatch {
            /**
             * `limited` specifies how requests are handled for a Limited priority level. This field must be non-empty if and only if `type` is `"Limited"`.
             */
            limited?: pulumi.Input<inputs.flowcontrol.v1alpha1.LimitedPriorityLevelConfigurationPatch>;
            /**
             * `type` indicates whether this priority level is subject to limitation on request execution.  A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationStatus represents the current state of a "request-priority".
         */
        interface PriorityLevelConfigurationStatus {
            /**
             * `conditions` is the current state of "request-priority".
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1alpha1.PriorityLevelConfigurationCondition>[]>;
        }
        /**
         * QueuingConfiguration holds the configuration parameters for queuing
         */
        interface QueuingConfiguration {
            /**
             * `handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8.
             */
            handSize?: pulumi.Input<number>;
            /**
             * `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50.
             */
            queueLengthLimit?: pulumi.Input<number>;
            /**
             * `queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64.
             */
            queues?: pulumi.Input<number>;
        }
        /**
         * QueuingConfiguration holds the configuration parameters for queuing
         */
        interface QueuingConfigurationPatch {
            /**
             * `handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8.
             */
            handSize?: pulumi.Input<number>;
            /**
             * `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50.
             */
            queueLengthLimit?: pulumi.Input<number>;
            /**
             * `queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64.
             */
            queues?: pulumi.Input<number>;
        }
        /**
         * ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource. A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) least one member of namespaces matches the request.
         */
        interface ResourcePolicyRule {
            /**
             * `apiGroups` is a list of matching API groups and may not be empty. "*" matches all API groups and, if present, must be the only entry. Required.
             */
            apiGroups: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). If this field is omitted or false then the `namespaces` field must contain a non-empty list.
             */
            clusterScope?: pulumi.Input<boolean>;
            /**
             * `namespaces` is a list of target namespaces that restricts matches.  A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true.
             */
            namespaces?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required.
             */
            resources: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs and, if present, must be the only entry. Required.
             */
            verbs: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource. A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) least one member of namespaces matches the request.
         */
        interface ResourcePolicyRulePatch {
            /**
             * `apiGroups` is a list of matching API groups and may not be empty. "*" matches all API groups and, if present, must be the only entry. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). If this field is omitted or false then the `namespaces` field must contain a non-empty list.
             */
            clusterScope?: pulumi.Input<boolean>;
            /**
             * `namespaces` is a list of target namespaces that restricts matches.  A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true.
             */
            namespaces?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs and, if present, must be the only entry. Required.
             */
            verbs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ServiceAccountSubject holds detailed information for service-account-kind subject.
         */
        interface ServiceAccountSubject {
            /**
             * `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. Required.
             */
            name: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of matching ServiceAccount objects. Required.
             */
            namespace: pulumi.Input<string>;
        }
        /**
         * ServiceAccountSubject holds detailed information for service-account-kind subject.
         */
        interface ServiceAccountSubjectPatch {
            /**
             * `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. Required.
             */
            name?: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of matching ServiceAccount objects. Required.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account.
         */
        interface Subject {
            group?: pulumi.Input<inputs.flowcontrol.v1alpha1.GroupSubject>;
            /**
             * Required
             */
            kind: pulumi.Input<string>;
            serviceAccount?: pulumi.Input<inputs.flowcontrol.v1alpha1.ServiceAccountSubject>;
            user?: pulumi.Input<inputs.flowcontrol.v1alpha1.UserSubject>;
        }
        /**
         * Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account.
         */
        interface SubjectPatch {
            group?: pulumi.Input<inputs.flowcontrol.v1alpha1.GroupSubjectPatch>;
            /**
             * Required
             */
            kind?: pulumi.Input<string>;
            serviceAccount?: pulumi.Input<inputs.flowcontrol.v1alpha1.ServiceAccountSubjectPatch>;
            user?: pulumi.Input<inputs.flowcontrol.v1alpha1.UserSubjectPatch>;
        }
        /**
         * UserSubject holds detailed information for user-kind subject.
         */
        interface UserSubject {
            /**
             * `name` is the username that matches, or "*" to match all usernames. Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * UserSubject holds detailed information for user-kind subject.
         */
        interface UserSubjectPatch {
            /**
             * `name` is the username that matches, or "*" to match all usernames. Required.
             */
            name?: pulumi.Input<string>;
        }
    }
    namespace v1beta1 {
        /**
         * FlowDistinguisherMethod specifies the method of a flow distinguisher.
         */
        interface FlowDistinguisherMethod {
            /**
             * `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * FlowDistinguisherMethod specifies the method of a flow distinguisher.
         */
        interface FlowDistinguisherMethodPatch {
            /**
             * `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * FlowSchema defines the schema of a group of flows. Note that a flow is made up of a set of inbound API requests with similar attributes and is identified by a pair of strings: the name of the FlowSchema and a "flow distinguisher".
         */
        interface FlowSchema {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"flowcontrol.apiserver.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"FlowSchema">;
            /**
             * `metadata` is the standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * `spec` is the specification of the desired behavior of a FlowSchema. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.flowcontrol.v1beta1.FlowSchemaSpec>;
            /**
             * `status` is the current status of a FlowSchema. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.flowcontrol.v1beta1.FlowSchemaStatus>;
        }
        /**
         * FlowSchemaCondition describes conditions for a FlowSchema.
         */
        interface FlowSchemaCondition {
            /**
             * `lastTransitionTime` is the last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * `message` is a human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * `reason` is a unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * `status` is the status of the condition. Can be True, False, Unknown. Required.
             */
            status?: pulumi.Input<string>;
            /**
             * `type` is the type of the condition. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * FlowSchemaSpec describes how the FlowSchema's specification looks like.
         */
        interface FlowSchemaSpec {
            /**
             * `distinguisherMethod` defines how to compute the flow distinguisher for requests that match this schema. `nil` specifies that the distinguisher is disabled and thus will always be the empty string.
             */
            distinguisherMethod?: pulumi.Input<inputs.flowcontrol.v1beta1.FlowDistinguisherMethod>;
            /**
             * `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default.
             */
            matchingPrecedence?: pulumi.Input<number>;
            /**
             * `priorityLevelConfiguration` should reference a PriorityLevelConfiguration in the cluster. If the reference cannot be resolved, the FlowSchema will be ignored and marked as invalid in its status. Required.
             */
            priorityLevelConfiguration: pulumi.Input<inputs.flowcontrol.v1beta1.PriorityLevelConfigurationReference>;
            /**
             * `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta1.PolicyRulesWithSubjects>[]>;
        }
        /**
         * FlowSchemaSpec describes how the FlowSchema's specification looks like.
         */
        interface FlowSchemaSpecPatch {
            /**
             * `distinguisherMethod` defines how to compute the flow distinguisher for requests that match this schema. `nil` specifies that the distinguisher is disabled and thus will always be the empty string.
             */
            distinguisherMethod?: pulumi.Input<inputs.flowcontrol.v1beta1.FlowDistinguisherMethodPatch>;
            /**
             * `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default.
             */
            matchingPrecedence?: pulumi.Input<number>;
            /**
             * `priorityLevelConfiguration` should reference a PriorityLevelConfiguration in the cluster. If the reference cannot be resolved, the FlowSchema will be ignored and marked as invalid in its status. Required.
             */
            priorityLevelConfiguration?: pulumi.Input<inputs.flowcontrol.v1beta1.PriorityLevelConfigurationReferencePatch>;
            /**
             * `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta1.PolicyRulesWithSubjectsPatch>[]>;
        }
        /**
         * FlowSchemaStatus represents the current state of a FlowSchema.
         */
        interface FlowSchemaStatus {
            /**
             * `conditions` is a list of the current states of FlowSchema.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta1.FlowSchemaCondition>[]>;
        }
        /**
         * GroupSubject holds detailed information for group-kind subject.
         */
        interface GroupSubject {
            /**
             * name is the user group that matches, or "*" to match all user groups. See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * GroupSubject holds detailed information for group-kind subject.
         */
        interface GroupSubjectPatch {
            /**
             * name is the user group that matches, or "*" to match all user groups. See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * LimitResponse defines how to handle requests that can not be executed right now.
         */
        interface LimitResponse {
            /**
             * `queuing` holds the configuration parameters for queuing. This field may be non-empty only if `type` is `"Queue"`.
             */
            queuing?: pulumi.Input<inputs.flowcontrol.v1beta1.QueuingConfiguration>;
            /**
             * `type` is "Queue" or "Reject". "Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * LimitResponse defines how to handle requests that can not be executed right now.
         */
        interface LimitResponsePatch {
            /**
             * `queuing` holds the configuration parameters for queuing. This field may be non-empty only if `type` is `"Queue"`.
             */
            queuing?: pulumi.Input<inputs.flowcontrol.v1beta1.QueuingConfigurationPatch>;
            /**
             * `type` is "Queue" or "Reject". "Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:
         *  * How are requests for this priority level limited?
         *  * What should be done with requests that exceed the limit?
         */
        interface LimitedPriorityLevelConfiguration {
            /**
             * `assuredConcurrencyShares` (ACS) configures the execution limit, which is a limit on the number of requests of this priority level that may be exeucting at a given time.  ACS must be a positive number. The server's concurrency limit (SCL) is divided among the concurrency-controlled priority levels in proportion to their assured concurrency shares. This produces the assured concurrency value (ACV) --- the number of requests that may be executing at a time --- for each such priority level:
             *
             *             ACV(l) = ceil( SCL * ACS(l) / ( sum[priority levels k] ACS(k) ) )
             *
             * bigger numbers of ACS mean more reserved concurrent requests (at the expense of every other PL). This field has a default value of 30.
             */
            assuredConcurrencyShares?: pulumi.Input<number>;
            /**
             * `limitResponse` indicates what to do with requests that can not be executed right now
             */
            limitResponse?: pulumi.Input<inputs.flowcontrol.v1beta1.LimitResponse>;
        }
        /**
         * LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:
         *  * How are requests for this priority level limited?
         *  * What should be done with requests that exceed the limit?
         */
        interface LimitedPriorityLevelConfigurationPatch {
            /**
             * `assuredConcurrencyShares` (ACS) configures the execution limit, which is a limit on the number of requests of this priority level that may be exeucting at a given time.  ACS must be a positive number. The server's concurrency limit (SCL) is divided among the concurrency-controlled priority levels in proportion to their assured concurrency shares. This produces the assured concurrency value (ACV) --- the number of requests that may be executing at a time --- for each such priority level:
             *
             *             ACV(l) = ceil( SCL * ACS(l) / ( sum[priority levels k] ACS(k) ) )
             *
             * bigger numbers of ACS mean more reserved concurrent requests (at the expense of every other PL). This field has a default value of 30.
             */
            assuredConcurrencyShares?: pulumi.Input<number>;
            /**
             * `limitResponse` indicates what to do with requests that can not be executed right now
             */
            limitResponse?: pulumi.Input<inputs.flowcontrol.v1beta1.LimitResponsePatch>;
        }
        /**
         * NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.
         */
        interface NonResourcePolicyRule {
            /**
             * `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. For example:
             *   - "/healthz" is legal
             *   - "/hea*" is illegal
             *   - "/hea" is legal but matches nothing
             *   - "/hea/*" also matches nothing
             *   - "/healthz/*" matches all per-component health checks.
             * "*" matches all non-resource urls. if it is present, it must be the only entry. Required.
             */
            nonResourceURLs: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required.
             */
            verbs: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.
         */
        interface NonResourcePolicyRulePatch {
            /**
             * `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. For example:
             *   - "/healthz" is legal
             *   - "/hea*" is illegal
             *   - "/hea" is legal but matches nothing
             *   - "/hea/*" also matches nothing
             *   - "/healthz/*" matches all per-component health checks.
             * "*" matches all non-resource urls. if it is present, it must be the only entry. Required.
             */
            nonResourceURLs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required.
             */
            verbs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver. The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request.
         */
        interface PolicyRulesWithSubjects {
            /**
             * `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL.
             */
            nonResourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta1.NonResourcePolicyRule>[]>;
            /**
             * `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. At least one of `resourceRules` and `nonResourceRules` has to be non-empty.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta1.ResourcePolicyRule>[]>;
            /**
             * subjects is the list of normal user, serviceaccount, or group that this rule cares about. There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required.
             */
            subjects: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta1.Subject>[]>;
        }
        /**
         * PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver. The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request.
         */
        interface PolicyRulesWithSubjectsPatch {
            /**
             * `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL.
             */
            nonResourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta1.NonResourcePolicyRulePatch>[]>;
            /**
             * `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. At least one of `resourceRules` and `nonResourceRules` has to be non-empty.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta1.ResourcePolicyRulePatch>[]>;
            /**
             * subjects is the list of normal user, serviceaccount, or group that this rule cares about. There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required.
             */
            subjects?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta1.SubjectPatch>[]>;
        }
        /**
         * PriorityLevelConfiguration represents the configuration of a priority level.
         */
        interface PriorityLevelConfiguration {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"flowcontrol.apiserver.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PriorityLevelConfiguration">;
            /**
             * `metadata` is the standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * `spec` is the specification of the desired behavior of a "request-priority". More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.flowcontrol.v1beta1.PriorityLevelConfigurationSpec>;
            /**
             * `status` is the current status of a "request-priority". More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.flowcontrol.v1beta1.PriorityLevelConfigurationStatus>;
        }
        /**
         * PriorityLevelConfigurationCondition defines the condition of priority level.
         */
        interface PriorityLevelConfigurationCondition {
            /**
             * `lastTransitionTime` is the last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * `message` is a human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * `reason` is a unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * `status` is the status of the condition. Can be True, False, Unknown. Required.
             */
            status?: pulumi.Input<string>;
            /**
             * `type` is the type of the condition. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationReference contains information that points to the "request-priority" being used.
         */
        interface PriorityLevelConfigurationReference {
            /**
             * `name` is the name of the priority level configuration being referenced Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationReference contains information that points to the "request-priority" being used.
         */
        interface PriorityLevelConfigurationReferencePatch {
            /**
             * `name` is the name of the priority level configuration being referenced Required.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationSpec specifies the configuration of a priority level.
         */
        interface PriorityLevelConfigurationSpec {
            /**
             * `limited` specifies how requests are handled for a Limited priority level. This field must be non-empty if and only if `type` is `"Limited"`.
             */
            limited?: pulumi.Input<inputs.flowcontrol.v1beta1.LimitedPriorityLevelConfiguration>;
            /**
             * `type` indicates whether this priority level is subject to limitation on request execution.  A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationSpec specifies the configuration of a priority level.
         */
        interface PriorityLevelConfigurationSpecPatch {
            /**
             * `limited` specifies how requests are handled for a Limited priority level. This field must be non-empty if and only if `type` is `"Limited"`.
             */
            limited?: pulumi.Input<inputs.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationPatch>;
            /**
             * `type` indicates whether this priority level is subject to limitation on request execution.  A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationStatus represents the current state of a "request-priority".
         */
        interface PriorityLevelConfigurationStatus {
            /**
             * `conditions` is the current state of "request-priority".
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta1.PriorityLevelConfigurationCondition>[]>;
        }
        /**
         * QueuingConfiguration holds the configuration parameters for queuing
         */
        interface QueuingConfiguration {
            /**
             * `handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8.
             */
            handSize?: pulumi.Input<number>;
            /**
             * `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50.
             */
            queueLengthLimit?: pulumi.Input<number>;
            /**
             * `queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64.
             */
            queues?: pulumi.Input<number>;
        }
        /**
         * QueuingConfiguration holds the configuration parameters for queuing
         */
        interface QueuingConfigurationPatch {
            /**
             * `handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8.
             */
            handSize?: pulumi.Input<number>;
            /**
             * `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50.
             */
            queueLengthLimit?: pulumi.Input<number>;
            /**
             * `queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64.
             */
            queues?: pulumi.Input<number>;
        }
        /**
         * ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource. A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) least one member of namespaces matches the request.
         */
        interface ResourcePolicyRule {
            /**
             * `apiGroups` is a list of matching API groups and may not be empty. "*" matches all API groups and, if present, must be the only entry. Required.
             */
            apiGroups: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). If this field is omitted or false then the `namespaces` field must contain a non-empty list.
             */
            clusterScope?: pulumi.Input<boolean>;
            /**
             * `namespaces` is a list of target namespaces that restricts matches.  A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true.
             */
            namespaces?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required.
             */
            resources: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs and, if present, must be the only entry. Required.
             */
            verbs: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource. A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) least one member of namespaces matches the request.
         */
        interface ResourcePolicyRulePatch {
            /**
             * `apiGroups` is a list of matching API groups and may not be empty. "*" matches all API groups and, if present, must be the only entry. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). If this field is omitted or false then the `namespaces` field must contain a non-empty list.
             */
            clusterScope?: pulumi.Input<boolean>;
            /**
             * `namespaces` is a list of target namespaces that restricts matches.  A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true.
             */
            namespaces?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs and, if present, must be the only entry. Required.
             */
            verbs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ServiceAccountSubject holds detailed information for service-account-kind subject.
         */
        interface ServiceAccountSubject {
            /**
             * `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. Required.
             */
            name: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of matching ServiceAccount objects. Required.
             */
            namespace: pulumi.Input<string>;
        }
        /**
         * ServiceAccountSubject holds detailed information for service-account-kind subject.
         */
        interface ServiceAccountSubjectPatch {
            /**
             * `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. Required.
             */
            name?: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of matching ServiceAccount objects. Required.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account.
         */
        interface Subject {
            group?: pulumi.Input<inputs.flowcontrol.v1beta1.GroupSubject>;
            /**
             * Required
             */
            kind: pulumi.Input<string>;
            serviceAccount?: pulumi.Input<inputs.flowcontrol.v1beta1.ServiceAccountSubject>;
            user?: pulumi.Input<inputs.flowcontrol.v1beta1.UserSubject>;
        }
        /**
         * Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account.
         */
        interface SubjectPatch {
            group?: pulumi.Input<inputs.flowcontrol.v1beta1.GroupSubjectPatch>;
            /**
             * Required
             */
            kind?: pulumi.Input<string>;
            serviceAccount?: pulumi.Input<inputs.flowcontrol.v1beta1.ServiceAccountSubjectPatch>;
            user?: pulumi.Input<inputs.flowcontrol.v1beta1.UserSubjectPatch>;
        }
        /**
         * UserSubject holds detailed information for user-kind subject.
         */
        interface UserSubject {
            /**
             * `name` is the username that matches, or "*" to match all usernames. Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * UserSubject holds detailed information for user-kind subject.
         */
        interface UserSubjectPatch {
            /**
             * `name` is the username that matches, or "*" to match all usernames. Required.
             */
            name?: pulumi.Input<string>;
        }
    }
    namespace v1beta2 {
        /**
         * ExemptPriorityLevelConfiguration describes the configurable aspects of the handling of exempt requests. In the mandatory exempt configuration object the values in the fields here can be modified by authorized users, unlike the rest of the `spec`.
         */
        interface ExemptPriorityLevelConfiguration {
            /**
             * `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels.  This value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.
             *
             * LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
             */
            lendablePercent?: pulumi.Input<number>;
            /**
             * `nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats nominally reserved for this priority level. This DOES NOT limit the dispatching from this priority level but affects the other priority levels through the borrowing mechanism. The server's concurrency limit (ServerCL) is divided among all the priority levels in proportion to their NCS values:
             *
             * NominalCL(i)  = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[priority level k] NCS(k)
             *
             * Bigger numbers mean a larger nominal concurrency limit, at the expense of every other priority level. This field has a default value of zero.
             */
            nominalConcurrencyShares?: pulumi.Input<number>;
        }
        /**
         * ExemptPriorityLevelConfiguration describes the configurable aspects of the handling of exempt requests. In the mandatory exempt configuration object the values in the fields here can be modified by authorized users, unlike the rest of the `spec`.
         */
        interface ExemptPriorityLevelConfigurationPatch {
            /**
             * `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels.  This value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.
             *
             * LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
             */
            lendablePercent?: pulumi.Input<number>;
            /**
             * `nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats nominally reserved for this priority level. This DOES NOT limit the dispatching from this priority level but affects the other priority levels through the borrowing mechanism. The server's concurrency limit (ServerCL) is divided among all the priority levels in proportion to their NCS values:
             *
             * NominalCL(i)  = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[priority level k] NCS(k)
             *
             * Bigger numbers mean a larger nominal concurrency limit, at the expense of every other priority level. This field has a default value of zero.
             */
            nominalConcurrencyShares?: pulumi.Input<number>;
        }
        /**
         * FlowDistinguisherMethod specifies the method of a flow distinguisher.
         */
        interface FlowDistinguisherMethod {
            /**
             * `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * FlowDistinguisherMethod specifies the method of a flow distinguisher.
         */
        interface FlowDistinguisherMethodPatch {
            /**
             * `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * FlowSchema defines the schema of a group of flows. Note that a flow is made up of a set of inbound API requests with similar attributes and is identified by a pair of strings: the name of the FlowSchema and a "flow distinguisher".
         */
        interface FlowSchema {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"flowcontrol.apiserver.k8s.io/v1beta2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"FlowSchema">;
            /**
             * `metadata` is the standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * `spec` is the specification of the desired behavior of a FlowSchema. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.flowcontrol.v1beta2.FlowSchemaSpec>;
            /**
             * `status` is the current status of a FlowSchema. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.flowcontrol.v1beta2.FlowSchemaStatus>;
        }
        /**
         * FlowSchemaCondition describes conditions for a FlowSchema.
         */
        interface FlowSchemaCondition {
            /**
             * `lastTransitionTime` is the last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * `message` is a human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * `reason` is a unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * `status` is the status of the condition. Can be True, False, Unknown. Required.
             */
            status?: pulumi.Input<string>;
            /**
             * `type` is the type of the condition. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * FlowSchemaSpec describes how the FlowSchema's specification looks like.
         */
        interface FlowSchemaSpec {
            /**
             * `distinguisherMethod` defines how to compute the flow distinguisher for requests that match this schema. `nil` specifies that the distinguisher is disabled and thus will always be the empty string.
             */
            distinguisherMethod?: pulumi.Input<inputs.flowcontrol.v1beta2.FlowDistinguisherMethod>;
            /**
             * `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default.
             */
            matchingPrecedence?: pulumi.Input<number>;
            /**
             * `priorityLevelConfiguration` should reference a PriorityLevelConfiguration in the cluster. If the reference cannot be resolved, the FlowSchema will be ignored and marked as invalid in its status. Required.
             */
            priorityLevelConfiguration: pulumi.Input<inputs.flowcontrol.v1beta2.PriorityLevelConfigurationReference>;
            /**
             * `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta2.PolicyRulesWithSubjects>[]>;
        }
        /**
         * FlowSchemaSpec describes how the FlowSchema's specification looks like.
         */
        interface FlowSchemaSpecPatch {
            /**
             * `distinguisherMethod` defines how to compute the flow distinguisher for requests that match this schema. `nil` specifies that the distinguisher is disabled and thus will always be the empty string.
             */
            distinguisherMethod?: pulumi.Input<inputs.flowcontrol.v1beta2.FlowDistinguisherMethodPatch>;
            /**
             * `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default.
             */
            matchingPrecedence?: pulumi.Input<number>;
            /**
             * `priorityLevelConfiguration` should reference a PriorityLevelConfiguration in the cluster. If the reference cannot be resolved, the FlowSchema will be ignored and marked as invalid in its status. Required.
             */
            priorityLevelConfiguration?: pulumi.Input<inputs.flowcontrol.v1beta2.PriorityLevelConfigurationReferencePatch>;
            /**
             * `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta2.PolicyRulesWithSubjectsPatch>[]>;
        }
        /**
         * FlowSchemaStatus represents the current state of a FlowSchema.
         */
        interface FlowSchemaStatus {
            /**
             * `conditions` is a list of the current states of FlowSchema.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta2.FlowSchemaCondition>[]>;
        }
        /**
         * GroupSubject holds detailed information for group-kind subject.
         */
        interface GroupSubject {
            /**
             * name is the user group that matches, or "*" to match all user groups. See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * GroupSubject holds detailed information for group-kind subject.
         */
        interface GroupSubjectPatch {
            /**
             * name is the user group that matches, or "*" to match all user groups. See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * LimitResponse defines how to handle requests that can not be executed right now.
         */
        interface LimitResponse {
            /**
             * `queuing` holds the configuration parameters for queuing. This field may be non-empty only if `type` is `"Queue"`.
             */
            queuing?: pulumi.Input<inputs.flowcontrol.v1beta2.QueuingConfiguration>;
            /**
             * `type` is "Queue" or "Reject". "Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * LimitResponse defines how to handle requests that can not be executed right now.
         */
        interface LimitResponsePatch {
            /**
             * `queuing` holds the configuration parameters for queuing. This field may be non-empty only if `type` is `"Queue"`.
             */
            queuing?: pulumi.Input<inputs.flowcontrol.v1beta2.QueuingConfigurationPatch>;
            /**
             * `type` is "Queue" or "Reject". "Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:
         *   - How are requests for this priority level limited?
         *   - What should be done with requests that exceed the limit?
         */
        interface LimitedPriorityLevelConfiguration {
            /**
             * `assuredConcurrencyShares` (ACS) configures the execution limit, which is a limit on the number of requests of this priority level that may be exeucting at a given time.  ACS must be a positive number. The server's concurrency limit (SCL) is divided among the concurrency-controlled priority levels in proportion to their assured concurrency shares. This produces the assured concurrency value (ACV) --- the number of requests that may be executing at a time --- for each such priority level:
             *
             *             ACV(l) = ceil( SCL * ACS(l) / ( sum[priority levels k] ACS(k) ) )
             *
             * bigger numbers of ACS mean more reserved concurrent requests (at the expense of every other PL). This field has a default value of 30.
             */
            assuredConcurrencyShares?: pulumi.Input<number>;
            /**
             * `borrowingLimitPercent`, if present, configures a limit on how many seats this priority level can borrow from other priority levels. The limit is known as this level's BorrowingConcurrencyLimit (BorrowingCL) and is a limit on the total number of seats that this level may borrow at any one time. This field holds the ratio of that limit to the level's nominal concurrency limit. When this field is non-nil, it must hold a non-negative integer and the limit is calculated as follows.
             *
             * BorrowingCL(i) = round( NominalCL(i) * borrowingLimitPercent(i)/100.0 )
             *
             * The value of this field can be more than 100, implying that this priority level can borrow a number of seats that is greater than its own nominal concurrency limit (NominalCL). When this field is left `nil`, the limit is effectively infinite.
             */
            borrowingLimitPercent?: pulumi.Input<number>;
            /**
             * `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels. The value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.
             *
             * LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
             */
            lendablePercent?: pulumi.Input<number>;
            /**
             * `limitResponse` indicates what to do with requests that can not be executed right now
             */
            limitResponse?: pulumi.Input<inputs.flowcontrol.v1beta2.LimitResponse>;
        }
        /**
         * LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:
         *   - How are requests for this priority level limited?
         *   - What should be done with requests that exceed the limit?
         */
        interface LimitedPriorityLevelConfigurationPatch {
            /**
             * `assuredConcurrencyShares` (ACS) configures the execution limit, which is a limit on the number of requests of this priority level that may be exeucting at a given time.  ACS must be a positive number. The server's concurrency limit (SCL) is divided among the concurrency-controlled priority levels in proportion to their assured concurrency shares. This produces the assured concurrency value (ACV) --- the number of requests that may be executing at a time --- for each such priority level:
             *
             *             ACV(l) = ceil( SCL * ACS(l) / ( sum[priority levels k] ACS(k) ) )
             *
             * bigger numbers of ACS mean more reserved concurrent requests (at the expense of every other PL). This field has a default value of 30.
             */
            assuredConcurrencyShares?: pulumi.Input<number>;
            /**
             * `borrowingLimitPercent`, if present, configures a limit on how many seats this priority level can borrow from other priority levels. The limit is known as this level's BorrowingConcurrencyLimit (BorrowingCL) and is a limit on the total number of seats that this level may borrow at any one time. This field holds the ratio of that limit to the level's nominal concurrency limit. When this field is non-nil, it must hold a non-negative integer and the limit is calculated as follows.
             *
             * BorrowingCL(i) = round( NominalCL(i) * borrowingLimitPercent(i)/100.0 )
             *
             * The value of this field can be more than 100, implying that this priority level can borrow a number of seats that is greater than its own nominal concurrency limit (NominalCL). When this field is left `nil`, the limit is effectively infinite.
             */
            borrowingLimitPercent?: pulumi.Input<number>;
            /**
             * `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels. The value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.
             *
             * LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
             */
            lendablePercent?: pulumi.Input<number>;
            /**
             * `limitResponse` indicates what to do with requests that can not be executed right now
             */
            limitResponse?: pulumi.Input<inputs.flowcontrol.v1beta2.LimitResponsePatch>;
        }
        /**
         * NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.
         */
        interface NonResourcePolicyRule {
            /**
             * `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. For example:
             *   - "/healthz" is legal
             *   - "/hea*" is illegal
             *   - "/hea" is legal but matches nothing
             *   - "/hea/*" also matches nothing
             *   - "/healthz/*" matches all per-component health checks.
             * "*" matches all non-resource urls. if it is present, it must be the only entry. Required.
             */
            nonResourceURLs: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required.
             */
            verbs: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.
         */
        interface NonResourcePolicyRulePatch {
            /**
             * `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. For example:
             *   - "/healthz" is legal
             *   - "/hea*" is illegal
             *   - "/hea" is legal but matches nothing
             *   - "/hea/*" also matches nothing
             *   - "/healthz/*" matches all per-component health checks.
             * "*" matches all non-resource urls. if it is present, it must be the only entry. Required.
             */
            nonResourceURLs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required.
             */
            verbs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver. The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request.
         */
        interface PolicyRulesWithSubjects {
            /**
             * `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL.
             */
            nonResourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta2.NonResourcePolicyRule>[]>;
            /**
             * `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. At least one of `resourceRules` and `nonResourceRules` has to be non-empty.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta2.ResourcePolicyRule>[]>;
            /**
             * subjects is the list of normal user, serviceaccount, or group that this rule cares about. There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required.
             */
            subjects: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta2.Subject>[]>;
        }
        /**
         * PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver. The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request.
         */
        interface PolicyRulesWithSubjectsPatch {
            /**
             * `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL.
             */
            nonResourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta2.NonResourcePolicyRulePatch>[]>;
            /**
             * `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. At least one of `resourceRules` and `nonResourceRules` has to be non-empty.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta2.ResourcePolicyRulePatch>[]>;
            /**
             * subjects is the list of normal user, serviceaccount, or group that this rule cares about. There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required.
             */
            subjects?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta2.SubjectPatch>[]>;
        }
        /**
         * PriorityLevelConfiguration represents the configuration of a priority level.
         */
        interface PriorityLevelConfiguration {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"flowcontrol.apiserver.k8s.io/v1beta2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PriorityLevelConfiguration">;
            /**
             * `metadata` is the standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * `spec` is the specification of the desired behavior of a "request-priority". More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.flowcontrol.v1beta2.PriorityLevelConfigurationSpec>;
            /**
             * `status` is the current status of a "request-priority". More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.flowcontrol.v1beta2.PriorityLevelConfigurationStatus>;
        }
        /**
         * PriorityLevelConfigurationCondition defines the condition of priority level.
         */
        interface PriorityLevelConfigurationCondition {
            /**
             * `lastTransitionTime` is the last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * `message` is a human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * `reason` is a unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * `status` is the status of the condition. Can be True, False, Unknown. Required.
             */
            status?: pulumi.Input<string>;
            /**
             * `type` is the type of the condition. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationReference contains information that points to the "request-priority" being used.
         */
        interface PriorityLevelConfigurationReference {
            /**
             * `name` is the name of the priority level configuration being referenced Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationReference contains information that points to the "request-priority" being used.
         */
        interface PriorityLevelConfigurationReferencePatch {
            /**
             * `name` is the name of the priority level configuration being referenced Required.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationSpec specifies the configuration of a priority level.
         */
        interface PriorityLevelConfigurationSpec {
            /**
             * `exempt` specifies how requests are handled for an exempt priority level. This field MUST be empty if `type` is `"Limited"`. This field MAY be non-empty if `type` is `"Exempt"`. If empty and `type` is `"Exempt"` then the default values for `ExemptPriorityLevelConfiguration` apply.
             */
            exempt?: pulumi.Input<inputs.flowcontrol.v1beta2.ExemptPriorityLevelConfiguration>;
            /**
             * `limited` specifies how requests are handled for a Limited priority level. This field must be non-empty if and only if `type` is `"Limited"`.
             */
            limited?: pulumi.Input<inputs.flowcontrol.v1beta2.LimitedPriorityLevelConfiguration>;
            /**
             * `type` indicates whether this priority level is subject to limitation on request execution.  A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationSpec specifies the configuration of a priority level.
         */
        interface PriorityLevelConfigurationSpecPatch {
            /**
             * `exempt` specifies how requests are handled for an exempt priority level. This field MUST be empty if `type` is `"Limited"`. This field MAY be non-empty if `type` is `"Exempt"`. If empty and `type` is `"Exempt"` then the default values for `ExemptPriorityLevelConfiguration` apply.
             */
            exempt?: pulumi.Input<inputs.flowcontrol.v1beta2.ExemptPriorityLevelConfigurationPatch>;
            /**
             * `limited` specifies how requests are handled for a Limited priority level. This field must be non-empty if and only if `type` is `"Limited"`.
             */
            limited?: pulumi.Input<inputs.flowcontrol.v1beta2.LimitedPriorityLevelConfigurationPatch>;
            /**
             * `type` indicates whether this priority level is subject to limitation on request execution.  A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationStatus represents the current state of a "request-priority".
         */
        interface PriorityLevelConfigurationStatus {
            /**
             * `conditions` is the current state of "request-priority".
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta2.PriorityLevelConfigurationCondition>[]>;
        }
        /**
         * QueuingConfiguration holds the configuration parameters for queuing
         */
        interface QueuingConfiguration {
            /**
             * `handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8.
             */
            handSize?: pulumi.Input<number>;
            /**
             * `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50.
             */
            queueLengthLimit?: pulumi.Input<number>;
            /**
             * `queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64.
             */
            queues?: pulumi.Input<number>;
        }
        /**
         * QueuingConfiguration holds the configuration parameters for queuing
         */
        interface QueuingConfigurationPatch {
            /**
             * `handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8.
             */
            handSize?: pulumi.Input<number>;
            /**
             * `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50.
             */
            queueLengthLimit?: pulumi.Input<number>;
            /**
             * `queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64.
             */
            queues?: pulumi.Input<number>;
        }
        /**
         * ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource. A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) either (d1) the request does not specify a namespace (i.e., `Namespace==""`) and clusterScope is true or (d2) the request specifies a namespace and least one member of namespaces matches the request's namespace.
         */
        interface ResourcePolicyRule {
            /**
             * `apiGroups` is a list of matching API groups and may not be empty. "*" matches all API groups and, if present, must be the only entry. Required.
             */
            apiGroups: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). If this field is omitted or false then the `namespaces` field must contain a non-empty list.
             */
            clusterScope?: pulumi.Input<boolean>;
            /**
             * `namespaces` is a list of target namespaces that restricts matches.  A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true.
             */
            namespaces?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required.
             */
            resources: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs and, if present, must be the only entry. Required.
             */
            verbs: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource. A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) either (d1) the request does not specify a namespace (i.e., `Namespace==""`) and clusterScope is true or (d2) the request specifies a namespace and least one member of namespaces matches the request's namespace.
         */
        interface ResourcePolicyRulePatch {
            /**
             * `apiGroups` is a list of matching API groups and may not be empty. "*" matches all API groups and, if present, must be the only entry. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). If this field is omitted or false then the `namespaces` field must contain a non-empty list.
             */
            clusterScope?: pulumi.Input<boolean>;
            /**
             * `namespaces` is a list of target namespaces that restricts matches.  A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true.
             */
            namespaces?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs and, if present, must be the only entry. Required.
             */
            verbs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ServiceAccountSubject holds detailed information for service-account-kind subject.
         */
        interface ServiceAccountSubject {
            /**
             * `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. Required.
             */
            name: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of matching ServiceAccount objects. Required.
             */
            namespace: pulumi.Input<string>;
        }
        /**
         * ServiceAccountSubject holds detailed information for service-account-kind subject.
         */
        interface ServiceAccountSubjectPatch {
            /**
             * `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. Required.
             */
            name?: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of matching ServiceAccount objects. Required.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account.
         */
        interface Subject {
            /**
             * `group` matches based on user group name.
             */
            group?: pulumi.Input<inputs.flowcontrol.v1beta2.GroupSubject>;
            /**
             * `kind` indicates which one of the other fields is non-empty. Required
             */
            kind: pulumi.Input<string>;
            /**
             * `serviceAccount` matches ServiceAccounts.
             */
            serviceAccount?: pulumi.Input<inputs.flowcontrol.v1beta2.ServiceAccountSubject>;
            /**
             * `user` matches based on username.
             */
            user?: pulumi.Input<inputs.flowcontrol.v1beta2.UserSubject>;
        }
        /**
         * Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account.
         */
        interface SubjectPatch {
            /**
             * `group` matches based on user group name.
             */
            group?: pulumi.Input<inputs.flowcontrol.v1beta2.GroupSubjectPatch>;
            /**
             * `kind` indicates which one of the other fields is non-empty. Required
             */
            kind?: pulumi.Input<string>;
            /**
             * `serviceAccount` matches ServiceAccounts.
             */
            serviceAccount?: pulumi.Input<inputs.flowcontrol.v1beta2.ServiceAccountSubjectPatch>;
            /**
             * `user` matches based on username.
             */
            user?: pulumi.Input<inputs.flowcontrol.v1beta2.UserSubjectPatch>;
        }
        /**
         * UserSubject holds detailed information for user-kind subject.
         */
        interface UserSubject {
            /**
             * `name` is the username that matches, or "*" to match all usernames. Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * UserSubject holds detailed information for user-kind subject.
         */
        interface UserSubjectPatch {
            /**
             * `name` is the username that matches, or "*" to match all usernames. Required.
             */
            name?: pulumi.Input<string>;
        }
    }
    namespace v1beta3 {
        /**
         * ExemptPriorityLevelConfiguration describes the configurable aspects of the handling of exempt requests. In the mandatory exempt configuration object the values in the fields here can be modified by authorized users, unlike the rest of the `spec`.
         */
        interface ExemptPriorityLevelConfiguration {
            /**
             * `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels.  This value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.
             *
             * LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
             */
            lendablePercent?: pulumi.Input<number>;
            /**
             * `nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats nominally reserved for this priority level. This DOES NOT limit the dispatching from this priority level but affects the other priority levels through the borrowing mechanism. The server's concurrency limit (ServerCL) is divided among all the priority levels in proportion to their NCS values:
             *
             * NominalCL(i)  = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[priority level k] NCS(k)
             *
             * Bigger numbers mean a larger nominal concurrency limit, at the expense of every other priority level. This field has a default value of zero.
             */
            nominalConcurrencyShares?: pulumi.Input<number>;
        }
        /**
         * ExemptPriorityLevelConfiguration describes the configurable aspects of the handling of exempt requests. In the mandatory exempt configuration object the values in the fields here can be modified by authorized users, unlike the rest of the `spec`.
         */
        interface ExemptPriorityLevelConfigurationPatch {
            /**
             * `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels.  This value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.
             *
             * LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
             */
            lendablePercent?: pulumi.Input<number>;
            /**
             * `nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats nominally reserved for this priority level. This DOES NOT limit the dispatching from this priority level but affects the other priority levels through the borrowing mechanism. The server's concurrency limit (ServerCL) is divided among all the priority levels in proportion to their NCS values:
             *
             * NominalCL(i)  = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[priority level k] NCS(k)
             *
             * Bigger numbers mean a larger nominal concurrency limit, at the expense of every other priority level. This field has a default value of zero.
             */
            nominalConcurrencyShares?: pulumi.Input<number>;
        }
        /**
         * FlowDistinguisherMethod specifies the method of a flow distinguisher.
         */
        interface FlowDistinguisherMethod {
            /**
             * `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * FlowDistinguisherMethod specifies the method of a flow distinguisher.
         */
        interface FlowDistinguisherMethodPatch {
            /**
             * `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * FlowSchema defines the schema of a group of flows. Note that a flow is made up of a set of inbound API requests with similar attributes and is identified by a pair of strings: the name of the FlowSchema and a "flow distinguisher".
         */
        interface FlowSchema {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"flowcontrol.apiserver.k8s.io/v1beta3">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"FlowSchema">;
            /**
             * `metadata` is the standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * `spec` is the specification of the desired behavior of a FlowSchema. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.flowcontrol.v1beta3.FlowSchemaSpec>;
            /**
             * `status` is the current status of a FlowSchema. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.flowcontrol.v1beta3.FlowSchemaStatus>;
        }
        /**
         * FlowSchemaCondition describes conditions for a FlowSchema.
         */
        interface FlowSchemaCondition {
            /**
             * `lastTransitionTime` is the last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * `message` is a human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * `reason` is a unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * `status` is the status of the condition. Can be True, False, Unknown. Required.
             */
            status?: pulumi.Input<string>;
            /**
             * `type` is the type of the condition. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * FlowSchemaSpec describes how the FlowSchema's specification looks like.
         */
        interface FlowSchemaSpec {
            /**
             * `distinguisherMethod` defines how to compute the flow distinguisher for requests that match this schema. `nil` specifies that the distinguisher is disabled and thus will always be the empty string.
             */
            distinguisherMethod?: pulumi.Input<inputs.flowcontrol.v1beta3.FlowDistinguisherMethod>;
            /**
             * `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default.
             */
            matchingPrecedence?: pulumi.Input<number>;
            /**
             * `priorityLevelConfiguration` should reference a PriorityLevelConfiguration in the cluster. If the reference cannot be resolved, the FlowSchema will be ignored and marked as invalid in its status. Required.
             */
            priorityLevelConfiguration: pulumi.Input<inputs.flowcontrol.v1beta3.PriorityLevelConfigurationReference>;
            /**
             * `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta3.PolicyRulesWithSubjects>[]>;
        }
        /**
         * FlowSchemaSpec describes how the FlowSchema's specification looks like.
         */
        interface FlowSchemaSpecPatch {
            /**
             * `distinguisherMethod` defines how to compute the flow distinguisher for requests that match this schema. `nil` specifies that the distinguisher is disabled and thus will always be the empty string.
             */
            distinguisherMethod?: pulumi.Input<inputs.flowcontrol.v1beta3.FlowDistinguisherMethodPatch>;
            /**
             * `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default.
             */
            matchingPrecedence?: pulumi.Input<number>;
            /**
             * `priorityLevelConfiguration` should reference a PriorityLevelConfiguration in the cluster. If the reference cannot be resolved, the FlowSchema will be ignored and marked as invalid in its status. Required.
             */
            priorityLevelConfiguration?: pulumi.Input<inputs.flowcontrol.v1beta3.PriorityLevelConfigurationReferencePatch>;
            /**
             * `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta3.PolicyRulesWithSubjectsPatch>[]>;
        }
        /**
         * FlowSchemaStatus represents the current state of a FlowSchema.
         */
        interface FlowSchemaStatus {
            /**
             * `conditions` is a list of the current states of FlowSchema.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta3.FlowSchemaCondition>[]>;
        }
        /**
         * GroupSubject holds detailed information for group-kind subject.
         */
        interface GroupSubject {
            /**
             * name is the user group that matches, or "*" to match all user groups. See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * GroupSubject holds detailed information for group-kind subject.
         */
        interface GroupSubjectPatch {
            /**
             * name is the user group that matches, or "*" to match all user groups. See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * LimitResponse defines how to handle requests that can not be executed right now.
         */
        interface LimitResponse {
            /**
             * `queuing` holds the configuration parameters for queuing. This field may be non-empty only if `type` is `"Queue"`.
             */
            queuing?: pulumi.Input<inputs.flowcontrol.v1beta3.QueuingConfiguration>;
            /**
             * `type` is "Queue" or "Reject". "Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * LimitResponse defines how to handle requests that can not be executed right now.
         */
        interface LimitResponsePatch {
            /**
             * `queuing` holds the configuration parameters for queuing. This field may be non-empty only if `type` is `"Queue"`.
             */
            queuing?: pulumi.Input<inputs.flowcontrol.v1beta3.QueuingConfigurationPatch>;
            /**
             * `type` is "Queue" or "Reject". "Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:
         *   - How are requests for this priority level limited?
         *   - What should be done with requests that exceed the limit?
         */
        interface LimitedPriorityLevelConfiguration {
            /**
             * `borrowingLimitPercent`, if present, configures a limit on how many seats this priority level can borrow from other priority levels. The limit is known as this level's BorrowingConcurrencyLimit (BorrowingCL) and is a limit on the total number of seats that this level may borrow at any one time. This field holds the ratio of that limit to the level's nominal concurrency limit. When this field is non-nil, it must hold a non-negative integer and the limit is calculated as follows.
             *
             * BorrowingCL(i) = round( NominalCL(i) * borrowingLimitPercent(i)/100.0 )
             *
             * The value of this field can be more than 100, implying that this priority level can borrow a number of seats that is greater than its own nominal concurrency limit (NominalCL). When this field is left `nil`, the limit is effectively infinite.
             */
            borrowingLimitPercent?: pulumi.Input<number>;
            /**
             * `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels. The value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.
             *
             * LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
             */
            lendablePercent?: pulumi.Input<number>;
            /**
             * `limitResponse` indicates what to do with requests that can not be executed right now
             */
            limitResponse?: pulumi.Input<inputs.flowcontrol.v1beta3.LimitResponse>;
            /**
             * `nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats available at this priority level. This is used both for requests dispatched from this priority level as well as requests dispatched from other priority levels borrowing seats from this level. The server's concurrency limit (ServerCL) is divided among the Limited priority levels in proportion to their NCS values:
             *
             * NominalCL(i)  = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[limited priority level k] NCS(k)
             *
             * Bigger numbers mean a larger nominal concurrency limit, at the expense of every other Limited priority level. This field has a default value of 30.
             */
            nominalConcurrencyShares?: pulumi.Input<number>;
        }
        /**
         * LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:
         *   - How are requests for this priority level limited?
         *   - What should be done with requests that exceed the limit?
         */
        interface LimitedPriorityLevelConfigurationPatch {
            /**
             * `borrowingLimitPercent`, if present, configures a limit on how many seats this priority level can borrow from other priority levels. The limit is known as this level's BorrowingConcurrencyLimit (BorrowingCL) and is a limit on the total number of seats that this level may borrow at any one time. This field holds the ratio of that limit to the level's nominal concurrency limit. When this field is non-nil, it must hold a non-negative integer and the limit is calculated as follows.
             *
             * BorrowingCL(i) = round( NominalCL(i) * borrowingLimitPercent(i)/100.0 )
             *
             * The value of this field can be more than 100, implying that this priority level can borrow a number of seats that is greater than its own nominal concurrency limit (NominalCL). When this field is left `nil`, the limit is effectively infinite.
             */
            borrowingLimitPercent?: pulumi.Input<number>;
            /**
             * `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels. The value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.
             *
             * LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
             */
            lendablePercent?: pulumi.Input<number>;
            /**
             * `limitResponse` indicates what to do with requests that can not be executed right now
             */
            limitResponse?: pulumi.Input<inputs.flowcontrol.v1beta3.LimitResponsePatch>;
            /**
             * `nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats available at this priority level. This is used both for requests dispatched from this priority level as well as requests dispatched from other priority levels borrowing seats from this level. The server's concurrency limit (ServerCL) is divided among the Limited priority levels in proportion to their NCS values:
             *
             * NominalCL(i)  = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[limited priority level k] NCS(k)
             *
             * Bigger numbers mean a larger nominal concurrency limit, at the expense of every other Limited priority level. This field has a default value of 30.
             */
            nominalConcurrencyShares?: pulumi.Input<number>;
        }
        /**
         * NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.
         */
        interface NonResourcePolicyRule {
            /**
             * `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. For example:
             *   - "/healthz" is legal
             *   - "/hea*" is illegal
             *   - "/hea" is legal but matches nothing
             *   - "/hea/*" also matches nothing
             *   - "/healthz/*" matches all per-component health checks.
             * "*" matches all non-resource urls. if it is present, it must be the only entry. Required.
             */
            nonResourceURLs: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required.
             */
            verbs: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.
         */
        interface NonResourcePolicyRulePatch {
            /**
             * `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. For example:
             *   - "/healthz" is legal
             *   - "/hea*" is illegal
             *   - "/hea" is legal but matches nothing
             *   - "/hea/*" also matches nothing
             *   - "/healthz/*" matches all per-component health checks.
             * "*" matches all non-resource urls. if it is present, it must be the only entry. Required.
             */
            nonResourceURLs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required.
             */
            verbs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver. The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request.
         */
        interface PolicyRulesWithSubjects {
            /**
             * `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL.
             */
            nonResourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta3.NonResourcePolicyRule>[]>;
            /**
             * `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. At least one of `resourceRules` and `nonResourceRules` has to be non-empty.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta3.ResourcePolicyRule>[]>;
            /**
             * subjects is the list of normal user, serviceaccount, or group that this rule cares about. There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required.
             */
            subjects: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta3.Subject>[]>;
        }
        /**
         * PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver. The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request.
         */
        interface PolicyRulesWithSubjectsPatch {
            /**
             * `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL.
             */
            nonResourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta3.NonResourcePolicyRulePatch>[]>;
            /**
             * `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. At least one of `resourceRules` and `nonResourceRules` has to be non-empty.
             */
            resourceRules?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta3.ResourcePolicyRulePatch>[]>;
            /**
             * subjects is the list of normal user, serviceaccount, or group that this rule cares about. There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required.
             */
            subjects?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta3.SubjectPatch>[]>;
        }
        /**
         * PriorityLevelConfiguration represents the configuration of a priority level.
         */
        interface PriorityLevelConfiguration {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"flowcontrol.apiserver.k8s.io/v1beta3">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PriorityLevelConfiguration">;
            /**
             * `metadata` is the standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * `spec` is the specification of the desired behavior of a "request-priority". More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.flowcontrol.v1beta3.PriorityLevelConfigurationSpec>;
            /**
             * `status` is the current status of a "request-priority". More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.flowcontrol.v1beta3.PriorityLevelConfigurationStatus>;
        }
        /**
         * PriorityLevelConfigurationCondition defines the condition of priority level.
         */
        interface PriorityLevelConfigurationCondition {
            /**
             * `lastTransitionTime` is the last time the condition transitioned from one status to another.
             */
            lastTransitionTime?: pulumi.Input<string>;
            /**
             * `message` is a human-readable message indicating details about last transition.
             */
            message?: pulumi.Input<string>;
            /**
             * `reason` is a unique, one-word, CamelCase reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * `status` is the status of the condition. Can be True, False, Unknown. Required.
             */
            status?: pulumi.Input<string>;
            /**
             * `type` is the type of the condition. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationReference contains information that points to the "request-priority" being used.
         */
        interface PriorityLevelConfigurationReference {
            /**
             * `name` is the name of the priority level configuration being referenced Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationReference contains information that points to the "request-priority" being used.
         */
        interface PriorityLevelConfigurationReferencePatch {
            /**
             * `name` is the name of the priority level configuration being referenced Required.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationSpec specifies the configuration of a priority level.
         */
        interface PriorityLevelConfigurationSpec {
            /**
             * `exempt` specifies how requests are handled for an exempt priority level. This field MUST be empty if `type` is `"Limited"`. This field MAY be non-empty if `type` is `"Exempt"`. If empty and `type` is `"Exempt"` then the default values for `ExemptPriorityLevelConfiguration` apply.
             */
            exempt?: pulumi.Input<inputs.flowcontrol.v1beta3.ExemptPriorityLevelConfiguration>;
            /**
             * `limited` specifies how requests are handled for a Limited priority level. This field must be non-empty if and only if `type` is `"Limited"`.
             */
            limited?: pulumi.Input<inputs.flowcontrol.v1beta3.LimitedPriorityLevelConfiguration>;
            /**
             * `type` indicates whether this priority level is subject to limitation on request execution.  A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required.
             */
            type: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationSpec specifies the configuration of a priority level.
         */
        interface PriorityLevelConfigurationSpecPatch {
            /**
             * `exempt` specifies how requests are handled for an exempt priority level. This field MUST be empty if `type` is `"Limited"`. This field MAY be non-empty if `type` is `"Exempt"`. If empty and `type` is `"Exempt"` then the default values for `ExemptPriorityLevelConfiguration` apply.
             */
            exempt?: pulumi.Input<inputs.flowcontrol.v1beta3.ExemptPriorityLevelConfigurationPatch>;
            /**
             * `limited` specifies how requests are handled for a Limited priority level. This field must be non-empty if and only if `type` is `"Limited"`.
             */
            limited?: pulumi.Input<inputs.flowcontrol.v1beta3.LimitedPriorityLevelConfigurationPatch>;
            /**
             * `type` indicates whether this priority level is subject to limitation on request execution.  A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required.
             */
            type?: pulumi.Input<string>;
        }
        /**
         * PriorityLevelConfigurationStatus represents the current state of a "request-priority".
         */
        interface PriorityLevelConfigurationStatus {
            /**
             * `conditions` is the current state of "request-priority".
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.flowcontrol.v1beta3.PriorityLevelConfigurationCondition>[]>;
        }
        /**
         * QueuingConfiguration holds the configuration parameters for queuing
         */
        interface QueuingConfiguration {
            /**
             * `handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8.
             */
            handSize?: pulumi.Input<number>;
            /**
             * `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50.
             */
            queueLengthLimit?: pulumi.Input<number>;
            /**
             * `queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64.
             */
            queues?: pulumi.Input<number>;
        }
        /**
         * QueuingConfiguration holds the configuration parameters for queuing
         */
        interface QueuingConfigurationPatch {
            /**
             * `handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8.
             */
            handSize?: pulumi.Input<number>;
            /**
             * `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50.
             */
            queueLengthLimit?: pulumi.Input<number>;
            /**
             * `queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64.
             */
            queues?: pulumi.Input<number>;
        }
        /**
         * ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource. A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) either (d1) the request does not specify a namespace (i.e., `Namespace==""`) and clusterScope is true or (d2) the request specifies a namespace and least one member of namespaces matches the request's namespace.
         */
        interface ResourcePolicyRule {
            /**
             * `apiGroups` is a list of matching API groups and may not be empty. "*" matches all API groups and, if present, must be the only entry. Required.
             */
            apiGroups: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). If this field is omitted or false then the `namespaces` field must contain a non-empty list.
             */
            clusterScope?: pulumi.Input<boolean>;
            /**
             * `namespaces` is a list of target namespaces that restricts matches.  A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true.
             */
            namespaces?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required.
             */
            resources: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs and, if present, must be the only entry. Required.
             */
            verbs: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource. A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) either (d1) the request does not specify a namespace (i.e., `Namespace==""`) and clusterScope is true or (d2) the request specifies a namespace and least one member of namespaces matches the request's namespace.
         */
        interface ResourcePolicyRulePatch {
            /**
             * `apiGroups` is a list of matching API groups and may not be empty. "*" matches all API groups and, if present, must be the only entry. Required.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). If this field is omitted or false then the `namespaces` field must contain a non-empty list.
             */
            clusterScope?: pulumi.Input<boolean>;
            /**
             * `namespaces` is a list of target namespaces that restricts matches.  A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true.
             */
            namespaces?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs and, if present, must be the only entry. Required.
             */
            verbs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ServiceAccountSubject holds detailed information for service-account-kind subject.
         */
        interface ServiceAccountSubject {
            /**
             * `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. Required.
             */
            name: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of matching ServiceAccount objects. Required.
             */
            namespace: pulumi.Input<string>;
        }
        /**
         * ServiceAccountSubject holds detailed information for service-account-kind subject.
         */
        interface ServiceAccountSubjectPatch {
            /**
             * `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. Required.
             */
            name?: pulumi.Input<string>;
            /**
             * `namespace` is the namespace of matching ServiceAccount objects. Required.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account.
         */
        interface Subject {
            /**
             * `group` matches based on user group name.
             */
            group?: pulumi.Input<inputs.flowcontrol.v1beta3.GroupSubject>;
            /**
             * `kind` indicates which one of the other fields is non-empty. Required
             */
            kind: pulumi.Input<string>;
            /**
             * `serviceAccount` matches ServiceAccounts.
             */
            serviceAccount?: pulumi.Input<inputs.flowcontrol.v1beta3.ServiceAccountSubject>;
            /**
             * `user` matches based on username.
             */
            user?: pulumi.Input<inputs.flowcontrol.v1beta3.UserSubject>;
        }
        /**
         * Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account.
         */
        interface SubjectPatch {
            /**
             * `group` matches based on user group name.
             */
            group?: pulumi.Input<inputs.flowcontrol.v1beta3.GroupSubjectPatch>;
            /**
             * `kind` indicates which one of the other fields is non-empty. Required
             */
            kind?: pulumi.Input<string>;
            /**
             * `serviceAccount` matches ServiceAccounts.
             */
            serviceAccount?: pulumi.Input<inputs.flowcontrol.v1beta3.ServiceAccountSubjectPatch>;
            /**
             * `user` matches based on username.
             */
            user?: pulumi.Input<inputs.flowcontrol.v1beta3.UserSubjectPatch>;
        }
        /**
         * UserSubject holds detailed information for user-kind subject.
         */
        interface UserSubject {
            /**
             * `name` is the username that matches, or "*" to match all usernames. Required.
             */
            name: pulumi.Input<string>;
        }
        /**
         * UserSubject holds detailed information for user-kind subject.
         */
        interface UserSubjectPatch {
            /**
             * `name` is the username that matches, or "*" to match all usernames. Required.
             */
            name?: pulumi.Input<string>;
        }
    }
}
export declare namespace helm {
    namespace v3 {
        /**
         * Specification defining the Helm chart repository to use.
         */
        interface RepositoryOpts {
            /**
             * The Repository's CA File
             */
            caFile?: pulumi.Input<string>;
            /**
             * The repository's cert file
             */
            certFile?: pulumi.Input<string>;
            /**
             * The repository's cert key file
             */
            keyFile?: pulumi.Input<string>;
            /**
             * Password for HTTP basic authentication
             */
            password?: pulumi.Input<string>;
            /**
             * Repository where to locate the requested chart. If it's a URL the chart is installed without installing the repository.
             */
            repo?: pulumi.Input<string>;
            /**
             * Username for HTTP basic authentication
             */
            username?: pulumi.Input<string>;
        }
    }
    namespace v4 {
        /**
         * Specification defining the post-renderer to use.
         */
        interface PostRenderer {
            /**
             * Arguments to pass to the post-renderer command.
             */
            args?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Path to an executable to be used for post rendering.
             */
            command: pulumi.Input<string>;
        }
        /**
         * Specification defining the Helm chart repository to use.
         */
        interface RepositoryOpts {
            /**
             * The Repository's CA File
             */
            caFile?: pulumi.Input<pulumi.asset.Asset | pulumi.asset.Archive>;
            /**
             * The repository's cert file
             */
            certFile?: pulumi.Input<pulumi.asset.Asset | pulumi.asset.Archive>;
            /**
             * The repository's cert key file
             */
            keyFile?: pulumi.Input<pulumi.asset.Asset | pulumi.asset.Archive>;
            /**
             * Password for HTTP basic authentication
             */
            password?: pulumi.Input<string>;
            /**
             * Repository where to locate the requested chart. If it's a URL the chart is installed without installing the repository.
             */
            repo?: pulumi.Input<string>;
            /**
             * Username for HTTP basic authentication
             */
            username?: pulumi.Input<string>;
        }
    }
}
export declare namespace meta {
    namespace v1 {
        /**
         * Condition contains details for one aspect of the current state of this API Resource.
         */
        interface Condition {
            /**
             * lastTransitionTime is the last time the condition transitioned from one status to another. This should be when the underlying condition changed.  If that is not known, then using the time when the API field changed is acceptable.
             */
            lastTransitionTime: pulumi.Input<string>;
            /**
             * message is a human readable message indicating details about the transition. This may be an empty string.
             */
            message: pulumi.Input<string>;
            /**
             * observedGeneration represents the .metadata.generation that the condition was set based upon. For instance, if .metadata.generation is currently 12, but the .status.conditions[x].observedGeneration is 9, the condition is out of date with respect to the current state of the instance.
             */
            observedGeneration?: pulumi.Input<number>;
            /**
             * reason contains a programmatic identifier indicating the reason for the condition's last transition. Producers of specific condition types may define expected values and meanings for this field, and whether the values are considered a guaranteed API. The value should be a CamelCase string. This field may not be empty.
             */
            reason: pulumi.Input<string>;
            /**
             * status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * type of condition in CamelCase or in foo.example.com/CamelCase.
             */
            type: pulumi.Input<string>;
        }
        /**
         * A label selector is a label query over a set of resources. The result of matchLabels and matchExpressions are ANDed. An empty label selector matches all objects. A null label selector matches no objects.
         */
        interface LabelSelector {
            /**
             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
             */
            matchExpressions?: pulumi.Input<pulumi.Input<inputs.meta.v1.LabelSelectorRequirement>[]>;
            /**
             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
             */
            matchLabels?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * A label selector is a label query over a set of resources. The result of matchLabels and matchExpressions are ANDed. An empty label selector matches all objects. A null label selector matches no objects.
         */
        interface LabelSelectorPatch {
            /**
             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
             */
            matchExpressions?: pulumi.Input<pulumi.Input<inputs.meta.v1.LabelSelectorRequirementPatch>[]>;
            /**
             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
             */
            matchLabels?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * A label selector requirement is a selector that contains values, a key, and an operator that relates the key and values.
         */
        interface LabelSelectorRequirement {
            /**
             * key is the label key that the selector applies to.
             */
            key: pulumi.Input<string>;
            /**
             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
             */
            operator: pulumi.Input<string>;
            /**
             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
             */
            values?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * A label selector requirement is a selector that contains values, a key, and an operator that relates the key and values.
         */
        interface LabelSelectorRequirementPatch {
            /**
             * key is the label key that the selector applies to.
             */
            key?: pulumi.Input<string>;
            /**
             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
             */
            operator?: pulumi.Input<string>;
            /**
             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
             */
            values?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ListMeta describes metadata that synthetic resources must have, including lists and various status objects. A resource may have only one of {ObjectMeta, ListMeta}.
         */
        interface ListMeta {
            /**
             * continue may be set if the user set a limit on the number of items returned, and indicates that the server has more data available. The value is opaque and may be used to issue another request to the endpoint that served this list to retrieve the next set of available objects. Continuing a consistent list may not be possible if the server configuration has changed or more than a few minutes have passed. The resourceVersion field returned when using this continue value will be identical to the value in the first response, unless you have received this token from an error message.
             */
            continue?: pulumi.Input<string>;
            /**
             * remainingItemCount is the number of subsequent items in the list which are not included in this list response. If the list request contained label or field selectors, then the number of remaining items is unknown and the field will be left unset and omitted during serialization. If the list is complete (either because it is not chunking or because this is the last chunk), then there are no more remaining items and this field will be left unset and omitted during serialization. Servers older than v1.15 do not set this field. The intended use of the remainingItemCount is *estimating* the size of a collection. Clients should not rely on the remainingItemCount to be set or to be exact.
             */
            remainingItemCount?: pulumi.Input<number>;
            /**
             * String that identifies the server's internal version of this object that can be used by clients to determine when objects have changed. Value must be treated as opaque by clients and passed unmodified back to the server. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency
             */
            resourceVersion?: pulumi.Input<string>;
            /**
             * Deprecated: selfLink is a legacy read-only field that is no longer populated by the system.
             */
            selfLink?: pulumi.Input<string>;
        }
        /**
         * ListMeta describes metadata that synthetic resources must have, including lists and various status objects. A resource may have only one of {ObjectMeta, ListMeta}.
         */
        interface ListMetaPatch {
            /**
             * continue may be set if the user set a limit on the number of items returned, and indicates that the server has more data available. The value is opaque and may be used to issue another request to the endpoint that served this list to retrieve the next set of available objects. Continuing a consistent list may not be possible if the server configuration has changed or more than a few minutes have passed. The resourceVersion field returned when using this continue value will be identical to the value in the first response, unless you have received this token from an error message.
             */
            continue?: pulumi.Input<string>;
            /**
             * remainingItemCount is the number of subsequent items in the list which are not included in this list response. If the list request contained label or field selectors, then the number of remaining items is unknown and the field will be left unset and omitted during serialization. If the list is complete (either because it is not chunking or because this is the last chunk), then there are no more remaining items and this field will be left unset and omitted during serialization. Servers older than v1.15 do not set this field. The intended use of the remainingItemCount is *estimating* the size of a collection. Clients should not rely on the remainingItemCount to be set or to be exact.
             */
            remainingItemCount?: pulumi.Input<number>;
            /**
             * String that identifies the server's internal version of this object that can be used by clients to determine when objects have changed. Value must be treated as opaque by clients and passed unmodified back to the server. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency
             */
            resourceVersion?: pulumi.Input<string>;
            /**
             * Deprecated: selfLink is a legacy read-only field that is no longer populated by the system.
             */
            selfLink?: pulumi.Input<string>;
        }
        /**
         * ManagedFieldsEntry is a workflow-id, a FieldSet and the group version of the resource that the fieldset applies to.
         */
        interface ManagedFieldsEntry {
            /**
             * APIVersion defines the version of this resource that this field set applies to. The format is "group/version" just like the top-level APIVersion field. It is necessary to track the version of a field set because it cannot be automatically converted.
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * FieldsType is the discriminator for the different fields format and version. There is currently only one possible value: "FieldsV1"
             */
            fieldsType?: pulumi.Input<string>;
            /**
             * FieldsV1 holds the first JSON version format as described in the "FieldsV1" type.
             */
            fieldsV1?: any;
            /**
             * Manager is an identifier of the workflow managing these fields.
             */
            manager?: pulumi.Input<string>;
            /**
             * Operation is the type of operation which lead to this ManagedFieldsEntry being created. The only valid values for this field are 'Apply' and 'Update'.
             */
            operation?: pulumi.Input<string>;
            /**
             * Subresource is the name of the subresource used to update that object, or empty string if the object was updated through the main resource. The value of this field is used to distinguish between managers, even if they share the same name. For example, a status update will be distinct from a regular update using the same manager name. Note that the APIVersion field is not related to the Subresource field and it always corresponds to the version of the main resource.
             */
            subresource?: pulumi.Input<string>;
            /**
             * Time is the timestamp of when the ManagedFields entry was added. The timestamp will also be updated if a field is added, the manager changes any of the owned fields value or removes a field. The timestamp does not update when a field is removed from the entry because another manager took it over.
             */
            time?: pulumi.Input<string>;
        }
        /**
         * ManagedFieldsEntry is a workflow-id, a FieldSet and the group version of the resource that the fieldset applies to.
         */
        interface ManagedFieldsEntryPatch {
            /**
             * APIVersion defines the version of this resource that this field set applies to. The format is "group/version" just like the top-level APIVersion field. It is necessary to track the version of a field set because it cannot be automatically converted.
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * FieldsType is the discriminator for the different fields format and version. There is currently only one possible value: "FieldsV1"
             */
            fieldsType?: pulumi.Input<string>;
            /**
             * FieldsV1 holds the first JSON version format as described in the "FieldsV1" type.
             */
            fieldsV1?: any;
            /**
             * Manager is an identifier of the workflow managing these fields.
             */
            manager?: pulumi.Input<string>;
            /**
             * Operation is the type of operation which lead to this ManagedFieldsEntry being created. The only valid values for this field are 'Apply' and 'Update'.
             */
            operation?: pulumi.Input<string>;
            /**
             * Subresource is the name of the subresource used to update that object, or empty string if the object was updated through the main resource. The value of this field is used to distinguish between managers, even if they share the same name. For example, a status update will be distinct from a regular update using the same manager name. Note that the APIVersion field is not related to the Subresource field and it always corresponds to the version of the main resource.
             */
            subresource?: pulumi.Input<string>;
            /**
             * Time is the timestamp of when the ManagedFields entry was added. The timestamp will also be updated if a field is added, the manager changes any of the owned fields value or removes a field. The timestamp does not update when a field is removed from the entry because another manager took it over.
             */
            time?: pulumi.Input<string>;
        }
        /**
         * ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
         */
        interface ObjectMeta {
            /**
             * Annotations is an unstructured key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/annotations
             */
            annotations?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * The name of the cluster which the object belongs to. This is used to distinguish resources with same name and namespace in different clusters. This field is not set anywhere right now and apiserver is going to ignore it if set in create or update request.
             */
            clusterName?: pulumi.Input<string>;
            /**
             * CreationTimestamp is a timestamp representing the server time when this object was created. It is not guaranteed to be set in happens-before order across separate operations. Clients may not set this value. It is represented in RFC3339 form and is in UTC.
             *
             * Populated by the system. Read-only. Null for lists. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            creationTimestamp?: pulumi.Input<string>;
            /**
             * Number of seconds allowed for this object to gracefully terminate before it will be removed from the system. Only set when deletionTimestamp is also set. May only be shortened. Read-only.
             */
            deletionGracePeriodSeconds?: pulumi.Input<number>;
            /**
             * DeletionTimestamp is RFC 3339 date and time at which this resource will be deleted. This field is set by the server when a graceful deletion is requested by the user, and is not directly settable by a client. The resource is expected to be deleted (no longer visible from resource lists, and not reachable by name) after the time in this field, once the finalizers list is empty. As long as the finalizers list contains items, deletion is blocked. Once the deletionTimestamp is set, this value may not be unset or be set further into the future, although it may be shortened or the resource may be deleted prior to this time. For example, a user may request that a pod is deleted in 30 seconds. The Kubelet will react by sending a graceful termination signal to the containers in the pod. After that 30 seconds, the Kubelet will send a hard termination signal (SIGKILL) to the container and after cleanup, remove the pod from the API. In the presence of network partitions, this object may still exist after this timestamp, until an administrator or automated process can determine the resource is fully terminated. If not set, graceful deletion of the object has not been requested.
             *
             * Populated by the system when a graceful deletion is requested. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            deletionTimestamp?: pulumi.Input<string>;
            /**
             * Must be empty before the object is deleted from the registry. Each entry is an identifier for the responsible component that will remove the entry from the list. If the deletionTimestamp of the object is non-nil, entries in this list can only be removed. Finalizers may be processed and removed in any order.  Order is NOT enforced because it introduces significant risk of stuck finalizers. finalizers is a shared field, any actor with permission can reorder it. If the finalizer list is processed in order, then this can lead to a situation in which the component responsible for the first finalizer in the list is waiting for a signal (field value, external system, or other) produced by a component responsible for a finalizer later in the list, resulting in a deadlock. Without enforced ordering finalizers are free to order amongst themselves and are not vulnerable to ordering changes in the list.
             */
            finalizers?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * GenerateName is an optional prefix, used by the server, to generate a unique name ONLY IF the Name field has not been provided. If this field is used, the name returned to the client will be different than the name passed. This value will also be combined with a unique suffix. The provided value has the same validation rules as the Name field, and may be truncated by the length of the suffix required to make the value unique on the server.
             *
             * If this field is specified and the generated name exists, the server will return a 409.
             *
             * Applied only if Name is not specified. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#idempotency
             */
            generateName?: pulumi.Input<string>;
            /**
             * A sequence number representing a specific generation of the desired state. Populated by the system. Read-only.
             */
            generation?: pulumi.Input<number>;
            /**
             * Map of string keys and values that can be used to organize and categorize (scope and select) objects. May match selectors of replication controllers and services. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels
             */
            labels?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * ManagedFields maps workflow-id and version to the set of fields that are managed by that workflow. This is mostly for internal housekeeping, and users typically shouldn't need to set or understand this field. A workflow can be the user's name, a controller's name, or the name of a specific apply path like "ci-cd". The set of fields is always in the version that the workflow used when modifying the object.
             */
            managedFields?: pulumi.Input<pulumi.Input<inputs.meta.v1.ManagedFieldsEntry>[]>;
            /**
             * Name must be unique within a namespace. Is required when creating resources, although some resources may allow a client to request the generation of an appropriate name automatically. Name is primarily intended for creation idempotence and configuration definition. Cannot be updated. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#names
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace defines the space within which each name must be unique. An empty namespace is equivalent to the "default" namespace, but "default" is the canonical representation. Not all objects are required to be scoped to a namespace - the value of this field for those objects will be empty.
             *
             * Must be a DNS_LABEL. Cannot be updated. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces
             */
            namespace?: pulumi.Input<string>;
            /**
             * List of objects depended by this object. If ALL objects in the list have been deleted, this object will be garbage collected. If this object is managed by a controller, then an entry in this list will point to this controller, with the controller field set to true. There cannot be more than one managing controller.
             */
            ownerReferences?: pulumi.Input<pulumi.Input<inputs.meta.v1.OwnerReference>[]>;
            /**
             * An opaque value that represents the internal version of this object that can be used by clients to determine when objects have changed. May be used for optimistic concurrency, change detection, and the watch operation on a resource or set of resources. Clients must treat these values as opaque and passed unmodified back to the server. They may only be valid for a particular resource or set of resources.
             *
             * Populated by the system. Read-only. Value must be treated as opaque by clients and . More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency
             */
            resourceVersion?: pulumi.Input<string>;
            /**
             * Deprecated: selfLink is a legacy read-only field that is no longer populated by the system.
             */
            selfLink?: pulumi.Input<string>;
            /**
             * UID is the unique in time and space value for this object. It is typically generated by the server on successful creation of a resource and is not allowed to change on PUT operations.
             *
             * Populated by the system. Read-only. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#uids
             */
            uid?: pulumi.Input<string>;
        }
        /**
         * ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
         */
        interface ObjectMetaPatch {
            /**
             * Annotations is an unstructured key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/annotations
             */
            annotations?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * The name of the cluster which the object belongs to. This is used to distinguish resources with same name and namespace in different clusters. This field is not set anywhere right now and apiserver is going to ignore it if set in create or update request.
             */
            clusterName?: pulumi.Input<string>;
            /**
             * CreationTimestamp is a timestamp representing the server time when this object was created. It is not guaranteed to be set in happens-before order across separate operations. Clients may not set this value. It is represented in RFC3339 form and is in UTC.
             *
             * Populated by the system. Read-only. Null for lists. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            creationTimestamp?: pulumi.Input<string>;
            /**
             * Number of seconds allowed for this object to gracefully terminate before it will be removed from the system. Only set when deletionTimestamp is also set. May only be shortened. Read-only.
             */
            deletionGracePeriodSeconds?: pulumi.Input<number>;
            /**
             * DeletionTimestamp is RFC 3339 date and time at which this resource will be deleted. This field is set by the server when a graceful deletion is requested by the user, and is not directly settable by a client. The resource is expected to be deleted (no longer visible from resource lists, and not reachable by name) after the time in this field, once the finalizers list is empty. As long as the finalizers list contains items, deletion is blocked. Once the deletionTimestamp is set, this value may not be unset or be set further into the future, although it may be shortened or the resource may be deleted prior to this time. For example, a user may request that a pod is deleted in 30 seconds. The Kubelet will react by sending a graceful termination signal to the containers in the pod. After that 30 seconds, the Kubelet will send a hard termination signal (SIGKILL) to the container and after cleanup, remove the pod from the API. In the presence of network partitions, this object may still exist after this timestamp, until an administrator or automated process can determine the resource is fully terminated. If not set, graceful deletion of the object has not been requested.
             *
             * Populated by the system when a graceful deletion is requested. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            deletionTimestamp?: pulumi.Input<string>;
            /**
             * Must be empty before the object is deleted from the registry. Each entry is an identifier for the responsible component that will remove the entry from the list. If the deletionTimestamp of the object is non-nil, entries in this list can only be removed. Finalizers may be processed and removed in any order.  Order is NOT enforced because it introduces significant risk of stuck finalizers. finalizers is a shared field, any actor with permission can reorder it. If the finalizer list is processed in order, then this can lead to a situation in which the component responsible for the first finalizer in the list is waiting for a signal (field value, external system, or other) produced by a component responsible for a finalizer later in the list, resulting in a deadlock. Without enforced ordering finalizers are free to order amongst themselves and are not vulnerable to ordering changes in the list.
             */
            finalizers?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * GenerateName is an optional prefix, used by the server, to generate a unique name ONLY IF the Name field has not been provided. If this field is used, the name returned to the client will be different than the name passed. This value will also be combined with a unique suffix. The provided value has the same validation rules as the Name field, and may be truncated by the length of the suffix required to make the value unique on the server.
             *
             * If this field is specified and the generated name exists, the server will return a 409.
             *
             * Applied only if Name is not specified. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#idempotency
             */
            generateName?: pulumi.Input<string>;
            /**
             * A sequence number representing a specific generation of the desired state. Populated by the system. Read-only.
             */
            generation?: pulumi.Input<number>;
            /**
             * Map of string keys and values that can be used to organize and categorize (scope and select) objects. May match selectors of replication controllers and services. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels
             */
            labels?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * ManagedFields maps workflow-id and version to the set of fields that are managed by that workflow. This is mostly for internal housekeeping, and users typically shouldn't need to set or understand this field. A workflow can be the user's name, a controller's name, or the name of a specific apply path like "ci-cd". The set of fields is always in the version that the workflow used when modifying the object.
             */
            managedFields?: pulumi.Input<pulumi.Input<inputs.meta.v1.ManagedFieldsEntryPatch>[]>;
            /**
             * Name must be unique within a namespace. Is required when creating resources, although some resources may allow a client to request the generation of an appropriate name automatically. Name is primarily intended for creation idempotence and configuration definition. Cannot be updated. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#names
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace defines the space within which each name must be unique. An empty namespace is equivalent to the "default" namespace, but "default" is the canonical representation. Not all objects are required to be scoped to a namespace - the value of this field for those objects will be empty.
             *
             * Must be a DNS_LABEL. Cannot be updated. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces
             */
            namespace?: pulumi.Input<string>;
            /**
             * List of objects depended by this object. If ALL objects in the list have been deleted, this object will be garbage collected. If this object is managed by a controller, then an entry in this list will point to this controller, with the controller field set to true. There cannot be more than one managing controller.
             */
            ownerReferences?: pulumi.Input<pulumi.Input<inputs.meta.v1.OwnerReferencePatch>[]>;
            /**
             * An opaque value that represents the internal version of this object that can be used by clients to determine when objects have changed. May be used for optimistic concurrency, change detection, and the watch operation on a resource or set of resources. Clients must treat these values as opaque and passed unmodified back to the server. They may only be valid for a particular resource or set of resources.
             *
             * Populated by the system. Read-only. Value must be treated as opaque by clients and . More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency
             */
            resourceVersion?: pulumi.Input<string>;
            /**
             * Deprecated: selfLink is a legacy read-only field that is no longer populated by the system.
             */
            selfLink?: pulumi.Input<string>;
            /**
             * UID is the unique in time and space value for this object. It is typically generated by the server on successful creation of a resource and is not allowed to change on PUT operations.
             *
             * Populated by the system. Read-only. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#uids
             */
            uid?: pulumi.Input<string>;
        }
        /**
         * OwnerReference contains enough information to let you identify an owning object. An owning object must be in the same namespace as the dependent, or be cluster-scoped, so there is no namespace field.
         */
        interface OwnerReference {
            /**
             * API version of the referent.
             */
            apiVersion: pulumi.Input<string>;
            /**
             * If true, AND if the owner has the "foregroundDeletion" finalizer, then the owner cannot be deleted from the key-value store until this reference is removed. See https://kubernetes.io/docs/concepts/architecture/garbage-collection/#foreground-deletion for how the garbage collector interacts with this field and enforces the foreground deletion. Defaults to false. To set this field, a user needs "delete" permission of the owner, otherwise 422 (Unprocessable Entity) will be returned.
             */
            blockOwnerDeletion?: pulumi.Input<boolean>;
            /**
             * If true, this reference points to the managing controller.
             */
            controller?: pulumi.Input<boolean>;
            /**
             * Kind of the referent. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind: pulumi.Input<string>;
            /**
             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#names
             */
            name: pulumi.Input<string>;
            /**
             * UID of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#uids
             */
            uid: pulumi.Input<string>;
        }
        /**
         * OwnerReference contains enough information to let you identify an owning object. An owning object must be in the same namespace as the dependent, or be cluster-scoped, so there is no namespace field.
         */
        interface OwnerReferencePatch {
            /**
             * API version of the referent.
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * If true, AND if the owner has the "foregroundDeletion" finalizer, then the owner cannot be deleted from the key-value store until this reference is removed. See https://kubernetes.io/docs/concepts/architecture/garbage-collection/#foreground-deletion for how the garbage collector interacts with this field and enforces the foreground deletion. Defaults to false. To set this field, a user needs "delete" permission of the owner, otherwise 422 (Unprocessable Entity) will be returned.
             */
            blockOwnerDeletion?: pulumi.Input<boolean>;
            /**
             * If true, this reference points to the managing controller.
             */
            controller?: pulumi.Input<boolean>;
            /**
             * Kind of the referent. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<string>;
            /**
             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#names
             */
            name?: pulumi.Input<string>;
            /**
             * UID of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#uids
             */
            uid?: pulumi.Input<string>;
        }
        /**
         * StatusCause provides more information about an api.Status failure, including cases when multiple errors are encountered.
         */
        interface StatusCause {
            /**
             * The field of the resource that has caused this error, as named by its JSON serialization. May include dot and postfix notation for nested attributes. Arrays are zero-indexed.  Fields may appear more than once in an array of causes due to fields having multiple errors. Optional.
             *
             * Examples:
             *   "name" - the field "name" on the current resource
             *   "items[0].name" - the field "name" on the first array entry in "items"
             */
            field?: pulumi.Input<string>;
            /**
             * A human-readable description of the cause of the error.  This field may be presented as-is to a reader.
             */
            message?: pulumi.Input<string>;
            /**
             * A machine-readable description of the cause of the error. If this value is empty there is no information available.
             */
            reason?: pulumi.Input<string>;
        }
        /**
         * StatusCause provides more information about an api.Status failure, including cases when multiple errors are encountered.
         */
        interface StatusCausePatch {
            /**
             * The field of the resource that has caused this error, as named by its JSON serialization. May include dot and postfix notation for nested attributes. Arrays are zero-indexed.  Fields may appear more than once in an array of causes due to fields having multiple errors. Optional.
             *
             * Examples:
             *   "name" - the field "name" on the current resource
             *   "items[0].name" - the field "name" on the first array entry in "items"
             */
            field?: pulumi.Input<string>;
            /**
             * A human-readable description of the cause of the error.  This field may be presented as-is to a reader.
             */
            message?: pulumi.Input<string>;
            /**
             * A machine-readable description of the cause of the error. If this value is empty there is no information available.
             */
            reason?: pulumi.Input<string>;
        }
        /**
         * StatusDetails is a set of additional properties that MAY be set by the server to provide additional information about a response. The Reason field of a Status object defines what attributes will be set. Clients must ignore fields that do not match the defined type of each attribute, and should assume that any attribute may be empty, invalid, or under defined.
         */
        interface StatusDetails {
            /**
             * The Causes array includes more details associated with the StatusReason failure. Not all StatusReasons may provide detailed causes.
             */
            causes?: pulumi.Input<pulumi.Input<inputs.meta.v1.StatusCause>[]>;
            /**
             * The group attribute of the resource associated with the status StatusReason.
             */
            group?: pulumi.Input<string>;
            /**
             * The kind attribute of the resource associated with the status StatusReason. On some operations may differ from the requested resource Kind. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<string>;
            /**
             * The name attribute of the resource associated with the status StatusReason (when there is a single name which can be described).
             */
            name?: pulumi.Input<string>;
            /**
             * If specified, the time in seconds before the operation should be retried. Some errors may indicate the client must take an alternate action - for those errors this field may indicate how long to wait before taking the alternate action.
             */
            retryAfterSeconds?: pulumi.Input<number>;
            /**
             * UID of the resource. (when there is a single resource which can be described). More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#uids
             */
            uid?: pulumi.Input<string>;
        }
        /**
         * StatusDetails is a set of additional properties that MAY be set by the server to provide additional information about a response. The Reason field of a Status object defines what attributes will be set. Clients must ignore fields that do not match the defined type of each attribute, and should assume that any attribute may be empty, invalid, or under defined.
         */
        interface StatusDetailsPatch {
            /**
             * The Causes array includes more details associated with the StatusReason failure. Not all StatusReasons may provide detailed causes.
             */
            causes?: pulumi.Input<pulumi.Input<inputs.meta.v1.StatusCausePatch>[]>;
            /**
             * The group attribute of the resource associated with the status StatusReason.
             */
            group?: pulumi.Input<string>;
            /**
             * The kind attribute of the resource associated with the status StatusReason. On some operations may differ from the requested resource Kind. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<string>;
            /**
             * The name attribute of the resource associated with the status StatusReason (when there is a single name which can be described).
             */
            name?: pulumi.Input<string>;
            /**
             * If specified, the time in seconds before the operation should be retried. Some errors may indicate the client must take an alternate action - for those errors this field may indicate how long to wait before taking the alternate action.
             */
            retryAfterSeconds?: pulumi.Input<number>;
            /**
             * UID of the resource. (when there is a single resource which can be described). More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#uids
             */
            uid?: pulumi.Input<string>;
        }
    }
}
export declare namespace networking {
    namespace v1 {
        /**
         * HTTPIngressPath associates a path with a backend. Incoming urls matching the path are forwarded to the backend.
         */
        interface HTTPIngressPath {
            /**
             * backend defines the referenced service endpoint to which the traffic will be forwarded to.
             */
            backend: pulumi.Input<inputs.networking.v1.IngressBackend>;
            /**
             * path is matched against the path of an incoming request. Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/' and must be present when using PathType with value "Exact" or "Prefix".
             */
            path?: pulumi.Input<string>;
            /**
             * pathType determines the interpretation of the path matching. PathType can be one of the following values: * Exact: Matches the URL path exactly. * Prefix: Matches based on a URL path prefix split by '/'. Matching is
             *   done on a path element by element basis. A path element refers is the
             *   list of labels in the path split by the '/' separator. A request is a
             *   match for path p if every p is an element-wise prefix of p of the
             *   request path. Note that if the last element of the path is a substring
             *   of the last element in request path, it is not a match (e.g. /foo/bar
             *   matches /foo/bar/baz, but does not match /foo/barbaz).
             * * ImplementationSpecific: Interpretation of the Path matching is up to
             *   the IngressClass. Implementations can treat this as a separate PathType
             *   or treat it identically to Prefix or Exact path types.
             * Implementations are required to support all path types.
             */
            pathType: pulumi.Input<string>;
        }
        /**
         * HTTPIngressPath associates a path with a backend. Incoming urls matching the path are forwarded to the backend.
         */
        interface HTTPIngressPathPatch {
            /**
             * backend defines the referenced service endpoint to which the traffic will be forwarded to.
             */
            backend?: pulumi.Input<inputs.networking.v1.IngressBackendPatch>;
            /**
             * path is matched against the path of an incoming request. Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/' and must be present when using PathType with value "Exact" or "Prefix".
             */
            path?: pulumi.Input<string>;
            /**
             * pathType determines the interpretation of the path matching. PathType can be one of the following values: * Exact: Matches the URL path exactly. * Prefix: Matches based on a URL path prefix split by '/'. Matching is
             *   done on a path element by element basis. A path element refers is the
             *   list of labels in the path split by the '/' separator. A request is a
             *   match for path p if every p is an element-wise prefix of p of the
             *   request path. Note that if the last element of the path is a substring
             *   of the last element in request path, it is not a match (e.g. /foo/bar
             *   matches /foo/bar/baz, but does not match /foo/barbaz).
             * * ImplementationSpecific: Interpretation of the Path matching is up to
             *   the IngressClass. Implementations can treat this as a separate PathType
             *   or treat it identically to Prefix or Exact path types.
             * Implementations are required to support all path types.
             */
            pathType?: pulumi.Input<string>;
        }
        /**
         * HTTPIngressRuleValue is a list of http selectors pointing to backends. In the example: http://<host>/<path>?<searchpart> -> backend where where parts of the url correspond to RFC 3986, this resource will be used to match against everything after the last '/' and before the first '?' or '#'.
         */
        interface HTTPIngressRuleValue {
            /**
             * paths is a collection of paths that map requests to backends.
             */
            paths: pulumi.Input<pulumi.Input<inputs.networking.v1.HTTPIngressPath>[]>;
        }
        /**
         * HTTPIngressRuleValue is a list of http selectors pointing to backends. In the example: http://<host>/<path>?<searchpart> -> backend where where parts of the url correspond to RFC 3986, this resource will be used to match against everything after the last '/' and before the first '?' or '#'.
         */
        interface HTTPIngressRuleValuePatch {
            /**
             * paths is a collection of paths that map requests to backends.
             */
            paths?: pulumi.Input<pulumi.Input<inputs.networking.v1.HTTPIngressPathPatch>[]>;
        }
        /**
         * IPAddress represents a single IP of a single IP Family. The object is designed to be used by APIs that operate on IP addresses. The object is used by the Service core API for allocation of IP addresses. An IP address can be represented in different formats, to guarantee the uniqueness of the IP, the name of the object is the IP address in canonical format, four decimal digits separated by dots suppressing leading zeros for IPv4 and the representation defined by RFC 5952 for IPv6. Valid: 192.168.1.5 or 2001:db8::1 or 2001:db8:aaaa:bbbb:cccc:dddd:eeee:1 Invalid: 10.01.2.3 or 2001:db8:0:0:0::1
         */
        interface IPAddress {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"networking.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"IPAddress">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec is the desired state of the IPAddress. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.networking.v1.IPAddressSpec>;
        }
        /**
         * IPAddressSpec describe the attributes in an IP Address.
         */
        interface IPAddressSpec {
            /**
             * ParentRef references the resource that an IPAddress is attached to. An IPAddress must reference a parent object.
             */
            parentRef: pulumi.Input<inputs.networking.v1.ParentReference>;
        }
        /**
         * IPAddressSpec describe the attributes in an IP Address.
         */
        interface IPAddressSpecPatch {
            /**
             * ParentRef references the resource that an IPAddress is attached to. An IPAddress must reference a parent object.
             */
            parentRef?: pulumi.Input<inputs.networking.v1.ParentReferencePatch>;
        }
        /**
         * IPBlock describes a particular CIDR (Ex. "192.168.1.0/24","2001:db8::/64") that is allowed to the pods matched by a NetworkPolicySpec's podSelector. The except entry describes CIDRs that should not be included within this rule.
         */
        interface IPBlock {
            /**
             * cidr is a string representing the IPBlock Valid examples are "192.168.1.0/24" or "2001:db8::/64"
             */
            cidr: pulumi.Input<string>;
            /**
             * except is a slice of CIDRs that should not be included within an IPBlock Valid examples are "192.168.1.0/24" or "2001:db8::/64" Except values will be rejected if they are outside the cidr range
             */
            except?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * IPBlock describes a particular CIDR (Ex. "192.168.1.0/24","2001:db8::/64") that is allowed to the pods matched by a NetworkPolicySpec's podSelector. The except entry describes CIDRs that should not be included within this rule.
         */
        interface IPBlockPatch {
            /**
             * cidr is a string representing the IPBlock Valid examples are "192.168.1.0/24" or "2001:db8::/64"
             */
            cidr?: pulumi.Input<string>;
            /**
             * except is a slice of CIDRs that should not be included within an IPBlock Valid examples are "192.168.1.0/24" or "2001:db8::/64" Except values will be rejected if they are outside the cidr range
             */
            except?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * Ingress is a collection of rules that allow inbound connections to reach the endpoints defined by a backend. An Ingress can be configured to give services externally-reachable urls, load balance traffic, terminate SSL, offer name based virtual hosting etc.
         *
         * This resource waits until its status is ready before registering success
         * for create/update, and populating output properties from the current state of the resource.
         * The following conditions are used to determine whether the resource creation has
         * succeeded or failed:
         *
         * 1.  Ingress object exists.
         * 2.  Endpoint objects exist with matching names for each Ingress path (except when Service
         *     type is ExternalName).
         * 3.  Ingress entry exists for '.status.loadBalancer.ingress'.
         *
         * If the Ingress has not reached a Ready state after 10 minutes, it will
         * time out and mark the resource update as Failed. You can override the default timeout value
         * by setting the 'customTimeouts' option on the resource.
         */
        interface Ingress {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"networking.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Ingress">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec is the desired state of the Ingress. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.networking.v1.IngressSpec>;
            /**
             * status is the current state of the Ingress. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.networking.v1.IngressStatus>;
        }
        /**
         * IngressBackend describes all endpoints for a given service and port.
         */
        interface IngressBackend {
            /**
             * resource is an ObjectRef to another Kubernetes resource in the namespace of the Ingress object. If resource is specified, a service.Name and service.Port must not be specified. This is a mutually exclusive setting with "Service".
             */
            resource?: pulumi.Input<inputs.core.v1.TypedLocalObjectReference>;
            /**
             * service references a service as a backend. This is a mutually exclusive setting with "Resource".
             */
            service?: pulumi.Input<inputs.networking.v1.IngressServiceBackend>;
        }
        /**
         * IngressBackend describes all endpoints for a given service and port.
         */
        interface IngressBackendPatch {
            /**
             * resource is an ObjectRef to another Kubernetes resource in the namespace of the Ingress object. If resource is specified, a service.Name and service.Port must not be specified. This is a mutually exclusive setting with "Service".
             */
            resource?: pulumi.Input<inputs.core.v1.TypedLocalObjectReferencePatch>;
            /**
             * service references a service as a backend. This is a mutually exclusive setting with "Resource".
             */
            service?: pulumi.Input<inputs.networking.v1.IngressServiceBackendPatch>;
        }
        /**
         * IngressClass represents the class of the Ingress, referenced by the Ingress Spec. The `ingressclass.kubernetes.io/is-default-class` annotation can be used to indicate that an IngressClass should be considered default. When a single IngressClass resource has this annotation set to true, new Ingress resources without a class specified will be assigned this default class.
         */
        interface IngressClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"networking.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"IngressClass">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec is the desired state of the IngressClass. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.networking.v1.IngressClassSpec>;
        }
        /**
         * IngressClassParametersReference identifies an API object. This can be used to specify a cluster or namespace-scoped resource.
         */
        interface IngressClassParametersReference {
            /**
             * apiGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * kind is the type of resource being referenced.
             */
            kind: pulumi.Input<string>;
            /**
             * name is the name of resource being referenced.
             */
            name: pulumi.Input<string>;
            /**
             * namespace is the namespace of the resource being referenced. This field is required when scope is set to "Namespace" and must be unset when scope is set to "Cluster".
             */
            namespace?: pulumi.Input<string>;
            /**
             * scope represents if this refers to a cluster or namespace scoped resource. This may be set to "Cluster" (default) or "Namespace".
             */
            scope?: pulumi.Input<string>;
        }
        /**
         * IngressClassParametersReference identifies an API object. This can be used to specify a cluster or namespace-scoped resource.
         */
        interface IngressClassParametersReferencePatch {
            /**
             * apiGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * kind is the type of resource being referenced.
             */
            kind?: pulumi.Input<string>;
            /**
             * name is the name of resource being referenced.
             */
            name?: pulumi.Input<string>;
            /**
             * namespace is the namespace of the resource being referenced. This field is required when scope is set to "Namespace" and must be unset when scope is set to "Cluster".
             */
            namespace?: pulumi.Input<string>;
            /**
             * scope represents if this refers to a cluster or namespace scoped resource. This may be set to "Cluster" (default) or "Namespace".
             */
            scope?: pulumi.Input<string>;
        }
        /**
         * IngressClassSpec provides information about the class of an Ingress.
         */
        interface IngressClassSpec {
            /**
             * controller refers to the name of the controller that should handle this class. This allows for different "flavors" that are controlled by the same controller. For example, you may have different parameters for the same implementing controller. This should be specified as a domain-prefixed path no more than 250 characters in length, e.g. "acme.io/ingress-controller". This field is immutable.
             */
            controller?: pulumi.Input<string>;
            /**
             * parameters is a link to a custom resource containing additional configuration for the controller. This is optional if the controller does not require extra parameters.
             */
            parameters?: pulumi.Input<inputs.networking.v1.IngressClassParametersReference>;
        }
        /**
         * IngressClassSpec provides information about the class of an Ingress.
         */
        interface IngressClassSpecPatch {
            /**
             * controller refers to the name of the controller that should handle this class. This allows for different "flavors" that are controlled by the same controller. For example, you may have different parameters for the same implementing controller. This should be specified as a domain-prefixed path no more than 250 characters in length, e.g. "acme.io/ingress-controller". This field is immutable.
             */
            controller?: pulumi.Input<string>;
            /**
             * parameters is a link to a custom resource containing additional configuration for the controller. This is optional if the controller does not require extra parameters.
             */
            parameters?: pulumi.Input<inputs.networking.v1.IngressClassParametersReferencePatch>;
        }
        /**
         * IngressLoadBalancerIngress represents the status of a load-balancer ingress point.
         */
        interface IngressLoadBalancerIngress {
            /**
             * hostname is set for load-balancer ingress points that are DNS based.
             */
            hostname?: pulumi.Input<string>;
            /**
             * ip is set for load-balancer ingress points that are IP based.
             */
            ip?: pulumi.Input<string>;
            /**
             * ports provides information about the ports exposed by this LoadBalancer.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.networking.v1.IngressPortStatus>[]>;
        }
        /**
         * IngressLoadBalancerStatus represents the status of a load-balancer.
         */
        interface IngressLoadBalancerStatus {
            /**
             * ingress is a list containing ingress points for the load-balancer.
             */
            ingress?: pulumi.Input<pulumi.Input<inputs.networking.v1.IngressLoadBalancerIngress>[]>;
        }
        /**
         * IngressPortStatus represents the error condition of a service port
         */
        interface IngressPortStatus {
            /**
             * error is to record the problem with the service port The format of the error shall comply with the following rules: - built-in error values shall be specified in this file and those shall use
             *   CamelCase names
             * - cloud provider specific error values must have names that comply with the
             *   format foo.example.com/CamelCase.
             */
            error?: pulumi.Input<string>;
            /**
             * port is the port number of the ingress port.
             */
            port: pulumi.Input<number>;
            /**
             * protocol is the protocol of the ingress port. The supported values are: "TCP", "UDP", "SCTP"
             */
            protocol: pulumi.Input<string>;
        }
        /**
         * IngressRule represents the rules mapping the paths under a specified host to the related backend services. Incoming requests are first evaluated for a host match, then routed to the backend associated with the matching IngressRuleValue.
         */
        interface IngressRule {
            /**
             * host is the fully qualified domain name of a network host, as defined by RFC 3986. Note the following deviations from the "host" part of the URI as defined in RFC 3986: 1. IPs are not allowed. Currently an IngressRuleValue can only apply to
             *    the IP in the Spec of the parent Ingress.
             * 2. The `:` delimiter is not respected because ports are not allowed.
             * 	  Currently the port of an Ingress is implicitly :80 for http and
             * 	  :443 for https.
             * Both these may change in the future. Incoming requests are matched against the host before the IngressRuleValue. If the host is unspecified, the Ingress routes all traffic based on the specified IngressRuleValue.
             *
             * host can be "precise" which is a domain name without the terminating dot of a network host (e.g. "foo.bar.com") or "wildcard", which is a domain name prefixed with a single wildcard label (e.g. "*.foo.com"). The wildcard character '*' must appear by itself as the first DNS label and matches only a single label. You cannot have a wildcard label by itself (e.g. Host == "*"). Requests will be matched against the Host field in the following way: 1. If host is precise, the request matches this rule if the http host header is equal to Host. 2. If host is a wildcard, then the request matches this rule if the http host header is to equal to the suffix (removing the first label) of the wildcard rule.
             */
            host?: pulumi.Input<string>;
            http?: pulumi.Input<inputs.networking.v1.HTTPIngressRuleValue>;
        }
        /**
         * IngressRule represents the rules mapping the paths under a specified host to the related backend services. Incoming requests are first evaluated for a host match, then routed to the backend associated with the matching IngressRuleValue.
         */
        interface IngressRulePatch {
            /**
             * host is the fully qualified domain name of a network host, as defined by RFC 3986. Note the following deviations from the "host" part of the URI as defined in RFC 3986: 1. IPs are not allowed. Currently an IngressRuleValue can only apply to
             *    the IP in the Spec of the parent Ingress.
             * 2. The `:` delimiter is not respected because ports are not allowed.
             * 	  Currently the port of an Ingress is implicitly :80 for http and
             * 	  :443 for https.
             * Both these may change in the future. Incoming requests are matched against the host before the IngressRuleValue. If the host is unspecified, the Ingress routes all traffic based on the specified IngressRuleValue.
             *
             * host can be "precise" which is a domain name without the terminating dot of a network host (e.g. "foo.bar.com") or "wildcard", which is a domain name prefixed with a single wildcard label (e.g. "*.foo.com"). The wildcard character '*' must appear by itself as the first DNS label and matches only a single label. You cannot have a wildcard label by itself (e.g. Host == "*"). Requests will be matched against the Host field in the following way: 1. If host is precise, the request matches this rule if the http host header is equal to Host. 2. If host is a wildcard, then the request matches this rule if the http host header is to equal to the suffix (removing the first label) of the wildcard rule.
             */
            host?: pulumi.Input<string>;
            http?: pulumi.Input<inputs.networking.v1.HTTPIngressRuleValuePatch>;
        }
        /**
         * IngressServiceBackend references a Kubernetes Service as a Backend.
         */
        interface IngressServiceBackend {
            /**
             * name is the referenced service. The service must exist in the same namespace as the Ingress object.
             */
            name: pulumi.Input<string>;
            /**
             * port of the referenced service. A port name or port number is required for a IngressServiceBackend.
             */
            port?: pulumi.Input<inputs.networking.v1.ServiceBackendPort>;
        }
        /**
         * IngressServiceBackend references a Kubernetes Service as a Backend.
         */
        interface IngressServiceBackendPatch {
            /**
             * name is the referenced service. The service must exist in the same namespace as the Ingress object.
             */
            name?: pulumi.Input<string>;
            /**
             * port of the referenced service. A port name or port number is required for a IngressServiceBackend.
             */
            port?: pulumi.Input<inputs.networking.v1.ServiceBackendPortPatch>;
        }
        /**
         * IngressSpec describes the Ingress the user wishes to exist.
         */
        interface IngressSpec {
            /**
             * defaultBackend is the backend that should handle requests that don't match any rule. If Rules are not specified, DefaultBackend must be specified. If DefaultBackend is not set, the handling of requests that do not match any of the rules will be up to the Ingress controller.
             */
            defaultBackend?: pulumi.Input<inputs.networking.v1.IngressBackend>;
            /**
             * ingressClassName is the name of an IngressClass cluster resource. Ingress controller implementations use this field to know whether they should be serving this Ingress resource, by a transitive connection (controller -> IngressClass -> Ingress resource). Although the `kubernetes.io/ingress.class` annotation (simple constant name) was never formally defined, it was widely supported by Ingress controllers to create a direct binding between Ingress controller and Ingress resources. Newly created Ingress resources should prefer using the field. However, even though the annotation is officially deprecated, for backwards compatibility reasons, ingress controllers should still honor that annotation if present.
             */
            ingressClassName?: pulumi.Input<string>;
            /**
             * rules is a list of host rules used to configure the Ingress. If unspecified, or no rule matches, all traffic is sent to the default backend.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.networking.v1.IngressRule>[]>;
            /**
             * tls represents the TLS configuration. Currently the Ingress only supports a single TLS port, 443. If multiple members of this list specify different hosts, they will be multiplexed on the same port according to the hostname specified through the SNI TLS extension, if the ingress controller fulfilling the ingress supports SNI.
             */
            tls?: pulumi.Input<pulumi.Input<inputs.networking.v1.IngressTLS>[]>;
        }
        /**
         * IngressSpec describes the Ingress the user wishes to exist.
         */
        interface IngressSpecPatch {
            /**
             * defaultBackend is the backend that should handle requests that don't match any rule. If Rules are not specified, DefaultBackend must be specified. If DefaultBackend is not set, the handling of requests that do not match any of the rules will be up to the Ingress controller.
             */
            defaultBackend?: pulumi.Input<inputs.networking.v1.IngressBackendPatch>;
            /**
             * ingressClassName is the name of an IngressClass cluster resource. Ingress controller implementations use this field to know whether they should be serving this Ingress resource, by a transitive connection (controller -> IngressClass -> Ingress resource). Although the `kubernetes.io/ingress.class` annotation (simple constant name) was never formally defined, it was widely supported by Ingress controllers to create a direct binding between Ingress controller and Ingress resources. Newly created Ingress resources should prefer using the field. However, even though the annotation is officially deprecated, for backwards compatibility reasons, ingress controllers should still honor that annotation if present.
             */
            ingressClassName?: pulumi.Input<string>;
            /**
             * rules is a list of host rules used to configure the Ingress. If unspecified, or no rule matches, all traffic is sent to the default backend.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.networking.v1.IngressRulePatch>[]>;
            /**
             * tls represents the TLS configuration. Currently the Ingress only supports a single TLS port, 443. If multiple members of this list specify different hosts, they will be multiplexed on the same port according to the hostname specified through the SNI TLS extension, if the ingress controller fulfilling the ingress supports SNI.
             */
            tls?: pulumi.Input<pulumi.Input<inputs.networking.v1.IngressTLSPatch>[]>;
        }
        /**
         * IngressStatus describe the current state of the Ingress.
         */
        interface IngressStatus {
            /**
             * loadBalancer contains the current status of the load-balancer.
             */
            loadBalancer?: pulumi.Input<inputs.networking.v1.IngressLoadBalancerStatus>;
        }
        /**
         * IngressTLS describes the transport layer security associated with an ingress.
         */
        interface IngressTLS {
            /**
             * hosts is a list of hosts included in the TLS certificate. The values in this list must match the name/s used in the tlsSecret. Defaults to the wildcard host setting for the loadbalancer controller fulfilling this Ingress, if left unspecified.
             */
            hosts?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * secretName is the name of the secret used to terminate TLS traffic on port 443. Field is left optional to allow TLS routing based on SNI hostname alone. If the SNI host in a listener conflicts with the "Host" header field used by an IngressRule, the SNI host is used for termination and value of the "Host" header is used for routing.
             */
            secretName?: pulumi.Input<string>;
        }
        /**
         * IngressTLS describes the transport layer security associated with an ingress.
         */
        interface IngressTLSPatch {
            /**
             * hosts is a list of hosts included in the TLS certificate. The values in this list must match the name/s used in the tlsSecret. Defaults to the wildcard host setting for the loadbalancer controller fulfilling this Ingress, if left unspecified.
             */
            hosts?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * secretName is the name of the secret used to terminate TLS traffic on port 443. Field is left optional to allow TLS routing based on SNI hostname alone. If the SNI host in a listener conflicts with the "Host" header field used by an IngressRule, the SNI host is used for termination and value of the "Host" header is used for routing.
             */
            secretName?: pulumi.Input<string>;
        }
        /**
         * NetworkPolicy describes what network traffic is allowed for a set of Pods
         */
        interface NetworkPolicy {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"networking.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"NetworkPolicy">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec represents the specification of the desired behavior for this NetworkPolicy.
             */
            spec?: pulumi.Input<inputs.networking.v1.NetworkPolicySpec>;
            /**
             * Status is the current state of the NetworkPolicy. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.networking.v1.NetworkPolicyStatus>;
        }
        /**
         * NetworkPolicyEgressRule describes a particular set of traffic that is allowed out of pods matched by a NetworkPolicySpec's podSelector. The traffic must match both ports and to. This type is beta-level in 1.8
         */
        interface NetworkPolicyEgressRule {
            /**
             * ports is a list of destination ports for outgoing traffic. Each item in this list is combined using a logical OR. If this field is empty or missing, this rule matches all ports (traffic not restricted by port). If this field is present and contains at least one item, then this rule allows traffic only if the traffic matches at least one port in the list.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.networking.v1.NetworkPolicyPort>[]>;
            /**
             * to is a list of destinations for outgoing traffic of pods selected for this rule. Items in this list are combined using a logical OR operation. If this field is empty or missing, this rule matches all destinations (traffic not restricted by destination). If this field is present and contains at least one item, this rule allows traffic only if the traffic matches at least one item in the to list.
             */
            to?: pulumi.Input<pulumi.Input<inputs.networking.v1.NetworkPolicyPeer>[]>;
        }
        /**
         * NetworkPolicyEgressRule describes a particular set of traffic that is allowed out of pods matched by a NetworkPolicySpec's podSelector. The traffic must match both ports and to. This type is beta-level in 1.8
         */
        interface NetworkPolicyEgressRulePatch {
            /**
             * ports is a list of destination ports for outgoing traffic. Each item in this list is combined using a logical OR. If this field is empty or missing, this rule matches all ports (traffic not restricted by port). If this field is present and contains at least one item, then this rule allows traffic only if the traffic matches at least one port in the list.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.networking.v1.NetworkPolicyPortPatch>[]>;
            /**
             * to is a list of destinations for outgoing traffic of pods selected for this rule. Items in this list are combined using a logical OR operation. If this field is empty or missing, this rule matches all destinations (traffic not restricted by destination). If this field is present and contains at least one item, this rule allows traffic only if the traffic matches at least one item in the to list.
             */
            to?: pulumi.Input<pulumi.Input<inputs.networking.v1.NetworkPolicyPeerPatch>[]>;
        }
        /**
         * NetworkPolicyIngressRule describes a particular set of traffic that is allowed to the pods matched by a NetworkPolicySpec's podSelector. The traffic must match both ports and from.
         */
        interface NetworkPolicyIngressRule {
            /**
             * from is a list of sources which should be able to access the pods selected for this rule. Items in this list are combined using a logical OR operation. If this field is empty or missing, this rule matches all sources (traffic not restricted by source). If this field is present and contains at least one item, this rule allows traffic only if the traffic matches at least one item in the from list.
             */
            from?: pulumi.Input<pulumi.Input<inputs.networking.v1.NetworkPolicyPeer>[]>;
            /**
             * ports is a list of ports which should be made accessible on the pods selected for this rule. Each item in this list is combined using a logical OR. If this field is empty or missing, this rule matches all ports (traffic not restricted by port). If this field is present and contains at least one item, then this rule allows traffic only if the traffic matches at least one port in the list.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.networking.v1.NetworkPolicyPort>[]>;
        }
        /**
         * NetworkPolicyIngressRule describes a particular set of traffic that is allowed to the pods matched by a NetworkPolicySpec's podSelector. The traffic must match both ports and from.
         */
        interface NetworkPolicyIngressRulePatch {
            /**
             * from is a list of sources which should be able to access the pods selected for this rule. Items in this list are combined using a logical OR operation. If this field is empty or missing, this rule matches all sources (traffic not restricted by source). If this field is present and contains at least one item, this rule allows traffic only if the traffic matches at least one item in the from list.
             */
            from?: pulumi.Input<pulumi.Input<inputs.networking.v1.NetworkPolicyPeerPatch>[]>;
            /**
             * ports is a list of ports which should be made accessible on the pods selected for this rule. Each item in this list is combined using a logical OR. If this field is empty or missing, this rule matches all ports (traffic not restricted by port). If this field is present and contains at least one item, then this rule allows traffic only if the traffic matches at least one port in the list.
             */
            ports?: pulumi.Input<pulumi.Input<inputs.networking.v1.NetworkPolicyPortPatch>[]>;
        }
        /**
         * NetworkPolicyPeer describes a peer to allow traffic to/from. Only certain combinations of fields are allowed
         */
        interface NetworkPolicyPeer {
            /**
             * ipBlock defines policy on a particular IPBlock. If this field is set then neither of the other fields can be.
             */
            ipBlock?: pulumi.Input<inputs.networking.v1.IPBlock>;
            /**
             * namespaceSelector selects namespaces using cluster-scoped labels. This field follows standard label selector semantics; if present but empty, it selects all namespaces.
             *
             * If podSelector is also set, then the NetworkPolicyPeer as a whole selects the pods matching podSelector in the namespaces selected by namespaceSelector. Otherwise it selects all pods in the namespaces selected by namespaceSelector.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * podSelector is a label selector which selects pods. This field follows standard label selector semantics; if present but empty, it selects all pods.
             *
             * If namespaceSelector is also set, then the NetworkPolicyPeer as a whole selects the pods matching podSelector in the Namespaces selected by NamespaceSelector. Otherwise it selects the pods matching podSelector in the policy's own namespace.
             */
            podSelector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
        }
        /**
         * NetworkPolicyPeer describes a peer to allow traffic to/from. Only certain combinations of fields are allowed
         */
        interface NetworkPolicyPeerPatch {
            /**
             * ipBlock defines policy on a particular IPBlock. If this field is set then neither of the other fields can be.
             */
            ipBlock?: pulumi.Input<inputs.networking.v1.IPBlockPatch>;
            /**
             * namespaceSelector selects namespaces using cluster-scoped labels. This field follows standard label selector semantics; if present but empty, it selects all namespaces.
             *
             * If podSelector is also set, then the NetworkPolicyPeer as a whole selects the pods matching podSelector in the namespaces selected by namespaceSelector. Otherwise it selects all pods in the namespaces selected by namespaceSelector.
             */
            namespaceSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * podSelector is a label selector which selects pods. This field follows standard label selector semantics; if present but empty, it selects all pods.
             *
             * If namespaceSelector is also set, then the NetworkPolicyPeer as a whole selects the pods matching podSelector in the Namespaces selected by NamespaceSelector. Otherwise it selects the pods matching podSelector in the policy's own namespace.
             */
            podSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
        }
        /**
         * NetworkPolicyPort describes a port to allow traffic on
         */
        interface NetworkPolicyPort {
            /**
             * endPort indicates that the range of ports from port to endPort if set, inclusive, should be allowed by the policy. This field cannot be defined if the port field is not defined or if the port field is defined as a named (string) port. The endPort must be equal or greater than port.
             */
            endPort?: pulumi.Input<number>;
            /**
             * port represents the port on the given protocol. This can either be a numerical or named port on a pod. If this field is not provided, this matches all port names and numbers. If present, only traffic on the specified protocol AND port will be matched.
             */
            port?: pulumi.Input<number | string>;
            /**
             * protocol represents the protocol (TCP, UDP, or SCTP) which traffic must match. If not specified, this field defaults to TCP.
             */
            protocol?: pulumi.Input<string>;
        }
        /**
         * NetworkPolicyPort describes a port to allow traffic on
         */
        interface NetworkPolicyPortPatch {
            /**
             * endPort indicates that the range of ports from port to endPort if set, inclusive, should be allowed by the policy. This field cannot be defined if the port field is not defined or if the port field is defined as a named (string) port. The endPort must be equal or greater than port.
             */
            endPort?: pulumi.Input<number>;
            /**
             * port represents the port on the given protocol. This can either be a numerical or named port on a pod. If this field is not provided, this matches all port names and numbers. If present, only traffic on the specified protocol AND port will be matched.
             */
            port?: pulumi.Input<number | string>;
            /**
             * protocol represents the protocol (TCP, UDP, or SCTP) which traffic must match. If not specified, this field defaults to TCP.
             */
            protocol?: pulumi.Input<string>;
        }
        /**
         * NetworkPolicySpec provides the specification of a NetworkPolicy
         */
        interface NetworkPolicySpec {
            /**
             * egress is a list of egress rules to be applied to the selected pods. Outgoing traffic is allowed if there are no NetworkPolicies selecting the pod (and cluster policy otherwise allows the traffic), OR if the traffic matches at least one egress rule across all of the NetworkPolicy objects whose podSelector matches the pod. If this field is empty then this NetworkPolicy limits all outgoing traffic (and serves solely to ensure that the pods it selects are isolated by default). This field is beta-level in 1.8
             */
            egress?: pulumi.Input<pulumi.Input<inputs.networking.v1.NetworkPolicyEgressRule>[]>;
            /**
             * ingress is a list of ingress rules to be applied to the selected pods. Traffic is allowed to a pod if there are no NetworkPolicies selecting the pod (and cluster policy otherwise allows the traffic), OR if the traffic source is the pod's local node, OR if the traffic matches at least one ingress rule across all of the NetworkPolicy objects whose podSelector matches the pod. If this field is empty then this NetworkPolicy does not allow any traffic (and serves solely to ensure that the pods it selects are isolated by default)
             */
            ingress?: pulumi.Input<pulumi.Input<inputs.networking.v1.NetworkPolicyIngressRule>[]>;
            /**
             * podSelector selects the pods to which this NetworkPolicy object applies. The array of ingress rules is applied to any pods selected by this field. Multiple network policies can select the same set of pods. In this case, the ingress rules for each are combined additively. This field is NOT optional and follows standard label selector semantics. An empty podSelector matches all pods in this namespace.
             */
            podSelector: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * policyTypes is a list of rule types that the NetworkPolicy relates to. Valid options are ["Ingress"], ["Egress"], or ["Ingress", "Egress"]. If this field is not specified, it will default based on the existence of ingress or egress rules; policies that contain an egress section are assumed to affect egress, and all policies (whether or not they contain an ingress section) are assumed to affect ingress. If you want to write an egress-only policy, you must explicitly specify policyTypes [ "Egress" ]. Likewise, if you want to write a policy that specifies that no egress is allowed, you must specify a policyTypes value that include "Egress" (since such a policy would not include an egress section and would otherwise default to just [ "Ingress" ]). This field is beta-level in 1.8
             */
            policyTypes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * NetworkPolicySpec provides the specification of a NetworkPolicy
         */
        interface NetworkPolicySpecPatch {
            /**
             * egress is a list of egress rules to be applied to the selected pods. Outgoing traffic is allowed if there are no NetworkPolicies selecting the pod (and cluster policy otherwise allows the traffic), OR if the traffic matches at least one egress rule across all of the NetworkPolicy objects whose podSelector matches the pod. If this field is empty then this NetworkPolicy limits all outgoing traffic (and serves solely to ensure that the pods it selects are isolated by default). This field is beta-level in 1.8
             */
            egress?: pulumi.Input<pulumi.Input<inputs.networking.v1.NetworkPolicyEgressRulePatch>[]>;
            /**
             * ingress is a list of ingress rules to be applied to the selected pods. Traffic is allowed to a pod if there are no NetworkPolicies selecting the pod (and cluster policy otherwise allows the traffic), OR if the traffic source is the pod's local node, OR if the traffic matches at least one ingress rule across all of the NetworkPolicy objects whose podSelector matches the pod. If this field is empty then this NetworkPolicy does not allow any traffic (and serves solely to ensure that the pods it selects are isolated by default)
             */
            ingress?: pulumi.Input<pulumi.Input<inputs.networking.v1.NetworkPolicyIngressRulePatch>[]>;
            /**
             * podSelector selects the pods to which this NetworkPolicy object applies. The array of ingress rules is applied to any pods selected by this field. Multiple network policies can select the same set of pods. In this case, the ingress rules for each are combined additively. This field is NOT optional and follows standard label selector semantics. An empty podSelector matches all pods in this namespace.
             */
            podSelector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * policyTypes is a list of rule types that the NetworkPolicy relates to. Valid options are ["Ingress"], ["Egress"], or ["Ingress", "Egress"]. If this field is not specified, it will default based on the existence of ingress or egress rules; policies that contain an egress section are assumed to affect egress, and all policies (whether or not they contain an ingress section) are assumed to affect ingress. If you want to write an egress-only policy, you must explicitly specify policyTypes [ "Egress" ]. Likewise, if you want to write a policy that specifies that no egress is allowed, you must specify a policyTypes value that include "Egress" (since such a policy would not include an egress section and would otherwise default to just [ "Ingress" ]). This field is beta-level in 1.8
             */
            policyTypes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * NetworkPolicyStatus describe the current state of the NetworkPolicy.
         */
        interface NetworkPolicyStatus {
            /**
             * Conditions holds an array of metav1.Condition that describe the state of the NetworkPolicy. Current service state
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.meta.v1.Condition>[]>;
        }
        /**
         * ParentReference describes a reference to a parent object.
         */
        interface ParentReference {
            /**
             * Group is the group of the object being referenced.
             */
            group?: pulumi.Input<string>;
            /**
             * Name is the name of the object being referenced.
             */
            name: pulumi.Input<string>;
            /**
             * Namespace is the namespace of the object being referenced.
             */
            namespace?: pulumi.Input<string>;
            /**
             * Resource is the resource of the object being referenced.
             */
            resource: pulumi.Input<string>;
        }
        /**
         * ParentReference describes a reference to a parent object.
         */
        interface ParentReferencePatch {
            /**
             * Group is the group of the object being referenced.
             */
            group?: pulumi.Input<string>;
            /**
             * Name is the name of the object being referenced.
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace is the namespace of the object being referenced.
             */
            namespace?: pulumi.Input<string>;
            /**
             * Resource is the resource of the object being referenced.
             */
            resource?: pulumi.Input<string>;
        }
        /**
         * ServiceBackendPort is the service port being referenced.
         */
        interface ServiceBackendPort {
            /**
             * name is the name of the port on the Service. This is a mutually exclusive setting with "Number".
             */
            name?: pulumi.Input<string>;
            /**
             * number is the numerical port number (e.g. 80) on the Service. This is a mutually exclusive setting with "Name".
             */
            number?: pulumi.Input<number>;
        }
        /**
         * ServiceBackendPort is the service port being referenced.
         */
        interface ServiceBackendPortPatch {
            /**
             * name is the name of the port on the Service. This is a mutually exclusive setting with "Number".
             */
            name?: pulumi.Input<string>;
            /**
             * number is the numerical port number (e.g. 80) on the Service. This is a mutually exclusive setting with "Name".
             */
            number?: pulumi.Input<number>;
        }
        /**
         * ServiceCIDR defines a range of IP addresses using CIDR format (e.g. 192.168.0.0/24 or 2001:db2::/64). This range is used to allocate ClusterIPs to Service objects.
         */
        interface ServiceCIDR {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"networking.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ServiceCIDR">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec is the desired state of the ServiceCIDR. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.networking.v1.ServiceCIDRSpec>;
            /**
             * status represents the current state of the ServiceCIDR. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.networking.v1.ServiceCIDRStatus>;
        }
        /**
         * ServiceCIDRSpec define the CIDRs the user wants to use for allocating ClusterIPs for Services.
         */
        interface ServiceCIDRSpec {
            /**
             * CIDRs defines the IP blocks in CIDR notation (e.g. "192.168.0.0/24" or "2001:db8::/64") from which to assign service cluster IPs. Max of two CIDRs is allowed, one of each IP family. This field is immutable.
             */
            cidrs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ServiceCIDRSpec define the CIDRs the user wants to use for allocating ClusterIPs for Services.
         */
        interface ServiceCIDRSpecPatch {
            /**
             * CIDRs defines the IP blocks in CIDR notation (e.g. "192.168.0.0/24" or "2001:db8::/64") from which to assign service cluster IPs. Max of two CIDRs is allowed, one of each IP family. This field is immutable.
             */
            cidrs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ServiceCIDRStatus describes the current state of the ServiceCIDR.
         */
        interface ServiceCIDRStatus {
            /**
             * conditions holds an array of metav1.Condition that describe the state of the ServiceCIDR. Current service state
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.meta.v1.Condition>[]>;
        }
    }
    namespace v1alpha1 {
        /**
         * ClusterCIDR represents a single configuration for per-Node Pod CIDR allocations when the MultiCIDRRangeAllocator is enabled (see the config for kube-controller-manager).  A cluster may have any number of ClusterCIDR resources, all of which will be considered when allocating a CIDR for a Node.  A ClusterCIDR is eligible to be used for a given Node when the node selector matches the node in question and has free CIDRs to allocate.  In case of multiple matching ClusterCIDR resources, the allocator will attempt to break ties using internal heuristics, but any ClusterCIDR whose node selector matches the Node may be used.
         */
        interface ClusterCIDR {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"networking.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ClusterCIDR">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec is the desired state of the ClusterCIDR. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.networking.v1alpha1.ClusterCIDRSpec>;
        }
        /**
         * ClusterCIDRSpec defines the desired state of ClusterCIDR.
         */
        interface ClusterCIDRSpec {
            /**
             * IPv4 defines an IPv4 IP block in CIDR notation(e.g. "10.0.0.0/8"). At least one of IPv4 and IPv6 must be specified. This field is immutable.
             */
            ipv4?: pulumi.Input<string>;
            /**
             * IPv6 defines an IPv6 IP block in CIDR notation(e.g. "2001:db8::/64"). At least one of IPv4 and IPv6 must be specified. This field is immutable.
             */
            ipv6?: pulumi.Input<string>;
            /**
             * NodeSelector defines which nodes the config is applicable to. An empty or nil NodeSelector selects all nodes. This field is immutable.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelector>;
            /**
             * PerNodeHostBits defines the number of host bits to be configured per node. A subnet mask determines how much of the address is used for network bits and host bits. For example an IPv4 address of 192.168.0.0/24, splits the address into 24 bits for the network portion and 8 bits for the host portion. To allocate 256 IPs, set this field to 8 (a /24 mask for IPv4 or a /120 for IPv6). Minimum value is 4 (16 IPs). This field is immutable.
             */
            perNodeHostBits: pulumi.Input<number>;
        }
        /**
         * ClusterCIDRSpec defines the desired state of ClusterCIDR.
         */
        interface ClusterCIDRSpecPatch {
            /**
             * IPv4 defines an IPv4 IP block in CIDR notation(e.g. "10.0.0.0/8"). At least one of IPv4 and IPv6 must be specified. This field is immutable.
             */
            ipv4?: pulumi.Input<string>;
            /**
             * IPv6 defines an IPv6 IP block in CIDR notation(e.g. "2001:db8::/64"). At least one of IPv4 and IPv6 must be specified. This field is immutable.
             */
            ipv6?: pulumi.Input<string>;
            /**
             * NodeSelector defines which nodes the config is applicable to. An empty or nil NodeSelector selects all nodes. This field is immutable.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelectorPatch>;
            /**
             * PerNodeHostBits defines the number of host bits to be configured per node. A subnet mask determines how much of the address is used for network bits and host bits. For example an IPv4 address of 192.168.0.0/24, splits the address into 24 bits for the network portion and 8 bits for the host portion. To allocate 256 IPs, set this field to 8 (a /24 mask for IPv4 or a /120 for IPv6). Minimum value is 4 (16 IPs). This field is immutable.
             */
            perNodeHostBits?: pulumi.Input<number>;
        }
        /**
         * IPAddress represents a single IP of a single IP Family. The object is designed to be used by APIs that operate on IP addresses. The object is used by the Service core API for allocation of IP addresses. An IP address can be represented in different formats, to guarantee the uniqueness of the IP, the name of the object is the IP address in canonical format, four decimal digits separated by dots suppressing leading zeros for IPv4 and the representation defined by RFC 5952 for IPv6. Valid: 192.168.1.5 or 2001:db8::1 or 2001:db8:aaaa:bbbb:cccc:dddd:eeee:1 Invalid: 10.01.2.3 or 2001:db8:0:0:0::1
         */
        interface IPAddress {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"networking.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"IPAddress">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec is the desired state of the IPAddress. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.networking.v1alpha1.IPAddressSpec>;
        }
        /**
         * IPAddressSpec describe the attributes in an IP Address.
         */
        interface IPAddressSpec {
            /**
             * ParentRef references the resource that an IPAddress is attached to. An IPAddress must reference a parent object.
             */
            parentRef: pulumi.Input<inputs.networking.v1alpha1.ParentReference>;
        }
        /**
         * IPAddressSpec describe the attributes in an IP Address.
         */
        interface IPAddressSpecPatch {
            /**
             * ParentRef references the resource that an IPAddress is attached to. An IPAddress must reference a parent object.
             */
            parentRef?: pulumi.Input<inputs.networking.v1alpha1.ParentReferencePatch>;
        }
        /**
         * ParentReference describes a reference to a parent object.
         */
        interface ParentReference {
            /**
             * Group is the group of the object being referenced.
             */
            group?: pulumi.Input<string>;
            /**
             * Name is the name of the object being referenced.
             */
            name: pulumi.Input<string>;
            /**
             * Namespace is the namespace of the object being referenced.
             */
            namespace?: pulumi.Input<string>;
            /**
             * Resource is the resource of the object being referenced.
             */
            resource: pulumi.Input<string>;
            /**
             * UID is the uid of the object being referenced.
             */
            uid?: pulumi.Input<string>;
        }
        /**
         * ParentReference describes a reference to a parent object.
         */
        interface ParentReferencePatch {
            /**
             * Group is the group of the object being referenced.
             */
            group?: pulumi.Input<string>;
            /**
             * Name is the name of the object being referenced.
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace is the namespace of the object being referenced.
             */
            namespace?: pulumi.Input<string>;
            /**
             * Resource is the resource of the object being referenced.
             */
            resource?: pulumi.Input<string>;
            /**
             * UID is the uid of the object being referenced.
             */
            uid?: pulumi.Input<string>;
        }
        /**
         * ServiceCIDR defines a range of IP addresses using CIDR format (e.g. 192.168.0.0/24 or 2001:db2::/64). This range is used to allocate ClusterIPs to Service objects.
         */
        interface ServiceCIDR {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"networking.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ServiceCIDR">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec is the desired state of the ServiceCIDR. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.networking.v1alpha1.ServiceCIDRSpec>;
            /**
             * status represents the current state of the ServiceCIDR. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.networking.v1alpha1.ServiceCIDRStatus>;
        }
        /**
         * ServiceCIDRSpec define the CIDRs the user wants to use for allocating ClusterIPs for Services.
         */
        interface ServiceCIDRSpec {
            /**
             * CIDRs defines the IP blocks in CIDR notation (e.g. "192.168.0.0/24" or "2001:db8::/64") from which to assign service cluster IPs. Max of two CIDRs is allowed, one of each IP family. This field is immutable.
             */
            cidrs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ServiceCIDRSpec define the CIDRs the user wants to use for allocating ClusterIPs for Services.
         */
        interface ServiceCIDRSpecPatch {
            /**
             * CIDRs defines the IP blocks in CIDR notation (e.g. "192.168.0.0/24" or "2001:db8::/64") from which to assign service cluster IPs. Max of two CIDRs is allowed, one of each IP family. This field is immutable.
             */
            cidrs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ServiceCIDRStatus describes the current state of the ServiceCIDR.
         */
        interface ServiceCIDRStatus {
            /**
             * conditions holds an array of metav1.Condition that describe the state of the ServiceCIDR. Current service state
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.meta.v1.Condition>[]>;
        }
    }
    namespace v1beta1 {
        /**
         * HTTPIngressPath associates a path regex with a backend. Incoming urls matching the path are forwarded to the backend.
         */
        interface HTTPIngressPath {
            /**
             * Backend defines the referenced service endpoint to which the traffic will be forwarded to.
             */
            backend: pulumi.Input<inputs.networking.v1beta1.IngressBackend>;
            /**
             * Path is an extended POSIX regex as defined by IEEE Std 1003.1, (i.e this follows the egrep/unix syntax, not the perl syntax) matched against the path of an incoming request. Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/'. If unspecified, the path defaults to a catch all sending traffic to the backend.
             */
            path?: pulumi.Input<string>;
            /**
             * PathType determines the interpretation of the Path matching. PathType can be one of the following values: * Exact: Matches the URL path exactly. * Prefix: Matches based on a URL path prefix split by '/'. Matching is
             *   done on a path element by element basis. A path element refers is the
             *   list of labels in the path split by the '/' separator. A request is a
             *   match for path p if every p is an element-wise prefix of p of the
             *   request path. Note that if the last element of the path is a substring
             *   of the last element in request path, it is not a match (e.g. /foo/bar
             *   matches /foo/bar/baz, but does not match /foo/barbaz).
             * * ImplementationSpecific: Interpretation of the Path matching is up to
             *   the IngressClass. Implementations can treat this as a separate PathType
             *   or treat it identically to Prefix or Exact path types.
             * Implementations are required to support all path types. Defaults to ImplementationSpecific.
             */
            pathType?: pulumi.Input<string>;
        }
        /**
         * HTTPIngressPath associates a path regex with a backend. Incoming urls matching the path are forwarded to the backend.
         */
        interface HTTPIngressPathPatch {
            /**
             * Backend defines the referenced service endpoint to which the traffic will be forwarded to.
             */
            backend?: pulumi.Input<inputs.networking.v1beta1.IngressBackendPatch>;
            /**
             * Path is an extended POSIX regex as defined by IEEE Std 1003.1, (i.e this follows the egrep/unix syntax, not the perl syntax) matched against the path of an incoming request. Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/'. If unspecified, the path defaults to a catch all sending traffic to the backend.
             */
            path?: pulumi.Input<string>;
            /**
             * PathType determines the interpretation of the Path matching. PathType can be one of the following values: * Exact: Matches the URL path exactly. * Prefix: Matches based on a URL path prefix split by '/'. Matching is
             *   done on a path element by element basis. A path element refers is the
             *   list of labels in the path split by the '/' separator. A request is a
             *   match for path p if every p is an element-wise prefix of p of the
             *   request path. Note that if the last element of the path is a substring
             *   of the last element in request path, it is not a match (e.g. /foo/bar
             *   matches /foo/bar/baz, but does not match /foo/barbaz).
             * * ImplementationSpecific: Interpretation of the Path matching is up to
             *   the IngressClass. Implementations can treat this as a separate PathType
             *   or treat it identically to Prefix or Exact path types.
             * Implementations are required to support all path types. Defaults to ImplementationSpecific.
             */
            pathType?: pulumi.Input<string>;
        }
        /**
         * HTTPIngressRuleValue is a list of http selectors pointing to backends. In the example: http://<host>/<path>?<searchpart> -> backend where where parts of the url correspond to RFC 3986, this resource will be used to match against everything after the last '/' and before the first '?' or '#'.
         */
        interface HTTPIngressRuleValue {
            /**
             * A collection of paths that map requests to backends.
             */
            paths: pulumi.Input<pulumi.Input<inputs.networking.v1beta1.HTTPIngressPath>[]>;
        }
        /**
         * HTTPIngressRuleValue is a list of http selectors pointing to backends. In the example: http://<host>/<path>?<searchpart> -> backend where where parts of the url correspond to RFC 3986, this resource will be used to match against everything after the last '/' and before the first '?' or '#'.
         */
        interface HTTPIngressRuleValuePatch {
            /**
             * A collection of paths that map requests to backends.
             */
            paths?: pulumi.Input<pulumi.Input<inputs.networking.v1beta1.HTTPIngressPathPatch>[]>;
        }
        /**
         * IPAddress represents a single IP of a single IP Family. The object is designed to be used by APIs that operate on IP addresses. The object is used by the Service core API for allocation of IP addresses. An IP address can be represented in different formats, to guarantee the uniqueness of the IP, the name of the object is the IP address in canonical format, four decimal digits separated by dots suppressing leading zeros for IPv4 and the representation defined by RFC 5952 for IPv6. Valid: 192.168.1.5 or 2001:db8::1 or 2001:db8:aaaa:bbbb:cccc:dddd:eeee:1 Invalid: 10.01.2.3 or 2001:db8:0:0:0::1
         */
        interface IPAddress {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"networking.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"IPAddress">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec is the desired state of the IPAddress. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.networking.v1beta1.IPAddressSpec>;
        }
        /**
         * IPAddressSpec describe the attributes in an IP Address.
         */
        interface IPAddressSpec {
            /**
             * ParentRef references the resource that an IPAddress is attached to. An IPAddress must reference a parent object.
             */
            parentRef: pulumi.Input<inputs.networking.v1beta1.ParentReference>;
        }
        /**
         * IPAddressSpec describe the attributes in an IP Address.
         */
        interface IPAddressSpecPatch {
            /**
             * ParentRef references the resource that an IPAddress is attached to. An IPAddress must reference a parent object.
             */
            parentRef?: pulumi.Input<inputs.networking.v1beta1.ParentReferencePatch>;
        }
        /**
         * Ingress is a collection of rules that allow inbound connections to reach the endpoints defined by a backend. An Ingress can be configured to give services externally-reachable urls, load balance traffic, terminate SSL, offer name based virtual hosting etc.
         *
         * This resource waits until its status is ready before registering success
         * for create/update, and populating output properties from the current state of the resource.
         * The following conditions are used to determine whether the resource creation has
         * succeeded or failed:
         *
         * 1.  Ingress object exists.
         * 2.  Endpoint objects exist with matching names for each Ingress path (except when Service
         *     type is ExternalName).
         * 3.  Ingress entry exists for '.status.loadBalancer.ingress'.
         *
         * If the Ingress has not reached a Ready state after 10 minutes, it will
         * time out and mark the resource update as Failed. You can override the default timeout value
         * by setting the 'customTimeouts' option on the resource.
         */
        interface Ingress {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"networking.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Ingress">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec is the desired state of the Ingress. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.networking.v1beta1.IngressSpec>;
            /**
             * Status is the current state of the Ingress. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.networking.v1beta1.IngressStatus>;
        }
        /**
         * IngressBackend describes all endpoints for a given service and port.
         */
        interface IngressBackend {
            /**
             * Resource is an ObjectRef to another Kubernetes resource in the namespace of the Ingress object. If resource is specified, serviceName and servicePort must not be specified.
             */
            resource?: pulumi.Input<inputs.core.v1.TypedLocalObjectReference>;
            /**
             * Specifies the name of the referenced service.
             */
            serviceName: pulumi.Input<string>;
            /**
             * Specifies the port of the referenced service.
             */
            servicePort: pulumi.Input<number | string>;
        }
        /**
         * IngressBackend describes all endpoints for a given service and port.
         */
        interface IngressBackendPatch {
            /**
             * Resource is an ObjectRef to another Kubernetes resource in the namespace of the Ingress object. If resource is specified, serviceName and servicePort must not be specified.
             */
            resource?: pulumi.Input<inputs.core.v1.TypedLocalObjectReferencePatch>;
            /**
             * Specifies the name of the referenced service.
             */
            serviceName?: pulumi.Input<string>;
            /**
             * Specifies the port of the referenced service.
             */
            servicePort?: pulumi.Input<number | string>;
        }
        /**
         * IngressClass represents the class of the Ingress, referenced by the Ingress Spec. The `ingressclass.kubernetes.io/is-default-class` annotation can be used to indicate that an IngressClass should be considered default. When a single IngressClass resource has this annotation set to true, new Ingress resources without a class specified will be assigned this default class.
         */
        interface IngressClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"networking.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"IngressClass">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec is the desired state of the IngressClass. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.networking.v1beta1.IngressClassSpec>;
        }
        /**
         * IngressClassSpec provides information about the class of an Ingress.
         */
        interface IngressClassSpec {
            /**
             * Controller refers to the name of the controller that should handle this class. This allows for different "flavors" that are controlled by the same controller. For example, you may have different Parameters for the same implementing controller. This should be specified as a domain-prefixed path no more than 250 characters in length, e.g. "acme.io/ingress-controller". This field is immutable.
             */
            controller?: pulumi.Input<string>;
            /**
             * Parameters is a link to a custom resource containing additional configuration for the controller. This is optional if the controller does not require extra parameters.
             */
            parameters?: pulumi.Input<inputs.core.v1.TypedLocalObjectReference>;
        }
        /**
         * IngressClassSpec provides information about the class of an Ingress.
         */
        interface IngressClassSpecPatch {
            /**
             * Controller refers to the name of the controller that should handle this class. This allows for different "flavors" that are controlled by the same controller. For example, you may have different Parameters for the same implementing controller. This should be specified as a domain-prefixed path no more than 250 characters in length, e.g. "acme.io/ingress-controller". This field is immutable.
             */
            controller?: pulumi.Input<string>;
            /**
             * Parameters is a link to a custom resource containing additional configuration for the controller. This is optional if the controller does not require extra parameters.
             */
            parameters?: pulumi.Input<inputs.core.v1.TypedLocalObjectReferencePatch>;
        }
        /**
         * IngressRule represents the rules mapping the paths under a specified host to the related backend services. Incoming requests are first evaluated for a host match, then routed to the backend associated with the matching IngressRuleValue.
         */
        interface IngressRule {
            /**
             * Host is the fully qualified domain name of a network host, as defined by RFC 3986. Note the following deviations from the "host" part of the URI as defined in the RFC: 1. IPs are not allowed. Currently an IngressRuleValue can only apply to the
             * 	  IP in the Spec of the parent Ingress.
             * 2. The `:` delimiter is not respected because ports are not allowed.
             * 	  Currently the port of an Ingress is implicitly :80 for http and
             * 	  :443 for https.
             * Both these may change in the future. Incoming requests are matched against the host before the IngressRuleValue. If the host is unspecified, the Ingress routes all traffic based on the specified IngressRuleValue.
             */
            host?: pulumi.Input<string>;
            http?: pulumi.Input<inputs.networking.v1beta1.HTTPIngressRuleValue>;
        }
        /**
         * IngressRule represents the rules mapping the paths under a specified host to the related backend services. Incoming requests are first evaluated for a host match, then routed to the backend associated with the matching IngressRuleValue.
         */
        interface IngressRulePatch {
            /**
             * Host is the fully qualified domain name of a network host, as defined by RFC 3986. Note the following deviations from the "host" part of the URI as defined in the RFC: 1. IPs are not allowed. Currently an IngressRuleValue can only apply to the
             * 	  IP in the Spec of the parent Ingress.
             * 2. The `:` delimiter is not respected because ports are not allowed.
             * 	  Currently the port of an Ingress is implicitly :80 for http and
             * 	  :443 for https.
             * Both these may change in the future. Incoming requests are matched against the host before the IngressRuleValue. If the host is unspecified, the Ingress routes all traffic based on the specified IngressRuleValue.
             */
            host?: pulumi.Input<string>;
            http?: pulumi.Input<inputs.networking.v1beta1.HTTPIngressRuleValuePatch>;
        }
        /**
         * IngressSpec describes the Ingress the user wishes to exist.
         */
        interface IngressSpec {
            /**
             * A default backend capable of servicing requests that don't match any rule. At least one of 'backend' or 'rules' must be specified. This field is optional to allow the loadbalancer controller or defaulting logic to specify a global default.
             */
            backend?: pulumi.Input<inputs.networking.v1beta1.IngressBackend>;
            /**
             * IngressClassName is the name of the IngressClass cluster resource. The associated IngressClass defines which controller will implement the resource. This replaces the deprecated `kubernetes.io/ingress.class` annotation. For backwards compatibility, when that annotation is set, it must be given precedence over this field. The controller may emit a warning if the field and annotation have different values. Implementations of this API should ignore Ingresses without a class specified. An IngressClass resource may be marked as default, which can be used to set a default value for this field. For more information, refer to the IngressClass documentation.
             */
            ingressClassName?: pulumi.Input<string>;
            /**
             * A list of host rules used to configure the Ingress. If unspecified, or no rule matches, all traffic is sent to the default backend.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.networking.v1beta1.IngressRule>[]>;
            /**
             * TLS configuration. Currently the Ingress only supports a single TLS port, 443. If multiple members of this list specify different hosts, they will be multiplexed on the same port according to the hostname specified through the SNI TLS extension, if the ingress controller fulfilling the ingress supports SNI.
             */
            tls?: pulumi.Input<pulumi.Input<inputs.networking.v1beta1.IngressTLS>[]>;
        }
        /**
         * IngressSpec describes the Ingress the user wishes to exist.
         */
        interface IngressSpecPatch {
            /**
             * A default backend capable of servicing requests that don't match any rule. At least one of 'backend' or 'rules' must be specified. This field is optional to allow the loadbalancer controller or defaulting logic to specify a global default.
             */
            backend?: pulumi.Input<inputs.networking.v1beta1.IngressBackendPatch>;
            /**
             * IngressClassName is the name of the IngressClass cluster resource. The associated IngressClass defines which controller will implement the resource. This replaces the deprecated `kubernetes.io/ingress.class` annotation. For backwards compatibility, when that annotation is set, it must be given precedence over this field. The controller may emit a warning if the field and annotation have different values. Implementations of this API should ignore Ingresses without a class specified. An IngressClass resource may be marked as default, which can be used to set a default value for this field. For more information, refer to the IngressClass documentation.
             */
            ingressClassName?: pulumi.Input<string>;
            /**
             * A list of host rules used to configure the Ingress. If unspecified, or no rule matches, all traffic is sent to the default backend.
             */
            rules?: pulumi.Input<pulumi.Input<inputs.networking.v1beta1.IngressRulePatch>[]>;
            /**
             * TLS configuration. Currently the Ingress only supports a single TLS port, 443. If multiple members of this list specify different hosts, they will be multiplexed on the same port according to the hostname specified through the SNI TLS extension, if the ingress controller fulfilling the ingress supports SNI.
             */
            tls?: pulumi.Input<pulumi.Input<inputs.networking.v1beta1.IngressTLSPatch>[]>;
        }
        /**
         * IngressStatus describe the current state of the Ingress.
         */
        interface IngressStatus {
            /**
             * LoadBalancer contains the current status of the load-balancer.
             */
            loadBalancer?: pulumi.Input<inputs.core.v1.LoadBalancerStatus>;
        }
        /**
         * IngressTLS describes the transport layer security associated with an Ingress.
         */
        interface IngressTLS {
            /**
             * Hosts are a list of hosts included in the TLS certificate. The values in this list must match the name/s used in the tlsSecret. Defaults to the wildcard host setting for the loadbalancer controller fulfilling this Ingress, if left unspecified.
             */
            hosts?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * SecretName is the name of the secret used to terminate SSL traffic on 443. Field is left optional to allow SSL routing based on SNI hostname alone. If the SNI host in a listener conflicts with the "Host" header field used by an IngressRule, the SNI host is used for termination and value of the Host header is used for routing.
             */
            secretName?: pulumi.Input<string>;
        }
        /**
         * IngressTLS describes the transport layer security associated with an Ingress.
         */
        interface IngressTLSPatch {
            /**
             * Hosts are a list of hosts included in the TLS certificate. The values in this list must match the name/s used in the tlsSecret. Defaults to the wildcard host setting for the loadbalancer controller fulfilling this Ingress, if left unspecified.
             */
            hosts?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * SecretName is the name of the secret used to terminate SSL traffic on 443. Field is left optional to allow SSL routing based on SNI hostname alone. If the SNI host in a listener conflicts with the "Host" header field used by an IngressRule, the SNI host is used for termination and value of the Host header is used for routing.
             */
            secretName?: pulumi.Input<string>;
        }
        /**
         * ParentReference describes a reference to a parent object.
         */
        interface ParentReference {
            /**
             * Group is the group of the object being referenced.
             */
            group?: pulumi.Input<string>;
            /**
             * Name is the name of the object being referenced.
             */
            name: pulumi.Input<string>;
            /**
             * Namespace is the namespace of the object being referenced.
             */
            namespace?: pulumi.Input<string>;
            /**
             * Resource is the resource of the object being referenced.
             */
            resource: pulumi.Input<string>;
        }
        /**
         * ParentReference describes a reference to a parent object.
         */
        interface ParentReferencePatch {
            /**
             * Group is the group of the object being referenced.
             */
            group?: pulumi.Input<string>;
            /**
             * Name is the name of the object being referenced.
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace is the namespace of the object being referenced.
             */
            namespace?: pulumi.Input<string>;
            /**
             * Resource is the resource of the object being referenced.
             */
            resource?: pulumi.Input<string>;
        }
        /**
         * ServiceCIDR defines a range of IP addresses using CIDR format (e.g. 192.168.0.0/24 or 2001:db2::/64). This range is used to allocate ClusterIPs to Service objects.
         */
        interface ServiceCIDR {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"networking.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ServiceCIDR">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec is the desired state of the ServiceCIDR. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec?: pulumi.Input<inputs.networking.v1beta1.ServiceCIDRSpec>;
            /**
             * status represents the current state of the ServiceCIDR. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            status?: pulumi.Input<inputs.networking.v1beta1.ServiceCIDRStatus>;
        }
        /**
         * ServiceCIDRSpec define the CIDRs the user wants to use for allocating ClusterIPs for Services.
         */
        interface ServiceCIDRSpec {
            /**
             * CIDRs defines the IP blocks in CIDR notation (e.g. "192.168.0.0/24" or "2001:db8::/64") from which to assign service cluster IPs. Max of two CIDRs is allowed, one of each IP family. This field is immutable.
             */
            cidrs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ServiceCIDRSpec define the CIDRs the user wants to use for allocating ClusterIPs for Services.
         */
        interface ServiceCIDRSpecPatch {
            /**
             * CIDRs defines the IP blocks in CIDR notation (e.g. "192.168.0.0/24" or "2001:db8::/64") from which to assign service cluster IPs. Max of two CIDRs is allowed, one of each IP family. This field is immutable.
             */
            cidrs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ServiceCIDRStatus describes the current state of the ServiceCIDR.
         */
        interface ServiceCIDRStatus {
            /**
             * conditions holds an array of metav1.Condition that describe the state of the ServiceCIDR. Current service state
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.meta.v1.Condition>[]>;
        }
    }
}
export declare namespace node {
    namespace v1 {
        /**
         * Overhead structure represents the resource overhead associated with running a pod.
         */
        interface Overhead {
            /**
             * podFixed represents the fixed resource overhead associated with running a pod.
             */
            podFixed?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * Overhead structure represents the resource overhead associated with running a pod.
         */
        interface OverheadPatch {
            /**
             * podFixed represents the fixed resource overhead associated with running a pod.
             */
            podFixed?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * RuntimeClass defines a class of container runtime supported in the cluster. The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod.  For more details, see https://kubernetes.io/docs/concepts/containers/runtime-class/
         */
        interface RuntimeClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"node.k8s.io/v1">;
            /**
             * handler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class. The possible values are specific to the node & CRI configuration.  It is assumed that all handlers are available on every node, and handlers of the same name are equivalent on every node. For example, a handler called "runc" might specify that the runc OCI runtime (using native Linux containers) will be used to run the containers in a pod. The Handler must be lowercase, conform to the DNS Label (RFC 1123) requirements, and is immutable.
             */
            handler: pulumi.Input<string>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"RuntimeClass">;
            /**
             * More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * overhead represents the resource overhead associated with running a pod for a given RuntimeClass. For more details, see
             *  https://kubernetes.io/docs/concepts/scheduling-eviction/pod-overhead/
             */
            overhead?: pulumi.Input<inputs.node.v1.Overhead>;
            /**
             * scheduling holds the scheduling constraints to ensure that pods running with this RuntimeClass are scheduled to nodes that support it. If scheduling is nil, this RuntimeClass is assumed to be supported by all nodes.
             */
            scheduling?: pulumi.Input<inputs.node.v1.Scheduling>;
        }
        /**
         * Scheduling specifies the scheduling constraints for nodes supporting a RuntimeClass.
         */
        interface Scheduling {
            /**
             * nodeSelector lists labels that must be present on nodes that support this RuntimeClass. Pods using this RuntimeClass can only be scheduled to a node matched by this selector. The RuntimeClass nodeSelector is merged with a pod's existing nodeSelector. Any conflicts will cause the pod to be rejected in admission.
             */
            nodeSelector?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.core.v1.Toleration>[]>;
        }
        /**
         * Scheduling specifies the scheduling constraints for nodes supporting a RuntimeClass.
         */
        interface SchedulingPatch {
            /**
             * nodeSelector lists labels that must be present on nodes that support this RuntimeClass. Pods using this RuntimeClass can only be scheduled to a node matched by this selector. The RuntimeClass nodeSelector is merged with a pod's existing nodeSelector. Any conflicts will cause the pod to be rejected in admission.
             */
            nodeSelector?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.core.v1.TolerationPatch>[]>;
        }
    }
    namespace v1alpha1 {
        /**
         * Overhead structure represents the resource overhead associated with running a pod.
         */
        interface Overhead {
            /**
             * PodFixed represents the fixed resource overhead associated with running a pod.
             */
            podFixed?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * Overhead structure represents the resource overhead associated with running a pod.
         */
        interface OverheadPatch {
            /**
             * PodFixed represents the fixed resource overhead associated with running a pod.
             */
            podFixed?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * RuntimeClass defines a class of container runtime supported in the cluster. The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are (currently) manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod.  For more details, see https://git.k8s.io/enhancements/keps/sig-node/runtime-class.md
         */
        interface RuntimeClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"node.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"RuntimeClass">;
            /**
             * More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the RuntimeClass More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
             */
            spec: pulumi.Input<inputs.node.v1alpha1.RuntimeClassSpec>;
        }
        /**
         * RuntimeClassSpec is a specification of a RuntimeClass. It contains parameters that are required to describe the RuntimeClass to the Container Runtime Interface (CRI) implementation, as well as any other components that need to understand how the pod will be run. The RuntimeClassSpec is immutable.
         */
        interface RuntimeClassSpec {
            /**
             * Overhead represents the resource overhead associated with running a pod for a given RuntimeClass. For more details, see https://git.k8s.io/enhancements/keps/sig-node/20190226-pod-overhead.md This field is alpha-level as of Kubernetes v1.15, and is only honored by servers that enable the PodOverhead feature.
             */
            overhead?: pulumi.Input<inputs.node.v1alpha1.Overhead>;
            /**
             * RuntimeHandler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class. The possible values are specific to the node & CRI configuration.  It is assumed that all handlers are available on every node, and handlers of the same name are equivalent on every node. For example, a handler called "runc" might specify that the runc OCI runtime (using native Linux containers) will be used to run the containers in a pod. The RuntimeHandler must conform to the DNS Label (RFC 1123) requirements and is immutable.
             */
            runtimeHandler: pulumi.Input<string>;
            /**
             * Scheduling holds the scheduling constraints to ensure that pods running with this RuntimeClass are scheduled to nodes that support it. If scheduling is nil, this RuntimeClass is assumed to be supported by all nodes.
             */
            scheduling?: pulumi.Input<inputs.node.v1alpha1.Scheduling>;
        }
        /**
         * RuntimeClassSpec is a specification of a RuntimeClass. It contains parameters that are required to describe the RuntimeClass to the Container Runtime Interface (CRI) implementation, as well as any other components that need to understand how the pod will be run. The RuntimeClassSpec is immutable.
         */
        interface RuntimeClassSpecPatch {
            /**
             * Overhead represents the resource overhead associated with running a pod for a given RuntimeClass. For more details, see https://git.k8s.io/enhancements/keps/sig-node/20190226-pod-overhead.md This field is alpha-level as of Kubernetes v1.15, and is only honored by servers that enable the PodOverhead feature.
             */
            overhead?: pulumi.Input<inputs.node.v1alpha1.OverheadPatch>;
            /**
             * RuntimeHandler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class. The possible values are specific to the node & CRI configuration.  It is assumed that all handlers are available on every node, and handlers of the same name are equivalent on every node. For example, a handler called "runc" might specify that the runc OCI runtime (using native Linux containers) will be used to run the containers in a pod. The RuntimeHandler must conform to the DNS Label (RFC 1123) requirements and is immutable.
             */
            runtimeHandler?: pulumi.Input<string>;
            /**
             * Scheduling holds the scheduling constraints to ensure that pods running with this RuntimeClass are scheduled to nodes that support it. If scheduling is nil, this RuntimeClass is assumed to be supported by all nodes.
             */
            scheduling?: pulumi.Input<inputs.node.v1alpha1.SchedulingPatch>;
        }
        /**
         * Scheduling specifies the scheduling constraints for nodes supporting a RuntimeClass.
         */
        interface Scheduling {
            /**
             * nodeSelector lists labels that must be present on nodes that support this RuntimeClass. Pods using this RuntimeClass can only be scheduled to a node matched by this selector. The RuntimeClass nodeSelector is merged with a pod's existing nodeSelector. Any conflicts will cause the pod to be rejected in admission.
             */
            nodeSelector?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.core.v1.Toleration>[]>;
        }
        /**
         * Scheduling specifies the scheduling constraints for nodes supporting a RuntimeClass.
         */
        interface SchedulingPatch {
            /**
             * nodeSelector lists labels that must be present on nodes that support this RuntimeClass. Pods using this RuntimeClass can only be scheduled to a node matched by this selector. The RuntimeClass nodeSelector is merged with a pod's existing nodeSelector. Any conflicts will cause the pod to be rejected in admission.
             */
            nodeSelector?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.core.v1.TolerationPatch>[]>;
        }
    }
    namespace v1beta1 {
        /**
         * Overhead structure represents the resource overhead associated with running a pod.
         */
        interface Overhead {
            /**
             * PodFixed represents the fixed resource overhead associated with running a pod.
             */
            podFixed?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * Overhead structure represents the resource overhead associated with running a pod.
         */
        interface OverheadPatch {
            /**
             * PodFixed represents the fixed resource overhead associated with running a pod.
             */
            podFixed?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * RuntimeClass defines a class of container runtime supported in the cluster. The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are (currently) manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod.  For more details, see https://git.k8s.io/enhancements/keps/sig-node/runtime-class.md
         */
        interface RuntimeClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"node.k8s.io/v1beta1">;
            /**
             * Handler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class. The possible values are specific to the node & CRI configuration.  It is assumed that all handlers are available on every node, and handlers of the same name are equivalent on every node. For example, a handler called "runc" might specify that the runc OCI runtime (using native Linux containers) will be used to run the containers in a pod. The Handler must conform to the DNS Label (RFC 1123) requirements, and is immutable.
             */
            handler: pulumi.Input<string>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"RuntimeClass">;
            /**
             * More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Overhead represents the resource overhead associated with running a pod for a given RuntimeClass. For more details, see https://git.k8s.io/enhancements/keps/sig-node/20190226-pod-overhead.md This field is alpha-level as of Kubernetes v1.15, and is only honored by servers that enable the PodOverhead feature.
             */
            overhead?: pulumi.Input<inputs.node.v1beta1.Overhead>;
            /**
             * Scheduling holds the scheduling constraints to ensure that pods running with this RuntimeClass are scheduled to nodes that support it. If scheduling is nil, this RuntimeClass is assumed to be supported by all nodes.
             */
            scheduling?: pulumi.Input<inputs.node.v1beta1.Scheduling>;
        }
        /**
         * Scheduling specifies the scheduling constraints for nodes supporting a RuntimeClass.
         */
        interface Scheduling {
            /**
             * nodeSelector lists labels that must be present on nodes that support this RuntimeClass. Pods using this RuntimeClass can only be scheduled to a node matched by this selector. The RuntimeClass nodeSelector is merged with a pod's existing nodeSelector. Any conflicts will cause the pod to be rejected in admission.
             */
            nodeSelector?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.core.v1.Toleration>[]>;
        }
        /**
         * Scheduling specifies the scheduling constraints for nodes supporting a RuntimeClass.
         */
        interface SchedulingPatch {
            /**
             * nodeSelector lists labels that must be present on nodes that support this RuntimeClass. Pods using this RuntimeClass can only be scheduled to a node matched by this selector. The RuntimeClass nodeSelector is merged with a pod's existing nodeSelector. Any conflicts will cause the pod to be rejected in admission.
             */
            nodeSelector?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.core.v1.TolerationPatch>[]>;
        }
    }
}
export declare namespace pkg {
    namespace version {
    }
}
export declare namespace policy {
    namespace v1 {
        /**
         * PodDisruptionBudget is an object to define the max disruption that can be caused to a collection of pods
         */
        interface PodDisruptionBudget {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"policy/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PodDisruptionBudget">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the PodDisruptionBudget.
             */
            spec?: pulumi.Input<inputs.policy.v1.PodDisruptionBudgetSpec>;
            /**
             * Most recently observed status of the PodDisruptionBudget.
             */
            status?: pulumi.Input<inputs.policy.v1.PodDisruptionBudgetStatus>;
        }
        /**
         * PodDisruptionBudgetSpec is a description of a PodDisruptionBudget.
         */
        interface PodDisruptionBudgetSpec {
            /**
             * An eviction is allowed if at most "maxUnavailable" pods selected by "selector" are unavailable after the eviction, i.e. even in absence of the evicted pod. For example, one can prevent all voluntary evictions by specifying 0. This is a mutually exclusive setting with "minAvailable".
             */
            maxUnavailable?: pulumi.Input<number | string>;
            /**
             * An eviction is allowed if at least "minAvailable" pods selected by "selector" will still be available after the eviction, i.e. even in the absence of the evicted pod.  So for example you can prevent all voluntary evictions by specifying "100%".
             */
            minAvailable?: pulumi.Input<number | string>;
            /**
             * Label query over pods whose evictions are managed by the disruption budget. A null selector will match no pods, while an empty ({}) selector will select all pods within the namespace.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * UnhealthyPodEvictionPolicy defines the criteria for when unhealthy pods should be considered for eviction. Current implementation considers healthy pods, as pods that have status.conditions item with type="Ready",status="True".
             *
             * Valid policies are IfHealthyBudget and AlwaysAllow. If no policy is specified, the default behavior will be used, which corresponds to the IfHealthyBudget policy.
             *
             * IfHealthyBudget policy means that running pods (status.phase="Running"), but not yet healthy can be evicted only if the guarded application is not disrupted (status.currentHealthy is at least equal to status.desiredHealthy). Healthy pods will be subject to the PDB for eviction.
             *
             * AlwaysAllow policy means that all running pods (status.phase="Running"), but not yet healthy are considered disrupted and can be evicted regardless of whether the criteria in a PDB is met. This means perspective running pods of a disrupted application might not get a chance to become healthy. Healthy pods will be subject to the PDB for eviction.
             *
             * Additional policies may be added in the future. Clients making eviction decisions should disallow eviction of unhealthy pods if they encounter an unrecognized policy in this field.
             */
            unhealthyPodEvictionPolicy?: pulumi.Input<string>;
        }
        /**
         * PodDisruptionBudgetSpec is a description of a PodDisruptionBudget.
         */
        interface PodDisruptionBudgetSpecPatch {
            /**
             * An eviction is allowed if at most "maxUnavailable" pods selected by "selector" are unavailable after the eviction, i.e. even in absence of the evicted pod. For example, one can prevent all voluntary evictions by specifying 0. This is a mutually exclusive setting with "minAvailable".
             */
            maxUnavailable?: pulumi.Input<number | string>;
            /**
             * An eviction is allowed if at least "minAvailable" pods selected by "selector" will still be available after the eviction, i.e. even in the absence of the evicted pod.  So for example you can prevent all voluntary evictions by specifying "100%".
             */
            minAvailable?: pulumi.Input<number | string>;
            /**
             * Label query over pods whose evictions are managed by the disruption budget. A null selector will match no pods, while an empty ({}) selector will select all pods within the namespace.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * UnhealthyPodEvictionPolicy defines the criteria for when unhealthy pods should be considered for eviction. Current implementation considers healthy pods, as pods that have status.conditions item with type="Ready",status="True".
             *
             * Valid policies are IfHealthyBudget and AlwaysAllow. If no policy is specified, the default behavior will be used, which corresponds to the IfHealthyBudget policy.
             *
             * IfHealthyBudget policy means that running pods (status.phase="Running"), but not yet healthy can be evicted only if the guarded application is not disrupted (status.currentHealthy is at least equal to status.desiredHealthy). Healthy pods will be subject to the PDB for eviction.
             *
             * AlwaysAllow policy means that all running pods (status.phase="Running"), but not yet healthy are considered disrupted and can be evicted regardless of whether the criteria in a PDB is met. This means perspective running pods of a disrupted application might not get a chance to become healthy. Healthy pods will be subject to the PDB for eviction.
             *
             * Additional policies may be added in the future. Clients making eviction decisions should disallow eviction of unhealthy pods if they encounter an unrecognized policy in this field.
             */
            unhealthyPodEvictionPolicy?: pulumi.Input<string>;
        }
        /**
         * PodDisruptionBudgetStatus represents information about the status of a PodDisruptionBudget. Status may trail the actual state of a system.
         */
        interface PodDisruptionBudgetStatus {
            /**
             * Conditions contain conditions for PDB. The disruption controller sets the DisruptionAllowed condition. The following are known values for the reason field (additional reasons could be added in the future): - SyncFailed: The controller encountered an error and wasn't able to compute
             *               the number of allowed disruptions. Therefore no disruptions are
             *               allowed and the status of the condition will be False.
             * - InsufficientPods: The number of pods are either at or below the number
             *                     required by the PodDisruptionBudget. No disruptions are
             *                     allowed and the status of the condition will be False.
             * - SufficientPods: There are more pods than required by the PodDisruptionBudget.
             *                   The condition will be True, and the number of allowed
             *                   disruptions are provided by the disruptionsAllowed property.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.meta.v1.Condition>[]>;
            /**
             * current number of healthy pods
             */
            currentHealthy: pulumi.Input<number>;
            /**
             * minimum desired number of healthy pods
             */
            desiredHealthy: pulumi.Input<number>;
            /**
             * DisruptedPods contains information about pods whose eviction was processed by the API server eviction subresource handler but has not yet been observed by the PodDisruptionBudget controller. A pod will be in this map from the time when the API server processed the eviction request to the time when the pod is seen by PDB controller as having been marked for deletion (or after a timeout). The key in the map is the name of the pod and the value is the time when the API server processed the eviction request. If the deletion didn't occur and a pod is still there it will be removed from the list automatically by PodDisruptionBudget controller after some time. If everything goes smooth this map should be empty for the most of the time. Large number of entries in the map may indicate problems with pod deletions.
             */
            disruptedPods?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Number of pod disruptions that are currently allowed.
             */
            disruptionsAllowed: pulumi.Input<number>;
            /**
             * total number of pods counted by this disruption budget
             */
            expectedPods: pulumi.Input<number>;
            /**
             * Most recent generation observed when updating this PDB status. DisruptionsAllowed and other status information is valid only if observedGeneration equals to PDB's object generation.
             */
            observedGeneration?: pulumi.Input<number>;
        }
    }
    namespace v1beta1 {
        /**
         * AllowedCSIDriver represents a single inline CSI Driver that is allowed to be used.
         */
        interface AllowedCSIDriver {
            /**
             * Name is the registered name of the CSI driver
             */
            name: pulumi.Input<string>;
        }
        /**
         * AllowedCSIDriver represents a single inline CSI Driver that is allowed to be used.
         */
        interface AllowedCSIDriverPatch {
            /**
             * Name is the registered name of the CSI driver
             */
            name?: pulumi.Input<string>;
        }
        /**
         * AllowedFlexVolume represents a single Flexvolume that is allowed to be used.
         */
        interface AllowedFlexVolume {
            /**
             * driver is the name of the Flexvolume driver.
             */
            driver: pulumi.Input<string>;
        }
        /**
         * AllowedFlexVolume represents a single Flexvolume that is allowed to be used.
         */
        interface AllowedFlexVolumePatch {
            /**
             * driver is the name of the Flexvolume driver.
             */
            driver?: pulumi.Input<string>;
        }
        /**
         * AllowedHostPath defines the host volume conditions that will be enabled by a policy for pods to use. It requires the path prefix to be defined.
         */
        interface AllowedHostPath {
            /**
             * pathPrefix is the path prefix that the host volume must match. It does not support `*`. Trailing slashes are trimmed when validating the path prefix with a host path.
             *
             * Examples: `/foo` would allow `/foo`, `/foo/` and `/foo/bar` `/foo` would not allow `/food` or `/etc/foo`
             */
            pathPrefix?: pulumi.Input<string>;
            /**
             * when set to true, will allow host volumes matching the pathPrefix only if all volume mounts are readOnly.
             */
            readOnly?: pulumi.Input<boolean>;
        }
        /**
         * AllowedHostPath defines the host volume conditions that will be enabled by a policy for pods to use. It requires the path prefix to be defined.
         */
        interface AllowedHostPathPatch {
            /**
             * pathPrefix is the path prefix that the host volume must match. It does not support `*`. Trailing slashes are trimmed when validating the path prefix with a host path.
             *
             * Examples: `/foo` would allow `/foo`, `/foo/` and `/foo/bar` `/foo` would not allow `/food` or `/etc/foo`
             */
            pathPrefix?: pulumi.Input<string>;
            /**
             * when set to true, will allow host volumes matching the pathPrefix only if all volume mounts are readOnly.
             */
            readOnly?: pulumi.Input<boolean>;
        }
        /**
         * FSGroupStrategyOptions defines the strategy type and options used to create the strategy.
         */
        interface FSGroupStrategyOptions {
            /**
             * ranges are the allowed ranges of fs groups.  If you would like to force a single fs group then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.IDRange>[]>;
            /**
             * rule is the strategy that will dictate what FSGroup is used in the SecurityContext.
             */
            rule?: pulumi.Input<string>;
        }
        /**
         * FSGroupStrategyOptions defines the strategy type and options used to create the strategy.
         */
        interface FSGroupStrategyOptionsPatch {
            /**
             * ranges are the allowed ranges of fs groups.  If you would like to force a single fs group then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.IDRangePatch>[]>;
            /**
             * rule is the strategy that will dictate what FSGroup is used in the SecurityContext.
             */
            rule?: pulumi.Input<string>;
        }
        /**
         * HostPortRange defines a range of host ports that will be enabled by a policy for pods to use.  It requires both the start and end to be defined.
         */
        interface HostPortRange {
            /**
             * max is the end of the range, inclusive.
             */
            max: pulumi.Input<number>;
            /**
             * min is the start of the range, inclusive.
             */
            min: pulumi.Input<number>;
        }
        /**
         * HostPortRange defines a range of host ports that will be enabled by a policy for pods to use.  It requires both the start and end to be defined.
         */
        interface HostPortRangePatch {
            /**
             * max is the end of the range, inclusive.
             */
            max?: pulumi.Input<number>;
            /**
             * min is the start of the range, inclusive.
             */
            min?: pulumi.Input<number>;
        }
        /**
         * IDRange provides a min/max of an allowed range of IDs.
         */
        interface IDRange {
            /**
             * max is the end of the range, inclusive.
             */
            max: pulumi.Input<number>;
            /**
             * min is the start of the range, inclusive.
             */
            min: pulumi.Input<number>;
        }
        /**
         * IDRange provides a min/max of an allowed range of IDs.
         */
        interface IDRangePatch {
            /**
             * max is the end of the range, inclusive.
             */
            max?: pulumi.Input<number>;
            /**
             * min is the start of the range, inclusive.
             */
            min?: pulumi.Input<number>;
        }
        /**
         * PodDisruptionBudget is an object to define the max disruption that can be caused to a collection of pods
         */
        interface PodDisruptionBudget {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"policy/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PodDisruptionBudget">;
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired behavior of the PodDisruptionBudget.
             */
            spec?: pulumi.Input<inputs.policy.v1beta1.PodDisruptionBudgetSpec>;
            /**
             * Most recently observed status of the PodDisruptionBudget.
             */
            status?: pulumi.Input<inputs.policy.v1beta1.PodDisruptionBudgetStatus>;
        }
        /**
         * PodDisruptionBudgetSpec is a description of a PodDisruptionBudget.
         */
        interface PodDisruptionBudgetSpec {
            /**
             * An eviction is allowed if at most "maxUnavailable" pods selected by "selector" are unavailable after the eviction, i.e. even in absence of the evicted pod. For example, one can prevent all voluntary evictions by specifying 0. This is a mutually exclusive setting with "minAvailable".
             */
            maxUnavailable?: pulumi.Input<number | string>;
            /**
             * An eviction is allowed if at least "minAvailable" pods selected by "selector" will still be available after the eviction, i.e. even in the absence of the evicted pod.  So for example you can prevent all voluntary evictions by specifying "100%".
             */
            minAvailable?: pulumi.Input<number | string>;
            /**
             * Label query over pods whose evictions are managed by the disruption budget.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
        }
        /**
         * PodDisruptionBudgetSpec is a description of a PodDisruptionBudget.
         */
        interface PodDisruptionBudgetSpecPatch {
            /**
             * An eviction is allowed if at most "maxUnavailable" pods selected by "selector" are unavailable after the eviction, i.e. even in absence of the evicted pod. For example, one can prevent all voluntary evictions by specifying 0. This is a mutually exclusive setting with "minAvailable".
             */
            maxUnavailable?: pulumi.Input<number | string>;
            /**
             * An eviction is allowed if at least "minAvailable" pods selected by "selector" will still be available after the eviction, i.e. even in the absence of the evicted pod.  So for example you can prevent all voluntary evictions by specifying "100%".
             */
            minAvailable?: pulumi.Input<number | string>;
            /**
             * Label query over pods whose evictions are managed by the disruption budget.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
        }
        /**
         * PodDisruptionBudgetStatus represents information about the status of a PodDisruptionBudget. Status may trail the actual state of a system.
         */
        interface PodDisruptionBudgetStatus {
            /**
             * current number of healthy pods
             */
            currentHealthy: pulumi.Input<number>;
            /**
             * minimum desired number of healthy pods
             */
            desiredHealthy: pulumi.Input<number>;
            /**
             * DisruptedPods contains information about pods whose eviction was processed by the API server eviction subresource handler but has not yet been observed by the PodDisruptionBudget controller. A pod will be in this map from the time when the API server processed the eviction request to the time when the pod is seen by PDB controller as having been marked for deletion (or after a timeout). The key in the map is the name of the pod and the value is the time when the API server processed the eviction request. If the deletion didn't occur and a pod is still there it will be removed from the list automatically by PodDisruptionBudget controller after some time. If everything goes smooth this map should be empty for the most of the time. Large number of entries in the map may indicate problems with pod deletions.
             */
            disruptedPods?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Number of pod disruptions that are currently allowed.
             */
            disruptionsAllowed: pulumi.Input<number>;
            /**
             * total number of pods counted by this disruption budget
             */
            expectedPods: pulumi.Input<number>;
            /**
             * Most recent generation observed when updating this PDB status. PodDisruptionsAllowed and other status information is valid only if observedGeneration equals to PDB's object generation.
             */
            observedGeneration?: pulumi.Input<number>;
        }
        /**
         * PodSecurityPolicy governs the ability to make requests that affect the Security Context that will be applied to a pod and container.
         */
        interface PodSecurityPolicy {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"policy/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PodSecurityPolicy">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec defines the policy enforced.
             */
            spec?: pulumi.Input<inputs.policy.v1beta1.PodSecurityPolicySpec>;
        }
        /**
         * PodSecurityPolicySpec defines the policy enforced.
         */
        interface PodSecurityPolicySpec {
            /**
             * allowPrivilegeEscalation determines if a pod can request to allow privilege escalation. If unspecified, defaults to true.
             */
            allowPrivilegeEscalation?: pulumi.Input<boolean>;
            /**
             * AllowedCSIDrivers is a whitelist of inline CSI drivers that must be explicitly set to be embedded within a pod spec. An empty value indicates that any CSI driver can be used for inline ephemeral volumes. This is an alpha field, and is only honored if the API server enables the CSIInlineVolume feature gate.
             */
            allowedCSIDrivers?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.AllowedCSIDriver>[]>;
            /**
             * allowedCapabilities is a list of capabilities that can be requested to add to the container. Capabilities in this field may be added at the pod author's discretion. You must not list a capability in both allowedCapabilities and requiredDropCapabilities.
             */
            allowedCapabilities?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * allowedFlexVolumes is a whitelist of allowed Flexvolumes.  Empty or nil indicates that all Flexvolumes may be used.  This parameter is effective only when the usage of the Flexvolumes is allowed in the "volumes" field.
             */
            allowedFlexVolumes?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.AllowedFlexVolume>[]>;
            /**
             * allowedHostPaths is a white list of allowed host paths. Empty indicates that all host paths may be used.
             */
            allowedHostPaths?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.AllowedHostPath>[]>;
            /**
             * AllowedProcMountTypes is a whitelist of allowed ProcMountTypes. Empty or nil indicates that only the DefaultProcMountType may be used. This requires the ProcMountType feature flag to be enabled.
             */
            allowedProcMountTypes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * allowedUnsafeSysctls is a list of explicitly allowed unsafe sysctls, defaults to none. Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of allowed sysctls. Single * means all unsafe sysctls are allowed. Kubelet has to whitelist all allowed unsafe sysctls explicitly to avoid rejection.
             *
             * Examples: e.g. "foo/*" allows "foo/bar", "foo/baz", etc. e.g. "foo.*" allows "foo.bar", "foo.baz", etc.
             */
            allowedUnsafeSysctls?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * defaultAddCapabilities is the default set of capabilities that will be added to the container unless the pod spec specifically drops the capability.  You may not list a capability in both defaultAddCapabilities and requiredDropCapabilities. Capabilities added here are implicitly allowed, and need not be included in the allowedCapabilities list.
             */
            defaultAddCapabilities?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * defaultAllowPrivilegeEscalation controls the default setting for whether a process can gain more privileges than its parent process.
             */
            defaultAllowPrivilegeEscalation?: pulumi.Input<boolean>;
            /**
             * forbiddenSysctls is a list of explicitly forbidden sysctls, defaults to none. Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of forbidden sysctls. Single * means all sysctls are forbidden.
             *
             * Examples: e.g. "foo/*" forbids "foo/bar", "foo/baz", etc. e.g. "foo.*" forbids "foo.bar", "foo.baz", etc.
             */
            forbiddenSysctls?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * fsGroup is the strategy that will dictate what fs group is used by the SecurityContext.
             */
            fsGroup: pulumi.Input<inputs.policy.v1beta1.FSGroupStrategyOptions>;
            /**
             * hostIPC determines if the policy allows the use of HostIPC in the pod spec.
             */
            hostIPC?: pulumi.Input<boolean>;
            /**
             * hostNetwork determines if the policy allows the use of HostNetwork in the pod spec.
             */
            hostNetwork?: pulumi.Input<boolean>;
            /**
             * hostPID determines if the policy allows the use of HostPID in the pod spec.
             */
            hostPID?: pulumi.Input<boolean>;
            /**
             * hostPorts determines which host port ranges are allowed to be exposed.
             */
            hostPorts?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.HostPortRange>[]>;
            /**
             * privileged determines if a pod can request to be run as privileged.
             */
            privileged?: pulumi.Input<boolean>;
            /**
             * readOnlyRootFilesystem when set to true will force containers to run with a read only root file system.  If the container specifically requests to run with a non-read only root file system the PSP should deny the pod. If set to false the container may run with a read only root file system if it wishes but it will not be forced to.
             */
            readOnlyRootFilesystem?: pulumi.Input<boolean>;
            /**
             * requiredDropCapabilities are the capabilities that will be dropped from the container.  These are required to be dropped and cannot be added.
             */
            requiredDropCapabilities?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * RunAsGroup is the strategy that will dictate the allowable RunAsGroup values that may be set. If this field is omitted, the pod's RunAsGroup can take any value. This field requires the RunAsGroup feature gate to be enabled.
             */
            runAsGroup?: pulumi.Input<inputs.policy.v1beta1.RunAsGroupStrategyOptions>;
            /**
             * runAsUser is the strategy that will dictate the allowable RunAsUser values that may be set.
             */
            runAsUser: pulumi.Input<inputs.policy.v1beta1.RunAsUserStrategyOptions>;
            /**
             * runtimeClass is the strategy that will dictate the allowable RuntimeClasses for a pod. If this field is omitted, the pod's runtimeClassName field is unrestricted. Enforcement of this field depends on the RuntimeClass feature gate being enabled.
             */
            runtimeClass?: pulumi.Input<inputs.policy.v1beta1.RuntimeClassStrategyOptions>;
            /**
             * seLinux is the strategy that will dictate the allowable labels that may be set.
             */
            seLinux: pulumi.Input<inputs.policy.v1beta1.SELinuxStrategyOptions>;
            /**
             * supplementalGroups is the strategy that will dictate what supplemental groups are used by the SecurityContext.
             */
            supplementalGroups: pulumi.Input<inputs.policy.v1beta1.SupplementalGroupsStrategyOptions>;
            /**
             * volumes is a white list of allowed volume plugins. Empty indicates that no volumes may be used. To allow all volumes you may use '*'.
             */
            volumes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * PodSecurityPolicySpec defines the policy enforced.
         */
        interface PodSecurityPolicySpecPatch {
            /**
             * allowPrivilegeEscalation determines if a pod can request to allow privilege escalation. If unspecified, defaults to true.
             */
            allowPrivilegeEscalation?: pulumi.Input<boolean>;
            /**
             * AllowedCSIDrivers is a whitelist of inline CSI drivers that must be explicitly set to be embedded within a pod spec. An empty value indicates that any CSI driver can be used for inline ephemeral volumes. This is an alpha field, and is only honored if the API server enables the CSIInlineVolume feature gate.
             */
            allowedCSIDrivers?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.AllowedCSIDriverPatch>[]>;
            /**
             * allowedCapabilities is a list of capabilities that can be requested to add to the container. Capabilities in this field may be added at the pod author's discretion. You must not list a capability in both allowedCapabilities and requiredDropCapabilities.
             */
            allowedCapabilities?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * allowedFlexVolumes is a whitelist of allowed Flexvolumes.  Empty or nil indicates that all Flexvolumes may be used.  This parameter is effective only when the usage of the Flexvolumes is allowed in the "volumes" field.
             */
            allowedFlexVolumes?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.AllowedFlexVolumePatch>[]>;
            /**
             * allowedHostPaths is a white list of allowed host paths. Empty indicates that all host paths may be used.
             */
            allowedHostPaths?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.AllowedHostPathPatch>[]>;
            /**
             * AllowedProcMountTypes is a whitelist of allowed ProcMountTypes. Empty or nil indicates that only the DefaultProcMountType may be used. This requires the ProcMountType feature flag to be enabled.
             */
            allowedProcMountTypes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * allowedUnsafeSysctls is a list of explicitly allowed unsafe sysctls, defaults to none. Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of allowed sysctls. Single * means all unsafe sysctls are allowed. Kubelet has to whitelist all allowed unsafe sysctls explicitly to avoid rejection.
             *
             * Examples: e.g. "foo/*" allows "foo/bar", "foo/baz", etc. e.g. "foo.*" allows "foo.bar", "foo.baz", etc.
             */
            allowedUnsafeSysctls?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * defaultAddCapabilities is the default set of capabilities that will be added to the container unless the pod spec specifically drops the capability.  You may not list a capability in both defaultAddCapabilities and requiredDropCapabilities. Capabilities added here are implicitly allowed, and need not be included in the allowedCapabilities list.
             */
            defaultAddCapabilities?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * defaultAllowPrivilegeEscalation controls the default setting for whether a process can gain more privileges than its parent process.
             */
            defaultAllowPrivilegeEscalation?: pulumi.Input<boolean>;
            /**
             * forbiddenSysctls is a list of explicitly forbidden sysctls, defaults to none. Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of forbidden sysctls. Single * means all sysctls are forbidden.
             *
             * Examples: e.g. "foo/*" forbids "foo/bar", "foo/baz", etc. e.g. "foo.*" forbids "foo.bar", "foo.baz", etc.
             */
            forbiddenSysctls?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * fsGroup is the strategy that will dictate what fs group is used by the SecurityContext.
             */
            fsGroup?: pulumi.Input<inputs.policy.v1beta1.FSGroupStrategyOptionsPatch>;
            /**
             * hostIPC determines if the policy allows the use of HostIPC in the pod spec.
             */
            hostIPC?: pulumi.Input<boolean>;
            /**
             * hostNetwork determines if the policy allows the use of HostNetwork in the pod spec.
             */
            hostNetwork?: pulumi.Input<boolean>;
            /**
             * hostPID determines if the policy allows the use of HostPID in the pod spec.
             */
            hostPID?: pulumi.Input<boolean>;
            /**
             * hostPorts determines which host port ranges are allowed to be exposed.
             */
            hostPorts?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.HostPortRangePatch>[]>;
            /**
             * privileged determines if a pod can request to be run as privileged.
             */
            privileged?: pulumi.Input<boolean>;
            /**
             * readOnlyRootFilesystem when set to true will force containers to run with a read only root file system.  If the container specifically requests to run with a non-read only root file system the PSP should deny the pod. If set to false the container may run with a read only root file system if it wishes but it will not be forced to.
             */
            readOnlyRootFilesystem?: pulumi.Input<boolean>;
            /**
             * requiredDropCapabilities are the capabilities that will be dropped from the container.  These are required to be dropped and cannot be added.
             */
            requiredDropCapabilities?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * RunAsGroup is the strategy that will dictate the allowable RunAsGroup values that may be set. If this field is omitted, the pod's RunAsGroup can take any value. This field requires the RunAsGroup feature gate to be enabled.
             */
            runAsGroup?: pulumi.Input<inputs.policy.v1beta1.RunAsGroupStrategyOptionsPatch>;
            /**
             * runAsUser is the strategy that will dictate the allowable RunAsUser values that may be set.
             */
            runAsUser?: pulumi.Input<inputs.policy.v1beta1.RunAsUserStrategyOptionsPatch>;
            /**
             * runtimeClass is the strategy that will dictate the allowable RuntimeClasses for a pod. If this field is omitted, the pod's runtimeClassName field is unrestricted. Enforcement of this field depends on the RuntimeClass feature gate being enabled.
             */
            runtimeClass?: pulumi.Input<inputs.policy.v1beta1.RuntimeClassStrategyOptionsPatch>;
            /**
             * seLinux is the strategy that will dictate the allowable labels that may be set.
             */
            seLinux?: pulumi.Input<inputs.policy.v1beta1.SELinuxStrategyOptionsPatch>;
            /**
             * supplementalGroups is the strategy that will dictate what supplemental groups are used by the SecurityContext.
             */
            supplementalGroups?: pulumi.Input<inputs.policy.v1beta1.SupplementalGroupsStrategyOptionsPatch>;
            /**
             * volumes is a white list of allowed volume plugins. Empty indicates that no volumes may be used. To allow all volumes you may use '*'.
             */
            volumes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * RunAsGroupStrategyOptions defines the strategy type and any options used to create the strategy.
         */
        interface RunAsGroupStrategyOptions {
            /**
             * ranges are the allowed ranges of gids that may be used. If you would like to force a single gid then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.IDRange>[]>;
            /**
             * rule is the strategy that will dictate the allowable RunAsGroup values that may be set.
             */
            rule: pulumi.Input<string>;
        }
        /**
         * RunAsGroupStrategyOptions defines the strategy type and any options used to create the strategy.
         */
        interface RunAsGroupStrategyOptionsPatch {
            /**
             * ranges are the allowed ranges of gids that may be used. If you would like to force a single gid then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.IDRangePatch>[]>;
            /**
             * rule is the strategy that will dictate the allowable RunAsGroup values that may be set.
             */
            rule?: pulumi.Input<string>;
        }
        /**
         * RunAsUserStrategyOptions defines the strategy type and any options used to create the strategy.
         */
        interface RunAsUserStrategyOptions {
            /**
             * ranges are the allowed ranges of uids that may be used. If you would like to force a single uid then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.IDRange>[]>;
            /**
             * rule is the strategy that will dictate the allowable RunAsUser values that may be set.
             */
            rule: pulumi.Input<string>;
        }
        /**
         * RunAsUserStrategyOptions defines the strategy type and any options used to create the strategy.
         */
        interface RunAsUserStrategyOptionsPatch {
            /**
             * ranges are the allowed ranges of uids that may be used. If you would like to force a single uid then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.IDRangePatch>[]>;
            /**
             * rule is the strategy that will dictate the allowable RunAsUser values that may be set.
             */
            rule?: pulumi.Input<string>;
        }
        /**
         * RuntimeClassStrategyOptions define the strategy that will dictate the allowable RuntimeClasses for a pod.
         */
        interface RuntimeClassStrategyOptions {
            /**
             * allowedRuntimeClassNames is a whitelist of RuntimeClass names that may be specified on a pod. A value of "*" means that any RuntimeClass name is allowed, and must be the only item in the list. An empty list requires the RuntimeClassName field to be unset.
             */
            allowedRuntimeClassNames: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * defaultRuntimeClassName is the default RuntimeClassName to set on the pod. The default MUST be allowed by the allowedRuntimeClassNames list. A value of nil does not mutate the Pod.
             */
            defaultRuntimeClassName?: pulumi.Input<string>;
        }
        /**
         * RuntimeClassStrategyOptions define the strategy that will dictate the allowable RuntimeClasses for a pod.
         */
        interface RuntimeClassStrategyOptionsPatch {
            /**
             * allowedRuntimeClassNames is a whitelist of RuntimeClass names that may be specified on a pod. A value of "*" means that any RuntimeClass name is allowed, and must be the only item in the list. An empty list requires the RuntimeClassName field to be unset.
             */
            allowedRuntimeClassNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * defaultRuntimeClassName is the default RuntimeClassName to set on the pod. The default MUST be allowed by the allowedRuntimeClassNames list. A value of nil does not mutate the Pod.
             */
            defaultRuntimeClassName?: pulumi.Input<string>;
        }
        /**
         * SELinuxStrategyOptions defines the strategy type and any options used to create the strategy.
         */
        interface SELinuxStrategyOptions {
            /**
             * rule is the strategy that will dictate the allowable labels that may be set.
             */
            rule: pulumi.Input<string>;
            /**
             * seLinuxOptions required to run as; required for MustRunAs More info: https://kubernetes.io/docs/tasks/configure-pod-container/security-context/
             */
            seLinuxOptions?: pulumi.Input<inputs.core.v1.SELinuxOptions>;
        }
        /**
         * SELinuxStrategyOptions defines the strategy type and any options used to create the strategy.
         */
        interface SELinuxStrategyOptionsPatch {
            /**
             * rule is the strategy that will dictate the allowable labels that may be set.
             */
            rule?: pulumi.Input<string>;
            /**
             * seLinuxOptions required to run as; required for MustRunAs More info: https://kubernetes.io/docs/tasks/configure-pod-container/security-context/
             */
            seLinuxOptions?: pulumi.Input<inputs.core.v1.SELinuxOptionsPatch>;
        }
        /**
         * SupplementalGroupsStrategyOptions defines the strategy type and options used to create the strategy.
         */
        interface SupplementalGroupsStrategyOptions {
            /**
             * ranges are the allowed ranges of supplemental groups.  If you would like to force a single supplemental group then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.IDRange>[]>;
            /**
             * rule is the strategy that will dictate what supplemental groups is used in the SecurityContext.
             */
            rule?: pulumi.Input<string>;
        }
        /**
         * SupplementalGroupsStrategyOptions defines the strategy type and options used to create the strategy.
         */
        interface SupplementalGroupsStrategyOptionsPatch {
            /**
             * ranges are the allowed ranges of supplemental groups.  If you would like to force a single supplemental group then supply a single range with the same start and end. Required for MustRunAs.
             */
            ranges?: pulumi.Input<pulumi.Input<inputs.policy.v1beta1.IDRangePatch>[]>;
            /**
             * rule is the strategy that will dictate what supplemental groups is used in the SecurityContext.
             */
            rule?: pulumi.Input<string>;
        }
    }
}
export declare namespace rbac {
    namespace v1 {
        /**
         * AggregationRule describes how to locate ClusterRoles to aggregate into the ClusterRole
         */
        interface AggregationRule {
            /**
             * ClusterRoleSelectors holds a list of selectors which will be used to find ClusterRoles and create the rules. If any of the selectors match, then the ClusterRole's permissions will be added
             */
            clusterRoleSelectors?: pulumi.Input<pulumi.Input<inputs.meta.v1.LabelSelector>[]>;
        }
        /**
         * AggregationRule describes how to locate ClusterRoles to aggregate into the ClusterRole
         */
        interface AggregationRulePatch {
            /**
             * ClusterRoleSelectors holds a list of selectors which will be used to find ClusterRoles and create the rules. If any of the selectors match, then the ClusterRole's permissions will be added
             */
            clusterRoleSelectors?: pulumi.Input<pulumi.Input<inputs.meta.v1.LabelSelectorPatch>[]>;
        }
        /**
         * ClusterRole is a cluster level, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding or ClusterRoleBinding.
         */
        interface ClusterRole {
            /**
             * AggregationRule is an optional field that describes how to build the Rules for this ClusterRole. If AggregationRule is set, then the Rules are controller managed and direct changes to Rules will be stomped by the controller.
             */
            aggregationRule?: pulumi.Input<inputs.rbac.v1.AggregationRule>;
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"rbac.authorization.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ClusterRole">;
            /**
             * Standard object's metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Rules holds all the PolicyRules for this ClusterRole
             */
            rules?: pulumi.Input<pulumi.Input<inputs.rbac.v1.PolicyRule>[]>;
        }
        /**
         * ClusterRoleBinding references a ClusterRole, but not contain it.  It can reference a ClusterRole in the global namespace, and adds who information via Subject.
         */
        interface ClusterRoleBinding {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"rbac.authorization.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ClusterRoleBinding">;
            /**
             * Standard object's metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * RoleRef can only reference a ClusterRole in the global namespace. If the RoleRef cannot be resolved, the Authorizer must return an error. This field is immutable.
             */
            roleRef: pulumi.Input<inputs.rbac.v1.RoleRef>;
            /**
             * Subjects holds references to the objects the role applies to.
             */
            subjects?: pulumi.Input<pulumi.Input<inputs.rbac.v1.Subject>[]>;
        }
        /**
         * PolicyRule holds information that describes a policy rule, but does not contain information about who the rule applies to or which namespace the rule applies to.
         */
        interface PolicyRule {
            /**
             * APIGroups is the name of the APIGroup that contains the resources.  If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed. "" represents the core API group and "*" represents all API groups.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * NonResourceURLs is a set of partial urls that a user should have access to.  *s are allowed, but only as the full, final step in the path Since non-resource URLs are not namespaced, this field is only applicable for ClusterRoles referenced from a ClusterRoleBinding. Rules can either apply to API resources (such as "pods" or "secrets") or non-resource URL paths (such as "/api"),  but not both.
             */
            nonResourceURLs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.
             */
            resourceNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to. '*' represents all resources.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Verbs is a list of Verbs that apply to ALL the ResourceKinds contained in this rule. '*' represents all verbs.
             */
            verbs: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * PolicyRule holds information that describes a policy rule, but does not contain information about who the rule applies to or which namespace the rule applies to.
         */
        interface PolicyRulePatch {
            /**
             * APIGroups is the name of the APIGroup that contains the resources.  If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed. "" represents the core API group and "*" represents all API groups.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * NonResourceURLs is a set of partial urls that a user should have access to.  *s are allowed, but only as the full, final step in the path Since non-resource URLs are not namespaced, this field is only applicable for ClusterRoles referenced from a ClusterRoleBinding. Rules can either apply to API resources (such as "pods" or "secrets") or non-resource URL paths (such as "/api"),  but not both.
             */
            nonResourceURLs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.
             */
            resourceNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to. '*' represents all resources.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Verbs is a list of Verbs that apply to ALL the ResourceKinds contained in this rule. '*' represents all verbs.
             */
            verbs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * Role is a namespaced, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding.
         */
        interface Role {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"rbac.authorization.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Role">;
            /**
             * Standard object's metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Rules holds all the PolicyRules for this Role
             */
            rules?: pulumi.Input<pulumi.Input<inputs.rbac.v1.PolicyRule>[]>;
        }
        /**
         * RoleBinding references a role, but does not contain it.  It can reference a Role in the same namespace or a ClusterRole in the global namespace. It adds who information via Subjects and namespace information by which namespace it exists in.  RoleBindings in a given namespace only have effect in that namespace.
         */
        interface RoleBinding {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"rbac.authorization.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"RoleBinding">;
            /**
             * Standard object's metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * RoleRef can reference a Role in the current namespace or a ClusterRole in the global namespace. If the RoleRef cannot be resolved, the Authorizer must return an error. This field is immutable.
             */
            roleRef: pulumi.Input<inputs.rbac.v1.RoleRef>;
            /**
             * Subjects holds references to the objects the role applies to.
             */
            subjects?: pulumi.Input<pulumi.Input<inputs.rbac.v1.Subject>[]>;
        }
        /**
         * RoleRef contains information that points to the role being used
         */
        interface RoleRef {
            /**
             * APIGroup is the group for the resource being referenced
             */
            apiGroup: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced
             */
            kind: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced
             */
            name: pulumi.Input<string>;
        }
        /**
         * RoleRef contains information that points to the role being used
         */
        interface RoleRefPatch {
            /**
             * APIGroup is the group for the resource being referenced
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced
             */
            kind?: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced
             */
            name?: pulumi.Input<string>;
        }
        /**
         * Subject contains a reference to the object or user identities a role binding applies to.  This can either hold a direct API object reference, or a value for non-objects such as user and group names.
         */
        interface Subject {
            /**
             * APIGroup holds the API group of the referenced subject. Defaults to "" for ServiceAccount subjects. Defaults to "rbac.authorization.k8s.io" for User and Group subjects.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind of object being referenced. Values defined by this API group are "User", "Group", and "ServiceAccount". If the Authorizer does not recognized the kind value, the Authorizer should report an error.
             */
            kind: pulumi.Input<string>;
            /**
             * Name of the object being referenced.
             */
            name: pulumi.Input<string>;
            /**
             * Namespace of the referenced object.  If the object kind is non-namespace, such as "User" or "Group", and this value is not empty the Authorizer should report an error.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * Subject contains a reference to the object or user identities a role binding applies to.  This can either hold a direct API object reference, or a value for non-objects such as user and group names.
         */
        interface SubjectPatch {
            /**
             * APIGroup holds the API group of the referenced subject. Defaults to "" for ServiceAccount subjects. Defaults to "rbac.authorization.k8s.io" for User and Group subjects.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind of object being referenced. Values defined by this API group are "User", "Group", and "ServiceAccount". If the Authorizer does not recognized the kind value, the Authorizer should report an error.
             */
            kind?: pulumi.Input<string>;
            /**
             * Name of the object being referenced.
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace of the referenced object.  If the object kind is non-namespace, such as "User" or "Group", and this value is not empty the Authorizer should report an error.
             */
            namespace?: pulumi.Input<string>;
        }
    }
    namespace v1alpha1 {
        /**
         * AggregationRule describes how to locate ClusterRoles to aggregate into the ClusterRole
         */
        interface AggregationRule {
            /**
             * ClusterRoleSelectors holds a list of selectors which will be used to find ClusterRoles and create the rules. If any of the selectors match, then the ClusterRole's permissions will be added
             */
            clusterRoleSelectors?: pulumi.Input<pulumi.Input<inputs.meta.v1.LabelSelector>[]>;
        }
        /**
         * AggregationRule describes how to locate ClusterRoles to aggregate into the ClusterRole
         */
        interface AggregationRulePatch {
            /**
             * ClusterRoleSelectors holds a list of selectors which will be used to find ClusterRoles and create the rules. If any of the selectors match, then the ClusterRole's permissions will be added
             */
            clusterRoleSelectors?: pulumi.Input<pulumi.Input<inputs.meta.v1.LabelSelectorPatch>[]>;
        }
        /**
         * ClusterRole is a cluster level, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding or ClusterRoleBinding. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 ClusterRole, and will no longer be served in v1.20.
         */
        interface ClusterRole {
            /**
             * AggregationRule is an optional field that describes how to build the Rules for this ClusterRole. If AggregationRule is set, then the Rules are controller managed and direct changes to Rules will be stomped by the controller.
             */
            aggregationRule?: pulumi.Input<inputs.rbac.v1alpha1.AggregationRule>;
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"rbac.authorization.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ClusterRole">;
            /**
             * Standard object's metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Rules holds all the PolicyRules for this ClusterRole
             */
            rules?: pulumi.Input<pulumi.Input<inputs.rbac.v1alpha1.PolicyRule>[]>;
        }
        /**
         * ClusterRoleBinding references a ClusterRole, but not contain it.  It can reference a ClusterRole in the global namespace, and adds who information via Subject. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 ClusterRoleBinding, and will no longer be served in v1.20.
         */
        interface ClusterRoleBinding {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"rbac.authorization.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ClusterRoleBinding">;
            /**
             * Standard object's metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * RoleRef can only reference a ClusterRole in the global namespace. If the RoleRef cannot be resolved, the Authorizer must return an error.
             */
            roleRef: pulumi.Input<inputs.rbac.v1alpha1.RoleRef>;
            /**
             * Subjects holds references to the objects the role applies to.
             */
            subjects?: pulumi.Input<pulumi.Input<inputs.rbac.v1alpha1.Subject>[]>;
        }
        /**
         * PolicyRule holds information that describes a policy rule, but does not contain information about who the rule applies to or which namespace the rule applies to.
         */
        interface PolicyRule {
            /**
             * APIGroups is the name of the APIGroup that contains the resources.  If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * NonResourceURLs is a set of partial urls that a user should have access to.  *s are allowed, but only as the full, final step in the path This name is intentionally different than the internal type so that the DefaultConvert works nicely and because the ordering may be different. Since non-resource URLs are not namespaced, this field is only applicable for ClusterRoles referenced from a ClusterRoleBinding. Rules can either apply to API resources (such as "pods" or "secrets") or non-resource URL paths (such as "/api"),  but not both.
             */
            nonResourceURLs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.
             */
            resourceNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to.  ResourceAll represents all resources.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Verbs is a list of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule.  VerbAll represents all kinds.
             */
            verbs: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * PolicyRule holds information that describes a policy rule, but does not contain information about who the rule applies to or which namespace the rule applies to.
         */
        interface PolicyRulePatch {
            /**
             * APIGroups is the name of the APIGroup that contains the resources.  If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * NonResourceURLs is a set of partial urls that a user should have access to.  *s are allowed, but only as the full, final step in the path This name is intentionally different than the internal type so that the DefaultConvert works nicely and because the ordering may be different. Since non-resource URLs are not namespaced, this field is only applicable for ClusterRoles referenced from a ClusterRoleBinding. Rules can either apply to API resources (such as "pods" or "secrets") or non-resource URL paths (such as "/api"),  but not both.
             */
            nonResourceURLs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.
             */
            resourceNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to.  ResourceAll represents all resources.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Verbs is a list of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule.  VerbAll represents all kinds.
             */
            verbs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * Role is a namespaced, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 Role, and will no longer be served in v1.20.
         */
        interface Role {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"rbac.authorization.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Role">;
            /**
             * Standard object's metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Rules holds all the PolicyRules for this Role
             */
            rules?: pulumi.Input<pulumi.Input<inputs.rbac.v1alpha1.PolicyRule>[]>;
        }
        /**
         * RoleBinding references a role, but does not contain it.  It can reference a Role in the same namespace or a ClusterRole in the global namespace. It adds who information via Subjects and namespace information by which namespace it exists in.  RoleBindings in a given namespace only have effect in that namespace. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 RoleBinding, and will no longer be served in v1.20.
         */
        interface RoleBinding {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"rbac.authorization.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"RoleBinding">;
            /**
             * Standard object's metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * RoleRef can reference a Role in the current namespace or a ClusterRole in the global namespace. If the RoleRef cannot be resolved, the Authorizer must return an error.
             */
            roleRef: pulumi.Input<inputs.rbac.v1alpha1.RoleRef>;
            /**
             * Subjects holds references to the objects the role applies to.
             */
            subjects?: pulumi.Input<pulumi.Input<inputs.rbac.v1alpha1.Subject>[]>;
        }
        /**
         * RoleRef contains information that points to the role being used
         */
        interface RoleRef {
            /**
             * APIGroup is the group for the resource being referenced
             */
            apiGroup: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced
             */
            kind: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced
             */
            name: pulumi.Input<string>;
        }
        /**
         * RoleRef contains information that points to the role being used
         */
        interface RoleRefPatch {
            /**
             * APIGroup is the group for the resource being referenced
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced
             */
            kind?: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced
             */
            name?: pulumi.Input<string>;
        }
        /**
         * Subject contains a reference to the object or user identities a role binding applies to.  This can either hold a direct API object reference, or a value for non-objects such as user and group names.
         */
        interface Subject {
            /**
             * APIVersion holds the API group and version of the referenced subject. Defaults to "v1" for ServiceAccount subjects. Defaults to "rbac.authorization.k8s.io/v1alpha1" for User and Group subjects.
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * Kind of object being referenced. Values defined by this API group are "User", "Group", and "ServiceAccount". If the Authorizer does not recognized the kind value, the Authorizer should report an error.
             */
            kind: pulumi.Input<string>;
            /**
             * Name of the object being referenced.
             */
            name: pulumi.Input<string>;
            /**
             * Namespace of the referenced object.  If the object kind is non-namespace, such as "User" or "Group", and this value is not empty the Authorizer should report an error.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * Subject contains a reference to the object or user identities a role binding applies to.  This can either hold a direct API object reference, or a value for non-objects such as user and group names.
         */
        interface SubjectPatch {
            /**
             * APIVersion holds the API group and version of the referenced subject. Defaults to "v1" for ServiceAccount subjects. Defaults to "rbac.authorization.k8s.io/v1alpha1" for User and Group subjects.
             */
            apiVersion?: pulumi.Input<string>;
            /**
             * Kind of object being referenced. Values defined by this API group are "User", "Group", and "ServiceAccount". If the Authorizer does not recognized the kind value, the Authorizer should report an error.
             */
            kind?: pulumi.Input<string>;
            /**
             * Name of the object being referenced.
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace of the referenced object.  If the object kind is non-namespace, such as "User" or "Group", and this value is not empty the Authorizer should report an error.
             */
            namespace?: pulumi.Input<string>;
        }
    }
    namespace v1beta1 {
        /**
         * AggregationRule describes how to locate ClusterRoles to aggregate into the ClusterRole
         */
        interface AggregationRule {
            /**
             * ClusterRoleSelectors holds a list of selectors which will be used to find ClusterRoles and create the rules. If any of the selectors match, then the ClusterRole's permissions will be added
             */
            clusterRoleSelectors?: pulumi.Input<pulumi.Input<inputs.meta.v1.LabelSelector>[]>;
        }
        /**
         * AggregationRule describes how to locate ClusterRoles to aggregate into the ClusterRole
         */
        interface AggregationRulePatch {
            /**
             * ClusterRoleSelectors holds a list of selectors which will be used to find ClusterRoles and create the rules. If any of the selectors match, then the ClusterRole's permissions will be added
             */
            clusterRoleSelectors?: pulumi.Input<pulumi.Input<inputs.meta.v1.LabelSelectorPatch>[]>;
        }
        /**
         * ClusterRole is a cluster level, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding or ClusterRoleBinding. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 ClusterRole, and will no longer be served in v1.20.
         */
        interface ClusterRole {
            /**
             * AggregationRule is an optional field that describes how to build the Rules for this ClusterRole. If AggregationRule is set, then the Rules are controller managed and direct changes to Rules will be stomped by the controller.
             */
            aggregationRule?: pulumi.Input<inputs.rbac.v1beta1.AggregationRule>;
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"rbac.authorization.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ClusterRole">;
            /**
             * Standard object's metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Rules holds all the PolicyRules for this ClusterRole
             */
            rules?: pulumi.Input<pulumi.Input<inputs.rbac.v1beta1.PolicyRule>[]>;
        }
        /**
         * ClusterRoleBinding references a ClusterRole, but not contain it.  It can reference a ClusterRole in the global namespace, and adds who information via Subject. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 ClusterRoleBinding, and will no longer be served in v1.20.
         */
        interface ClusterRoleBinding {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"rbac.authorization.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ClusterRoleBinding">;
            /**
             * Standard object's metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * RoleRef can only reference a ClusterRole in the global namespace. If the RoleRef cannot be resolved, the Authorizer must return an error.
             */
            roleRef: pulumi.Input<inputs.rbac.v1beta1.RoleRef>;
            /**
             * Subjects holds references to the objects the role applies to.
             */
            subjects?: pulumi.Input<pulumi.Input<inputs.rbac.v1beta1.Subject>[]>;
        }
        /**
         * PolicyRule holds information that describes a policy rule, but does not contain information about who the rule applies to or which namespace the rule applies to.
         */
        interface PolicyRule {
            /**
             * APIGroups is the name of the APIGroup that contains the resources.  If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * NonResourceURLs is a set of partial urls that a user should have access to.  *s are allowed, but only as the full, final step in the path Since non-resource URLs are not namespaced, this field is only applicable for ClusterRoles referenced from a ClusterRoleBinding. Rules can either apply to API resources (such as "pods" or "secrets") or non-resource URL paths (such as "/api"),  but not both.
             */
            nonResourceURLs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.
             */
            resourceNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to.  '*' represents all resources in the specified apiGroups. '*&#47;foo' represents the subresource 'foo' for all resources in the specified apiGroups.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Verbs is a list of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule.  VerbAll represents all kinds.
             */
            verbs: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * PolicyRule holds information that describes a policy rule, but does not contain information about who the rule applies to or which namespace the rule applies to.
         */
        interface PolicyRulePatch {
            /**
             * APIGroups is the name of the APIGroup that contains the resources.  If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed.
             */
            apiGroups?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * NonResourceURLs is a set of partial urls that a user should have access to.  *s are allowed, but only as the full, final step in the path Since non-resource URLs are not namespaced, this field is only applicable for ClusterRoles referenced from a ClusterRoleBinding. Rules can either apply to API resources (such as "pods" or "secrets") or non-resource URL paths (such as "/api"),  but not both.
             */
            nonResourceURLs?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.
             */
            resourceNames?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Resources is a list of resources this rule applies to.  '*' represents all resources in the specified apiGroups. '*&#47;foo' represents the subresource 'foo' for all resources in the specified apiGroups.
             */
            resources?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Verbs is a list of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule.  VerbAll represents all kinds.
             */
            verbs?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * Role is a namespaced, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 Role, and will no longer be served in v1.20.
         */
        interface Role {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"rbac.authorization.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"Role">;
            /**
             * Standard object's metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Rules holds all the PolicyRules for this Role
             */
            rules?: pulumi.Input<pulumi.Input<inputs.rbac.v1beta1.PolicyRule>[]>;
        }
        /**
         * RoleBinding references a role, but does not contain it.  It can reference a Role in the same namespace or a ClusterRole in the global namespace. It adds who information via Subjects and namespace information by which namespace it exists in.  RoleBindings in a given namespace only have effect in that namespace. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 RoleBinding, and will no longer be served in v1.20.
         */
        interface RoleBinding {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"rbac.authorization.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"RoleBinding">;
            /**
             * Standard object's metadata.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * RoleRef can reference a Role in the current namespace or a ClusterRole in the global namespace. If the RoleRef cannot be resolved, the Authorizer must return an error.
             */
            roleRef: pulumi.Input<inputs.rbac.v1beta1.RoleRef>;
            /**
             * Subjects holds references to the objects the role applies to.
             */
            subjects?: pulumi.Input<pulumi.Input<inputs.rbac.v1beta1.Subject>[]>;
        }
        /**
         * RoleRef contains information that points to the role being used
         */
        interface RoleRef {
            /**
             * APIGroup is the group for the resource being referenced
             */
            apiGroup: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced
             */
            kind: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced
             */
            name: pulumi.Input<string>;
        }
        /**
         * RoleRef contains information that points to the role being used
         */
        interface RoleRefPatch {
            /**
             * APIGroup is the group for the resource being referenced
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced
             */
            kind?: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced
             */
            name?: pulumi.Input<string>;
        }
        /**
         * Subject contains a reference to the object or user identities a role binding applies to.  This can either hold a direct API object reference, or a value for non-objects such as user and group names.
         */
        interface Subject {
            /**
             * APIGroup holds the API group of the referenced subject. Defaults to "" for ServiceAccount subjects. Defaults to "rbac.authorization.k8s.io" for User and Group subjects.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind of object being referenced. Values defined by this API group are "User", "Group", and "ServiceAccount". If the Authorizer does not recognized the kind value, the Authorizer should report an error.
             */
            kind: pulumi.Input<string>;
            /**
             * Name of the object being referenced.
             */
            name: pulumi.Input<string>;
            /**
             * Namespace of the referenced object.  If the object kind is non-namespace, such as "User" or "Group", and this value is not empty the Authorizer should report an error.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * Subject contains a reference to the object or user identities a role binding applies to.  This can either hold a direct API object reference, or a value for non-objects such as user and group names.
         */
        interface SubjectPatch {
            /**
             * APIGroup holds the API group of the referenced subject. Defaults to "" for ServiceAccount subjects. Defaults to "rbac.authorization.k8s.io" for User and Group subjects.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind of object being referenced. Values defined by this API group are "User", "Group", and "ServiceAccount". If the Authorizer does not recognized the kind value, the Authorizer should report an error.
             */
            kind?: pulumi.Input<string>;
            /**
             * Name of the object being referenced.
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace of the referenced object.  If the object kind is non-namespace, such as "User" or "Group", and this value is not empty the Authorizer should report an error.
             */
            namespace?: pulumi.Input<string>;
        }
    }
}
export declare namespace resource {
    namespace v1alpha1 {
        /**
         * AllocationResult contains attributed of an allocated resource.
         */
        interface AllocationResult {
            /**
             * This field will get set by the resource driver after it has allocated the resource driver to inform the scheduler where it can schedule Pods using the ResourceClaim.
             *
             * Setting this field is optional. If null, the resource is available everywhere.
             */
            availableOnNodes?: pulumi.Input<inputs.core.v1.NodeSelector>;
            /**
             * ResourceHandle contains arbitrary data returned by the driver after a successful allocation. This is opaque for Kubernetes. Driver documentation may explain to users how to interpret this data if needed.
             *
             * The maximum size of this field is 16KiB. This may get increased in the future, but not reduced.
             */
            resourceHandle?: pulumi.Input<string>;
            /**
             * Shareable determines whether the resource supports more than one consumer at a time.
             */
            shareable?: pulumi.Input<boolean>;
        }
        /**
         * PodScheduling objects hold information that is needed to schedule a Pod with ResourceClaims that use "WaitForFirstConsumer" allocation mode.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface PodScheduling {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PodScheduling">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec describes where resources for the Pod are needed.
             */
            spec: pulumi.Input<inputs.resource.v1alpha1.PodSchedulingSpec>;
            /**
             * Status describes where resources for the Pod can be allocated.
             */
            status?: pulumi.Input<inputs.resource.v1alpha1.PodSchedulingStatus>;
        }
        /**
         * PodSchedulingSpec describes where resources for the Pod are needed.
         */
        interface PodSchedulingSpec {
            /**
             * PotentialNodes lists nodes where the Pod might be able to run.
             *
             * The size of this field is limited to 128. This is large enough for many clusters. Larger clusters may need more attempts to find a node that suits all pending resources. This may get increased in the future, but not reduced.
             */
            potentialNodes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * SelectedNode is the node for which allocation of ResourceClaims that are referenced by the Pod and that use "WaitForFirstConsumer" allocation is to be attempted.
             */
            selectedNode?: pulumi.Input<string>;
        }
        /**
         * PodSchedulingSpec describes where resources for the Pod are needed.
         */
        interface PodSchedulingSpecPatch {
            /**
             * PotentialNodes lists nodes where the Pod might be able to run.
             *
             * The size of this field is limited to 128. This is large enough for many clusters. Larger clusters may need more attempts to find a node that suits all pending resources. This may get increased in the future, but not reduced.
             */
            potentialNodes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * SelectedNode is the node for which allocation of ResourceClaims that are referenced by the Pod and that use "WaitForFirstConsumer" allocation is to be attempted.
             */
            selectedNode?: pulumi.Input<string>;
        }
        /**
         * PodSchedulingStatus describes where resources for the Pod can be allocated.
         */
        interface PodSchedulingStatus {
            /**
             * ResourceClaims describes resource availability for each pod.spec.resourceClaim entry where the corresponding ResourceClaim uses "WaitForFirstConsumer" allocation mode.
             */
            resourceClaims?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha1.ResourceClaimSchedulingStatus>[]>;
        }
        /**
         * ResourceClaim describes which resources are needed by a resource consumer. Its status tracks whether the resource has been allocated and what the resulting attributes are.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface ResourceClaim {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceClaim">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec describes the desired attributes of a resource that then needs to be allocated. It can only be set once when creating the ResourceClaim.
             */
            spec: pulumi.Input<inputs.resource.v1alpha1.ResourceClaimSpec>;
            /**
             * Status describes whether the resource is available and with which attributes.
             */
            status?: pulumi.Input<inputs.resource.v1alpha1.ResourceClaimStatus>;
        }
        /**
         * ResourceClaimConsumerReference contains enough information to let you locate the consumer of a ResourceClaim. The user must be a resource in the same namespace as the ResourceClaim.
         */
        interface ResourceClaimConsumerReference {
            /**
             * APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced.
             */
            name: pulumi.Input<string>;
            /**
             * Resource is the type of resource being referenced, for example "pods".
             */
            resource: pulumi.Input<string>;
            /**
             * UID identifies exactly one incarnation of the resource.
             */
            uid: pulumi.Input<string>;
        }
        /**
         * ResourceClaimParametersReference contains enough information to let you locate the parameters for a ResourceClaim. The object must be in the same namespace as the ResourceClaim.
         */
        interface ResourceClaimParametersReference {
            /**
             * APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced. This is the same value as in the parameter object's metadata, for example "ConfigMap".
             */
            kind: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced.
             */
            name: pulumi.Input<string>;
        }
        /**
         * ResourceClaimParametersReference contains enough information to let you locate the parameters for a ResourceClaim. The object must be in the same namespace as the ResourceClaim.
         */
        interface ResourceClaimParametersReferencePatch {
            /**
             * APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced. This is the same value as in the parameter object's metadata, for example "ConfigMap".
             */
            kind?: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * ResourceClaimSchedulingStatus contains information about one particular ResourceClaim with "WaitForFirstConsumer" allocation mode.
         */
        interface ResourceClaimSchedulingStatus {
            /**
             * Name matches the pod.spec.resourceClaims[*].Name field.
             */
            name?: pulumi.Input<string>;
            /**
             * UnsuitableNodes lists nodes that the ResourceClaim cannot be allocated for.
             *
             * The size of this field is limited to 128, the same as for PodSchedulingSpec.PotentialNodes. This may get increased in the future, but not reduced.
             */
            unsuitableNodes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ResourceClaimSpec defines how a resource is to be allocated.
         */
        interface ResourceClaimSpec {
            /**
             * Allocation can start immediately or when a Pod wants to use the resource. "WaitForFirstConsumer" is the default.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * ParametersRef references a separate object with arbitrary parameters that will be used by the driver when allocating a resource for the claim.
             *
             * The object must be in the same namespace as the ResourceClaim.
             */
            parametersRef?: pulumi.Input<inputs.resource.v1alpha1.ResourceClaimParametersReference>;
            /**
             * ResourceClassName references the driver and additional parameters via the name of a ResourceClass that was created as part of the driver deployment.
             */
            resourceClassName: pulumi.Input<string>;
        }
        /**
         * ResourceClaimSpec defines how a resource is to be allocated.
         */
        interface ResourceClaimSpecPatch {
            /**
             * Allocation can start immediately or when a Pod wants to use the resource. "WaitForFirstConsumer" is the default.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * ParametersRef references a separate object with arbitrary parameters that will be used by the driver when allocating a resource for the claim.
             *
             * The object must be in the same namespace as the ResourceClaim.
             */
            parametersRef?: pulumi.Input<inputs.resource.v1alpha1.ResourceClaimParametersReferencePatch>;
            /**
             * ResourceClassName references the driver and additional parameters via the name of a ResourceClass that was created as part of the driver deployment.
             */
            resourceClassName?: pulumi.Input<string>;
        }
        /**
         * ResourceClaimStatus tracks whether the resource has been allocated and what the resulting attributes are.
         */
        interface ResourceClaimStatus {
            /**
             * Allocation is set by the resource driver once a resource has been allocated successfully. If this is not specified, the resource is not yet allocated.
             */
            allocation?: pulumi.Input<inputs.resource.v1alpha1.AllocationResult>;
            /**
             * DeallocationRequested indicates that a ResourceClaim is to be deallocated.
             *
             * The driver then must deallocate this claim and reset the field together with clearing the Allocation field.
             *
             * While DeallocationRequested is set, no new consumers may be added to ReservedFor.
             */
            deallocationRequested?: pulumi.Input<boolean>;
            /**
             * DriverName is a copy of the driver name from the ResourceClass at the time when allocation started.
             */
            driverName?: pulumi.Input<string>;
            /**
             * ReservedFor indicates which entities are currently allowed to use the claim. A Pod which references a ResourceClaim which is not reserved for that Pod will not be started.
             *
             * There can be at most 32 such reservations. This may get increased in the future, but not reduced.
             */
            reservedFor?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha1.ResourceClaimConsumerReference>[]>;
        }
        /**
         * ResourceClaimTemplate is used to produce ResourceClaim objects.
         */
        interface ResourceClaimTemplate {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceClaimTemplate">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Describes the ResourceClaim that is to be generated.
             *
             * This field is immutable. A ResourceClaim will get created by the control plane for a Pod when needed and then not get updated anymore.
             */
            spec: pulumi.Input<inputs.resource.v1alpha1.ResourceClaimTemplateSpec>;
        }
        /**
         * ResourceClaimTemplateSpec contains the metadata and fields for a ResourceClaim.
         */
        interface ResourceClaimTemplateSpec {
            /**
             * ObjectMeta may contain labels and annotations that will be copied into the PVC when creating it. No other fields are allowed and will be rejected during validation.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec for the ResourceClaim. The entire content is copied unchanged into the ResourceClaim that gets created from this template. The same fields as in a ResourceClaim are also valid here.
             */
            spec: pulumi.Input<inputs.resource.v1alpha1.ResourceClaimSpec>;
        }
        /**
         * ResourceClaimTemplateSpec contains the metadata and fields for a ResourceClaim.
         */
        interface ResourceClaimTemplateSpecPatch {
            /**
             * ObjectMeta may contain labels and annotations that will be copied into the PVC when creating it. No other fields are allowed and will be rejected during validation.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMetaPatch>;
            /**
             * Spec for the ResourceClaim. The entire content is copied unchanged into the ResourceClaim that gets created from this template. The same fields as in a ResourceClaim are also valid here.
             */
            spec?: pulumi.Input<inputs.resource.v1alpha1.ResourceClaimSpecPatch>;
        }
        /**
         * ResourceClass is used by administrators to influence how resources are allocated.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface ResourceClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha1">;
            /**
             * DriverName defines the name of the dynamic resource driver that is used for allocation of a ResourceClaim that uses this class.
             *
             * Resource drivers have a unique name in forward domain order (acme.example.com).
             */
            driverName: pulumi.Input<string>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceClass">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * ParametersRef references an arbitrary separate object that may hold parameters that will be used by the driver when allocating a resource that uses this class. A dynamic resource driver can distinguish between parameters stored here and and those stored in ResourceClaimSpec.
             */
            parametersRef?: pulumi.Input<inputs.resource.v1alpha1.ResourceClassParametersReference>;
            /**
             * Only nodes matching the selector will be considered by the scheduler when trying to find a Node that fits a Pod when that Pod uses a ResourceClaim that has not been allocated yet.
             *
             * Setting this field is optional. If null, all nodes are candidates.
             */
            suitableNodes?: pulumi.Input<inputs.core.v1.NodeSelector>;
        }
        /**
         * ResourceClassParametersReference contains enough information to let you locate the parameters for a ResourceClass.
         */
        interface ResourceClassParametersReference {
            /**
             * APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced. This is the same value as in the parameter object's metadata.
             */
            kind: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced.
             */
            name: pulumi.Input<string>;
            /**
             * Namespace that contains the referenced resource. Must be empty for cluster-scoped resources and non-empty for namespaced resources.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * ResourceClassParametersReference contains enough information to let you locate the parameters for a ResourceClass.
         */
        interface ResourceClassParametersReferencePatch {
            /**
             * APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced. This is the same value as in the parameter object's metadata.
             */
            kind?: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced.
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace that contains the referenced resource. Must be empty for cluster-scoped resources and non-empty for namespaced resources.
             */
            namespace?: pulumi.Input<string>;
        }
    }
    namespace v1alpha2 {
        /**
         * AllocationResult contains attributes of an allocated resource.
         */
        interface AllocationResult {
            /**
             * This field will get set by the resource driver after it has allocated the resource to inform the scheduler where it can schedule Pods using the ResourceClaim.
             *
             * Setting this field is optional. If null, the resource is available everywhere.
             */
            availableOnNodes?: pulumi.Input<inputs.core.v1.NodeSelector>;
            /**
             * ResourceHandles contain the state associated with an allocation that should be maintained throughout the lifetime of a claim. Each ResourceHandle contains data that should be passed to a specific kubelet plugin once it lands on a node. This data is returned by the driver after a successful allocation and is opaque to Kubernetes. Driver documentation may explain to users how to interpret this data if needed.
             *
             * Setting this field is optional. It has a maximum size of 32 entries. If null (or empty), it is assumed this allocation will be processed by a single kubelet plugin with no ResourceHandle data attached. The name of the kubelet plugin invoked will match the DriverName set in the ResourceClaimStatus this AllocationResult is embedded in.
             */
            resourceHandles?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha2.ResourceHandle>[]>;
            /**
             * Shareable determines whether the resource supports more than one consumer at a time.
             */
            shareable?: pulumi.Input<boolean>;
        }
        /**
         * DriverAllocationResult contains vendor parameters and the allocation result for one request.
         */
        interface DriverAllocationResult {
            /**
             * NamedResources describes the allocation result when using the named resources model.
             */
            namedResources?: pulumi.Input<inputs.resource.v1alpha2.NamedResourcesAllocationResult>;
            /**
             * VendorRequestParameters are the per-request configuration parameters from the time that the claim was allocated.
             */
            vendorRequestParameters?: any;
        }
        /**
         * DriverRequests describes all resources that are needed from one particular driver.
         */
        interface DriverRequests {
            /**
             * DriverName is the name used by the DRA driver kubelet plugin.
             */
            driverName?: pulumi.Input<string>;
            /**
             * Requests describes all resources that are needed from the driver.
             */
            requests?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha2.ResourceRequest>[]>;
            /**
             * VendorParameters are arbitrary setup parameters for all requests of the claim. They are ignored while allocating the claim.
             */
            vendorParameters?: any;
        }
        /**
         * DriverRequests describes all resources that are needed from one particular driver.
         */
        interface DriverRequestsPatch {
            /**
             * DriverName is the name used by the DRA driver kubelet plugin.
             */
            driverName?: pulumi.Input<string>;
            /**
             * Requests describes all resources that are needed from the driver.
             */
            requests?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha2.ResourceRequestPatch>[]>;
            /**
             * VendorParameters are arbitrary setup parameters for all requests of the claim. They are ignored while allocating the claim.
             */
            vendorParameters?: any;
        }
        /**
         * NamedResourcesAllocationResult is used in AllocationResultModel.
         */
        interface NamedResourcesAllocationResult {
            /**
             * Name is the name of the selected resource instance.
             */
            name: pulumi.Input<string>;
        }
        /**
         * NamedResourcesAttribute is a combination of an attribute name and its value.
         */
        interface NamedResourcesAttribute {
            /**
             * BoolValue is a true/false value.
             */
            bool?: pulumi.Input<boolean>;
            /**
             * IntValue is a 64-bit integer.
             */
            int?: pulumi.Input<number>;
            /**
             * IntSliceValue is an array of 64-bit integers.
             */
            intSlice?: pulumi.Input<inputs.resource.v1alpha2.NamedResourcesIntSlice>;
            /**
             * Name is unique identifier among all resource instances managed by the driver on the node. It must be a DNS subdomain.
             */
            name: pulumi.Input<string>;
            /**
             * QuantityValue is a quantity.
             */
            quantity?: pulumi.Input<string>;
            /**
             * StringValue is a string.
             */
            string?: pulumi.Input<string>;
            /**
             * StringSliceValue is an array of strings.
             */
            stringSlice?: pulumi.Input<inputs.resource.v1alpha2.NamedResourcesStringSlice>;
            /**
             * VersionValue is a semantic version according to semver.org spec 2.0.0.
             */
            version?: pulumi.Input<string>;
        }
        /**
         * NamedResourcesAttribute is a combination of an attribute name and its value.
         */
        interface NamedResourcesAttributePatch {
            /**
             * BoolValue is a true/false value.
             */
            bool?: pulumi.Input<boolean>;
            /**
             * IntValue is a 64-bit integer.
             */
            int?: pulumi.Input<number>;
            /**
             * IntSliceValue is an array of 64-bit integers.
             */
            intSlice?: pulumi.Input<inputs.resource.v1alpha2.NamedResourcesIntSlicePatch>;
            /**
             * Name is unique identifier among all resource instances managed by the driver on the node. It must be a DNS subdomain.
             */
            name?: pulumi.Input<string>;
            /**
             * QuantityValue is a quantity.
             */
            quantity?: pulumi.Input<string>;
            /**
             * StringValue is a string.
             */
            string?: pulumi.Input<string>;
            /**
             * StringSliceValue is an array of strings.
             */
            stringSlice?: pulumi.Input<inputs.resource.v1alpha2.NamedResourcesStringSlicePatch>;
            /**
             * VersionValue is a semantic version according to semver.org spec 2.0.0.
             */
            version?: pulumi.Input<string>;
        }
        /**
         * NamedResourcesFilter is used in ResourceFilterModel.
         */
        interface NamedResourcesFilter {
            /**
             * Selector is a CEL expression which must evaluate to true if a resource instance is suitable. The language is as defined in https://kubernetes.io/docs/reference/using-api/cel/
             *
             * In addition, for each type NamedResourcesin AttributeValue there is a map that resolves to the corresponding value of the instance under evaluation. For example:
             *
             *    attributes.quantity["a"].isGreaterThan(quantity("0")) &&
             *    attributes.stringslice["b"].isSorted()
             */
            selector: pulumi.Input<string>;
        }
        /**
         * NamedResourcesFilter is used in ResourceFilterModel.
         */
        interface NamedResourcesFilterPatch {
            /**
             * Selector is a CEL expression which must evaluate to true if a resource instance is suitable. The language is as defined in https://kubernetes.io/docs/reference/using-api/cel/
             *
             * In addition, for each type NamedResourcesin AttributeValue there is a map that resolves to the corresponding value of the instance under evaluation. For example:
             *
             *    attributes.quantity["a"].isGreaterThan(quantity("0")) &&
             *    attributes.stringslice["b"].isSorted()
             */
            selector?: pulumi.Input<string>;
        }
        /**
         * NamedResourcesInstance represents one individual hardware instance that can be selected based on its attributes.
         */
        interface NamedResourcesInstance {
            /**
             * Attributes defines the attributes of this resource instance. The name of each attribute must be unique.
             */
            attributes?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha2.NamedResourcesAttribute>[]>;
            /**
             * Name is unique identifier among all resource instances managed by the driver on the node. It must be a DNS subdomain.
             */
            name: pulumi.Input<string>;
        }
        /**
         * NamedResourcesInstance represents one individual hardware instance that can be selected based on its attributes.
         */
        interface NamedResourcesInstancePatch {
            /**
             * Attributes defines the attributes of this resource instance. The name of each attribute must be unique.
             */
            attributes?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha2.NamedResourcesAttributePatch>[]>;
            /**
             * Name is unique identifier among all resource instances managed by the driver on the node. It must be a DNS subdomain.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * NamedResourcesIntSlice contains a slice of 64-bit integers.
         */
        interface NamedResourcesIntSlice {
            /**
             * Ints is the slice of 64-bit integers.
             */
            ints: pulumi.Input<pulumi.Input<number>[]>;
        }
        /**
         * NamedResourcesIntSlice contains a slice of 64-bit integers.
         */
        interface NamedResourcesIntSlicePatch {
            /**
             * Ints is the slice of 64-bit integers.
             */
            ints?: pulumi.Input<pulumi.Input<number>[]>;
        }
        /**
         * NamedResourcesRequest is used in ResourceRequestModel.
         */
        interface NamedResourcesRequest {
            /**
             * Selector is a CEL expression which must evaluate to true if a resource instance is suitable. The language is as defined in https://kubernetes.io/docs/reference/using-api/cel/
             *
             * In addition, for each type NamedResourcesin AttributeValue there is a map that resolves to the corresponding value of the instance under evaluation. For example:
             *
             *    attributes.quantity["a"].isGreaterThan(quantity("0")) &&
             *    attributes.stringslice["b"].isSorted()
             */
            selector: pulumi.Input<string>;
        }
        /**
         * NamedResourcesRequest is used in ResourceRequestModel.
         */
        interface NamedResourcesRequestPatch {
            /**
             * Selector is a CEL expression which must evaluate to true if a resource instance is suitable. The language is as defined in https://kubernetes.io/docs/reference/using-api/cel/
             *
             * In addition, for each type NamedResourcesin AttributeValue there is a map that resolves to the corresponding value of the instance under evaluation. For example:
             *
             *    attributes.quantity["a"].isGreaterThan(quantity("0")) &&
             *    attributes.stringslice["b"].isSorted()
             */
            selector?: pulumi.Input<string>;
        }
        /**
         * NamedResourcesResources is used in ResourceModel.
         */
        interface NamedResourcesResources {
            /**
             * The list of all individual resources instances currently available.
             */
            instances: pulumi.Input<pulumi.Input<inputs.resource.v1alpha2.NamedResourcesInstance>[]>;
        }
        /**
         * NamedResourcesResources is used in ResourceModel.
         */
        interface NamedResourcesResourcesPatch {
            /**
             * The list of all individual resources instances currently available.
             */
            instances?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha2.NamedResourcesInstancePatch>[]>;
        }
        /**
         * NamedResourcesStringSlice contains a slice of strings.
         */
        interface NamedResourcesStringSlice {
            /**
             * Strings is the slice of strings.
             */
            strings: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * NamedResourcesStringSlice contains a slice of strings.
         */
        interface NamedResourcesStringSlicePatch {
            /**
             * Strings is the slice of strings.
             */
            strings?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * PodSchedulingContext objects hold information that is needed to schedule a Pod with ResourceClaims that use "WaitForFirstConsumer" allocation mode.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface PodSchedulingContext {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PodSchedulingContext">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec describes where resources for the Pod are needed.
             */
            spec: pulumi.Input<inputs.resource.v1alpha2.PodSchedulingContextSpec>;
            /**
             * Status describes where resources for the Pod can be allocated.
             */
            status?: pulumi.Input<inputs.resource.v1alpha2.PodSchedulingContextStatus>;
        }
        /**
         * PodSchedulingContextSpec describes where resources for the Pod are needed.
         */
        interface PodSchedulingContextSpec {
            /**
             * PotentialNodes lists nodes where the Pod might be able to run.
             *
             * The size of this field is limited to 128. This is large enough for many clusters. Larger clusters may need more attempts to find a node that suits all pending resources. This may get increased in the future, but not reduced.
             */
            potentialNodes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * SelectedNode is the node for which allocation of ResourceClaims that are referenced by the Pod and that use "WaitForFirstConsumer" allocation is to be attempted.
             */
            selectedNode?: pulumi.Input<string>;
        }
        /**
         * PodSchedulingContextSpec describes where resources for the Pod are needed.
         */
        interface PodSchedulingContextSpecPatch {
            /**
             * PotentialNodes lists nodes where the Pod might be able to run.
             *
             * The size of this field is limited to 128. This is large enough for many clusters. Larger clusters may need more attempts to find a node that suits all pending resources. This may get increased in the future, but not reduced.
             */
            potentialNodes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * SelectedNode is the node for which allocation of ResourceClaims that are referenced by the Pod and that use "WaitForFirstConsumer" allocation is to be attempted.
             */
            selectedNode?: pulumi.Input<string>;
        }
        /**
         * PodSchedulingContextStatus describes where resources for the Pod can be allocated.
         */
        interface PodSchedulingContextStatus {
            /**
             * ResourceClaims describes resource availability for each pod.spec.resourceClaim entry where the corresponding ResourceClaim uses "WaitForFirstConsumer" allocation mode.
             */
            resourceClaims?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha2.ResourceClaimSchedulingStatus>[]>;
        }
        /**
         * ResourceClaim describes which resources are needed by a resource consumer. Its status tracks whether the resource has been allocated and what the resulting attributes are.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface ResourceClaim {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceClaim">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec describes the desired attributes of a resource that then needs to be allocated. It can only be set once when creating the ResourceClaim.
             */
            spec: pulumi.Input<inputs.resource.v1alpha2.ResourceClaimSpec>;
            /**
             * Status describes whether the resource is available and with which attributes.
             */
            status?: pulumi.Input<inputs.resource.v1alpha2.ResourceClaimStatus>;
        }
        /**
         * ResourceClaimConsumerReference contains enough information to let you locate the consumer of a ResourceClaim. The user must be a resource in the same namespace as the ResourceClaim.
         */
        interface ResourceClaimConsumerReference {
            /**
             * APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced.
             */
            name: pulumi.Input<string>;
            /**
             * Resource is the type of resource being referenced, for example "pods".
             */
            resource: pulumi.Input<string>;
            /**
             * UID identifies exactly one incarnation of the resource.
             */
            uid: pulumi.Input<string>;
        }
        /**
         * ResourceClaimParameters defines resource requests for a ResourceClaim in an in-tree format understood by Kubernetes.
         */
        interface ResourceClaimParameters {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha2">;
            /**
             * DriverRequests describes all resources that are needed for the allocated claim. A single claim may use resources coming from different drivers. For each driver, this array has at most one entry which then may have one or more per-driver requests.
             *
             * May be empty, in which case the claim can always be allocated.
             */
            driverRequests?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha2.DriverRequests>[]>;
            /**
             * If this object was created from some other resource, then this links back to that resource. This field is used to find the in-tree representation of the claim parameters when the parameter reference of the claim refers to some unknown type.
             */
            generatedFrom?: pulumi.Input<inputs.resource.v1alpha2.ResourceClaimParametersReference>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceClaimParameters">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Shareable indicates whether the allocated claim is meant to be shareable by multiple consumers at the same time.
             */
            shareable?: pulumi.Input<boolean>;
        }
        /**
         * ResourceClaimParametersReference contains enough information to let you locate the parameters for a ResourceClaim. The object must be in the same namespace as the ResourceClaim.
         */
        interface ResourceClaimParametersReference {
            /**
             * APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced. This is the same value as in the parameter object's metadata, for example "ConfigMap".
             */
            kind: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced.
             */
            name: pulumi.Input<string>;
        }
        /**
         * ResourceClaimParametersReference contains enough information to let you locate the parameters for a ResourceClaim. The object must be in the same namespace as the ResourceClaim.
         */
        interface ResourceClaimParametersReferencePatch {
            /**
             * APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced. This is the same value as in the parameter object's metadata, for example "ConfigMap".
             */
            kind?: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * ResourceClaimSchedulingStatus contains information about one particular ResourceClaim with "WaitForFirstConsumer" allocation mode.
         */
        interface ResourceClaimSchedulingStatus {
            /**
             * Name matches the pod.spec.resourceClaims[*].Name field.
             */
            name?: pulumi.Input<string>;
            /**
             * UnsuitableNodes lists nodes that the ResourceClaim cannot be allocated for.
             *
             * The size of this field is limited to 128, the same as for PodSchedulingSpec.PotentialNodes. This may get increased in the future, but not reduced.
             */
            unsuitableNodes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ResourceClaimSpec defines how a resource is to be allocated.
         */
        interface ResourceClaimSpec {
            /**
             * Allocation can start immediately or when a Pod wants to use the resource. "WaitForFirstConsumer" is the default.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * ParametersRef references a separate object with arbitrary parameters that will be used by the driver when allocating a resource for the claim.
             *
             * The object must be in the same namespace as the ResourceClaim.
             */
            parametersRef?: pulumi.Input<inputs.resource.v1alpha2.ResourceClaimParametersReference>;
            /**
             * ResourceClassName references the driver and additional parameters via the name of a ResourceClass that was created as part of the driver deployment.
             */
            resourceClassName: pulumi.Input<string>;
        }
        /**
         * ResourceClaimSpec defines how a resource is to be allocated.
         */
        interface ResourceClaimSpecPatch {
            /**
             * Allocation can start immediately or when a Pod wants to use the resource. "WaitForFirstConsumer" is the default.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * ParametersRef references a separate object with arbitrary parameters that will be used by the driver when allocating a resource for the claim.
             *
             * The object must be in the same namespace as the ResourceClaim.
             */
            parametersRef?: pulumi.Input<inputs.resource.v1alpha2.ResourceClaimParametersReferencePatch>;
            /**
             * ResourceClassName references the driver and additional parameters via the name of a ResourceClass that was created as part of the driver deployment.
             */
            resourceClassName?: pulumi.Input<string>;
        }
        /**
         * ResourceClaimStatus tracks whether the resource has been allocated and what the resulting attributes are.
         */
        interface ResourceClaimStatus {
            /**
             * Allocation is set by the resource driver once a resource or set of resources has been allocated successfully. If this is not specified, the resources have not been allocated yet.
             */
            allocation?: pulumi.Input<inputs.resource.v1alpha2.AllocationResult>;
            /**
             * DeallocationRequested indicates that a ResourceClaim is to be deallocated.
             *
             * The driver then must deallocate this claim and reset the field together with clearing the Allocation field.
             *
             * While DeallocationRequested is set, no new consumers may be added to ReservedFor.
             */
            deallocationRequested?: pulumi.Input<boolean>;
            /**
             * DriverName is a copy of the driver name from the ResourceClass at the time when allocation started.
             */
            driverName?: pulumi.Input<string>;
            /**
             * ReservedFor indicates which entities are currently allowed to use the claim. A Pod which references a ResourceClaim which is not reserved for that Pod will not be started.
             *
             * There can be at most 32 such reservations. This may get increased in the future, but not reduced.
             */
            reservedFor?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha2.ResourceClaimConsumerReference>[]>;
        }
        /**
         * ResourceClaimTemplate is used to produce ResourceClaim objects.
         */
        interface ResourceClaimTemplate {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceClaimTemplate">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Describes the ResourceClaim that is to be generated.
             *
             * This field is immutable. A ResourceClaim will get created by the control plane for a Pod when needed and then not get updated anymore.
             */
            spec: pulumi.Input<inputs.resource.v1alpha2.ResourceClaimTemplateSpec>;
        }
        /**
         * ResourceClaimTemplateSpec contains the metadata and fields for a ResourceClaim.
         */
        interface ResourceClaimTemplateSpec {
            /**
             * ObjectMeta may contain labels and annotations that will be copied into the PVC when creating it. No other fields are allowed and will be rejected during validation.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec for the ResourceClaim. The entire content is copied unchanged into the ResourceClaim that gets created from this template. The same fields as in a ResourceClaim are also valid here.
             */
            spec: pulumi.Input<inputs.resource.v1alpha2.ResourceClaimSpec>;
        }
        /**
         * ResourceClaimTemplateSpec contains the metadata and fields for a ResourceClaim.
         */
        interface ResourceClaimTemplateSpecPatch {
            /**
             * ObjectMeta may contain labels and annotations that will be copied into the PVC when creating it. No other fields are allowed and will be rejected during validation.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMetaPatch>;
            /**
             * Spec for the ResourceClaim. The entire content is copied unchanged into the ResourceClaim that gets created from this template. The same fields as in a ResourceClaim are also valid here.
             */
            spec?: pulumi.Input<inputs.resource.v1alpha2.ResourceClaimSpecPatch>;
        }
        /**
         * ResourceClass is used by administrators to influence how resources are allocated.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface ResourceClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha2">;
            /**
             * DriverName defines the name of the dynamic resource driver that is used for allocation of a ResourceClaim that uses this class.
             *
             * Resource drivers have a unique name in forward domain order (acme.example.com).
             */
            driverName: pulumi.Input<string>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceClass">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * ParametersRef references an arbitrary separate object that may hold parameters that will be used by the driver when allocating a resource that uses this class. A dynamic resource driver can distinguish between parameters stored here and and those stored in ResourceClaimSpec.
             */
            parametersRef?: pulumi.Input<inputs.resource.v1alpha2.ResourceClassParametersReference>;
            /**
             * If and only if allocation of claims using this class is handled via structured parameters, then StructuredParameters must be set to true.
             */
            structuredParameters?: pulumi.Input<boolean>;
            /**
             * Only nodes matching the selector will be considered by the scheduler when trying to find a Node that fits a Pod when that Pod uses a ResourceClaim that has not been allocated yet.
             *
             * Setting this field is optional. If null, all nodes are candidates.
             */
            suitableNodes?: pulumi.Input<inputs.core.v1.NodeSelector>;
        }
        /**
         * ResourceClassParameters defines resource requests for a ResourceClass in an in-tree format understood by Kubernetes.
         */
        interface ResourceClassParameters {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha2">;
            /**
             * Filters describes additional contraints that must be met when using the class.
             */
            filters?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha2.ResourceFilter>[]>;
            /**
             * If this object was created from some other resource, then this links back to that resource. This field is used to find the in-tree representation of the class parameters when the parameter reference of the class refers to some unknown type.
             */
            generatedFrom?: pulumi.Input<inputs.resource.v1alpha2.ResourceClassParametersReference>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceClassParameters">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * VendorParameters are arbitrary setup parameters for all claims using this class. They are ignored while allocating the claim. There must not be more than one entry per driver.
             */
            vendorParameters?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha2.VendorParameters>[]>;
        }
        /**
         * ResourceClassParametersReference contains enough information to let you locate the parameters for a ResourceClass.
         */
        interface ResourceClassParametersReference {
            /**
             * APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced. This is the same value as in the parameter object's metadata.
             */
            kind: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced.
             */
            name: pulumi.Input<string>;
            /**
             * Namespace that contains the referenced resource. Must be empty for cluster-scoped resources and non-empty for namespaced resources.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * ResourceClassParametersReference contains enough information to let you locate the parameters for a ResourceClass.
         */
        interface ResourceClassParametersReferencePatch {
            /**
             * APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Kind is the type of resource being referenced. This is the same value as in the parameter object's metadata.
             */
            kind?: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced.
             */
            name?: pulumi.Input<string>;
            /**
             * Namespace that contains the referenced resource. Must be empty for cluster-scoped resources and non-empty for namespaced resources.
             */
            namespace?: pulumi.Input<string>;
        }
        /**
         * ResourceFilter is a filter for resources from one particular driver.
         */
        interface ResourceFilter {
            /**
             * DriverName is the name used by the DRA driver kubelet plugin.
             */
            driverName?: pulumi.Input<string>;
            /**
             * NamedResources describes a resource filter using the named resources model.
             */
            namedResources?: pulumi.Input<inputs.resource.v1alpha2.NamedResourcesFilter>;
        }
        /**
         * ResourceFilter is a filter for resources from one particular driver.
         */
        interface ResourceFilterPatch {
            /**
             * DriverName is the name used by the DRA driver kubelet plugin.
             */
            driverName?: pulumi.Input<string>;
            /**
             * NamedResources describes a resource filter using the named resources model.
             */
            namedResources?: pulumi.Input<inputs.resource.v1alpha2.NamedResourcesFilterPatch>;
        }
        /**
         * ResourceHandle holds opaque resource data for processing by a specific kubelet plugin.
         */
        interface ResourceHandle {
            /**
             * Data contains the opaque data associated with this ResourceHandle. It is set by the controller component of the resource driver whose name matches the DriverName set in the ResourceClaimStatus this ResourceHandle is embedded in. It is set at allocation time and is intended for processing by the kubelet plugin whose name matches the DriverName set in this ResourceHandle.
             *
             * The maximum size of this field is 16KiB. This may get increased in the future, but not reduced.
             */
            data?: pulumi.Input<string>;
            /**
             * DriverName specifies the name of the resource driver whose kubelet plugin should be invoked to process this ResourceHandle's data once it lands on a node. This may differ from the DriverName set in ResourceClaimStatus this ResourceHandle is embedded in.
             */
            driverName?: pulumi.Input<string>;
            /**
             * If StructuredData is set, then it needs to be used instead of Data.
             */
            structuredData?: pulumi.Input<inputs.resource.v1alpha2.StructuredResourceHandle>;
        }
        /**
         * ResourceRequest is a request for resources from one particular driver.
         */
        interface ResourceRequest {
            /**
             * NamedResources describes a request for resources with the named resources model.
             */
            namedResources?: pulumi.Input<inputs.resource.v1alpha2.NamedResourcesRequest>;
            /**
             * VendorParameters are arbitrary setup parameters for the requested resource. They are ignored while allocating a claim.
             */
            vendorParameters?: any;
        }
        /**
         * ResourceRequest is a request for resources from one particular driver.
         */
        interface ResourceRequestPatch {
            /**
             * NamedResources describes a request for resources with the named resources model.
             */
            namedResources?: pulumi.Input<inputs.resource.v1alpha2.NamedResourcesRequestPatch>;
            /**
             * VendorParameters are arbitrary setup parameters for the requested resource. They are ignored while allocating a claim.
             */
            vendorParameters?: any;
        }
        /**
         * ResourceSlice provides information about available resources on individual nodes.
         */
        interface ResourceSlice {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha2">;
            /**
             * DriverName identifies the DRA driver providing the capacity information. A field selector can be used to list only ResourceSlice objects with a certain driver name.
             */
            driverName: pulumi.Input<string>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceSlice">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * NamedResources describes available resources using the named resources model.
             */
            namedResources?: pulumi.Input<inputs.resource.v1alpha2.NamedResourcesResources>;
            /**
             * NodeName identifies the node which provides the resources if they are local to a node.
             *
             * A field selector can be used to list only ResourceSlice objects with a certain node name.
             */
            nodeName?: pulumi.Input<string>;
        }
        /**
         * StructuredResourceHandle is the in-tree representation of the allocation result.
         */
        interface StructuredResourceHandle {
            /**
             * NodeName is the name of the node providing the necessary resources if the resources are local to a node.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * Results lists all allocated driver resources.
             */
            results: pulumi.Input<pulumi.Input<inputs.resource.v1alpha2.DriverAllocationResult>[]>;
            /**
             * VendorClaimParameters are the per-claim configuration parameters from the resource claim parameters at the time that the claim was allocated.
             */
            vendorClaimParameters?: any;
            /**
             * VendorClassParameters are the per-claim configuration parameters from the resource class at the time that the claim was allocated.
             */
            vendorClassParameters?: any;
        }
        /**
         * VendorParameters are opaque parameters for one particular driver.
         */
        interface VendorParameters {
            /**
             * DriverName is the name used by the DRA driver kubelet plugin.
             */
            driverName?: pulumi.Input<string>;
            /**
             * Parameters can be arbitrary setup parameters. They are ignored while allocating a claim.
             */
            parameters?: any;
        }
        /**
         * VendorParameters are opaque parameters for one particular driver.
         */
        interface VendorParametersPatch {
            /**
             * DriverName is the name used by the DRA driver kubelet plugin.
             */
            driverName?: pulumi.Input<string>;
            /**
             * Parameters can be arbitrary setup parameters. They are ignored while allocating a claim.
             */
            parameters?: any;
        }
    }
    namespace v1alpha3 {
        /**
         * AllocatedDeviceStatus contains the status of an allocated device, if the driver chooses to report it. This may include driver-specific information.
         */
        interface AllocatedDeviceStatus {
            /**
             * Conditions contains the latest observation of the device's state. If the device has been configured according to the class and claim config references, the `Ready` condition should be True.
             *
             * Must not contain more than 8 entries.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.meta.v1.Condition>[]>;
            /**
             * Data contains arbitrary driver-specific data.
             *
             * The length of the raw data must be smaller or equal to 10 Ki.
             */
            data?: any;
            /**
             * Device references one device instance via its name in the driver's resource pool. It must be a DNS label.
             */
            device: pulumi.Input<string>;
            /**
             * Driver specifies the name of the DRA driver whose kubelet plugin should be invoked to process the allocation once the claim is needed on a node.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver.
             */
            driver: pulumi.Input<string>;
            /**
             * NetworkData contains network-related information specific to the device.
             */
            networkData?: pulumi.Input<inputs.resource.v1alpha3.NetworkDeviceData>;
            /**
             * This name together with the driver name and the device name field identify which device was allocated (`<driver name>/<pool name>/<device name>`).
             *
             * Must not be longer than 253 characters and may contain one or more DNS sub-domains separated by slashes.
             */
            pool: pulumi.Input<string>;
        }
        /**
         * AllocationResult contains attributes of an allocated resource.
         */
        interface AllocationResult {
            /**
             * Controller is the name of the DRA driver which handled the allocation. That driver is also responsible for deallocating the claim. It is empty when the claim can be deallocated without involving a driver.
             *
             * A driver may allocate devices provided by other drivers, so this driver name here can be different from the driver names listed for the results.
             *
             * This is an alpha field and requires enabling the DRAControlPlaneController feature gate.
             */
            controller?: pulumi.Input<string>;
            /**
             * Devices is the result of allocating devices.
             */
            devices?: pulumi.Input<inputs.resource.v1alpha3.DeviceAllocationResult>;
            /**
             * NodeSelector defines where the allocated resources are available. If unset, they are available everywhere.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelector>;
        }
        /**
         * BasicDevice defines one device instance.
         */
        interface BasicDevice {
            /**
             * AllNodes indicates that all nodes have access to the device.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            allNodes?: pulumi.Input<boolean>;
            /**
             * Attributes defines the set of attributes for this device. The name of each attribute must be unique in that set.
             *
             * The maximum number of attributes and capacities combined is 32.
             */
            attributes?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1alpha3.DeviceAttribute>;
            }>;
            /**
             * Capacity defines the set of capacities for this device. The name of each capacity must be unique in that set.
             *
             * The maximum number of attributes and capacities combined is 32.
             */
            capacity?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * ConsumesCounters defines a list of references to sharedCounters and the set of counters that the device will consume from those counter sets.
             *
             * There can only be a single entry per counterSet.
             *
             * The total number of device counter consumption entries must be <= 32. In addition, the total number in the entire ResourceSlice must be <= 1024 (for example, 64 devices with 16 counters each).
             */
            consumesCounters?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceCounterConsumption>[]>;
            /**
             * NodeName identifies the node where the device is available.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * NodeSelector defines the nodes where the device is available.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelector>;
            /**
             * If specified, these are the driver-defined taints.
             *
             * The maximum number of taints is 4.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            taints?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceTaint>[]>;
        }
        /**
         * BasicDevice defines one device instance.
         */
        interface BasicDevicePatch {
            /**
             * AllNodes indicates that all nodes have access to the device.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            allNodes?: pulumi.Input<boolean>;
            /**
             * Attributes defines the set of attributes for this device. The name of each attribute must be unique in that set.
             *
             * The maximum number of attributes and capacities combined is 32.
             */
            attributes?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1alpha3.DeviceAttribute>;
            }>;
            /**
             * Capacity defines the set of capacities for this device. The name of each capacity must be unique in that set.
             *
             * The maximum number of attributes and capacities combined is 32.
             */
            capacity?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * ConsumesCounters defines a list of references to sharedCounters and the set of counters that the device will consume from those counter sets.
             *
             * There can only be a single entry per counterSet.
             *
             * The total number of device counter consumption entries must be <= 32. In addition, the total number in the entire ResourceSlice must be <= 1024 (for example, 64 devices with 16 counters each).
             */
            consumesCounters?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceCounterConsumptionPatch>[]>;
            /**
             * NodeName identifies the node where the device is available.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * NodeSelector defines the nodes where the device is available.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelectorPatch>;
            /**
             * If specified, these are the driver-defined taints.
             *
             * The maximum number of taints is 4.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            taints?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceTaintPatch>[]>;
        }
        /**
         * CELDeviceSelector contains a CEL expression for selecting a device.
         */
        interface CELDeviceSelector {
            /**
             * Expression is a CEL expression which evaluates a single device. It must evaluate to true when the device under consideration satisfies the desired criteria, and false when it does not. Any other result is an error and causes allocation of devices to abort.
             *
             * The expression's input is an object named "device", which carries the following properties:
             *  - driver (string): the name of the driver which defines this device.
             *  - attributes (map[string]object): the device's attributes, grouped by prefix
             *    (e.g. device.attributes["dra.example.com"] evaluates to an object with all
             *    of the attributes which were prefixed by "dra.example.com".
             *  - capacity (map[string]object): the device's capacities, grouped by prefix.
             *
             * Example: Consider a device with driver="dra.example.com", which exposes two attributes named "model" and "ext.example.com/family" and which exposes one capacity named "modules". This input to this expression would have the following fields:
             *
             *     device.driver
             *     device.attributes["dra.example.com"].model
             *     device.attributes["ext.example.com"].family
             *     device.capacity["dra.example.com"].modules
             *
             * The device.driver field can be used to check for a specific driver, either as a high-level precondition (i.e. you only want to consider devices from this driver) or as part of a multi-clause expression that is meant to consider devices from different drivers.
             *
             * The value type of each attribute is defined by the device definition, and users who write these expressions must consult the documentation for their specific drivers. The value type of each capacity is Quantity.
             *
             * If an unknown prefix is used as a lookup in either device.attributes or device.capacity, an empty map will be returned. Any reference to an unknown field will cause an evaluation error and allocation to abort.
             *
             * A robust expression should check for the existence of attributes before referencing them.
             *
             * For ease of use, the cel.bind() function is enabled, and can be used to simplify expressions that access multiple attributes with the same domain. For example:
             *
             *     cel.bind(dra, device.attributes["dra.example.com"], dra.someBool && dra.anotherBool)
             *
             * The length of the expression must be smaller or equal to 10 Ki. The cost of evaluating it is also limited based on the estimated number of logical steps.
             */
            expression: pulumi.Input<string>;
        }
        /**
         * CELDeviceSelector contains a CEL expression for selecting a device.
         */
        interface CELDeviceSelectorPatch {
            /**
             * Expression is a CEL expression which evaluates a single device. It must evaluate to true when the device under consideration satisfies the desired criteria, and false when it does not. Any other result is an error and causes allocation of devices to abort.
             *
             * The expression's input is an object named "device", which carries the following properties:
             *  - driver (string): the name of the driver which defines this device.
             *  - attributes (map[string]object): the device's attributes, grouped by prefix
             *    (e.g. device.attributes["dra.example.com"] evaluates to an object with all
             *    of the attributes which were prefixed by "dra.example.com".
             *  - capacity (map[string]object): the device's capacities, grouped by prefix.
             *
             * Example: Consider a device with driver="dra.example.com", which exposes two attributes named "model" and "ext.example.com/family" and which exposes one capacity named "modules". This input to this expression would have the following fields:
             *
             *     device.driver
             *     device.attributes["dra.example.com"].model
             *     device.attributes["ext.example.com"].family
             *     device.capacity["dra.example.com"].modules
             *
             * The device.driver field can be used to check for a specific driver, either as a high-level precondition (i.e. you only want to consider devices from this driver) or as part of a multi-clause expression that is meant to consider devices from different drivers.
             *
             * The value type of each attribute is defined by the device definition, and users who write these expressions must consult the documentation for their specific drivers. The value type of each capacity is Quantity.
             *
             * If an unknown prefix is used as a lookup in either device.attributes or device.capacity, an empty map will be returned. Any reference to an unknown field will cause an evaluation error and allocation to abort.
             *
             * A robust expression should check for the existence of attributes before referencing them.
             *
             * For ease of use, the cel.bind() function is enabled, and can be used to simplify expressions that access multiple attributes with the same domain. For example:
             *
             *     cel.bind(dra, device.attributes["dra.example.com"], dra.someBool && dra.anotherBool)
             *
             * The length of the expression must be smaller or equal to 10 Ki. The cost of evaluating it is also limited based on the estimated number of logical steps.
             */
            expression?: pulumi.Input<string>;
        }
        /**
         * Counter describes a quantity associated with a device.
         */
        interface Counter {
            /**
             * Value defines how much of a certain device counter is available.
             */
            value: pulumi.Input<string>;
        }
        /**
         * CounterSet defines a named set of counters that are available to be used by devices defined in the ResourceSlice.
         *
         * The counters are not allocatable by themselves, but can be referenced by devices. When a device is allocated, the portion of counters it uses will no longer be available for use by other devices.
         */
        interface CounterSet {
            /**
             * Counters defines the counters that will be consumed by the device. The name of each counter must be unique in that set and must be a DNS label.
             *
             * To ensure this uniqueness, capacities defined by the vendor must be listed without the driver name as domain prefix in their name. All others must be listed with their domain prefix.
             *
             * The maximum number of counters is 32.
             */
            counters: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1alpha3.Counter>;
            }>;
            /**
             * CounterSet is the name of the set from which the counters defined will be consumed.
             */
            name: pulumi.Input<string>;
        }
        /**
         * CounterSet defines a named set of counters that are available to be used by devices defined in the ResourceSlice.
         *
         * The counters are not allocatable by themselves, but can be referenced by devices. When a device is allocated, the portion of counters it uses will no longer be available for use by other devices.
         */
        interface CounterSetPatch {
            /**
             * Counters defines the counters that will be consumed by the device. The name of each counter must be unique in that set and must be a DNS label.
             *
             * To ensure this uniqueness, capacities defined by the vendor must be listed without the driver name as domain prefix in their name. All others must be listed with their domain prefix.
             *
             * The maximum number of counters is 32.
             */
            counters?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1alpha3.Counter>;
            }>;
            /**
             * CounterSet is the name of the set from which the counters defined will be consumed.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * Device represents one individual hardware instance that can be selected based on its attributes. Besides the name, exactly one field must be set.
         */
        interface Device {
            /**
             * Basic defines one device instance.
             */
            basic?: pulumi.Input<inputs.resource.v1alpha3.BasicDevice>;
            /**
             * Name is unique identifier among all devices managed by the driver in the pool. It must be a DNS label.
             */
            name: pulumi.Input<string>;
        }
        /**
         * DeviceAllocationConfiguration gets embedded in an AllocationResult.
         */
        interface DeviceAllocationConfiguration {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1alpha3.OpaqueDeviceConfiguration>;
            /**
             * Requests lists the names of requests where the configuration applies. If empty, its applies to all requests.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the configuration applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Source records whether the configuration comes from a class and thus is not something that a normal user would have been able to set or from a claim.
             */
            source: pulumi.Input<string>;
        }
        /**
         * DeviceAllocationResult is the result of allocating devices.
         */
        interface DeviceAllocationResult {
            /**
             * This field is a combination of all the claim and class configuration parameters. Drivers can distinguish between those based on a flag.
             *
             * This includes configuration parameters for drivers which have no allocated devices in the result because it is up to the drivers which configuration parameters they support. They can silently ignore unknown configuration parameters.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceAllocationConfiguration>[]>;
            /**
             * Results lists all allocated devices.
             */
            results?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceRequestAllocationResult>[]>;
        }
        /**
         * DeviceAttribute must have exactly one field set.
         */
        interface DeviceAttribute {
            /**
             * BoolValue is a true/false value.
             */
            bool?: pulumi.Input<boolean>;
            /**
             * IntValue is a number.
             */
            int?: pulumi.Input<number>;
            /**
             * StringValue is a string. Must not be longer than 64 characters.
             */
            string?: pulumi.Input<string>;
            /**
             * VersionValue is a semantic version according to semver.org spec 2.0.0. Must not be longer than 64 characters.
             */
            version?: pulumi.Input<string>;
        }
        /**
         * DeviceClaim defines how to request devices with a ResourceClaim.
         */
        interface DeviceClaim {
            /**
             * This field holds configuration for multiple potential drivers which could satisfy requests in this claim. It is ignored while allocating the claim.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceClaimConfiguration>[]>;
            /**
             * These constraints must be satisfied by the set of devices that get allocated for the claim.
             */
            constraints?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceConstraint>[]>;
            /**
             * Requests represent individual requests for distinct devices which must all be satisfied. If empty, nothing needs to be allocated.
             */
            requests?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceRequest>[]>;
        }
        /**
         * DeviceClaimConfiguration is used for configuration parameters in DeviceClaim.
         */
        interface DeviceClaimConfiguration {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1alpha3.OpaqueDeviceConfiguration>;
            /**
             * Requests lists the names of requests where the configuration applies. If empty, it applies to all requests.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the configuration applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * DeviceClaimConfiguration is used for configuration parameters in DeviceClaim.
         */
        interface DeviceClaimConfigurationPatch {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1alpha3.OpaqueDeviceConfigurationPatch>;
            /**
             * Requests lists the names of requests where the configuration applies. If empty, it applies to all requests.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the configuration applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * DeviceClaim defines how to request devices with a ResourceClaim.
         */
        interface DeviceClaimPatch {
            /**
             * This field holds configuration for multiple potential drivers which could satisfy requests in this claim. It is ignored while allocating the claim.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceClaimConfigurationPatch>[]>;
            /**
             * These constraints must be satisfied by the set of devices that get allocated for the claim.
             */
            constraints?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceConstraintPatch>[]>;
            /**
             * Requests represent individual requests for distinct devices which must all be satisfied. If empty, nothing needs to be allocated.
             */
            requests?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceRequestPatch>[]>;
        }
        /**
         * DeviceClass is a vendor- or admin-provided resource that contains device configuration and selectors. It can be referenced in the device requests of a claim to apply these presets. Cluster scoped.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface DeviceClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha3">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"DeviceClass">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines what can be allocated and how to configure it.
             *
             * This is mutable. Consumers have to be prepared for classes changing at any time, either because they get updated or replaced. Claim allocations are done once based on whatever was set in classes at the time of allocation.
             *
             * Changing the spec automatically increments the metadata.generation number.
             */
            spec: pulumi.Input<inputs.resource.v1alpha3.DeviceClassSpec>;
        }
        /**
         * DeviceClassConfiguration is used in DeviceClass.
         */
        interface DeviceClassConfiguration {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1alpha3.OpaqueDeviceConfiguration>;
        }
        /**
         * DeviceClassConfiguration is used in DeviceClass.
         */
        interface DeviceClassConfigurationPatch {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1alpha3.OpaqueDeviceConfigurationPatch>;
        }
        /**
         * DeviceClassSpec is used in a [DeviceClass] to define what can be allocated and how to configure it.
         */
        interface DeviceClassSpec {
            /**
             * Config defines configuration parameters that apply to each device that is claimed via this class. Some classses may potentially be satisfied by multiple drivers, so each instance of a vendor configuration applies to exactly one driver.
             *
             * They are passed to the driver, but are not considered while allocating the claim.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceClassConfiguration>[]>;
            /**
             * Each selector must be satisfied by a device which is claimed via this class.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceSelector>[]>;
            /**
             * Only nodes matching the selector will be considered by the scheduler when trying to find a Node that fits a Pod when that Pod uses a claim that has not been allocated yet *and* that claim gets allocated through a control plane controller. It is ignored when the claim does not use a control plane controller for allocation.
             *
             * Setting this field is optional. If unset, all Nodes are candidates.
             *
             * This is an alpha field and requires enabling the DRAControlPlaneController feature gate.
             */
            suitableNodes?: pulumi.Input<inputs.core.v1.NodeSelector>;
        }
        /**
         * DeviceClassSpec is used in a [DeviceClass] to define what can be allocated and how to configure it.
         */
        interface DeviceClassSpecPatch {
            /**
             * Config defines configuration parameters that apply to each device that is claimed via this class. Some classses may potentially be satisfied by multiple drivers, so each instance of a vendor configuration applies to exactly one driver.
             *
             * They are passed to the driver, but are not considered while allocating the claim.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceClassConfigurationPatch>[]>;
            /**
             * Each selector must be satisfied by a device which is claimed via this class.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceSelectorPatch>[]>;
            /**
             * Only nodes matching the selector will be considered by the scheduler when trying to find a Node that fits a Pod when that Pod uses a claim that has not been allocated yet *and* that claim gets allocated through a control plane controller. It is ignored when the claim does not use a control plane controller for allocation.
             *
             * Setting this field is optional. If unset, all Nodes are candidates.
             *
             * This is an alpha field and requires enabling the DRAControlPlaneController feature gate.
             */
            suitableNodes?: pulumi.Input<inputs.core.v1.NodeSelectorPatch>;
        }
        /**
         * DeviceConstraint must have exactly one field set besides Requests.
         */
        interface DeviceConstraint {
            /**
             * MatchAttribute requires that all devices in question have this attribute and that its type and value are the same across those devices.
             *
             * For example, if you specified "dra.example.com/numa" (a hypothetical example!), then only devices in the same NUMA node will be chosen. A device which does not have that attribute will not be chosen. All devices should use a value of the same type for this attribute because that is part of its specification, but if one device doesn't, then it also will not be chosen.
             *
             * Must include the domain qualifier.
             */
            matchAttribute?: pulumi.Input<string>;
            /**
             * Requests is a list of the one or more requests in this claim which must co-satisfy this constraint. If a request is fulfilled by multiple devices, then all of the devices must satisfy the constraint. If this is not specified, this constraint applies to all requests in this claim.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the constraint applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * DeviceConstraint must have exactly one field set besides Requests.
         */
        interface DeviceConstraintPatch {
            /**
             * MatchAttribute requires that all devices in question have this attribute and that its type and value are the same across those devices.
             *
             * For example, if you specified "dra.example.com/numa" (a hypothetical example!), then only devices in the same NUMA node will be chosen. A device which does not have that attribute will not be chosen. All devices should use a value of the same type for this attribute because that is part of its specification, but if one device doesn't, then it also will not be chosen.
             *
             * Must include the domain qualifier.
             */
            matchAttribute?: pulumi.Input<string>;
            /**
             * Requests is a list of the one or more requests in this claim which must co-satisfy this constraint. If a request is fulfilled by multiple devices, then all of the devices must satisfy the constraint. If this is not specified, this constraint applies to all requests in this claim.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the constraint applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * DeviceCounterConsumption defines a set of counters that a device will consume from a CounterSet.
         */
        interface DeviceCounterConsumption {
            /**
             * CounterSet defines the set from which the counters defined will be consumed.
             */
            counterSet: pulumi.Input<string>;
            /**
             * Counters defines the Counter that will be consumed by the device.
             *
             * The maximum number counters in a device is 32. In addition, the maximum number of all counters in all devices is 1024 (for example, 64 devices with 16 counters each).
             */
            counters: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1alpha3.Counter>;
            }>;
        }
        /**
         * DeviceCounterConsumption defines a set of counters that a device will consume from a CounterSet.
         */
        interface DeviceCounterConsumptionPatch {
            /**
             * CounterSet defines the set from which the counters defined will be consumed.
             */
            counterSet?: pulumi.Input<string>;
            /**
             * Counters defines the Counter that will be consumed by the device.
             *
             * The maximum number counters in a device is 32. In addition, the maximum number of all counters in all devices is 1024 (for example, 64 devices with 16 counters each).
             */
            counters?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1alpha3.Counter>;
            }>;
        }
        /**
         * Device represents one individual hardware instance that can be selected based on its attributes. Besides the name, exactly one field must be set.
         */
        interface DevicePatch {
            /**
             * Basic defines one device instance.
             */
            basic?: pulumi.Input<inputs.resource.v1alpha3.BasicDevicePatch>;
            /**
             * Name is unique identifier among all devices managed by the driver in the pool. It must be a DNS label.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * DeviceRequest is a request for devices required for a claim. This is typically a request for a single resource like a device, but can also ask for several identical devices.
         */
        interface DeviceRequest {
            /**
             * AdminAccess indicates that this is a claim for administrative access to the device(s). Claims with AdminAccess are expected to be used for monitoring or other management services for a device.  They ignore all ordinary claims to the device with respect to access modes and any resource allocations.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             *
             * This is an alpha field and requires enabling the DRAAdminAccess feature gate. Admin access is disabled if this field is unset or set to false, otherwise it is enabled.
             */
            adminAccess?: pulumi.Input<boolean>;
            /**
             * AllocationMode and its related fields define how devices are allocated to satisfy this request. Supported values are:
             *
             * - ExactCount: This request is for a specific number of devices.
             *   This is the default. The exact number is provided in the
             *   count field.
             *
             * - All: This request is for all of the matching devices in a pool.
             *   At least one device must exist on the node for the allocation to succeed.
             *   Allocation will fail if some devices are already allocated,
             *   unless adminAccess is requested.
             *
             * If AllocationMode is not specified, the default mode is ExactCount. If the mode is ExactCount and count is not specified, the default count is one. Any other requests must specify this field.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             *
             * More modes may get added in the future. Clients must refuse to handle requests with unknown modes.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * Count is used only when the count mode is "ExactCount". Must be greater than zero. If AllocationMode is ExactCount and this field is not specified, the default is one.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             */
            count?: pulumi.Input<number>;
            /**
             * DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this request.
             *
             * A class is required if no subrequests are specified in the firstAvailable list and no class can be set if subrequests are specified in the firstAvailable list. Which classes are available depends on the cluster.
             *
             * Administrators may use this to restrict which devices may get requested by only installing classes with selectors for permitted devices. If users are free to request anything without restrictions, then administrators can create an empty DeviceClass for users to reference.
             */
            deviceClassName?: pulumi.Input<string>;
            /**
             * FirstAvailable contains subrequests, of which exactly one will be satisfied by the scheduler to satisfy this request. It tries to satisfy them in the order in which they are listed here. So if there are two entries in the list, the scheduler will only check the second one if it determines that the first one cannot be used.
             *
             * This field may only be set in the entries of DeviceClaim.Requests.
             *
             * DRA does not yet implement scoring, so the scheduler will select the first set of devices that satisfies all the requests in the claim. And if the requirements can be satisfied on more than one node, other scheduling features will determine which node is chosen. This means that the set of devices allocated to a claim might not be the optimal set available to the cluster. Scoring will be implemented later.
             */
            firstAvailable?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceSubRequest>[]>;
            /**
             * Name can be used to reference this request in a pod.spec.containers[].resources.claims entry and in a constraint of the claim.
             *
             * Must be a DNS label.
             */
            name: pulumi.Input<string>;
            /**
             * Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this request. All selectors must be satisfied for a device to be considered.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceSelector>[]>;
            /**
             * If specified, the request's tolerations.
             *
             * Tolerations for NoSchedule are required to allocate a device which has a taint with that effect. The same applies to NoExecute.
             *
             * In addition, should any of the allocated devices get tainted with NoExecute after allocation and that effect is not tolerated, then all pods consuming the ResourceClaim get deleted to evict them. The scheduler will not let new pods reserve the claim while it has these tainted devices. Once all pods are evicted, the claim will get deallocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceToleration>[]>;
        }
        /**
         * DeviceRequestAllocationResult contains the allocation result for one request.
         */
        interface DeviceRequestAllocationResult {
            /**
             * AdminAccess indicates that this device was allocated for administrative access. See the corresponding request field for a definition of mode.
             *
             * This is an alpha field and requires enabling the DRAAdminAccess feature gate. Admin access is disabled if this field is unset or set to false, otherwise it is enabled.
             */
            adminAccess?: pulumi.Input<boolean>;
            /**
             * Device references one device instance via its name in the driver's resource pool. It must be a DNS label.
             */
            device: pulumi.Input<string>;
            /**
             * Driver specifies the name of the DRA driver whose kubelet plugin should be invoked to process the allocation once the claim is needed on a node.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver.
             */
            driver: pulumi.Input<string>;
            /**
             * This name together with the driver name and the device name field identify which device was allocated (`<driver name>/<pool name>/<device name>`).
             *
             * Must not be longer than 253 characters and may contain one or more DNS sub-domains separated by slashes.
             */
            pool: pulumi.Input<string>;
            /**
             * Request is the name of the request in the claim which caused this device to be allocated. If it references a subrequest in the firstAvailable list on a DeviceRequest, this field must include both the name of the main request and the subrequest using the format <main request>/<subrequest>.
             *
             * Multiple devices may have been allocated per request.
             */
            request: pulumi.Input<string>;
            /**
             * A copy of all tolerations specified in the request at the time when the device got allocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceToleration>[]>;
        }
        /**
         * DeviceRequest is a request for devices required for a claim. This is typically a request for a single resource like a device, but can also ask for several identical devices.
         */
        interface DeviceRequestPatch {
            /**
             * AdminAccess indicates that this is a claim for administrative access to the device(s). Claims with AdminAccess are expected to be used for monitoring or other management services for a device.  They ignore all ordinary claims to the device with respect to access modes and any resource allocations.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             *
             * This is an alpha field and requires enabling the DRAAdminAccess feature gate. Admin access is disabled if this field is unset or set to false, otherwise it is enabled.
             */
            adminAccess?: pulumi.Input<boolean>;
            /**
             * AllocationMode and its related fields define how devices are allocated to satisfy this request. Supported values are:
             *
             * - ExactCount: This request is for a specific number of devices.
             *   This is the default. The exact number is provided in the
             *   count field.
             *
             * - All: This request is for all of the matching devices in a pool.
             *   At least one device must exist on the node for the allocation to succeed.
             *   Allocation will fail if some devices are already allocated,
             *   unless adminAccess is requested.
             *
             * If AllocationMode is not specified, the default mode is ExactCount. If the mode is ExactCount and count is not specified, the default count is one. Any other requests must specify this field.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             *
             * More modes may get added in the future. Clients must refuse to handle requests with unknown modes.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * Count is used only when the count mode is "ExactCount". Must be greater than zero. If AllocationMode is ExactCount and this field is not specified, the default is one.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             */
            count?: pulumi.Input<number>;
            /**
             * DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this request.
             *
             * A class is required if no subrequests are specified in the firstAvailable list and no class can be set if subrequests are specified in the firstAvailable list. Which classes are available depends on the cluster.
             *
             * Administrators may use this to restrict which devices may get requested by only installing classes with selectors for permitted devices. If users are free to request anything without restrictions, then administrators can create an empty DeviceClass for users to reference.
             */
            deviceClassName?: pulumi.Input<string>;
            /**
             * FirstAvailable contains subrequests, of which exactly one will be satisfied by the scheduler to satisfy this request. It tries to satisfy them in the order in which they are listed here. So if there are two entries in the list, the scheduler will only check the second one if it determines that the first one cannot be used.
             *
             * This field may only be set in the entries of DeviceClaim.Requests.
             *
             * DRA does not yet implement scoring, so the scheduler will select the first set of devices that satisfies all the requests in the claim. And if the requirements can be satisfied on more than one node, other scheduling features will determine which node is chosen. This means that the set of devices allocated to a claim might not be the optimal set available to the cluster. Scoring will be implemented later.
             */
            firstAvailable?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceSubRequestPatch>[]>;
            /**
             * Name can be used to reference this request in a pod.spec.containers[].resources.claims entry and in a constraint of the claim.
             *
             * Must be a DNS label.
             */
            name?: pulumi.Input<string>;
            /**
             * Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this request. All selectors must be satisfied for a device to be considered.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceSelectorPatch>[]>;
            /**
             * If specified, the request's tolerations.
             *
             * Tolerations for NoSchedule are required to allocate a device which has a taint with that effect. The same applies to NoExecute.
             *
             * In addition, should any of the allocated devices get tainted with NoExecute after allocation and that effect is not tolerated, then all pods consuming the ResourceClaim get deleted to evict them. The scheduler will not let new pods reserve the claim while it has these tainted devices. Once all pods are evicted, the claim will get deallocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceTolerationPatch>[]>;
        }
        /**
         * DeviceSelector must have exactly one field set.
         */
        interface DeviceSelector {
            /**
             * CEL contains a CEL expression for selecting a device.
             */
            cel?: pulumi.Input<inputs.resource.v1alpha3.CELDeviceSelector>;
        }
        /**
         * DeviceSelector must have exactly one field set.
         */
        interface DeviceSelectorPatch {
            /**
             * CEL contains a CEL expression for selecting a device.
             */
            cel?: pulumi.Input<inputs.resource.v1alpha3.CELDeviceSelectorPatch>;
        }
        /**
         * DeviceSubRequest describes a request for device provided in the claim.spec.devices.requests[].firstAvailable array. Each is typically a request for a single resource like a device, but can also ask for several identical devices.
         *
         * DeviceSubRequest is similar to Request, but doesn't expose the AdminAccess or FirstAvailable fields, as those can only be set on the top-level request. AdminAccess is not supported for requests with a prioritized list, and recursive FirstAvailable fields are not supported.
         */
        interface DeviceSubRequest {
            /**
             * AllocationMode and its related fields define how devices are allocated to satisfy this request. Supported values are:
             *
             * - ExactCount: This request is for a specific number of devices.
             *   This is the default. The exact number is provided in the
             *   count field.
             *
             * - All: This request is for all of the matching devices in a pool.
             *   Allocation will fail if some devices are already allocated,
             *   unless adminAccess is requested.
             *
             * If AllocationMode is not specified, the default mode is ExactCount. If the mode is ExactCount and count is not specified, the default count is one. Any other requests must specify this field.
             *
             * More modes may get added in the future. Clients must refuse to handle requests with unknown modes.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * Count is used only when the count mode is "ExactCount". Must be greater than zero. If AllocationMode is ExactCount and this field is not specified, the default is one.
             */
            count?: pulumi.Input<number>;
            /**
             * DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this subrequest.
             *
             * A class is required. Which classes are available depends on the cluster.
             *
             * Administrators may use this to restrict which devices may get requested by only installing classes with selectors for permitted devices. If users are free to request anything without restrictions, then administrators can create an empty DeviceClass for users to reference.
             */
            deviceClassName: pulumi.Input<string>;
            /**
             * Name can be used to reference this subrequest in the list of constraints or the list of configurations for the claim. References must use the format <main request>/<subrequest>.
             *
             * Must be a DNS label.
             */
            name: pulumi.Input<string>;
            /**
             * Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this request. All selectors must be satisfied for a device to be considered.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceSelector>[]>;
            /**
             * If specified, the request's tolerations.
             *
             * Tolerations for NoSchedule are required to allocate a device which has a taint with that effect. The same applies to NoExecute.
             *
             * In addition, should any of the allocated devices get tainted with NoExecute after allocation and that effect is not tolerated, then all pods consuming the ResourceClaim get deleted to evict them. The scheduler will not let new pods reserve the claim while it has these tainted devices. Once all pods are evicted, the claim will get deallocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceToleration>[]>;
        }
        /**
         * DeviceSubRequest describes a request for device provided in the claim.spec.devices.requests[].firstAvailable array. Each is typically a request for a single resource like a device, but can also ask for several identical devices.
         *
         * DeviceSubRequest is similar to Request, but doesn't expose the AdminAccess or FirstAvailable fields, as those can only be set on the top-level request. AdminAccess is not supported for requests with a prioritized list, and recursive FirstAvailable fields are not supported.
         */
        interface DeviceSubRequestPatch {
            /**
             * AllocationMode and its related fields define how devices are allocated to satisfy this request. Supported values are:
             *
             * - ExactCount: This request is for a specific number of devices.
             *   This is the default. The exact number is provided in the
             *   count field.
             *
             * - All: This request is for all of the matching devices in a pool.
             *   Allocation will fail if some devices are already allocated,
             *   unless adminAccess is requested.
             *
             * If AllocationMode is not specified, the default mode is ExactCount. If the mode is ExactCount and count is not specified, the default count is one. Any other requests must specify this field.
             *
             * More modes may get added in the future. Clients must refuse to handle requests with unknown modes.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * Count is used only when the count mode is "ExactCount". Must be greater than zero. If AllocationMode is ExactCount and this field is not specified, the default is one.
             */
            count?: pulumi.Input<number>;
            /**
             * DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this subrequest.
             *
             * A class is required. Which classes are available depends on the cluster.
             *
             * Administrators may use this to restrict which devices may get requested by only installing classes with selectors for permitted devices. If users are free to request anything without restrictions, then administrators can create an empty DeviceClass for users to reference.
             */
            deviceClassName?: pulumi.Input<string>;
            /**
             * Name can be used to reference this subrequest in the list of constraints or the list of configurations for the claim. References must use the format <main request>/<subrequest>.
             *
             * Must be a DNS label.
             */
            name?: pulumi.Input<string>;
            /**
             * Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this request. All selectors must be satisfied for a device to be considered.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceSelectorPatch>[]>;
            /**
             * If specified, the request's tolerations.
             *
             * Tolerations for NoSchedule are required to allocate a device which has a taint with that effect. The same applies to NoExecute.
             *
             * In addition, should any of the allocated devices get tainted with NoExecute after allocation and that effect is not tolerated, then all pods consuming the ResourceClaim get deleted to evict them. The scheduler will not let new pods reserve the claim while it has these tainted devices. Once all pods are evicted, the claim will get deallocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceTolerationPatch>[]>;
        }
        /**
         * The device this taint is attached to has the "effect" on any claim which does not tolerate the taint and, through the claim, to pods using the claim.
         */
        interface DeviceTaint {
            /**
             * The effect of the taint on claims that do not tolerate the taint and through such claims on the pods using them. Valid effects are NoSchedule and NoExecute. PreferNoSchedule as used for nodes is not valid here.
             */
            effect: pulumi.Input<string>;
            /**
             * The taint key to be applied to a device. Must be a label name.
             */
            key: pulumi.Input<string>;
            /**
             * TimeAdded represents the time at which the taint was added. Added automatically during create or update if not set.
             */
            timeAdded?: pulumi.Input<string>;
            /**
             * The taint value corresponding to the taint key. Must be a label value.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * The device this taint is attached to has the "effect" on any claim which does not tolerate the taint and, through the claim, to pods using the claim.
         */
        interface DeviceTaintPatch {
            /**
             * The effect of the taint on claims that do not tolerate the taint and through such claims on the pods using them. Valid effects are NoSchedule and NoExecute. PreferNoSchedule as used for nodes is not valid here.
             */
            effect?: pulumi.Input<string>;
            /**
             * The taint key to be applied to a device. Must be a label name.
             */
            key?: pulumi.Input<string>;
            /**
             * TimeAdded represents the time at which the taint was added. Added automatically during create or update if not set.
             */
            timeAdded?: pulumi.Input<string>;
            /**
             * The taint value corresponding to the taint key. Must be a label value.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * DeviceTaintRule adds one taint to all devices which match the selector. This has the same effect as if the taint was specified directly in the ResourceSlice by the DRA driver.
         */
        interface DeviceTaintRule {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha3">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"DeviceTaintRule">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec specifies the selector and one taint.
             *
             * Changing the spec automatically increments the metadata.generation number.
             */
            spec: pulumi.Input<inputs.resource.v1alpha3.DeviceTaintRuleSpec>;
        }
        /**
         * DeviceTaintRuleSpec specifies the selector and one taint.
         */
        interface DeviceTaintRuleSpec {
            /**
             * DeviceSelector defines which device(s) the taint is applied to. All selector criteria must be satified for a device to match. The empty selector matches all devices. Without a selector, no devices are matches.
             */
            deviceSelector?: pulumi.Input<inputs.resource.v1alpha3.DeviceTaintSelector>;
            /**
             * The taint that gets applied to matching devices.
             */
            taint: pulumi.Input<inputs.resource.v1alpha3.DeviceTaint>;
        }
        /**
         * DeviceTaintRuleSpec specifies the selector and one taint.
         */
        interface DeviceTaintRuleSpecPatch {
            /**
             * DeviceSelector defines which device(s) the taint is applied to. All selector criteria must be satified for a device to match. The empty selector matches all devices. Without a selector, no devices are matches.
             */
            deviceSelector?: pulumi.Input<inputs.resource.v1alpha3.DeviceTaintSelectorPatch>;
            /**
             * The taint that gets applied to matching devices.
             */
            taint?: pulumi.Input<inputs.resource.v1alpha3.DeviceTaintPatch>;
        }
        /**
         * DeviceTaintSelector defines which device(s) a DeviceTaintRule applies to. The empty selector matches all devices. Without a selector, no devices are matched.
         */
        interface DeviceTaintSelector {
            /**
             * If device is set, only devices with that name are selected. This field corresponds to slice.spec.devices[].name.
             *
             * Setting also driver and pool may be required to avoid ambiguity, but is not required.
             */
            device?: pulumi.Input<string>;
            /**
             * If DeviceClassName is set, the selectors defined there must be satisfied by a device to be selected. This field corresponds to class.metadata.name.
             */
            deviceClassName?: pulumi.Input<string>;
            /**
             * If driver is set, only devices from that driver are selected. This fields corresponds to slice.spec.driver.
             */
            driver?: pulumi.Input<string>;
            /**
             * If pool is set, only devices in that pool are selected.
             *
             * Also setting the driver name may be useful to avoid ambiguity when different drivers use the same pool name, but this is not required because selecting pools from different drivers may also be useful, for example when drivers with node-local devices use the node name as their pool name.
             */
            pool?: pulumi.Input<string>;
            /**
             * Selectors contains the same selection criteria as a ResourceClaim. Currently, CEL expressions are supported. All of these selectors must be satisfied.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceSelector>[]>;
        }
        /**
         * DeviceTaintSelector defines which device(s) a DeviceTaintRule applies to. The empty selector matches all devices. Without a selector, no devices are matched.
         */
        interface DeviceTaintSelectorPatch {
            /**
             * If device is set, only devices with that name are selected. This field corresponds to slice.spec.devices[].name.
             *
             * Setting also driver and pool may be required to avoid ambiguity, but is not required.
             */
            device?: pulumi.Input<string>;
            /**
             * If DeviceClassName is set, the selectors defined there must be satisfied by a device to be selected. This field corresponds to class.metadata.name.
             */
            deviceClassName?: pulumi.Input<string>;
            /**
             * If driver is set, only devices from that driver are selected. This fields corresponds to slice.spec.driver.
             */
            driver?: pulumi.Input<string>;
            /**
             * If pool is set, only devices in that pool are selected.
             *
             * Also setting the driver name may be useful to avoid ambiguity when different drivers use the same pool name, but this is not required because selecting pools from different drivers may also be useful, for example when drivers with node-local devices use the node name as their pool name.
             */
            pool?: pulumi.Input<string>;
            /**
             * Selectors contains the same selection criteria as a ResourceClaim. Currently, CEL expressions are supported. All of these selectors must be satisfied.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DeviceSelectorPatch>[]>;
        }
        /**
         * The ResourceClaim this DeviceToleration is attached to tolerates any taint that matches the triple <key,value,effect> using the matching operator <operator>.
         */
        interface DeviceToleration {
            /**
             * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule and NoExecute.
             */
            effect?: pulumi.Input<string>;
            /**
             * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys. Must be a label name.
             */
            key?: pulumi.Input<string>;
            /**
             * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a ResourceClaim can tolerate all taints of a particular category.
             */
            operator?: pulumi.Input<string>;
            /**
             * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system. If larger than zero, the time when the pod needs to be evicted is calculated as <time when taint was adedd> + <toleration seconds>.
             */
            tolerationSeconds?: pulumi.Input<number>;
            /**
             * Value is the taint value the toleration matches to. If the operator is Exists, the value must be empty, otherwise just a regular string. Must be a label value.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * The ResourceClaim this DeviceToleration is attached to tolerates any taint that matches the triple <key,value,effect> using the matching operator <operator>.
         */
        interface DeviceTolerationPatch {
            /**
             * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule and NoExecute.
             */
            effect?: pulumi.Input<string>;
            /**
             * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys. Must be a label name.
             */
            key?: pulumi.Input<string>;
            /**
             * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a ResourceClaim can tolerate all taints of a particular category.
             */
            operator?: pulumi.Input<string>;
            /**
             * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system. If larger than zero, the time when the pod needs to be evicted is calculated as <time when taint was adedd> + <toleration seconds>.
             */
            tolerationSeconds?: pulumi.Input<number>;
            /**
             * Value is the taint value the toleration matches to. If the operator is Exists, the value must be empty, otherwise just a regular string. Must be a label value.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * NetworkDeviceData provides network-related details for the allocated device. This information may be filled by drivers or other components to configure or identify the device within a network context.
         */
        interface NetworkDeviceData {
            /**
             * HardwareAddress represents the hardware address (e.g. MAC Address) of the device's network interface.
             *
             * Must not be longer than 128 characters.
             */
            hardwareAddress?: pulumi.Input<string>;
            /**
             * InterfaceName specifies the name of the network interface associated with the allocated device. This might be the name of a physical or virtual network interface being configured in the pod.
             *
             * Must not be longer than 256 characters.
             */
            interfaceName?: pulumi.Input<string>;
            /**
             * IPs lists the network addresses assigned to the device's network interface. This can include both IPv4 and IPv6 addresses. The IPs are in the CIDR notation, which includes both the address and the associated subnet mask. e.g.: "192.0.2.5/24" for IPv4 and "2001:db8::5/64" for IPv6.
             *
             * Must not contain more than 16 entries.
             */
            ips?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * OpaqueDeviceConfiguration contains configuration parameters for a driver in a format defined by the driver vendor.
         */
        interface OpaqueDeviceConfiguration {
            /**
             * Driver is used to determine which kubelet plugin needs to be passed these configuration parameters.
             *
             * An admission policy provided by the driver developer could use this to decide whether it needs to validate them.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver.
             */
            driver: pulumi.Input<string>;
            /**
             * Parameters can contain arbitrary data. It is the responsibility of the driver developer to handle validation and versioning. Typically this includes self-identification and a version ("kind" + "apiVersion" for Kubernetes types), with conversion between different versions.
             *
             * The length of the raw data must be smaller or equal to 10 Ki.
             */
            parameters: any;
        }
        /**
         * OpaqueDeviceConfiguration contains configuration parameters for a driver in a format defined by the driver vendor.
         */
        interface OpaqueDeviceConfigurationPatch {
            /**
             * Driver is used to determine which kubelet plugin needs to be passed these configuration parameters.
             *
             * An admission policy provided by the driver developer could use this to decide whether it needs to validate them.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver.
             */
            driver?: pulumi.Input<string>;
            /**
             * Parameters can contain arbitrary data. It is the responsibility of the driver developer to handle validation and versioning. Typically this includes self-identification and a version ("kind" + "apiVersion" for Kubernetes types), with conversion between different versions.
             *
             * The length of the raw data must be smaller or equal to 10 Ki.
             */
            parameters?: any;
        }
        /**
         * PodSchedulingContext objects hold information that is needed to schedule a Pod with ResourceClaims that use "WaitForFirstConsumer" allocation mode.
         *
         * This is an alpha type and requires enabling the DRAControlPlaneController feature gate.
         */
        interface PodSchedulingContext {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha3">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PodSchedulingContext">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec describes where resources for the Pod are needed.
             */
            spec: pulumi.Input<inputs.resource.v1alpha3.PodSchedulingContextSpec>;
            /**
             * Status describes where resources for the Pod can be allocated.
             */
            status?: pulumi.Input<inputs.resource.v1alpha3.PodSchedulingContextStatus>;
        }
        /**
         * PodSchedulingContextSpec describes where resources for the Pod are needed.
         */
        interface PodSchedulingContextSpec {
            /**
             * PotentialNodes lists nodes where the Pod might be able to run.
             *
             * The size of this field is limited to 128. This is large enough for many clusters. Larger clusters may need more attempts to find a node that suits all pending resources. This may get increased in the future, but not reduced.
             */
            potentialNodes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * SelectedNode is the node for which allocation of ResourceClaims that are referenced by the Pod and that use "WaitForFirstConsumer" allocation is to be attempted.
             */
            selectedNode?: pulumi.Input<string>;
        }
        /**
         * PodSchedulingContextSpec describes where resources for the Pod are needed.
         */
        interface PodSchedulingContextSpecPatch {
            /**
             * PotentialNodes lists nodes where the Pod might be able to run.
             *
             * The size of this field is limited to 128. This is large enough for many clusters. Larger clusters may need more attempts to find a node that suits all pending resources. This may get increased in the future, but not reduced.
             */
            potentialNodes?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * SelectedNode is the node for which allocation of ResourceClaims that are referenced by the Pod and that use "WaitForFirstConsumer" allocation is to be attempted.
             */
            selectedNode?: pulumi.Input<string>;
        }
        /**
         * PodSchedulingContextStatus describes where resources for the Pod can be allocated.
         */
        interface PodSchedulingContextStatus {
            /**
             * ResourceClaims describes resource availability for each pod.spec.resourceClaim entry where the corresponding ResourceClaim uses "WaitForFirstConsumer" allocation mode.
             */
            resourceClaims?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.ResourceClaimSchedulingStatus>[]>;
        }
        /**
         * ResourceClaim describes a request for access to resources in the cluster, for use by workloads. For example, if a workload needs an accelerator device with specific properties, this is how that request is expressed. The status stanza tracks whether this claim has been satisfied and what specific resources have been allocated.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface ResourceClaim {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha3">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceClaim">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec describes what is being requested and how to configure it. The spec is immutable.
             */
            spec: pulumi.Input<inputs.resource.v1alpha3.ResourceClaimSpec>;
            /**
             * Status describes whether the claim is ready to use and what has been allocated.
             */
            status?: pulumi.Input<inputs.resource.v1alpha3.ResourceClaimStatus>;
        }
        /**
         * ResourceClaimConsumerReference contains enough information to let you locate the consumer of a ResourceClaim. The user must be a resource in the same namespace as the ResourceClaim.
         */
        interface ResourceClaimConsumerReference {
            /**
             * APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced.
             */
            name: pulumi.Input<string>;
            /**
             * Resource is the type of resource being referenced, for example "pods".
             */
            resource: pulumi.Input<string>;
            /**
             * UID identifies exactly one incarnation of the resource.
             */
            uid: pulumi.Input<string>;
        }
        /**
         * ResourceClaimSchedulingStatus contains information about one particular ResourceClaim with "WaitForFirstConsumer" allocation mode.
         */
        interface ResourceClaimSchedulingStatus {
            /**
             * Name matches the pod.spec.resourceClaims[*].Name field.
             */
            name: pulumi.Input<string>;
            /**
             * UnsuitableNodes lists nodes that the ResourceClaim cannot be allocated for.
             *
             * The size of this field is limited to 128, the same as for PodSchedulingSpec.PotentialNodes. This may get increased in the future, but not reduced.
             */
            unsuitableNodes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * ResourceClaimSpec defines what is being requested in a ResourceClaim and how to configure it.
         */
        interface ResourceClaimSpec {
            /**
             * Controller is the name of the DRA driver that is meant to handle allocation of this claim. If empty, allocation is handled by the scheduler while scheduling a pod.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver.
             *
             * This is an alpha field and requires enabling the DRAControlPlaneController feature gate.
             */
            controller?: pulumi.Input<string>;
            /**
             * Devices defines how to request devices.
             */
            devices?: pulumi.Input<inputs.resource.v1alpha3.DeviceClaim>;
        }
        /**
         * ResourceClaimSpec defines what is being requested in a ResourceClaim and how to configure it.
         */
        interface ResourceClaimSpecPatch {
            /**
             * Controller is the name of the DRA driver that is meant to handle allocation of this claim. If empty, allocation is handled by the scheduler while scheduling a pod.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver.
             *
             * This is an alpha field and requires enabling the DRAControlPlaneController feature gate.
             */
            controller?: pulumi.Input<string>;
            /**
             * Devices defines how to request devices.
             */
            devices?: pulumi.Input<inputs.resource.v1alpha3.DeviceClaimPatch>;
        }
        /**
         * ResourceClaimStatus tracks whether the resource has been allocated and what the result of that was.
         */
        interface ResourceClaimStatus {
            /**
             * Allocation is set once the claim has been allocated successfully.
             */
            allocation?: pulumi.Input<inputs.resource.v1alpha3.AllocationResult>;
            /**
             * Indicates that a claim is to be deallocated. While this is set, no new consumers may be added to ReservedFor.
             *
             * This is only used if the claim needs to be deallocated by a DRA driver. That driver then must deallocate this claim and reset the field together with clearing the Allocation field.
             *
             * This is an alpha field and requires enabling the DRAControlPlaneController feature gate.
             */
            deallocationRequested?: pulumi.Input<boolean>;
            /**
             * Devices contains the status of each device allocated for this claim, as reported by the driver. This can include driver-specific information. Entries are owned by their respective drivers.
             */
            devices?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.AllocatedDeviceStatus>[]>;
            /**
             * ReservedFor indicates which entities are currently allowed to use the claim. A Pod which references a ResourceClaim which is not reserved for that Pod will not be started. A claim that is in use or might be in use because it has been reserved must not get deallocated.
             *
             * In a cluster with multiple scheduler instances, two pods might get scheduled concurrently by different schedulers. When they reference the same ResourceClaim which already has reached its maximum number of consumers, only one pod can be scheduled.
             *
             * Both schedulers try to add their pod to the claim.status.reservedFor field, but only the update that reaches the API server first gets stored. The other one fails with an error and the scheduler which issued it knows that it must put the pod back into the queue, waiting for the ResourceClaim to become usable again.
             *
             * There can be at most 256 such reservations. This may get increased in the future, but not reduced.
             */
            reservedFor?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.ResourceClaimConsumerReference>[]>;
        }
        /**
         * ResourceClaimTemplate is used to produce ResourceClaim objects.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface ResourceClaimTemplate {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha3">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceClaimTemplate">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Describes the ResourceClaim that is to be generated.
             *
             * This field is immutable. A ResourceClaim will get created by the control plane for a Pod when needed and then not get updated anymore.
             */
            spec: pulumi.Input<inputs.resource.v1alpha3.ResourceClaimTemplateSpec>;
        }
        /**
         * ResourceClaimTemplateSpec contains the metadata and fields for a ResourceClaim.
         */
        interface ResourceClaimTemplateSpec {
            /**
             * ObjectMeta may contain labels and annotations that will be copied into the ResourceClaim when creating it. No other fields are allowed and will be rejected during validation.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec for the ResourceClaim. The entire content is copied unchanged into the ResourceClaim that gets created from this template. The same fields as in a ResourceClaim are also valid here.
             */
            spec: pulumi.Input<inputs.resource.v1alpha3.ResourceClaimSpec>;
        }
        /**
         * ResourceClaimTemplateSpec contains the metadata and fields for a ResourceClaim.
         */
        interface ResourceClaimTemplateSpecPatch {
            /**
             * ObjectMeta may contain labels and annotations that will be copied into the ResourceClaim when creating it. No other fields are allowed and will be rejected during validation.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMetaPatch>;
            /**
             * Spec for the ResourceClaim. The entire content is copied unchanged into the ResourceClaim that gets created from this template. The same fields as in a ResourceClaim are also valid here.
             */
            spec?: pulumi.Input<inputs.resource.v1alpha3.ResourceClaimSpecPatch>;
        }
        /**
         * ResourcePool describes the pool that ResourceSlices belong to.
         */
        interface ResourcePool {
            /**
             * Generation tracks the change in a pool over time. Whenever a driver changes something about one or more of the resources in a pool, it must change the generation in all ResourceSlices which are part of that pool. Consumers of ResourceSlices should only consider resources from the pool with the highest generation number. The generation may be reset by drivers, which should be fine for consumers, assuming that all ResourceSlices in a pool are updated to match or deleted.
             *
             * Combined with ResourceSliceCount, this mechanism enables consumers to detect pools which are comprised of multiple ResourceSlices and are in an incomplete state.
             */
            generation: pulumi.Input<number>;
            /**
             * Name is used to identify the pool. For node-local devices, this is often the node name, but this is not required.
             *
             * It must not be longer than 253 characters and must consist of one or more DNS sub-domains separated by slashes. This field is immutable.
             */
            name: pulumi.Input<string>;
            /**
             * ResourceSliceCount is the total number of ResourceSlices in the pool at this generation number. Must be greater than zero.
             *
             * Consumers can use this to check whether they have seen all ResourceSlices belonging to the same pool.
             */
            resourceSliceCount: pulumi.Input<number>;
        }
        /**
         * ResourcePool describes the pool that ResourceSlices belong to.
         */
        interface ResourcePoolPatch {
            /**
             * Generation tracks the change in a pool over time. Whenever a driver changes something about one or more of the resources in a pool, it must change the generation in all ResourceSlices which are part of that pool. Consumers of ResourceSlices should only consider resources from the pool with the highest generation number. The generation may be reset by drivers, which should be fine for consumers, assuming that all ResourceSlices in a pool are updated to match or deleted.
             *
             * Combined with ResourceSliceCount, this mechanism enables consumers to detect pools which are comprised of multiple ResourceSlices and are in an incomplete state.
             */
            generation?: pulumi.Input<number>;
            /**
             * Name is used to identify the pool. For node-local devices, this is often the node name, but this is not required.
             *
             * It must not be longer than 253 characters and must consist of one or more DNS sub-domains separated by slashes. This field is immutable.
             */
            name?: pulumi.Input<string>;
            /**
             * ResourceSliceCount is the total number of ResourceSlices in the pool at this generation number. Must be greater than zero.
             *
             * Consumers can use this to check whether they have seen all ResourceSlices belonging to the same pool.
             */
            resourceSliceCount?: pulumi.Input<number>;
        }
        /**
         * ResourceSlice represents one or more resources in a pool of similar resources, managed by a common driver. A pool may span more than one ResourceSlice, and exactly how many ResourceSlices comprise a pool is determined by the driver.
         *
         * At the moment, the only supported resources are devices with attributes and capacities. Each device in a given pool, regardless of how many ResourceSlices, must have a unique name. The ResourceSlice in which a device gets published may change over time. The unique identifier for a device is the tuple <driver name>, <pool name>, <device name>.
         *
         * Whenever a driver needs to update a pool, it increments the pool.Spec.Pool.Generation number and updates all ResourceSlices with that new number and new resource definitions. A consumer must only use ResourceSlices with the highest generation number and ignore all others.
         *
         * When allocating all resources in a pool matching certain criteria or when looking for the best solution among several different alternatives, a consumer should check the number of ResourceSlices in a pool (included in each ResourceSlice) to determine whether its view of a pool is complete and if not, should wait until the driver has completed updating the pool.
         *
         * For resources that are not local to a node, the node name is not set. Instead, the driver may use a node selector to specify where the devices are available.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface ResourceSlice {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1alpha3">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceSlice">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Contains the information published by the driver.
             *
             * Changing the spec automatically increments the metadata.generation number.
             */
            spec: pulumi.Input<inputs.resource.v1alpha3.ResourceSliceSpec>;
        }
        /**
         * ResourceSliceSpec contains the information published by the driver in one ResourceSlice.
         */
        interface ResourceSliceSpec {
            /**
             * AllNodes indicates that all nodes have access to the resources in the pool.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            allNodes?: pulumi.Input<boolean>;
            /**
             * Devices lists some or all of the devices in this pool.
             *
             * Must not have more than 128 entries.
             */
            devices?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.Device>[]>;
            /**
             * Driver identifies the DRA driver providing the capacity information. A field selector can be used to list only ResourceSlice objects with a certain driver name.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver. This field is immutable.
             */
            driver: pulumi.Input<string>;
            /**
             * NodeName identifies the node which provides the resources in this pool. A field selector can be used to list only ResourceSlice objects belonging to a certain node.
             *
             * This field can be used to limit access from nodes to ResourceSlices with the same node name. It also indicates to autoscalers that adding new nodes of the same type as some old node might also make new resources available.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set. This field is immutable.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * NodeSelector defines which nodes have access to the resources in the pool, when that pool is not limited to a single node.
             *
             * Must use exactly one term.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelector>;
            /**
             * PerDeviceNodeSelection defines whether the access from nodes to resources in the pool is set on the ResourceSlice level or on each device. If it is set to true, every device defined the ResourceSlice must specify this individually.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            perDeviceNodeSelection?: pulumi.Input<boolean>;
            /**
             * Pool describes the pool that this ResourceSlice belongs to.
             */
            pool: pulumi.Input<inputs.resource.v1alpha3.ResourcePool>;
            /**
             * SharedCounters defines a list of counter sets, each of which has a name and a list of counters available.
             *
             * The names of the SharedCounters must be unique in the ResourceSlice.
             *
             * The maximum number of SharedCounters is 32.
             */
            sharedCounters?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.CounterSet>[]>;
        }
        /**
         * ResourceSliceSpec contains the information published by the driver in one ResourceSlice.
         */
        interface ResourceSliceSpecPatch {
            /**
             * AllNodes indicates that all nodes have access to the resources in the pool.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            allNodes?: pulumi.Input<boolean>;
            /**
             * Devices lists some or all of the devices in this pool.
             *
             * Must not have more than 128 entries.
             */
            devices?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.DevicePatch>[]>;
            /**
             * Driver identifies the DRA driver providing the capacity information. A field selector can be used to list only ResourceSlice objects with a certain driver name.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver. This field is immutable.
             */
            driver?: pulumi.Input<string>;
            /**
             * NodeName identifies the node which provides the resources in this pool. A field selector can be used to list only ResourceSlice objects belonging to a certain node.
             *
             * This field can be used to limit access from nodes to ResourceSlices with the same node name. It also indicates to autoscalers that adding new nodes of the same type as some old node might also make new resources available.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set. This field is immutable.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * NodeSelector defines which nodes have access to the resources in the pool, when that pool is not limited to a single node.
             *
             * Must use exactly one term.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelectorPatch>;
            /**
             * PerDeviceNodeSelection defines whether the access from nodes to resources in the pool is set on the ResourceSlice level or on each device. If it is set to true, every device defined the ResourceSlice must specify this individually.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            perDeviceNodeSelection?: pulumi.Input<boolean>;
            /**
             * Pool describes the pool that this ResourceSlice belongs to.
             */
            pool?: pulumi.Input<inputs.resource.v1alpha3.ResourcePoolPatch>;
            /**
             * SharedCounters defines a list of counter sets, each of which has a name and a list of counters available.
             *
             * The names of the SharedCounters must be unique in the ResourceSlice.
             *
             * The maximum number of SharedCounters is 32.
             */
            sharedCounters?: pulumi.Input<pulumi.Input<inputs.resource.v1alpha3.CounterSetPatch>[]>;
        }
    }
    namespace v1beta1 {
        /**
         * AllocatedDeviceStatus contains the status of an allocated device, if the driver chooses to report it. This may include driver-specific information.
         */
        interface AllocatedDeviceStatus {
            /**
             * Conditions contains the latest observation of the device's state. If the device has been configured according to the class and claim config references, the `Ready` condition should be True.
             *
             * Must not contain more than 8 entries.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.meta.v1.Condition>[]>;
            /**
             * Data contains arbitrary driver-specific data.
             *
             * The length of the raw data must be smaller or equal to 10 Ki.
             */
            data?: any;
            /**
             * Device references one device instance via its name in the driver's resource pool. It must be a DNS label.
             */
            device: pulumi.Input<string>;
            /**
             * Driver specifies the name of the DRA driver whose kubelet plugin should be invoked to process the allocation once the claim is needed on a node.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver.
             */
            driver: pulumi.Input<string>;
            /**
             * NetworkData contains network-related information specific to the device.
             */
            networkData?: pulumi.Input<inputs.resource.v1beta1.NetworkDeviceData>;
            /**
             * This name together with the driver name and the device name field identify which device was allocated (`<driver name>/<pool name>/<device name>`).
             *
             * Must not be longer than 253 characters and may contain one or more DNS sub-domains separated by slashes.
             */
            pool: pulumi.Input<string>;
        }
        /**
         * AllocationResult contains attributes of an allocated resource.
         */
        interface AllocationResult {
            /**
             * Devices is the result of allocating devices.
             */
            devices?: pulumi.Input<inputs.resource.v1beta1.DeviceAllocationResult>;
            /**
             * NodeSelector defines where the allocated resources are available. If unset, they are available everywhere.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelector>;
        }
        /**
         * BasicDevice defines one device instance.
         */
        interface BasicDevice {
            /**
             * AllNodes indicates that all nodes have access to the device.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            allNodes?: pulumi.Input<boolean>;
            /**
             * Attributes defines the set of attributes for this device. The name of each attribute must be unique in that set.
             *
             * The maximum number of attributes and capacities combined is 32.
             */
            attributes?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta1.DeviceAttribute>;
            }>;
            /**
             * Capacity defines the set of capacities for this device. The name of each capacity must be unique in that set.
             *
             * The maximum number of attributes and capacities combined is 32.
             */
            capacity?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta1.DeviceCapacity>;
            }>;
            /**
             * ConsumesCounters defines a list of references to sharedCounters and the set of counters that the device will consume from those counter sets.
             *
             * There can only be a single entry per counterSet.
             *
             * The total number of device counter consumption entries must be <= 32. In addition, the total number in the entire ResourceSlice must be <= 1024 (for example, 64 devices with 16 counters each).
             */
            consumesCounters?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceCounterConsumption>[]>;
            /**
             * NodeName identifies the node where the device is available.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * NodeSelector defines the nodes where the device is available.
             *
             * Must use exactly one term.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelector>;
            /**
             * If specified, these are the driver-defined taints.
             *
             * The maximum number of taints is 4.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            taints?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceTaint>[]>;
        }
        /**
         * BasicDevice defines one device instance.
         */
        interface BasicDevicePatch {
            /**
             * AllNodes indicates that all nodes have access to the device.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            allNodes?: pulumi.Input<boolean>;
            /**
             * Attributes defines the set of attributes for this device. The name of each attribute must be unique in that set.
             *
             * The maximum number of attributes and capacities combined is 32.
             */
            attributes?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta1.DeviceAttribute>;
            }>;
            /**
             * Capacity defines the set of capacities for this device. The name of each capacity must be unique in that set.
             *
             * The maximum number of attributes and capacities combined is 32.
             */
            capacity?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta1.DeviceCapacity>;
            }>;
            /**
             * ConsumesCounters defines a list of references to sharedCounters and the set of counters that the device will consume from those counter sets.
             *
             * There can only be a single entry per counterSet.
             *
             * The total number of device counter consumption entries must be <= 32. In addition, the total number in the entire ResourceSlice must be <= 1024 (for example, 64 devices with 16 counters each).
             */
            consumesCounters?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceCounterConsumptionPatch>[]>;
            /**
             * NodeName identifies the node where the device is available.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * NodeSelector defines the nodes where the device is available.
             *
             * Must use exactly one term.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelectorPatch>;
            /**
             * If specified, these are the driver-defined taints.
             *
             * The maximum number of taints is 4.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            taints?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceTaintPatch>[]>;
        }
        /**
         * CELDeviceSelector contains a CEL expression for selecting a device.
         */
        interface CELDeviceSelector {
            /**
             * Expression is a CEL expression which evaluates a single device. It must evaluate to true when the device under consideration satisfies the desired criteria, and false when it does not. Any other result is an error and causes allocation of devices to abort.
             *
             * The expression's input is an object named "device", which carries the following properties:
             *  - driver (string): the name of the driver which defines this device.
             *  - attributes (map[string]object): the device's attributes, grouped by prefix
             *    (e.g. device.attributes["dra.example.com"] evaluates to an object with all
             *    of the attributes which were prefixed by "dra.example.com".
             *  - capacity (map[string]object): the device's capacities, grouped by prefix.
             *
             * Example: Consider a device with driver="dra.example.com", which exposes two attributes named "model" and "ext.example.com/family" and which exposes one capacity named "modules". This input to this expression would have the following fields:
             *
             *     device.driver
             *     device.attributes["dra.example.com"].model
             *     device.attributes["ext.example.com"].family
             *     device.capacity["dra.example.com"].modules
             *
             * The device.driver field can be used to check for a specific driver, either as a high-level precondition (i.e. you only want to consider devices from this driver) or as part of a multi-clause expression that is meant to consider devices from different drivers.
             *
             * The value type of each attribute is defined by the device definition, and users who write these expressions must consult the documentation for their specific drivers. The value type of each capacity is Quantity.
             *
             * If an unknown prefix is used as a lookup in either device.attributes or device.capacity, an empty map will be returned. Any reference to an unknown field will cause an evaluation error and allocation to abort.
             *
             * A robust expression should check for the existence of attributes before referencing them.
             *
             * For ease of use, the cel.bind() function is enabled, and can be used to simplify expressions that access multiple attributes with the same domain. For example:
             *
             *     cel.bind(dra, device.attributes["dra.example.com"], dra.someBool && dra.anotherBool)
             *
             * The length of the expression must be smaller or equal to 10 Ki. The cost of evaluating it is also limited based on the estimated number of logical steps.
             */
            expression: pulumi.Input<string>;
        }
        /**
         * CELDeviceSelector contains a CEL expression for selecting a device.
         */
        interface CELDeviceSelectorPatch {
            /**
             * Expression is a CEL expression which evaluates a single device. It must evaluate to true when the device under consideration satisfies the desired criteria, and false when it does not. Any other result is an error and causes allocation of devices to abort.
             *
             * The expression's input is an object named "device", which carries the following properties:
             *  - driver (string): the name of the driver which defines this device.
             *  - attributes (map[string]object): the device's attributes, grouped by prefix
             *    (e.g. device.attributes["dra.example.com"] evaluates to an object with all
             *    of the attributes which were prefixed by "dra.example.com".
             *  - capacity (map[string]object): the device's capacities, grouped by prefix.
             *
             * Example: Consider a device with driver="dra.example.com", which exposes two attributes named "model" and "ext.example.com/family" and which exposes one capacity named "modules". This input to this expression would have the following fields:
             *
             *     device.driver
             *     device.attributes["dra.example.com"].model
             *     device.attributes["ext.example.com"].family
             *     device.capacity["dra.example.com"].modules
             *
             * The device.driver field can be used to check for a specific driver, either as a high-level precondition (i.e. you only want to consider devices from this driver) or as part of a multi-clause expression that is meant to consider devices from different drivers.
             *
             * The value type of each attribute is defined by the device definition, and users who write these expressions must consult the documentation for their specific drivers. The value type of each capacity is Quantity.
             *
             * If an unknown prefix is used as a lookup in either device.attributes or device.capacity, an empty map will be returned. Any reference to an unknown field will cause an evaluation error and allocation to abort.
             *
             * A robust expression should check for the existence of attributes before referencing them.
             *
             * For ease of use, the cel.bind() function is enabled, and can be used to simplify expressions that access multiple attributes with the same domain. For example:
             *
             *     cel.bind(dra, device.attributes["dra.example.com"], dra.someBool && dra.anotherBool)
             *
             * The length of the expression must be smaller or equal to 10 Ki. The cost of evaluating it is also limited based on the estimated number of logical steps.
             */
            expression?: pulumi.Input<string>;
        }
        /**
         * Counter describes a quantity associated with a device.
         */
        interface Counter {
            /**
             * Value defines how much of a certain device counter is available.
             */
            value: pulumi.Input<string>;
        }
        /**
         * CounterSet defines a named set of counters that are available to be used by devices defined in the ResourceSlice.
         *
         * The counters are not allocatable by themselves, but can be referenced by devices. When a device is allocated, the portion of counters it uses will no longer be available for use by other devices.
         */
        interface CounterSet {
            /**
             * Counters defines the set of counters for this CounterSet The name of each counter must be unique in that set and must be a DNS label.
             *
             * The maximum number of counters is 32.
             */
            counters: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta1.Counter>;
            }>;
            /**
             * Name defines the name of the counter set. It must be a DNS label.
             */
            name: pulumi.Input<string>;
        }
        /**
         * CounterSet defines a named set of counters that are available to be used by devices defined in the ResourceSlice.
         *
         * The counters are not allocatable by themselves, but can be referenced by devices. When a device is allocated, the portion of counters it uses will no longer be available for use by other devices.
         */
        interface CounterSetPatch {
            /**
             * Counters defines the set of counters for this CounterSet The name of each counter must be unique in that set and must be a DNS label.
             *
             * The maximum number of counters is 32.
             */
            counters?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta1.Counter>;
            }>;
            /**
             * Name defines the name of the counter set. It must be a DNS label.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * Device represents one individual hardware instance that can be selected based on its attributes. Besides the name, exactly one field must be set.
         */
        interface Device {
            /**
             * Basic defines one device instance.
             */
            basic?: pulumi.Input<inputs.resource.v1beta1.BasicDevice>;
            /**
             * Name is unique identifier among all devices managed by the driver in the pool. It must be a DNS label.
             */
            name: pulumi.Input<string>;
        }
        /**
         * DeviceAllocationConfiguration gets embedded in an AllocationResult.
         */
        interface DeviceAllocationConfiguration {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1beta1.OpaqueDeviceConfiguration>;
            /**
             * Requests lists the names of requests where the configuration applies. If empty, its applies to all requests.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the configuration applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Source records whether the configuration comes from a class and thus is not something that a normal user would have been able to set or from a claim.
             */
            source: pulumi.Input<string>;
        }
        /**
         * DeviceAllocationResult is the result of allocating devices.
         */
        interface DeviceAllocationResult {
            /**
             * This field is a combination of all the claim and class configuration parameters. Drivers can distinguish between those based on a flag.
             *
             * This includes configuration parameters for drivers which have no allocated devices in the result because it is up to the drivers which configuration parameters they support. They can silently ignore unknown configuration parameters.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceAllocationConfiguration>[]>;
            /**
             * Results lists all allocated devices.
             */
            results?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceRequestAllocationResult>[]>;
        }
        /**
         * DeviceAttribute must have exactly one field set.
         */
        interface DeviceAttribute {
            /**
             * BoolValue is a true/false value.
             */
            bool?: pulumi.Input<boolean>;
            /**
             * IntValue is a number.
             */
            int?: pulumi.Input<number>;
            /**
             * StringValue is a string. Must not be longer than 64 characters.
             */
            string?: pulumi.Input<string>;
            /**
             * VersionValue is a semantic version according to semver.org spec 2.0.0. Must not be longer than 64 characters.
             */
            version?: pulumi.Input<string>;
        }
        /**
         * DeviceCapacity describes a quantity associated with a device.
         */
        interface DeviceCapacity {
            /**
             * Value defines how much of a certain device capacity is available.
             */
            value: pulumi.Input<string>;
        }
        /**
         * DeviceClaim defines how to request devices with a ResourceClaim.
         */
        interface DeviceClaim {
            /**
             * This field holds configuration for multiple potential drivers which could satisfy requests in this claim. It is ignored while allocating the claim.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceClaimConfiguration>[]>;
            /**
             * These constraints must be satisfied by the set of devices that get allocated for the claim.
             */
            constraints?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceConstraint>[]>;
            /**
             * Requests represent individual requests for distinct devices which must all be satisfied. If empty, nothing needs to be allocated.
             */
            requests?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceRequest>[]>;
        }
        /**
         * DeviceClaimConfiguration is used for configuration parameters in DeviceClaim.
         */
        interface DeviceClaimConfiguration {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1beta1.OpaqueDeviceConfiguration>;
            /**
             * Requests lists the names of requests where the configuration applies. If empty, it applies to all requests.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the configuration applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * DeviceClaimConfiguration is used for configuration parameters in DeviceClaim.
         */
        interface DeviceClaimConfigurationPatch {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1beta1.OpaqueDeviceConfigurationPatch>;
            /**
             * Requests lists the names of requests where the configuration applies. If empty, it applies to all requests.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the configuration applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * DeviceClaim defines how to request devices with a ResourceClaim.
         */
        interface DeviceClaimPatch {
            /**
             * This field holds configuration for multiple potential drivers which could satisfy requests in this claim. It is ignored while allocating the claim.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceClaimConfigurationPatch>[]>;
            /**
             * These constraints must be satisfied by the set of devices that get allocated for the claim.
             */
            constraints?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceConstraintPatch>[]>;
            /**
             * Requests represent individual requests for distinct devices which must all be satisfied. If empty, nothing needs to be allocated.
             */
            requests?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceRequestPatch>[]>;
        }
        /**
         * DeviceClass is a vendor- or admin-provided resource that contains device configuration and selectors. It can be referenced in the device requests of a claim to apply these presets. Cluster scoped.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface DeviceClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"DeviceClass">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines what can be allocated and how to configure it.
             *
             * This is mutable. Consumers have to be prepared for classes changing at any time, either because they get updated or replaced. Claim allocations are done once based on whatever was set in classes at the time of allocation.
             *
             * Changing the spec automatically increments the metadata.generation number.
             */
            spec: pulumi.Input<inputs.resource.v1beta1.DeviceClassSpec>;
        }
        /**
         * DeviceClassConfiguration is used in DeviceClass.
         */
        interface DeviceClassConfiguration {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1beta1.OpaqueDeviceConfiguration>;
        }
        /**
         * DeviceClassConfiguration is used in DeviceClass.
         */
        interface DeviceClassConfigurationPatch {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1beta1.OpaqueDeviceConfigurationPatch>;
        }
        /**
         * DeviceClassSpec is used in a [DeviceClass] to define what can be allocated and how to configure it.
         */
        interface DeviceClassSpec {
            /**
             * Config defines configuration parameters that apply to each device that is claimed via this class. Some classses may potentially be satisfied by multiple drivers, so each instance of a vendor configuration applies to exactly one driver.
             *
             * They are passed to the driver, but are not considered while allocating the claim.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceClassConfiguration>[]>;
            /**
             * Each selector must be satisfied by a device which is claimed via this class.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceSelector>[]>;
        }
        /**
         * DeviceClassSpec is used in a [DeviceClass] to define what can be allocated and how to configure it.
         */
        interface DeviceClassSpecPatch {
            /**
             * Config defines configuration parameters that apply to each device that is claimed via this class. Some classses may potentially be satisfied by multiple drivers, so each instance of a vendor configuration applies to exactly one driver.
             *
             * They are passed to the driver, but are not considered while allocating the claim.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceClassConfigurationPatch>[]>;
            /**
             * Each selector must be satisfied by a device which is claimed via this class.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceSelectorPatch>[]>;
        }
        /**
         * DeviceConstraint must have exactly one field set besides Requests.
         */
        interface DeviceConstraint {
            /**
             * MatchAttribute requires that all devices in question have this attribute and that its type and value are the same across those devices.
             *
             * For example, if you specified "dra.example.com/numa" (a hypothetical example!), then only devices in the same NUMA node will be chosen. A device which does not have that attribute will not be chosen. All devices should use a value of the same type for this attribute because that is part of its specification, but if one device doesn't, then it also will not be chosen.
             *
             * Must include the domain qualifier.
             */
            matchAttribute?: pulumi.Input<string>;
            /**
             * Requests is a list of the one or more requests in this claim which must co-satisfy this constraint. If a request is fulfilled by multiple devices, then all of the devices must satisfy the constraint. If this is not specified, this constraint applies to all requests in this claim.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the constraint applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * DeviceConstraint must have exactly one field set besides Requests.
         */
        interface DeviceConstraintPatch {
            /**
             * MatchAttribute requires that all devices in question have this attribute and that its type and value are the same across those devices.
             *
             * For example, if you specified "dra.example.com/numa" (a hypothetical example!), then only devices in the same NUMA node will be chosen. A device which does not have that attribute will not be chosen. All devices should use a value of the same type for this attribute because that is part of its specification, but if one device doesn't, then it also will not be chosen.
             *
             * Must include the domain qualifier.
             */
            matchAttribute?: pulumi.Input<string>;
            /**
             * Requests is a list of the one or more requests in this claim which must co-satisfy this constraint. If a request is fulfilled by multiple devices, then all of the devices must satisfy the constraint. If this is not specified, this constraint applies to all requests in this claim.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the constraint applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * DeviceCounterConsumption defines a set of counters that a device will consume from a CounterSet.
         */
        interface DeviceCounterConsumption {
            /**
             * CounterSet is the name of the set from which the counters defined will be consumed.
             */
            counterSet: pulumi.Input<string>;
            /**
             * Counters defines the counters that will be consumed by the device.
             *
             * The maximum number counters in a device is 32. In addition, the maximum number of all counters in all devices is 1024 (for example, 64 devices with 16 counters each).
             */
            counters: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta1.Counter>;
            }>;
        }
        /**
         * DeviceCounterConsumption defines a set of counters that a device will consume from a CounterSet.
         */
        interface DeviceCounterConsumptionPatch {
            /**
             * CounterSet is the name of the set from which the counters defined will be consumed.
             */
            counterSet?: pulumi.Input<string>;
            /**
             * Counters defines the counters that will be consumed by the device.
             *
             * The maximum number counters in a device is 32. In addition, the maximum number of all counters in all devices is 1024 (for example, 64 devices with 16 counters each).
             */
            counters?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta1.Counter>;
            }>;
        }
        /**
         * Device represents one individual hardware instance that can be selected based on its attributes. Besides the name, exactly one field must be set.
         */
        interface DevicePatch {
            /**
             * Basic defines one device instance.
             */
            basic?: pulumi.Input<inputs.resource.v1beta1.BasicDevicePatch>;
            /**
             * Name is unique identifier among all devices managed by the driver in the pool. It must be a DNS label.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * DeviceRequest is a request for devices required for a claim. This is typically a request for a single resource like a device, but can also ask for several identical devices.
         */
        interface DeviceRequest {
            /**
             * AdminAccess indicates that this is a claim for administrative access to the device(s). Claims with AdminAccess are expected to be used for monitoring or other management services for a device.  They ignore all ordinary claims to the device with respect to access modes and any resource allocations.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             *
             * This is an alpha field and requires enabling the DRAAdminAccess feature gate. Admin access is disabled if this field is unset or set to false, otherwise it is enabled.
             */
            adminAccess?: pulumi.Input<boolean>;
            /**
             * AllocationMode and its related fields define how devices are allocated to satisfy this request. Supported values are:
             *
             * - ExactCount: This request is for a specific number of devices.
             *   This is the default. The exact number is provided in the
             *   count field.
             *
             * - All: This request is for all of the matching devices in a pool.
             *   At least one device must exist on the node for the allocation to succeed.
             *   Allocation will fail if some devices are already allocated,
             *   unless adminAccess is requested.
             *
             * If AllocationMode is not specified, the default mode is ExactCount. If the mode is ExactCount and count is not specified, the default count is one. Any other requests must specify this field.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             *
             * More modes may get added in the future. Clients must refuse to handle requests with unknown modes.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * Count is used only when the count mode is "ExactCount". Must be greater than zero. If AllocationMode is ExactCount and this field is not specified, the default is one.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             */
            count?: pulumi.Input<number>;
            /**
             * DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this request.
             *
             * A class is required if no subrequests are specified in the firstAvailable list and no class can be set if subrequests are specified in the firstAvailable list. Which classes are available depends on the cluster.
             *
             * Administrators may use this to restrict which devices may get requested by only installing classes with selectors for permitted devices. If users are free to request anything without restrictions, then administrators can create an empty DeviceClass for users to reference.
             */
            deviceClassName?: pulumi.Input<string>;
            /**
             * FirstAvailable contains subrequests, of which exactly one will be satisfied by the scheduler to satisfy this request. It tries to satisfy them in the order in which they are listed here. So if there are two entries in the list, the scheduler will only check the second one if it determines that the first one cannot be used.
             *
             * This field may only be set in the entries of DeviceClaim.Requests.
             *
             * DRA does not yet implement scoring, so the scheduler will select the first set of devices that satisfies all the requests in the claim. And if the requirements can be satisfied on more than one node, other scheduling features will determine which node is chosen. This means that the set of devices allocated to a claim might not be the optimal set available to the cluster. Scoring will be implemented later.
             */
            firstAvailable?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceSubRequest>[]>;
            /**
             * Name can be used to reference this request in a pod.spec.containers[].resources.claims entry and in a constraint of the claim.
             *
             * Must be a DNS label and unique among all DeviceRequests in a ResourceClaim.
             */
            name: pulumi.Input<string>;
            /**
             * Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this request. All selectors must be satisfied for a device to be considered.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceSelector>[]>;
            /**
             * If specified, the request's tolerations.
             *
             * Tolerations for NoSchedule are required to allocate a device which has a taint with that effect. The same applies to NoExecute.
             *
             * In addition, should any of the allocated devices get tainted with NoExecute after allocation and that effect is not tolerated, then all pods consuming the ResourceClaim get deleted to evict them. The scheduler will not let new pods reserve the claim while it has these tainted devices. Once all pods are evicted, the claim will get deallocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceToleration>[]>;
        }
        /**
         * DeviceRequestAllocationResult contains the allocation result for one request.
         */
        interface DeviceRequestAllocationResult {
            /**
             * AdminAccess indicates that this device was allocated for administrative access. See the corresponding request field for a definition of mode.
             *
             * This is an alpha field and requires enabling the DRAAdminAccess feature gate. Admin access is disabled if this field is unset or set to false, otherwise it is enabled.
             */
            adminAccess?: pulumi.Input<boolean>;
            /**
             * Device references one device instance via its name in the driver's resource pool. It must be a DNS label.
             */
            device: pulumi.Input<string>;
            /**
             * Driver specifies the name of the DRA driver whose kubelet plugin should be invoked to process the allocation once the claim is needed on a node.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver.
             */
            driver: pulumi.Input<string>;
            /**
             * This name together with the driver name and the device name field identify which device was allocated (`<driver name>/<pool name>/<device name>`).
             *
             * Must not be longer than 253 characters and may contain one or more DNS sub-domains separated by slashes.
             */
            pool: pulumi.Input<string>;
            /**
             * Request is the name of the request in the claim which caused this device to be allocated. If it references a subrequest in the firstAvailable list on a DeviceRequest, this field must include both the name of the main request and the subrequest using the format <main request>/<subrequest>.
             *
             * Multiple devices may have been allocated per request.
             */
            request: pulumi.Input<string>;
            /**
             * A copy of all tolerations specified in the request at the time when the device got allocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceToleration>[]>;
        }
        /**
         * DeviceRequest is a request for devices required for a claim. This is typically a request for a single resource like a device, but can also ask for several identical devices.
         */
        interface DeviceRequestPatch {
            /**
             * AdminAccess indicates that this is a claim for administrative access to the device(s). Claims with AdminAccess are expected to be used for monitoring or other management services for a device.  They ignore all ordinary claims to the device with respect to access modes and any resource allocations.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             *
             * This is an alpha field and requires enabling the DRAAdminAccess feature gate. Admin access is disabled if this field is unset or set to false, otherwise it is enabled.
             */
            adminAccess?: pulumi.Input<boolean>;
            /**
             * AllocationMode and its related fields define how devices are allocated to satisfy this request. Supported values are:
             *
             * - ExactCount: This request is for a specific number of devices.
             *   This is the default. The exact number is provided in the
             *   count field.
             *
             * - All: This request is for all of the matching devices in a pool.
             *   At least one device must exist on the node for the allocation to succeed.
             *   Allocation will fail if some devices are already allocated,
             *   unless adminAccess is requested.
             *
             * If AllocationMode is not specified, the default mode is ExactCount. If the mode is ExactCount and count is not specified, the default count is one. Any other requests must specify this field.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             *
             * More modes may get added in the future. Clients must refuse to handle requests with unknown modes.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * Count is used only when the count mode is "ExactCount". Must be greater than zero. If AllocationMode is ExactCount and this field is not specified, the default is one.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             */
            count?: pulumi.Input<number>;
            /**
             * DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this request.
             *
             * A class is required if no subrequests are specified in the firstAvailable list and no class can be set if subrequests are specified in the firstAvailable list. Which classes are available depends on the cluster.
             *
             * Administrators may use this to restrict which devices may get requested by only installing classes with selectors for permitted devices. If users are free to request anything without restrictions, then administrators can create an empty DeviceClass for users to reference.
             */
            deviceClassName?: pulumi.Input<string>;
            /**
             * FirstAvailable contains subrequests, of which exactly one will be satisfied by the scheduler to satisfy this request. It tries to satisfy them in the order in which they are listed here. So if there are two entries in the list, the scheduler will only check the second one if it determines that the first one cannot be used.
             *
             * This field may only be set in the entries of DeviceClaim.Requests.
             *
             * DRA does not yet implement scoring, so the scheduler will select the first set of devices that satisfies all the requests in the claim. And if the requirements can be satisfied on more than one node, other scheduling features will determine which node is chosen. This means that the set of devices allocated to a claim might not be the optimal set available to the cluster. Scoring will be implemented later.
             */
            firstAvailable?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceSubRequestPatch>[]>;
            /**
             * Name can be used to reference this request in a pod.spec.containers[].resources.claims entry and in a constraint of the claim.
             *
             * Must be a DNS label and unique among all DeviceRequests in a ResourceClaim.
             */
            name?: pulumi.Input<string>;
            /**
             * Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this request. All selectors must be satisfied for a device to be considered.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceSelectorPatch>[]>;
            /**
             * If specified, the request's tolerations.
             *
             * Tolerations for NoSchedule are required to allocate a device which has a taint with that effect. The same applies to NoExecute.
             *
             * In addition, should any of the allocated devices get tainted with NoExecute after allocation and that effect is not tolerated, then all pods consuming the ResourceClaim get deleted to evict them. The scheduler will not let new pods reserve the claim while it has these tainted devices. Once all pods are evicted, the claim will get deallocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceTolerationPatch>[]>;
        }
        /**
         * DeviceSelector must have exactly one field set.
         */
        interface DeviceSelector {
            /**
             * CEL contains a CEL expression for selecting a device.
             */
            cel?: pulumi.Input<inputs.resource.v1beta1.CELDeviceSelector>;
        }
        /**
         * DeviceSelector must have exactly one field set.
         */
        interface DeviceSelectorPatch {
            /**
             * CEL contains a CEL expression for selecting a device.
             */
            cel?: pulumi.Input<inputs.resource.v1beta1.CELDeviceSelectorPatch>;
        }
        /**
         * DeviceSubRequest describes a request for device provided in the claim.spec.devices.requests[].firstAvailable array. Each is typically a request for a single resource like a device, but can also ask for several identical devices.
         *
         * DeviceSubRequest is similar to Request, but doesn't expose the AdminAccess or FirstAvailable fields, as those can only be set on the top-level request. AdminAccess is not supported for requests with a prioritized list, and recursive FirstAvailable fields are not supported.
         */
        interface DeviceSubRequest {
            /**
             * AllocationMode and its related fields define how devices are allocated to satisfy this subrequest. Supported values are:
             *
             * - ExactCount: This request is for a specific number of devices.
             *   This is the default. The exact number is provided in the
             *   count field.
             *
             * - All: This subrequest is for all of the matching devices in a pool.
             *   Allocation will fail if some devices are already allocated,
             *   unless adminAccess is requested.
             *
             * If AllocationMode is not specified, the default mode is ExactCount. If the mode is ExactCount and count is not specified, the default count is one. Any other subrequests must specify this field.
             *
             * More modes may get added in the future. Clients must refuse to handle requests with unknown modes.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * Count is used only when the count mode is "ExactCount". Must be greater than zero. If AllocationMode is ExactCount and this field is not specified, the default is one.
             */
            count?: pulumi.Input<number>;
            /**
             * DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this subrequest.
             *
             * A class is required. Which classes are available depends on the cluster.
             *
             * Administrators may use this to restrict which devices may get requested by only installing classes with selectors for permitted devices. If users are free to request anything without restrictions, then administrators can create an empty DeviceClass for users to reference.
             */
            deviceClassName: pulumi.Input<string>;
            /**
             * Name can be used to reference this subrequest in the list of constraints or the list of configurations for the claim. References must use the format <main request>/<subrequest>.
             *
             * Must be a DNS label.
             */
            name: pulumi.Input<string>;
            /**
             * Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this subrequest. All selectors must be satisfied for a device to be considered.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceSelector>[]>;
            /**
             * If specified, the request's tolerations.
             *
             * Tolerations for NoSchedule are required to allocate a device which has a taint with that effect. The same applies to NoExecute.
             *
             * In addition, should any of the allocated devices get tainted with NoExecute after allocation and that effect is not tolerated, then all pods consuming the ResourceClaim get deleted to evict them. The scheduler will not let new pods reserve the claim while it has these tainted devices. Once all pods are evicted, the claim will get deallocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceToleration>[]>;
        }
        /**
         * DeviceSubRequest describes a request for device provided in the claim.spec.devices.requests[].firstAvailable array. Each is typically a request for a single resource like a device, but can also ask for several identical devices.
         *
         * DeviceSubRequest is similar to Request, but doesn't expose the AdminAccess or FirstAvailable fields, as those can only be set on the top-level request. AdminAccess is not supported for requests with a prioritized list, and recursive FirstAvailable fields are not supported.
         */
        interface DeviceSubRequestPatch {
            /**
             * AllocationMode and its related fields define how devices are allocated to satisfy this subrequest. Supported values are:
             *
             * - ExactCount: This request is for a specific number of devices.
             *   This is the default. The exact number is provided in the
             *   count field.
             *
             * - All: This subrequest is for all of the matching devices in a pool.
             *   Allocation will fail if some devices are already allocated,
             *   unless adminAccess is requested.
             *
             * If AllocationMode is not specified, the default mode is ExactCount. If the mode is ExactCount and count is not specified, the default count is one. Any other subrequests must specify this field.
             *
             * More modes may get added in the future. Clients must refuse to handle requests with unknown modes.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * Count is used only when the count mode is "ExactCount". Must be greater than zero. If AllocationMode is ExactCount and this field is not specified, the default is one.
             */
            count?: pulumi.Input<number>;
            /**
             * DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this subrequest.
             *
             * A class is required. Which classes are available depends on the cluster.
             *
             * Administrators may use this to restrict which devices may get requested by only installing classes with selectors for permitted devices. If users are free to request anything without restrictions, then administrators can create an empty DeviceClass for users to reference.
             */
            deviceClassName?: pulumi.Input<string>;
            /**
             * Name can be used to reference this subrequest in the list of constraints or the list of configurations for the claim. References must use the format <main request>/<subrequest>.
             *
             * Must be a DNS label.
             */
            name?: pulumi.Input<string>;
            /**
             * Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this subrequest. All selectors must be satisfied for a device to be considered.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceSelectorPatch>[]>;
            /**
             * If specified, the request's tolerations.
             *
             * Tolerations for NoSchedule are required to allocate a device which has a taint with that effect. The same applies to NoExecute.
             *
             * In addition, should any of the allocated devices get tainted with NoExecute after allocation and that effect is not tolerated, then all pods consuming the ResourceClaim get deleted to evict them. The scheduler will not let new pods reserve the claim while it has these tainted devices. Once all pods are evicted, the claim will get deallocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DeviceTolerationPatch>[]>;
        }
        /**
         * The device this taint is attached to has the "effect" on any claim which does not tolerate the taint and, through the claim, to pods using the claim.
         */
        interface DeviceTaint {
            /**
             * The effect of the taint on claims that do not tolerate the taint and through such claims on the pods using them. Valid effects are NoSchedule and NoExecute. PreferNoSchedule as used for nodes is not valid here.
             */
            effect: pulumi.Input<string>;
            /**
             * The taint key to be applied to a device. Must be a label name.
             */
            key: pulumi.Input<string>;
            /**
             * TimeAdded represents the time at which the taint was added. Added automatically during create or update if not set.
             */
            timeAdded?: pulumi.Input<string>;
            /**
             * The taint value corresponding to the taint key. Must be a label value.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * The device this taint is attached to has the "effect" on any claim which does not tolerate the taint and, through the claim, to pods using the claim.
         */
        interface DeviceTaintPatch {
            /**
             * The effect of the taint on claims that do not tolerate the taint and through such claims on the pods using them. Valid effects are NoSchedule and NoExecute. PreferNoSchedule as used for nodes is not valid here.
             */
            effect?: pulumi.Input<string>;
            /**
             * The taint key to be applied to a device. Must be a label name.
             */
            key?: pulumi.Input<string>;
            /**
             * TimeAdded represents the time at which the taint was added. Added automatically during create or update if not set.
             */
            timeAdded?: pulumi.Input<string>;
            /**
             * The taint value corresponding to the taint key. Must be a label value.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * The ResourceClaim this DeviceToleration is attached to tolerates any taint that matches the triple <key,value,effect> using the matching operator <operator>.
         */
        interface DeviceToleration {
            /**
             * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule and NoExecute.
             */
            effect?: pulumi.Input<string>;
            /**
             * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys. Must be a label name.
             */
            key?: pulumi.Input<string>;
            /**
             * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a ResourceClaim can tolerate all taints of a particular category.
             */
            operator?: pulumi.Input<string>;
            /**
             * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system. If larger than zero, the time when the pod needs to be evicted is calculated as <time when taint was adedd> + <toleration seconds>.
             */
            tolerationSeconds?: pulumi.Input<number>;
            /**
             * Value is the taint value the toleration matches to. If the operator is Exists, the value must be empty, otherwise just a regular string. Must be a label value.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * The ResourceClaim this DeviceToleration is attached to tolerates any taint that matches the triple <key,value,effect> using the matching operator <operator>.
         */
        interface DeviceTolerationPatch {
            /**
             * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule and NoExecute.
             */
            effect?: pulumi.Input<string>;
            /**
             * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys. Must be a label name.
             */
            key?: pulumi.Input<string>;
            /**
             * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a ResourceClaim can tolerate all taints of a particular category.
             */
            operator?: pulumi.Input<string>;
            /**
             * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system. If larger than zero, the time when the pod needs to be evicted is calculated as <time when taint was adedd> + <toleration seconds>.
             */
            tolerationSeconds?: pulumi.Input<number>;
            /**
             * Value is the taint value the toleration matches to. If the operator is Exists, the value must be empty, otherwise just a regular string. Must be a label value.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * NetworkDeviceData provides network-related details for the allocated device. This information may be filled by drivers or other components to configure or identify the device within a network context.
         */
        interface NetworkDeviceData {
            /**
             * HardwareAddress represents the hardware address (e.g. MAC Address) of the device's network interface.
             *
             * Must not be longer than 128 characters.
             */
            hardwareAddress?: pulumi.Input<string>;
            /**
             * InterfaceName specifies the name of the network interface associated with the allocated device. This might be the name of a physical or virtual network interface being configured in the pod.
             *
             * Must not be longer than 256 characters.
             */
            interfaceName?: pulumi.Input<string>;
            /**
             * IPs lists the network addresses assigned to the device's network interface. This can include both IPv4 and IPv6 addresses. The IPs are in the CIDR notation, which includes both the address and the associated subnet mask. e.g.: "192.0.2.5/24" for IPv4 and "2001:db8::5/64" for IPv6.
             *
             * Must not contain more than 16 entries.
             */
            ips?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * OpaqueDeviceConfiguration contains configuration parameters for a driver in a format defined by the driver vendor.
         */
        interface OpaqueDeviceConfiguration {
            /**
             * Driver is used to determine which kubelet plugin needs to be passed these configuration parameters.
             *
             * An admission policy provided by the driver developer could use this to decide whether it needs to validate them.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver.
             */
            driver: pulumi.Input<string>;
            /**
             * Parameters can contain arbitrary data. It is the responsibility of the driver developer to handle validation and versioning. Typically this includes self-identification and a version ("kind" + "apiVersion" for Kubernetes types), with conversion between different versions.
             *
             * The length of the raw data must be smaller or equal to 10 Ki.
             */
            parameters: any;
        }
        /**
         * OpaqueDeviceConfiguration contains configuration parameters for a driver in a format defined by the driver vendor.
         */
        interface OpaqueDeviceConfigurationPatch {
            /**
             * Driver is used to determine which kubelet plugin needs to be passed these configuration parameters.
             *
             * An admission policy provided by the driver developer could use this to decide whether it needs to validate them.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver.
             */
            driver?: pulumi.Input<string>;
            /**
             * Parameters can contain arbitrary data. It is the responsibility of the driver developer to handle validation and versioning. Typically this includes self-identification and a version ("kind" + "apiVersion" for Kubernetes types), with conversion between different versions.
             *
             * The length of the raw data must be smaller or equal to 10 Ki.
             */
            parameters?: any;
        }
        /**
         * ResourceClaim describes a request for access to resources in the cluster, for use by workloads. For example, if a workload needs an accelerator device with specific properties, this is how that request is expressed. The status stanza tracks whether this claim has been satisfied and what specific resources have been allocated.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface ResourceClaim {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceClaim">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec describes what is being requested and how to configure it. The spec is immutable.
             */
            spec: pulumi.Input<inputs.resource.v1beta1.ResourceClaimSpec>;
            /**
             * Status describes whether the claim is ready to use and what has been allocated.
             */
            status?: pulumi.Input<inputs.resource.v1beta1.ResourceClaimStatus>;
        }
        /**
         * ResourceClaimConsumerReference contains enough information to let you locate the consumer of a ResourceClaim. The user must be a resource in the same namespace as the ResourceClaim.
         */
        interface ResourceClaimConsumerReference {
            /**
             * APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced.
             */
            name: pulumi.Input<string>;
            /**
             * Resource is the type of resource being referenced, for example "pods".
             */
            resource: pulumi.Input<string>;
            /**
             * UID identifies exactly one incarnation of the resource.
             */
            uid: pulumi.Input<string>;
        }
        /**
         * ResourceClaimSpec defines what is being requested in a ResourceClaim and how to configure it.
         */
        interface ResourceClaimSpec {
            /**
             * Devices defines how to request devices.
             */
            devices?: pulumi.Input<inputs.resource.v1beta1.DeviceClaim>;
        }
        /**
         * ResourceClaimSpec defines what is being requested in a ResourceClaim and how to configure it.
         */
        interface ResourceClaimSpecPatch {
            /**
             * Devices defines how to request devices.
             */
            devices?: pulumi.Input<inputs.resource.v1beta1.DeviceClaimPatch>;
        }
        /**
         * ResourceClaimStatus tracks whether the resource has been allocated and what the result of that was.
         */
        interface ResourceClaimStatus {
            /**
             * Allocation is set once the claim has been allocated successfully.
             */
            allocation?: pulumi.Input<inputs.resource.v1beta1.AllocationResult>;
            /**
             * Devices contains the status of each device allocated for this claim, as reported by the driver. This can include driver-specific information. Entries are owned by their respective drivers.
             */
            devices?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.AllocatedDeviceStatus>[]>;
            /**
             * ReservedFor indicates which entities are currently allowed to use the claim. A Pod which references a ResourceClaim which is not reserved for that Pod will not be started. A claim that is in use or might be in use because it has been reserved must not get deallocated.
             *
             * In a cluster with multiple scheduler instances, two pods might get scheduled concurrently by different schedulers. When they reference the same ResourceClaim which already has reached its maximum number of consumers, only one pod can be scheduled.
             *
             * Both schedulers try to add their pod to the claim.status.reservedFor field, but only the update that reaches the API server first gets stored. The other one fails with an error and the scheduler which issued it knows that it must put the pod back into the queue, waiting for the ResourceClaim to become usable again.
             *
             * There can be at most 256 such reservations. This may get increased in the future, but not reduced.
             */
            reservedFor?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.ResourceClaimConsumerReference>[]>;
        }
        /**
         * ResourceClaimTemplate is used to produce ResourceClaim objects.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface ResourceClaimTemplate {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceClaimTemplate">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Describes the ResourceClaim that is to be generated.
             *
             * This field is immutable. A ResourceClaim will get created by the control plane for a Pod when needed and then not get updated anymore.
             */
            spec: pulumi.Input<inputs.resource.v1beta1.ResourceClaimTemplateSpec>;
        }
        /**
         * ResourceClaimTemplateSpec contains the metadata and fields for a ResourceClaim.
         */
        interface ResourceClaimTemplateSpec {
            /**
             * ObjectMeta may contain labels and annotations that will be copied into the ResourceClaim when creating it. No other fields are allowed and will be rejected during validation.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec for the ResourceClaim. The entire content is copied unchanged into the ResourceClaim that gets created from this template. The same fields as in a ResourceClaim are also valid here.
             */
            spec: pulumi.Input<inputs.resource.v1beta1.ResourceClaimSpec>;
        }
        /**
         * ResourceClaimTemplateSpec contains the metadata and fields for a ResourceClaim.
         */
        interface ResourceClaimTemplateSpecPatch {
            /**
             * ObjectMeta may contain labels and annotations that will be copied into the ResourceClaim when creating it. No other fields are allowed and will be rejected during validation.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMetaPatch>;
            /**
             * Spec for the ResourceClaim. The entire content is copied unchanged into the ResourceClaim that gets created from this template. The same fields as in a ResourceClaim are also valid here.
             */
            spec?: pulumi.Input<inputs.resource.v1beta1.ResourceClaimSpecPatch>;
        }
        /**
         * ResourcePool describes the pool that ResourceSlices belong to.
         */
        interface ResourcePool {
            /**
             * Generation tracks the change in a pool over time. Whenever a driver changes something about one or more of the resources in a pool, it must change the generation in all ResourceSlices which are part of that pool. Consumers of ResourceSlices should only consider resources from the pool with the highest generation number. The generation may be reset by drivers, which should be fine for consumers, assuming that all ResourceSlices in a pool are updated to match or deleted.
             *
             * Combined with ResourceSliceCount, this mechanism enables consumers to detect pools which are comprised of multiple ResourceSlices and are in an incomplete state.
             */
            generation: pulumi.Input<number>;
            /**
             * Name is used to identify the pool. For node-local devices, this is often the node name, but this is not required.
             *
             * It must not be longer than 253 characters and must consist of one or more DNS sub-domains separated by slashes. This field is immutable.
             */
            name: pulumi.Input<string>;
            /**
             * ResourceSliceCount is the total number of ResourceSlices in the pool at this generation number. Must be greater than zero.
             *
             * Consumers can use this to check whether they have seen all ResourceSlices belonging to the same pool.
             */
            resourceSliceCount: pulumi.Input<number>;
        }
        /**
         * ResourcePool describes the pool that ResourceSlices belong to.
         */
        interface ResourcePoolPatch {
            /**
             * Generation tracks the change in a pool over time. Whenever a driver changes something about one or more of the resources in a pool, it must change the generation in all ResourceSlices which are part of that pool. Consumers of ResourceSlices should only consider resources from the pool with the highest generation number. The generation may be reset by drivers, which should be fine for consumers, assuming that all ResourceSlices in a pool are updated to match or deleted.
             *
             * Combined with ResourceSliceCount, this mechanism enables consumers to detect pools which are comprised of multiple ResourceSlices and are in an incomplete state.
             */
            generation?: pulumi.Input<number>;
            /**
             * Name is used to identify the pool. For node-local devices, this is often the node name, but this is not required.
             *
             * It must not be longer than 253 characters and must consist of one or more DNS sub-domains separated by slashes. This field is immutable.
             */
            name?: pulumi.Input<string>;
            /**
             * ResourceSliceCount is the total number of ResourceSlices in the pool at this generation number. Must be greater than zero.
             *
             * Consumers can use this to check whether they have seen all ResourceSlices belonging to the same pool.
             */
            resourceSliceCount?: pulumi.Input<number>;
        }
        /**
         * ResourceSlice represents one or more resources in a pool of similar resources, managed by a common driver. A pool may span more than one ResourceSlice, and exactly how many ResourceSlices comprise a pool is determined by the driver.
         *
         * At the moment, the only supported resources are devices with attributes and capacities. Each device in a given pool, regardless of how many ResourceSlices, must have a unique name. The ResourceSlice in which a device gets published may change over time. The unique identifier for a device is the tuple <driver name>, <pool name>, <device name>.
         *
         * Whenever a driver needs to update a pool, it increments the pool.Spec.Pool.Generation number and updates all ResourceSlices with that new number and new resource definitions. A consumer must only use ResourceSlices with the highest generation number and ignore all others.
         *
         * When allocating all resources in a pool matching certain criteria or when looking for the best solution among several different alternatives, a consumer should check the number of ResourceSlices in a pool (included in each ResourceSlice) to determine whether its view of a pool is complete and if not, should wait until the driver has completed updating the pool.
         *
         * For resources that are not local to a node, the node name is not set. Instead, the driver may use a node selector to specify where the devices are available.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface ResourceSlice {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceSlice">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Contains the information published by the driver.
             *
             * Changing the spec automatically increments the metadata.generation number.
             */
            spec: pulumi.Input<inputs.resource.v1beta1.ResourceSliceSpec>;
        }
        /**
         * ResourceSliceSpec contains the information published by the driver in one ResourceSlice.
         */
        interface ResourceSliceSpec {
            /**
             * AllNodes indicates that all nodes have access to the resources in the pool.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            allNodes?: pulumi.Input<boolean>;
            /**
             * Devices lists some or all of the devices in this pool.
             *
             * Must not have more than 128 entries.
             */
            devices?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.Device>[]>;
            /**
             * Driver identifies the DRA driver providing the capacity information. A field selector can be used to list only ResourceSlice objects with a certain driver name.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver. This field is immutable.
             */
            driver: pulumi.Input<string>;
            /**
             * NodeName identifies the node which provides the resources in this pool. A field selector can be used to list only ResourceSlice objects belonging to a certain node.
             *
             * This field can be used to limit access from nodes to ResourceSlices with the same node name. It also indicates to autoscalers that adding new nodes of the same type as some old node might also make new resources available.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set. This field is immutable.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * NodeSelector defines which nodes have access to the resources in the pool, when that pool is not limited to a single node.
             *
             * Must use exactly one term.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelector>;
            /**
             * PerDeviceNodeSelection defines whether the access from nodes to resources in the pool is set on the ResourceSlice level or on each device. If it is set to true, every device defined the ResourceSlice must specify this individually.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            perDeviceNodeSelection?: pulumi.Input<boolean>;
            /**
             * Pool describes the pool that this ResourceSlice belongs to.
             */
            pool: pulumi.Input<inputs.resource.v1beta1.ResourcePool>;
            /**
             * SharedCounters defines a list of counter sets, each of which has a name and a list of counters available.
             *
             * The names of the SharedCounters must be unique in the ResourceSlice.
             *
             * The maximum number of SharedCounters is 32.
             */
            sharedCounters?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.CounterSet>[]>;
        }
        /**
         * ResourceSliceSpec contains the information published by the driver in one ResourceSlice.
         */
        interface ResourceSliceSpecPatch {
            /**
             * AllNodes indicates that all nodes have access to the resources in the pool.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            allNodes?: pulumi.Input<boolean>;
            /**
             * Devices lists some or all of the devices in this pool.
             *
             * Must not have more than 128 entries.
             */
            devices?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.DevicePatch>[]>;
            /**
             * Driver identifies the DRA driver providing the capacity information. A field selector can be used to list only ResourceSlice objects with a certain driver name.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver. This field is immutable.
             */
            driver?: pulumi.Input<string>;
            /**
             * NodeName identifies the node which provides the resources in this pool. A field selector can be used to list only ResourceSlice objects belonging to a certain node.
             *
             * This field can be used to limit access from nodes to ResourceSlices with the same node name. It also indicates to autoscalers that adding new nodes of the same type as some old node might also make new resources available.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set. This field is immutable.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * NodeSelector defines which nodes have access to the resources in the pool, when that pool is not limited to a single node.
             *
             * Must use exactly one term.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelectorPatch>;
            /**
             * PerDeviceNodeSelection defines whether the access from nodes to resources in the pool is set on the ResourceSlice level or on each device. If it is set to true, every device defined the ResourceSlice must specify this individually.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            perDeviceNodeSelection?: pulumi.Input<boolean>;
            /**
             * Pool describes the pool that this ResourceSlice belongs to.
             */
            pool?: pulumi.Input<inputs.resource.v1beta1.ResourcePoolPatch>;
            /**
             * SharedCounters defines a list of counter sets, each of which has a name and a list of counters available.
             *
             * The names of the SharedCounters must be unique in the ResourceSlice.
             *
             * The maximum number of SharedCounters is 32.
             */
            sharedCounters?: pulumi.Input<pulumi.Input<inputs.resource.v1beta1.CounterSetPatch>[]>;
        }
    }
    namespace v1beta2 {
        /**
         * AllocatedDeviceStatus contains the status of an allocated device, if the driver chooses to report it. This may include driver-specific information.
         */
        interface AllocatedDeviceStatus {
            /**
             * Conditions contains the latest observation of the device's state. If the device has been configured according to the class and claim config references, the `Ready` condition should be True.
             *
             * Must not contain more than 8 entries.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.meta.v1.Condition>[]>;
            /**
             * Data contains arbitrary driver-specific data.
             *
             * The length of the raw data must be smaller or equal to 10 Ki.
             */
            data?: any;
            /**
             * Device references one device instance via its name in the driver's resource pool. It must be a DNS label.
             */
            device: pulumi.Input<string>;
            /**
             * Driver specifies the name of the DRA driver whose kubelet plugin should be invoked to process the allocation once the claim is needed on a node.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver.
             */
            driver: pulumi.Input<string>;
            /**
             * NetworkData contains network-related information specific to the device.
             */
            networkData?: pulumi.Input<inputs.resource.v1beta2.NetworkDeviceData>;
            /**
             * This name together with the driver name and the device name field identify which device was allocated (`<driver name>/<pool name>/<device name>`).
             *
             * Must not be longer than 253 characters and may contain one or more DNS sub-domains separated by slashes.
             */
            pool: pulumi.Input<string>;
        }
        /**
         * AllocationResult contains attributes of an allocated resource.
         */
        interface AllocationResult {
            /**
             * Devices is the result of allocating devices.
             */
            devices?: pulumi.Input<inputs.resource.v1beta2.DeviceAllocationResult>;
            /**
             * NodeSelector defines where the allocated resources are available. If unset, they are available everywhere.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelector>;
        }
        /**
         * CELDeviceSelector contains a CEL expression for selecting a device.
         */
        interface CELDeviceSelector {
            /**
             * Expression is a CEL expression which evaluates a single device. It must evaluate to true when the device under consideration satisfies the desired criteria, and false when it does not. Any other result is an error and causes allocation of devices to abort.
             *
             * The expression's input is an object named "device", which carries the following properties:
             *  - driver (string): the name of the driver which defines this device.
             *  - attributes (map[string]object): the device's attributes, grouped by prefix
             *    (e.g. device.attributes["dra.example.com"] evaluates to an object with all
             *    of the attributes which were prefixed by "dra.example.com".
             *  - capacity (map[string]object): the device's capacities, grouped by prefix.
             *
             * Example: Consider a device with driver="dra.example.com", which exposes two attributes named "model" and "ext.example.com/family" and which exposes one capacity named "modules". This input to this expression would have the following fields:
             *
             *     device.driver
             *     device.attributes["dra.example.com"].model
             *     device.attributes["ext.example.com"].family
             *     device.capacity["dra.example.com"].modules
             *
             * The device.driver field can be used to check for a specific driver, either as a high-level precondition (i.e. you only want to consider devices from this driver) or as part of a multi-clause expression that is meant to consider devices from different drivers.
             *
             * The value type of each attribute is defined by the device definition, and users who write these expressions must consult the documentation for their specific drivers. The value type of each capacity is Quantity.
             *
             * If an unknown prefix is used as a lookup in either device.attributes or device.capacity, an empty map will be returned. Any reference to an unknown field will cause an evaluation error and allocation to abort.
             *
             * A robust expression should check for the existence of attributes before referencing them.
             *
             * For ease of use, the cel.bind() function is enabled, and can be used to simplify expressions that access multiple attributes with the same domain. For example:
             *
             *     cel.bind(dra, device.attributes["dra.example.com"], dra.someBool && dra.anotherBool)
             *
             * The length of the expression must be smaller or equal to 10 Ki. The cost of evaluating it is also limited based on the estimated number of logical steps.
             */
            expression: pulumi.Input<string>;
        }
        /**
         * CELDeviceSelector contains a CEL expression for selecting a device.
         */
        interface CELDeviceSelectorPatch {
            /**
             * Expression is a CEL expression which evaluates a single device. It must evaluate to true when the device under consideration satisfies the desired criteria, and false when it does not. Any other result is an error and causes allocation of devices to abort.
             *
             * The expression's input is an object named "device", which carries the following properties:
             *  - driver (string): the name of the driver which defines this device.
             *  - attributes (map[string]object): the device's attributes, grouped by prefix
             *    (e.g. device.attributes["dra.example.com"] evaluates to an object with all
             *    of the attributes which were prefixed by "dra.example.com".
             *  - capacity (map[string]object): the device's capacities, grouped by prefix.
             *
             * Example: Consider a device with driver="dra.example.com", which exposes two attributes named "model" and "ext.example.com/family" and which exposes one capacity named "modules". This input to this expression would have the following fields:
             *
             *     device.driver
             *     device.attributes["dra.example.com"].model
             *     device.attributes["ext.example.com"].family
             *     device.capacity["dra.example.com"].modules
             *
             * The device.driver field can be used to check for a specific driver, either as a high-level precondition (i.e. you only want to consider devices from this driver) or as part of a multi-clause expression that is meant to consider devices from different drivers.
             *
             * The value type of each attribute is defined by the device definition, and users who write these expressions must consult the documentation for their specific drivers. The value type of each capacity is Quantity.
             *
             * If an unknown prefix is used as a lookup in either device.attributes or device.capacity, an empty map will be returned. Any reference to an unknown field will cause an evaluation error and allocation to abort.
             *
             * A robust expression should check for the existence of attributes before referencing them.
             *
             * For ease of use, the cel.bind() function is enabled, and can be used to simplify expressions that access multiple attributes with the same domain. For example:
             *
             *     cel.bind(dra, device.attributes["dra.example.com"], dra.someBool && dra.anotherBool)
             *
             * The length of the expression must be smaller or equal to 10 Ki. The cost of evaluating it is also limited based on the estimated number of logical steps.
             */
            expression?: pulumi.Input<string>;
        }
        /**
         * Counter describes a quantity associated with a device.
         */
        interface Counter {
            /**
             * Value defines how much of a certain device counter is available.
             */
            value: pulumi.Input<string>;
        }
        /**
         * CounterSet defines a named set of counters that are available to be used by devices defined in the ResourceSlice.
         *
         * The counters are not allocatable by themselves, but can be referenced by devices. When a device is allocated, the portion of counters it uses will no longer be available for use by other devices.
         */
        interface CounterSet {
            /**
             * Counters defines the set of counters for this CounterSet The name of each counter must be unique in that set and must be a DNS label.
             *
             * The maximum number of counters in all sets is 32.
             */
            counters: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta2.Counter>;
            }>;
            /**
             * Name defines the name of the counter set. It must be a DNS label.
             */
            name: pulumi.Input<string>;
        }
        /**
         * CounterSet defines a named set of counters that are available to be used by devices defined in the ResourceSlice.
         *
         * The counters are not allocatable by themselves, but can be referenced by devices. When a device is allocated, the portion of counters it uses will no longer be available for use by other devices.
         */
        interface CounterSetPatch {
            /**
             * Counters defines the set of counters for this CounterSet The name of each counter must be unique in that set and must be a DNS label.
             *
             * The maximum number of counters in all sets is 32.
             */
            counters?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta2.Counter>;
            }>;
            /**
             * Name defines the name of the counter set. It must be a DNS label.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * Device represents one individual hardware instance that can be selected based on its attributes. Besides the name, exactly one field must be set.
         */
        interface Device {
            /**
             * AllNodes indicates that all nodes have access to the device.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            allNodes?: pulumi.Input<boolean>;
            /**
             * Attributes defines the set of attributes for this device. The name of each attribute must be unique in that set.
             *
             * The maximum number of attributes and capacities combined is 32.
             */
            attributes?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta2.DeviceAttribute>;
            }>;
            /**
             * Capacity defines the set of capacities for this device. The name of each capacity must be unique in that set.
             *
             * The maximum number of attributes and capacities combined is 32.
             */
            capacity?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta2.DeviceCapacity>;
            }>;
            /**
             * ConsumesCounters defines a list of references to sharedCounters and the set of counters that the device will consume from those counter sets.
             *
             * There can only be a single entry per counterSet.
             *
             * The total number of device counter consumption entries must be <= 32. In addition, the total number in the entire ResourceSlice must be <= 1024 (for example, 64 devices with 16 counters each).
             */
            consumesCounters?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceCounterConsumption>[]>;
            /**
             * Name is unique identifier among all devices managed by the driver in the pool. It must be a DNS label.
             */
            name: pulumi.Input<string>;
            /**
             * NodeName identifies the node where the device is available.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * NodeSelector defines the nodes where the device is available.
             *
             * Must use exactly one term.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelector>;
            /**
             * If specified, these are the driver-defined taints.
             *
             * The maximum number of taints is 4.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            taints?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceTaint>[]>;
        }
        /**
         * DeviceAllocationConfiguration gets embedded in an AllocationResult.
         */
        interface DeviceAllocationConfiguration {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1beta2.OpaqueDeviceConfiguration>;
            /**
             * Requests lists the names of requests where the configuration applies. If empty, its applies to all requests.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the configuration applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Source records whether the configuration comes from a class and thus is not something that a normal user would have been able to set or from a claim.
             */
            source: pulumi.Input<string>;
        }
        /**
         * DeviceAllocationResult is the result of allocating devices.
         */
        interface DeviceAllocationResult {
            /**
             * This field is a combination of all the claim and class configuration parameters. Drivers can distinguish between those based on a flag.
             *
             * This includes configuration parameters for drivers which have no allocated devices in the result because it is up to the drivers which configuration parameters they support. They can silently ignore unknown configuration parameters.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceAllocationConfiguration>[]>;
            /**
             * Results lists all allocated devices.
             */
            results?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceRequestAllocationResult>[]>;
        }
        /**
         * DeviceAttribute must have exactly one field set.
         */
        interface DeviceAttribute {
            /**
             * BoolValue is a true/false value.
             */
            bool?: pulumi.Input<boolean>;
            /**
             * IntValue is a number.
             */
            int?: pulumi.Input<number>;
            /**
             * StringValue is a string. Must not be longer than 64 characters.
             */
            string?: pulumi.Input<string>;
            /**
             * VersionValue is a semantic version according to semver.org spec 2.0.0. Must not be longer than 64 characters.
             */
            version?: pulumi.Input<string>;
        }
        /**
         * DeviceCapacity describes a quantity associated with a device.
         */
        interface DeviceCapacity {
            /**
             * Value defines how much of a certain device capacity is available.
             */
            value: pulumi.Input<string>;
        }
        /**
         * DeviceClaim defines how to request devices with a ResourceClaim.
         */
        interface DeviceClaim {
            /**
             * This field holds configuration for multiple potential drivers which could satisfy requests in this claim. It is ignored while allocating the claim.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceClaimConfiguration>[]>;
            /**
             * These constraints must be satisfied by the set of devices that get allocated for the claim.
             */
            constraints?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceConstraint>[]>;
            /**
             * Requests represent individual requests for distinct devices which must all be satisfied. If empty, nothing needs to be allocated.
             */
            requests?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceRequest>[]>;
        }
        /**
         * DeviceClaimConfiguration is used for configuration parameters in DeviceClaim.
         */
        interface DeviceClaimConfiguration {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1beta2.OpaqueDeviceConfiguration>;
            /**
             * Requests lists the names of requests where the configuration applies. If empty, it applies to all requests.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the configuration applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * DeviceClaimConfiguration is used for configuration parameters in DeviceClaim.
         */
        interface DeviceClaimConfigurationPatch {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1beta2.OpaqueDeviceConfigurationPatch>;
            /**
             * Requests lists the names of requests where the configuration applies. If empty, it applies to all requests.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the configuration applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * DeviceClaim defines how to request devices with a ResourceClaim.
         */
        interface DeviceClaimPatch {
            /**
             * This field holds configuration for multiple potential drivers which could satisfy requests in this claim. It is ignored while allocating the claim.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceClaimConfigurationPatch>[]>;
            /**
             * These constraints must be satisfied by the set of devices that get allocated for the claim.
             */
            constraints?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceConstraintPatch>[]>;
            /**
             * Requests represent individual requests for distinct devices which must all be satisfied. If empty, nothing needs to be allocated.
             */
            requests?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceRequestPatch>[]>;
        }
        /**
         * DeviceClass is a vendor- or admin-provided resource that contains device configuration and selectors. It can be referenced in the device requests of a claim to apply these presets. Cluster scoped.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface DeviceClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1beta2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"DeviceClass">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec defines what can be allocated and how to configure it.
             *
             * This is mutable. Consumers have to be prepared for classes changing at any time, either because they get updated or replaced. Claim allocations are done once based on whatever was set in classes at the time of allocation.
             *
             * Changing the spec automatically increments the metadata.generation number.
             */
            spec: pulumi.Input<inputs.resource.v1beta2.DeviceClassSpec>;
        }
        /**
         * DeviceClassConfiguration is used in DeviceClass.
         */
        interface DeviceClassConfiguration {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1beta2.OpaqueDeviceConfiguration>;
        }
        /**
         * DeviceClassConfiguration is used in DeviceClass.
         */
        interface DeviceClassConfigurationPatch {
            /**
             * Opaque provides driver-specific configuration parameters.
             */
            opaque?: pulumi.Input<inputs.resource.v1beta2.OpaqueDeviceConfigurationPatch>;
        }
        /**
         * DeviceClassSpec is used in a [DeviceClass] to define what can be allocated and how to configure it.
         */
        interface DeviceClassSpec {
            /**
             * Config defines configuration parameters that apply to each device that is claimed via this class. Some classses may potentially be satisfied by multiple drivers, so each instance of a vendor configuration applies to exactly one driver.
             *
             * They are passed to the driver, but are not considered while allocating the claim.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceClassConfiguration>[]>;
            /**
             * Each selector must be satisfied by a device which is claimed via this class.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceSelector>[]>;
        }
        /**
         * DeviceClassSpec is used in a [DeviceClass] to define what can be allocated and how to configure it.
         */
        interface DeviceClassSpecPatch {
            /**
             * Config defines configuration parameters that apply to each device that is claimed via this class. Some classses may potentially be satisfied by multiple drivers, so each instance of a vendor configuration applies to exactly one driver.
             *
             * They are passed to the driver, but are not considered while allocating the claim.
             */
            config?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceClassConfigurationPatch>[]>;
            /**
             * Each selector must be satisfied by a device which is claimed via this class.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceSelectorPatch>[]>;
        }
        /**
         * DeviceConstraint must have exactly one field set besides Requests.
         */
        interface DeviceConstraint {
            /**
             * MatchAttribute requires that all devices in question have this attribute and that its type and value are the same across those devices.
             *
             * For example, if you specified "dra.example.com/numa" (a hypothetical example!), then only devices in the same NUMA node will be chosen. A device which does not have that attribute will not be chosen. All devices should use a value of the same type for this attribute because that is part of its specification, but if one device doesn't, then it also will not be chosen.
             *
             * Must include the domain qualifier.
             */
            matchAttribute?: pulumi.Input<string>;
            /**
             * Requests is a list of the one or more requests in this claim which must co-satisfy this constraint. If a request is fulfilled by multiple devices, then all of the devices must satisfy the constraint. If this is not specified, this constraint applies to all requests in this claim.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the constraint applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * DeviceConstraint must have exactly one field set besides Requests.
         */
        interface DeviceConstraintPatch {
            /**
             * MatchAttribute requires that all devices in question have this attribute and that its type and value are the same across those devices.
             *
             * For example, if you specified "dra.example.com/numa" (a hypothetical example!), then only devices in the same NUMA node will be chosen. A device which does not have that attribute will not be chosen. All devices should use a value of the same type for this attribute because that is part of its specification, but if one device doesn't, then it also will not be chosen.
             *
             * Must include the domain qualifier.
             */
            matchAttribute?: pulumi.Input<string>;
            /**
             * Requests is a list of the one or more requests in this claim which must co-satisfy this constraint. If a request is fulfilled by multiple devices, then all of the devices must satisfy the constraint. If this is not specified, this constraint applies to all requests in this claim.
             *
             * References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the constraint applies to all subrequests.
             */
            requests?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * DeviceCounterConsumption defines a set of counters that a device will consume from a CounterSet.
         */
        interface DeviceCounterConsumption {
            /**
             * CounterSet is the name of the set from which the counters defined will be consumed.
             */
            counterSet: pulumi.Input<string>;
            /**
             * Counters defines the counters that will be consumed by the device.
             *
             * The maximum number counters in a device is 32. In addition, the maximum number of all counters in all devices is 1024 (for example, 64 devices with 16 counters each).
             */
            counters: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta2.Counter>;
            }>;
        }
        /**
         * DeviceCounterConsumption defines a set of counters that a device will consume from a CounterSet.
         */
        interface DeviceCounterConsumptionPatch {
            /**
             * CounterSet is the name of the set from which the counters defined will be consumed.
             */
            counterSet?: pulumi.Input<string>;
            /**
             * Counters defines the counters that will be consumed by the device.
             *
             * The maximum number counters in a device is 32. In addition, the maximum number of all counters in all devices is 1024 (for example, 64 devices with 16 counters each).
             */
            counters?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta2.Counter>;
            }>;
        }
        /**
         * Device represents one individual hardware instance that can be selected based on its attributes. Besides the name, exactly one field must be set.
         */
        interface DevicePatch {
            /**
             * AllNodes indicates that all nodes have access to the device.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            allNodes?: pulumi.Input<boolean>;
            /**
             * Attributes defines the set of attributes for this device. The name of each attribute must be unique in that set.
             *
             * The maximum number of attributes and capacities combined is 32.
             */
            attributes?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta2.DeviceAttribute>;
            }>;
            /**
             * Capacity defines the set of capacities for this device. The name of each capacity must be unique in that set.
             *
             * The maximum number of attributes and capacities combined is 32.
             */
            capacity?: pulumi.Input<{
                [key: string]: pulumi.Input<inputs.resource.v1beta2.DeviceCapacity>;
            }>;
            /**
             * ConsumesCounters defines a list of references to sharedCounters and the set of counters that the device will consume from those counter sets.
             *
             * There can only be a single entry per counterSet.
             *
             * The total number of device counter consumption entries must be <= 32. In addition, the total number in the entire ResourceSlice must be <= 1024 (for example, 64 devices with 16 counters each).
             */
            consumesCounters?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceCounterConsumptionPatch>[]>;
            /**
             * Name is unique identifier among all devices managed by the driver in the pool. It must be a DNS label.
             */
            name?: pulumi.Input<string>;
            /**
             * NodeName identifies the node where the device is available.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * NodeSelector defines the nodes where the device is available.
             *
             * Must use exactly one term.
             *
             * Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelectorPatch>;
            /**
             * If specified, these are the driver-defined taints.
             *
             * The maximum number of taints is 4.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            taints?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceTaintPatch>[]>;
        }
        /**
         * DeviceRequest is a request for devices required for a claim. This is typically a request for a single resource like a device, but can also ask for several identical devices. With FirstAvailable it is also possible to provide a prioritized list of requests.
         */
        interface DeviceRequest {
            /**
             * Exactly specifies the details for a single request that must be met exactly for the request to be satisfied.
             *
             * One of Exactly or FirstAvailable must be set.
             */
            exactly?: pulumi.Input<inputs.resource.v1beta2.ExactDeviceRequest>;
            /**
             * FirstAvailable contains subrequests, of which exactly one will be selected by the scheduler. It tries to satisfy them in the order in which they are listed here. So if there are two entries in the list, the scheduler will only check the second one if it determines that the first one can not be used.
             *
             * DRA does not yet implement scoring, so the scheduler will select the first set of devices that satisfies all the requests in the claim. And if the requirements can be satisfied on more than one node, other scheduling features will determine which node is chosen. This means that the set of devices allocated to a claim might not be the optimal set available to the cluster. Scoring will be implemented later.
             */
            firstAvailable?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceSubRequest>[]>;
            /**
             * Name can be used to reference this request in a pod.spec.containers[].resources.claims entry and in a constraint of the claim.
             *
             * References using the name in the DeviceRequest will uniquely identify a request when the Exactly field is set. When the FirstAvailable field is set, a reference to the name of the DeviceRequest will match whatever subrequest is chosen by the scheduler.
             *
             * Must be a DNS label.
             */
            name: pulumi.Input<string>;
        }
        /**
         * DeviceRequestAllocationResult contains the allocation result for one request.
         */
        interface DeviceRequestAllocationResult {
            /**
             * AdminAccess indicates that this device was allocated for administrative access. See the corresponding request field for a definition of mode.
             *
             * This is an alpha field and requires enabling the DRAAdminAccess feature gate. Admin access is disabled if this field is unset or set to false, otherwise it is enabled.
             */
            adminAccess?: pulumi.Input<boolean>;
            /**
             * Device references one device instance via its name in the driver's resource pool. It must be a DNS label.
             */
            device: pulumi.Input<string>;
            /**
             * Driver specifies the name of the DRA driver whose kubelet plugin should be invoked to process the allocation once the claim is needed on a node.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver.
             */
            driver: pulumi.Input<string>;
            /**
             * This name together with the driver name and the device name field identify which device was allocated (`<driver name>/<pool name>/<device name>`).
             *
             * Must not be longer than 253 characters and may contain one or more DNS sub-domains separated by slashes.
             */
            pool: pulumi.Input<string>;
            /**
             * Request is the name of the request in the claim which caused this device to be allocated. If it references a subrequest in the firstAvailable list on a DeviceRequest, this field must include both the name of the main request and the subrequest using the format <main request>/<subrequest>.
             *
             * Multiple devices may have been allocated per request.
             */
            request: pulumi.Input<string>;
            /**
             * A copy of all tolerations specified in the request at the time when the device got allocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceToleration>[]>;
        }
        /**
         * DeviceRequest is a request for devices required for a claim. This is typically a request for a single resource like a device, but can also ask for several identical devices. With FirstAvailable it is also possible to provide a prioritized list of requests.
         */
        interface DeviceRequestPatch {
            /**
             * Exactly specifies the details for a single request that must be met exactly for the request to be satisfied.
             *
             * One of Exactly or FirstAvailable must be set.
             */
            exactly?: pulumi.Input<inputs.resource.v1beta2.ExactDeviceRequestPatch>;
            /**
             * FirstAvailable contains subrequests, of which exactly one will be selected by the scheduler. It tries to satisfy them in the order in which they are listed here. So if there are two entries in the list, the scheduler will only check the second one if it determines that the first one can not be used.
             *
             * DRA does not yet implement scoring, so the scheduler will select the first set of devices that satisfies all the requests in the claim. And if the requirements can be satisfied on more than one node, other scheduling features will determine which node is chosen. This means that the set of devices allocated to a claim might not be the optimal set available to the cluster. Scoring will be implemented later.
             */
            firstAvailable?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceSubRequestPatch>[]>;
            /**
             * Name can be used to reference this request in a pod.spec.containers[].resources.claims entry and in a constraint of the claim.
             *
             * References using the name in the DeviceRequest will uniquely identify a request when the Exactly field is set. When the FirstAvailable field is set, a reference to the name of the DeviceRequest will match whatever subrequest is chosen by the scheduler.
             *
             * Must be a DNS label.
             */
            name?: pulumi.Input<string>;
        }
        /**
         * DeviceSelector must have exactly one field set.
         */
        interface DeviceSelector {
            /**
             * CEL contains a CEL expression for selecting a device.
             */
            cel?: pulumi.Input<inputs.resource.v1beta2.CELDeviceSelector>;
        }
        /**
         * DeviceSelector must have exactly one field set.
         */
        interface DeviceSelectorPatch {
            /**
             * CEL contains a CEL expression for selecting a device.
             */
            cel?: pulumi.Input<inputs.resource.v1beta2.CELDeviceSelectorPatch>;
        }
        /**
         * DeviceSubRequest describes a request for device provided in the claim.spec.devices.requests[].firstAvailable array. Each is typically a request for a single resource like a device, but can also ask for several identical devices.
         *
         * DeviceSubRequest is similar to ExactDeviceRequest, but doesn't expose the AdminAccess field as that one is only supported when requesting a specific device.
         */
        interface DeviceSubRequest {
            /**
             * AllocationMode and its related fields define how devices are allocated to satisfy this subrequest. Supported values are:
             *
             * - ExactCount: This request is for a specific number of devices.
             *   This is the default. The exact number is provided in the
             *   count field.
             *
             * - All: This subrequest is for all of the matching devices in a pool.
             *   Allocation will fail if some devices are already allocated,
             *   unless adminAccess is requested.
             *
             * If AllocationMode is not specified, the default mode is ExactCount. If the mode is ExactCount and count is not specified, the default count is one. Any other subrequests must specify this field.
             *
             * More modes may get added in the future. Clients must refuse to handle requests with unknown modes.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * Count is used only when the count mode is "ExactCount". Must be greater than zero. If AllocationMode is ExactCount and this field is not specified, the default is one.
             */
            count?: pulumi.Input<number>;
            /**
             * DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this subrequest.
             *
             * A class is required. Which classes are available depends on the cluster.
             *
             * Administrators may use this to restrict which devices may get requested by only installing classes with selectors for permitted devices. If users are free to request anything without restrictions, then administrators can create an empty DeviceClass for users to reference.
             */
            deviceClassName: pulumi.Input<string>;
            /**
             * Name can be used to reference this subrequest in the list of constraints or the list of configurations for the claim. References must use the format <main request>/<subrequest>.
             *
             * Must be a DNS label.
             */
            name: pulumi.Input<string>;
            /**
             * Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this subrequest. All selectors must be satisfied for a device to be considered.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceSelector>[]>;
            /**
             * If specified, the request's tolerations.
             *
             * Tolerations for NoSchedule are required to allocate a device which has a taint with that effect. The same applies to NoExecute.
             *
             * In addition, should any of the allocated devices get tainted with NoExecute after allocation and that effect is not tolerated, then all pods consuming the ResourceClaim get deleted to evict them. The scheduler will not let new pods reserve the claim while it has these tainted devices. Once all pods are evicted, the claim will get deallocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceToleration>[]>;
        }
        /**
         * DeviceSubRequest describes a request for device provided in the claim.spec.devices.requests[].firstAvailable array. Each is typically a request for a single resource like a device, but can also ask for several identical devices.
         *
         * DeviceSubRequest is similar to ExactDeviceRequest, but doesn't expose the AdminAccess field as that one is only supported when requesting a specific device.
         */
        interface DeviceSubRequestPatch {
            /**
             * AllocationMode and its related fields define how devices are allocated to satisfy this subrequest. Supported values are:
             *
             * - ExactCount: This request is for a specific number of devices.
             *   This is the default. The exact number is provided in the
             *   count field.
             *
             * - All: This subrequest is for all of the matching devices in a pool.
             *   Allocation will fail if some devices are already allocated,
             *   unless adminAccess is requested.
             *
             * If AllocationMode is not specified, the default mode is ExactCount. If the mode is ExactCount and count is not specified, the default count is one. Any other subrequests must specify this field.
             *
             * More modes may get added in the future. Clients must refuse to handle requests with unknown modes.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * Count is used only when the count mode is "ExactCount". Must be greater than zero. If AllocationMode is ExactCount and this field is not specified, the default is one.
             */
            count?: pulumi.Input<number>;
            /**
             * DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this subrequest.
             *
             * A class is required. Which classes are available depends on the cluster.
             *
             * Administrators may use this to restrict which devices may get requested by only installing classes with selectors for permitted devices. If users are free to request anything without restrictions, then administrators can create an empty DeviceClass for users to reference.
             */
            deviceClassName?: pulumi.Input<string>;
            /**
             * Name can be used to reference this subrequest in the list of constraints or the list of configurations for the claim. References must use the format <main request>/<subrequest>.
             *
             * Must be a DNS label.
             */
            name?: pulumi.Input<string>;
            /**
             * Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this subrequest. All selectors must be satisfied for a device to be considered.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceSelectorPatch>[]>;
            /**
             * If specified, the request's tolerations.
             *
             * Tolerations for NoSchedule are required to allocate a device which has a taint with that effect. The same applies to NoExecute.
             *
             * In addition, should any of the allocated devices get tainted with NoExecute after allocation and that effect is not tolerated, then all pods consuming the ResourceClaim get deleted to evict them. The scheduler will not let new pods reserve the claim while it has these tainted devices. Once all pods are evicted, the claim will get deallocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceTolerationPatch>[]>;
        }
        /**
         * The device this taint is attached to has the "effect" on any claim which does not tolerate the taint and, through the claim, to pods using the claim.
         */
        interface DeviceTaint {
            /**
             * The effect of the taint on claims that do not tolerate the taint and through such claims on the pods using them. Valid effects are NoSchedule and NoExecute. PreferNoSchedule as used for nodes is not valid here.
             */
            effect: pulumi.Input<string>;
            /**
             * The taint key to be applied to a device. Must be a label name.
             */
            key: pulumi.Input<string>;
            /**
             * TimeAdded represents the time at which the taint was added. Added automatically during create or update if not set.
             */
            timeAdded?: pulumi.Input<string>;
            /**
             * The taint value corresponding to the taint key. Must be a label value.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * The device this taint is attached to has the "effect" on any claim which does not tolerate the taint and, through the claim, to pods using the claim.
         */
        interface DeviceTaintPatch {
            /**
             * The effect of the taint on claims that do not tolerate the taint and through such claims on the pods using them. Valid effects are NoSchedule and NoExecute. PreferNoSchedule as used for nodes is not valid here.
             */
            effect?: pulumi.Input<string>;
            /**
             * The taint key to be applied to a device. Must be a label name.
             */
            key?: pulumi.Input<string>;
            /**
             * TimeAdded represents the time at which the taint was added. Added automatically during create or update if not set.
             */
            timeAdded?: pulumi.Input<string>;
            /**
             * The taint value corresponding to the taint key. Must be a label value.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * The ResourceClaim this DeviceToleration is attached to tolerates any taint that matches the triple <key,value,effect> using the matching operator <operator>.
         */
        interface DeviceToleration {
            /**
             * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule and NoExecute.
             */
            effect?: pulumi.Input<string>;
            /**
             * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys. Must be a label name.
             */
            key?: pulumi.Input<string>;
            /**
             * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a ResourceClaim can tolerate all taints of a particular category.
             */
            operator?: pulumi.Input<string>;
            /**
             * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system. If larger than zero, the time when the pod needs to be evicted is calculated as <time when taint was adedd> + <toleration seconds>.
             */
            tolerationSeconds?: pulumi.Input<number>;
            /**
             * Value is the taint value the toleration matches to. If the operator is Exists, the value must be empty, otherwise just a regular string. Must be a label value.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * The ResourceClaim this DeviceToleration is attached to tolerates any taint that matches the triple <key,value,effect> using the matching operator <operator>.
         */
        interface DeviceTolerationPatch {
            /**
             * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule and NoExecute.
             */
            effect?: pulumi.Input<string>;
            /**
             * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys. Must be a label name.
             */
            key?: pulumi.Input<string>;
            /**
             * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a ResourceClaim can tolerate all taints of a particular category.
             */
            operator?: pulumi.Input<string>;
            /**
             * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system. If larger than zero, the time when the pod needs to be evicted is calculated as <time when taint was adedd> + <toleration seconds>.
             */
            tolerationSeconds?: pulumi.Input<number>;
            /**
             * Value is the taint value the toleration matches to. If the operator is Exists, the value must be empty, otherwise just a regular string. Must be a label value.
             */
            value?: pulumi.Input<string>;
        }
        /**
         * ExactDeviceRequest is a request for one or more identical devices.
         */
        interface ExactDeviceRequest {
            /**
             * AdminAccess indicates that this is a claim for administrative access to the device(s). Claims with AdminAccess are expected to be used for monitoring or other management services for a device.  They ignore all ordinary claims to the device with respect to access modes and any resource allocations.
             *
             * This is an alpha field and requires enabling the DRAAdminAccess feature gate. Admin access is disabled if this field is unset or set to false, otherwise it is enabled.
             */
            adminAccess?: pulumi.Input<boolean>;
            /**
             * AllocationMode and its related fields define how devices are allocated to satisfy this request. Supported values are:
             *
             * - ExactCount: This request is for a specific number of devices.
             *   This is the default. The exact number is provided in the
             *   count field.
             *
             * - All: This request is for all of the matching devices in a pool.
             *   At least one device must exist on the node for the allocation to succeed.
             *   Allocation will fail if some devices are already allocated,
             *   unless adminAccess is requested.
             *
             * If AllocationMode is not specified, the default mode is ExactCount. If the mode is ExactCount and count is not specified, the default count is one. Any other requests must specify this field.
             *
             * More modes may get added in the future. Clients must refuse to handle requests with unknown modes.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * Count is used only when the count mode is "ExactCount". Must be greater than zero. If AllocationMode is ExactCount and this field is not specified, the default is one.
             */
            count?: pulumi.Input<number>;
            /**
             * DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this request.
             *
             * A DeviceClassName is required.
             *
             * Administrators may use this to restrict which devices may get requested by only installing classes with selectors for permitted devices. If users are free to request anything without restrictions, then administrators can create an empty DeviceClass for users to reference.
             */
            deviceClassName: pulumi.Input<string>;
            /**
             * Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this request. All selectors must be satisfied for a device to be considered.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceSelector>[]>;
            /**
             * If specified, the request's tolerations.
             *
             * Tolerations for NoSchedule are required to allocate a device which has a taint with that effect. The same applies to NoExecute.
             *
             * In addition, should any of the allocated devices get tainted with NoExecute after allocation and that effect is not tolerated, then all pods consuming the ResourceClaim get deleted to evict them. The scheduler will not let new pods reserve the claim while it has these tainted devices. Once all pods are evicted, the claim will get deallocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceToleration>[]>;
        }
        /**
         * ExactDeviceRequest is a request for one or more identical devices.
         */
        interface ExactDeviceRequestPatch {
            /**
             * AdminAccess indicates that this is a claim for administrative access to the device(s). Claims with AdminAccess are expected to be used for monitoring or other management services for a device.  They ignore all ordinary claims to the device with respect to access modes and any resource allocations.
             *
             * This is an alpha field and requires enabling the DRAAdminAccess feature gate. Admin access is disabled if this field is unset or set to false, otherwise it is enabled.
             */
            adminAccess?: pulumi.Input<boolean>;
            /**
             * AllocationMode and its related fields define how devices are allocated to satisfy this request. Supported values are:
             *
             * - ExactCount: This request is for a specific number of devices.
             *   This is the default. The exact number is provided in the
             *   count field.
             *
             * - All: This request is for all of the matching devices in a pool.
             *   At least one device must exist on the node for the allocation to succeed.
             *   Allocation will fail if some devices are already allocated,
             *   unless adminAccess is requested.
             *
             * If AllocationMode is not specified, the default mode is ExactCount. If the mode is ExactCount and count is not specified, the default count is one. Any other requests must specify this field.
             *
             * More modes may get added in the future. Clients must refuse to handle requests with unknown modes.
             */
            allocationMode?: pulumi.Input<string>;
            /**
             * Count is used only when the count mode is "ExactCount". Must be greater than zero. If AllocationMode is ExactCount and this field is not specified, the default is one.
             */
            count?: pulumi.Input<number>;
            /**
             * DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this request.
             *
             * A DeviceClassName is required.
             *
             * Administrators may use this to restrict which devices may get requested by only installing classes with selectors for permitted devices. If users are free to request anything without restrictions, then administrators can create an empty DeviceClass for users to reference.
             */
            deviceClassName?: pulumi.Input<string>;
            /**
             * Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this request. All selectors must be satisfied for a device to be considered.
             */
            selectors?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceSelectorPatch>[]>;
            /**
             * If specified, the request's tolerations.
             *
             * Tolerations for NoSchedule are required to allocate a device which has a taint with that effect. The same applies to NoExecute.
             *
             * In addition, should any of the allocated devices get tainted with NoExecute after allocation and that effect is not tolerated, then all pods consuming the ResourceClaim get deleted to evict them. The scheduler will not let new pods reserve the claim while it has these tainted devices. Once all pods are evicted, the claim will get deallocated.
             *
             * The maximum number of tolerations is 16.
             *
             * This is an alpha field and requires enabling the DRADeviceTaints feature gate.
             */
            tolerations?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DeviceTolerationPatch>[]>;
        }
        /**
         * NetworkDeviceData provides network-related details for the allocated device. This information may be filled by drivers or other components to configure or identify the device within a network context.
         */
        interface NetworkDeviceData {
            /**
             * HardwareAddress represents the hardware address (e.g. MAC Address) of the device's network interface.
             *
             * Must not be longer than 128 characters.
             */
            hardwareAddress?: pulumi.Input<string>;
            /**
             * InterfaceName specifies the name of the network interface associated with the allocated device. This might be the name of a physical or virtual network interface being configured in the pod.
             *
             * Must not be longer than 256 characters.
             */
            interfaceName?: pulumi.Input<string>;
            /**
             * IPs lists the network addresses assigned to the device's network interface. This can include both IPv4 and IPv6 addresses. The IPs are in the CIDR notation, which includes both the address and the associated subnet mask. e.g.: "192.0.2.5/24" for IPv4 and "2001:db8::5/64" for IPv6.
             */
            ips?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * OpaqueDeviceConfiguration contains configuration parameters for a driver in a format defined by the driver vendor.
         */
        interface OpaqueDeviceConfiguration {
            /**
             * Driver is used to determine which kubelet plugin needs to be passed these configuration parameters.
             *
             * An admission policy provided by the driver developer could use this to decide whether it needs to validate them.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver.
             */
            driver: pulumi.Input<string>;
            /**
             * Parameters can contain arbitrary data. It is the responsibility of the driver developer to handle validation and versioning. Typically this includes self-identification and a version ("kind" + "apiVersion" for Kubernetes types), with conversion between different versions.
             *
             * The length of the raw data must be smaller or equal to 10 Ki.
             */
            parameters: any;
        }
        /**
         * OpaqueDeviceConfiguration contains configuration parameters for a driver in a format defined by the driver vendor.
         */
        interface OpaqueDeviceConfigurationPatch {
            /**
             * Driver is used to determine which kubelet plugin needs to be passed these configuration parameters.
             *
             * An admission policy provided by the driver developer could use this to decide whether it needs to validate them.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver.
             */
            driver?: pulumi.Input<string>;
            /**
             * Parameters can contain arbitrary data. It is the responsibility of the driver developer to handle validation and versioning. Typically this includes self-identification and a version ("kind" + "apiVersion" for Kubernetes types), with conversion between different versions.
             *
             * The length of the raw data must be smaller or equal to 10 Ki.
             */
            parameters?: any;
        }
        /**
         * ResourceClaim describes a request for access to resources in the cluster, for use by workloads. For example, if a workload needs an accelerator device with specific properties, this is how that request is expressed. The status stanza tracks whether this claim has been satisfied and what specific resources have been allocated.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface ResourceClaim {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1beta2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceClaim">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec describes what is being requested and how to configure it. The spec is immutable.
             */
            spec: pulumi.Input<inputs.resource.v1beta2.ResourceClaimSpec>;
            /**
             * Status describes whether the claim is ready to use and what has been allocated.
             */
            status?: pulumi.Input<inputs.resource.v1beta2.ResourceClaimStatus>;
        }
        /**
         * ResourceClaimConsumerReference contains enough information to let you locate the consumer of a ResourceClaim. The user must be a resource in the same namespace as the ResourceClaim.
         */
        interface ResourceClaimConsumerReference {
            /**
             * APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources.
             */
            apiGroup?: pulumi.Input<string>;
            /**
             * Name is the name of resource being referenced.
             */
            name: pulumi.Input<string>;
            /**
             * Resource is the type of resource being referenced, for example "pods".
             */
            resource: pulumi.Input<string>;
            /**
             * UID identifies exactly one incarnation of the resource.
             */
            uid: pulumi.Input<string>;
        }
        /**
         * ResourceClaimSpec defines what is being requested in a ResourceClaim and how to configure it.
         */
        interface ResourceClaimSpec {
            /**
             * Devices defines how to request devices.
             */
            devices?: pulumi.Input<inputs.resource.v1beta2.DeviceClaim>;
        }
        /**
         * ResourceClaimSpec defines what is being requested in a ResourceClaim and how to configure it.
         */
        interface ResourceClaimSpecPatch {
            /**
             * Devices defines how to request devices.
             */
            devices?: pulumi.Input<inputs.resource.v1beta2.DeviceClaimPatch>;
        }
        /**
         * ResourceClaimStatus tracks whether the resource has been allocated and what the result of that was.
         */
        interface ResourceClaimStatus {
            /**
             * Allocation is set once the claim has been allocated successfully.
             */
            allocation?: pulumi.Input<inputs.resource.v1beta2.AllocationResult>;
            /**
             * Devices contains the status of each device allocated for this claim, as reported by the driver. This can include driver-specific information. Entries are owned by their respective drivers.
             */
            devices?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.AllocatedDeviceStatus>[]>;
            /**
             * ReservedFor indicates which entities are currently allowed to use the claim. A Pod which references a ResourceClaim which is not reserved for that Pod will not be started. A claim that is in use or might be in use because it has been reserved must not get deallocated.
             *
             * In a cluster with multiple scheduler instances, two pods might get scheduled concurrently by different schedulers. When they reference the same ResourceClaim which already has reached its maximum number of consumers, only one pod can be scheduled.
             *
             * Both schedulers try to add their pod to the claim.status.reservedFor field, but only the update that reaches the API server first gets stored. The other one fails with an error and the scheduler which issued it knows that it must put the pod back into the queue, waiting for the ResourceClaim to become usable again.
             *
             * There can be at most 256 such reservations. This may get increased in the future, but not reduced.
             */
            reservedFor?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.ResourceClaimConsumerReference>[]>;
        }
        /**
         * ResourceClaimTemplate is used to produce ResourceClaim objects.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface ResourceClaimTemplate {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1beta2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceClaimTemplate">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Describes the ResourceClaim that is to be generated.
             *
             * This field is immutable. A ResourceClaim will get created by the control plane for a Pod when needed and then not get updated anymore.
             */
            spec: pulumi.Input<inputs.resource.v1beta2.ResourceClaimTemplateSpec>;
        }
        /**
         * ResourceClaimTemplateSpec contains the metadata and fields for a ResourceClaim.
         */
        interface ResourceClaimTemplateSpec {
            /**
             * ObjectMeta may contain labels and annotations that will be copied into the ResourceClaim when creating it. No other fields are allowed and will be rejected during validation.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Spec for the ResourceClaim. The entire content is copied unchanged into the ResourceClaim that gets created from this template. The same fields as in a ResourceClaim are also valid here.
             */
            spec: pulumi.Input<inputs.resource.v1beta2.ResourceClaimSpec>;
        }
        /**
         * ResourceClaimTemplateSpec contains the metadata and fields for a ResourceClaim.
         */
        interface ResourceClaimTemplateSpecPatch {
            /**
             * ObjectMeta may contain labels and annotations that will be copied into the ResourceClaim when creating it. No other fields are allowed and will be rejected during validation.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMetaPatch>;
            /**
             * Spec for the ResourceClaim. The entire content is copied unchanged into the ResourceClaim that gets created from this template. The same fields as in a ResourceClaim are also valid here.
             */
            spec?: pulumi.Input<inputs.resource.v1beta2.ResourceClaimSpecPatch>;
        }
        /**
         * ResourcePool describes the pool that ResourceSlices belong to.
         */
        interface ResourcePool {
            /**
             * Generation tracks the change in a pool over time. Whenever a driver changes something about one or more of the resources in a pool, it must change the generation in all ResourceSlices which are part of that pool. Consumers of ResourceSlices should only consider resources from the pool with the highest generation number. The generation may be reset by drivers, which should be fine for consumers, assuming that all ResourceSlices in a pool are updated to match or deleted.
             *
             * Combined with ResourceSliceCount, this mechanism enables consumers to detect pools which are comprised of multiple ResourceSlices and are in an incomplete state.
             */
            generation: pulumi.Input<number>;
            /**
             * Name is used to identify the pool. For node-local devices, this is often the node name, but this is not required.
             *
             * It must not be longer than 253 characters and must consist of one or more DNS sub-domains separated by slashes. This field is immutable.
             */
            name: pulumi.Input<string>;
            /**
             * ResourceSliceCount is the total number of ResourceSlices in the pool at this generation number. Must be greater than zero.
             *
             * Consumers can use this to check whether they have seen all ResourceSlices belonging to the same pool.
             */
            resourceSliceCount: pulumi.Input<number>;
        }
        /**
         * ResourcePool describes the pool that ResourceSlices belong to.
         */
        interface ResourcePoolPatch {
            /**
             * Generation tracks the change in a pool over time. Whenever a driver changes something about one or more of the resources in a pool, it must change the generation in all ResourceSlices which are part of that pool. Consumers of ResourceSlices should only consider resources from the pool with the highest generation number. The generation may be reset by drivers, which should be fine for consumers, assuming that all ResourceSlices in a pool are updated to match or deleted.
             *
             * Combined with ResourceSliceCount, this mechanism enables consumers to detect pools which are comprised of multiple ResourceSlices and are in an incomplete state.
             */
            generation?: pulumi.Input<number>;
            /**
             * Name is used to identify the pool. For node-local devices, this is often the node name, but this is not required.
             *
             * It must not be longer than 253 characters and must consist of one or more DNS sub-domains separated by slashes. This field is immutable.
             */
            name?: pulumi.Input<string>;
            /**
             * ResourceSliceCount is the total number of ResourceSlices in the pool at this generation number. Must be greater than zero.
             *
             * Consumers can use this to check whether they have seen all ResourceSlices belonging to the same pool.
             */
            resourceSliceCount?: pulumi.Input<number>;
        }
        /**
         * ResourceSlice represents one or more resources in a pool of similar resources, managed by a common driver. A pool may span more than one ResourceSlice, and exactly how many ResourceSlices comprise a pool is determined by the driver.
         *
         * At the moment, the only supported resources are devices with attributes and capacities. Each device in a given pool, regardless of how many ResourceSlices, must have a unique name. The ResourceSlice in which a device gets published may change over time. The unique identifier for a device is the tuple <driver name>, <pool name>, <device name>.
         *
         * Whenever a driver needs to update a pool, it increments the pool.Spec.Pool.Generation number and updates all ResourceSlices with that new number and new resource definitions. A consumer must only use ResourceSlices with the highest generation number and ignore all others.
         *
         * When allocating all resources in a pool matching certain criteria or when looking for the best solution among several different alternatives, a consumer should check the number of ResourceSlices in a pool (included in each ResourceSlice) to determine whether its view of a pool is complete and if not, should wait until the driver has completed updating the pool.
         *
         * For resources that are not local to a node, the node name is not set. Instead, the driver may use a node selector to specify where the devices are available.
         *
         * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
         */
        interface ResourceSlice {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"resource.k8s.io/v1beta2">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"ResourceSlice">;
            /**
             * Standard object metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Contains the information published by the driver.
             *
             * Changing the spec automatically increments the metadata.generation number.
             */
            spec: pulumi.Input<inputs.resource.v1beta2.ResourceSliceSpec>;
        }
        /**
         * ResourceSliceSpec contains the information published by the driver in one ResourceSlice.
         */
        interface ResourceSliceSpec {
            /**
             * AllNodes indicates that all nodes have access to the resources in the pool.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            allNodes?: pulumi.Input<boolean>;
            /**
             * Devices lists some or all of the devices in this pool.
             *
             * Must not have more than 128 entries.
             */
            devices?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.Device>[]>;
            /**
             * Driver identifies the DRA driver providing the capacity information. A field selector can be used to list only ResourceSlice objects with a certain driver name.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver. This field is immutable.
             */
            driver: pulumi.Input<string>;
            /**
             * NodeName identifies the node which provides the resources in this pool. A field selector can be used to list only ResourceSlice objects belonging to a certain node.
             *
             * This field can be used to limit access from nodes to ResourceSlices with the same node name. It also indicates to autoscalers that adding new nodes of the same type as some old node might also make new resources available.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set. This field is immutable.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * NodeSelector defines which nodes have access to the resources in the pool, when that pool is not limited to a single node.
             *
             * Must use exactly one term.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelector>;
            /**
             * PerDeviceNodeSelection defines whether the access from nodes to resources in the pool is set on the ResourceSlice level or on each device. If it is set to true, every device defined the ResourceSlice must specify this individually.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            perDeviceNodeSelection?: pulumi.Input<boolean>;
            /**
             * Pool describes the pool that this ResourceSlice belongs to.
             */
            pool: pulumi.Input<inputs.resource.v1beta2.ResourcePool>;
            /**
             * SharedCounters defines a list of counter sets, each of which has a name and a list of counters available.
             *
             * The names of the SharedCounters must be unique in the ResourceSlice.
             *
             * The maximum number of counters in all sets is 32.
             */
            sharedCounters?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.CounterSet>[]>;
        }
        /**
         * ResourceSliceSpec contains the information published by the driver in one ResourceSlice.
         */
        interface ResourceSliceSpecPatch {
            /**
             * AllNodes indicates that all nodes have access to the resources in the pool.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            allNodes?: pulumi.Input<boolean>;
            /**
             * Devices lists some or all of the devices in this pool.
             *
             * Must not have more than 128 entries.
             */
            devices?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.DevicePatch>[]>;
            /**
             * Driver identifies the DRA driver providing the capacity information. A field selector can be used to list only ResourceSlice objects with a certain driver name.
             *
             * Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver. This field is immutable.
             */
            driver?: pulumi.Input<string>;
            /**
             * NodeName identifies the node which provides the resources in this pool. A field selector can be used to list only ResourceSlice objects belonging to a certain node.
             *
             * This field can be used to limit access from nodes to ResourceSlices with the same node name. It also indicates to autoscalers that adding new nodes of the same type as some old node might also make new resources available.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set. This field is immutable.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * NodeSelector defines which nodes have access to the resources in the pool, when that pool is not limited to a single node.
             *
             * Must use exactly one term.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            nodeSelector?: pulumi.Input<inputs.core.v1.NodeSelectorPatch>;
            /**
             * PerDeviceNodeSelection defines whether the access from nodes to resources in the pool is set on the ResourceSlice level or on each device. If it is set to true, every device defined the ResourceSlice must specify this individually.
             *
             * Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
             */
            perDeviceNodeSelection?: pulumi.Input<boolean>;
            /**
             * Pool describes the pool that this ResourceSlice belongs to.
             */
            pool?: pulumi.Input<inputs.resource.v1beta2.ResourcePoolPatch>;
            /**
             * SharedCounters defines a list of counter sets, each of which has a name and a list of counters available.
             *
             * The names of the SharedCounters must be unique in the ResourceSlice.
             *
             * The maximum number of counters in all sets is 32.
             */
            sharedCounters?: pulumi.Input<pulumi.Input<inputs.resource.v1beta2.CounterSetPatch>[]>;
        }
    }
}
export declare namespace scheduling {
    namespace v1 {
        /**
         * PriorityClass defines mapping from a priority class name to the priority integer value. The value can be any valid integer.
         */
        interface PriorityClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"scheduling.k8s.io/v1">;
            /**
             * description is an arbitrary string that usually provides guidelines on when this priority class should be used.
             */
            description?: pulumi.Input<string>;
            /**
             * globalDefault specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class. Only one PriorityClass can be marked as `globalDefault`. However, if more than one PriorityClasses exists with their `globalDefault` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority.
             */
            globalDefault?: pulumi.Input<boolean>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PriorityClass">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * preemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset.
             */
            preemptionPolicy?: pulumi.Input<string>;
            /**
             * value represents the integer value of this priority class. This is the actual priority that pods receive when they have the name of this class in their pod spec.
             */
            value: pulumi.Input<number>;
        }
    }
    namespace v1alpha1 {
        /**
         * DEPRECATED - This group version of PriorityClass is deprecated by scheduling.k8s.io/v1/PriorityClass. PriorityClass defines mapping from a priority class name to the priority integer value. The value can be any valid integer.
         */
        interface PriorityClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"scheduling.k8s.io/v1alpha1">;
            /**
             * description is an arbitrary string that usually provides guidelines on when this priority class should be used.
             */
            description?: pulumi.Input<string>;
            /**
             * globalDefault specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class. Only one PriorityClass can be marked as `globalDefault`. However, if more than one PriorityClasses exists with their `globalDefault` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority.
             */
            globalDefault?: pulumi.Input<boolean>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PriorityClass">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * PreemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. This field is alpha-level and is only honored by servers that enable the NonPreemptingPriority feature.
             */
            preemptionPolicy?: pulumi.Input<string>;
            /**
             * The value of this priority class. This is the actual priority that pods receive when they have the name of this class in their pod spec.
             */
            value: pulumi.Input<number>;
        }
    }
    namespace v1beta1 {
        /**
         * DEPRECATED - This group version of PriorityClass is deprecated by scheduling.k8s.io/v1/PriorityClass. PriorityClass defines mapping from a priority class name to the priority integer value. The value can be any valid integer.
         */
        interface PriorityClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"scheduling.k8s.io/v1beta1">;
            /**
             * description is an arbitrary string that usually provides guidelines on when this priority class should be used.
             */
            description?: pulumi.Input<string>;
            /**
             * globalDefault specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class. Only one PriorityClass can be marked as `globalDefault`. However, if more than one PriorityClasses exists with their `globalDefault` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority.
             */
            globalDefault?: pulumi.Input<boolean>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PriorityClass">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * PreemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. This field is alpha-level and is only honored by servers that enable the NonPreemptingPriority feature.
             */
            preemptionPolicy?: pulumi.Input<string>;
            /**
             * The value of this priority class. This is the actual priority that pods receive when they have the name of this class in their pod spec.
             */
            value: pulumi.Input<number>;
        }
    }
}
export declare namespace settings {
    namespace v1alpha1 {
        /**
         * PodPreset is a policy resource that defines additional runtime requirements for a Pod.
         */
        interface PodPreset {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"settings.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"PodPreset">;
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            spec?: pulumi.Input<inputs.settings.v1alpha1.PodPresetSpec>;
        }
        /**
         * PodPresetSpec is a description of a pod preset.
         */
        interface PodPresetSpec {
            /**
             * Env defines the collection of EnvVar to inject into containers.
             */
            env?: pulumi.Input<pulumi.Input<inputs.core.v1.EnvVar>[]>;
            /**
             * EnvFrom defines the collection of EnvFromSource to inject into containers.
             */
            envFrom?: pulumi.Input<pulumi.Input<inputs.core.v1.EnvFromSource>[]>;
            /**
             * Selector is a label query over a set of resources, in this case pods. Required.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * VolumeMounts defines the collection of VolumeMount to inject into containers.
             */
            volumeMounts?: pulumi.Input<pulumi.Input<inputs.core.v1.VolumeMount>[]>;
            /**
             * Volumes defines the collection of Volume to inject into the pod.
             */
            volumes?: pulumi.Input<pulumi.Input<inputs.core.v1.Volume>[]>;
        }
        /**
         * PodPresetSpec is a description of a pod preset.
         */
        interface PodPresetSpecPatch {
            /**
             * Env defines the collection of EnvVar to inject into containers.
             */
            env?: pulumi.Input<pulumi.Input<inputs.core.v1.EnvVarPatch>[]>;
            /**
             * EnvFrom defines the collection of EnvFromSource to inject into containers.
             */
            envFrom?: pulumi.Input<pulumi.Input<inputs.core.v1.EnvFromSourcePatch>[]>;
            /**
             * Selector is a label query over a set of resources, in this case pods. Required.
             */
            selector?: pulumi.Input<inputs.meta.v1.LabelSelectorPatch>;
            /**
             * VolumeMounts defines the collection of VolumeMount to inject into containers.
             */
            volumeMounts?: pulumi.Input<pulumi.Input<inputs.core.v1.VolumeMountPatch>[]>;
            /**
             * Volumes defines the collection of Volume to inject into the pod.
             */
            volumes?: pulumi.Input<pulumi.Input<inputs.core.v1.VolumePatch>[]>;
        }
    }
}
export declare namespace storage {
    namespace v1 {
        /**
         * CSIDriver captures information about a Container Storage Interface (CSI) volume driver deployed on the cluster. Kubernetes attach detach controller uses this object to determine whether attach is required. Kubelet uses this object to determine whether pod information needs to be passed on mount. CSIDriver objects are non-namespaced.
         */
        interface CSIDriver {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"storage.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"CSIDriver">;
            /**
             * Standard object metadata. metadata.Name indicates the name of the CSI driver that this object refers to; it MUST be the same name returned by the CSI GetPluginName() call for that driver. The driver name must be 63 characters or less, beginning and ending with an alphanumeric character ([a-z0-9A-Z]) with dashes (-), dots (.), and alphanumerics between. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec represents the specification of the CSI Driver.
             */
            spec: pulumi.Input<inputs.storage.v1.CSIDriverSpec>;
        }
        /**
         * CSIDriverSpec is the specification of a CSIDriver.
         */
        interface CSIDriverSpec {
            /**
             * attachRequired indicates this CSI volume driver requires an attach operation (because it implements the CSI ControllerPublishVolume() method), and that the Kubernetes attach detach controller should call the attach volume interface which checks the volumeattachment status and waits until the volume is attached before proceeding to mounting. The CSI external-attacher coordinates with CSI volume driver and updates the volumeattachment status when the attach operation is complete. If the CSIDriverRegistry feature gate is enabled and the value is specified to false, the attach operation will be skipped. Otherwise the attach operation will be called.
             *
             * This field is immutable.
             */
            attachRequired?: pulumi.Input<boolean>;
            /**
             * fsGroupPolicy defines if the underlying volume supports changing ownership and permission of the volume before being mounted. Refer to the specific FSGroupPolicy values for additional details.
             *
             * This field was immutable in Kubernetes < 1.29 and now is mutable.
             *
             * Defaults to ReadWriteOnceWithFSType, which will examine each volume to determine if Kubernetes should modify ownership and permissions of the volume. With the default policy the defined fsGroup will only be applied if a fstype is defined and the volume's access mode contains ReadWriteOnce.
             */
            fsGroupPolicy?: pulumi.Input<string>;
            /**
             * nodeAllocatableUpdatePeriodSeconds specifies the interval between periodic updates of the CSINode allocatable capacity for this driver. When set, both periodic updates and updates triggered by capacity-related failures are enabled. If not set, no updates occur (neither periodic nor upon detecting capacity-related failures), and the allocatable.count remains static. The minimum allowed value for this field is 10 seconds.
             *
             * This is an alpha feature and requires the MutableCSINodeAllocatableCount feature gate to be enabled.
             *
             * This field is mutable.
             */
            nodeAllocatableUpdatePeriodSeconds?: pulumi.Input<number>;
            /**
             * podInfoOnMount indicates this CSI volume driver requires additional pod information (like podName, podUID, etc.) during mount operations, if set to true. If set to false, pod information will not be passed on mount. Default is false.
             *
             * The CSI driver specifies podInfoOnMount as part of driver deployment. If true, Kubelet will pass pod information as VolumeContext in the CSI NodePublishVolume() calls. The CSI driver is responsible for parsing and validating the information passed in as VolumeContext.
             *
             * The following VolumeContext will be passed if podInfoOnMount is set to true. This list might grow, but the prefix will be used. "csi.storage.k8s.io/pod.name": pod.Name "csi.storage.k8s.io/pod.namespace": pod.Namespace "csi.storage.k8s.io/pod.uid": string(pod.UID) "csi.storage.k8s.io/ephemeral": "true" if the volume is an ephemeral inline volume
             *                                 defined by a CSIVolumeSource, otherwise "false"
             *
             * "csi.storage.k8s.io/ephemeral" is a new feature in Kubernetes 1.16. It is only required for drivers which support both the "Persistent" and "Ephemeral" VolumeLifecycleMode. Other drivers can leave pod info disabled and/or ignore this field. As Kubernetes 1.15 doesn't support this field, drivers can only support one mode when deployed on such a cluster and the deployment determines which mode that is, for example via a command line parameter of the driver.
             *
             * This field was immutable in Kubernetes < 1.29 and now is mutable.
             */
            podInfoOnMount?: pulumi.Input<boolean>;
            /**
             * requiresRepublish indicates the CSI driver wants `NodePublishVolume` being periodically called to reflect any possible change in the mounted volume. This field defaults to false.
             *
             * Note: After a successful initial NodePublishVolume call, subsequent calls to NodePublishVolume should only update the contents of the volume. New mount points will not be seen by a running container.
             */
            requiresRepublish?: pulumi.Input<boolean>;
            /**
             * seLinuxMount specifies if the CSI driver supports "-o context" mount option.
             *
             * When "true", the CSI driver must ensure that all volumes provided by this CSI driver can be mounted separately with different `-o context` options. This is typical for storage backends that provide volumes as filesystems on block devices or as independent shared volumes. Kubernetes will call NodeStage / NodePublish with "-o context=xyz" mount option when mounting a ReadWriteOncePod volume used in Pod that has explicitly set SELinux context. In the future, it may be expanded to other volume AccessModes. In any case, Kubernetes will ensure that the volume is mounted only with a single SELinux context.
             *
             * When "false", Kubernetes won't pass any special SELinux mount options to the driver. This is typical for volumes that represent subdirectories of a bigger shared filesystem.
             *
             * Default is "false".
             */
            seLinuxMount?: pulumi.Input<boolean>;
            /**
             * storageCapacity indicates that the CSI volume driver wants pod scheduling to consider the storage capacity that the driver deployment will report by creating CSIStorageCapacity objects with capacity information, if set to true.
             *
             * The check can be enabled immediately when deploying a driver. In that case, provisioning new volumes with late binding will pause until the driver deployment has published some suitable CSIStorageCapacity object.
             *
             * Alternatively, the driver can be deployed with the field unset or false and it can be flipped later when storage capacity information has been published.
             *
             * This field was immutable in Kubernetes <= 1.22 and now is mutable.
             */
            storageCapacity?: pulumi.Input<boolean>;
            /**
             * tokenRequests indicates the CSI driver needs pods' service account tokens it is mounting volume for to do necessary authentication. Kubelet will pass the tokens in VolumeContext in the CSI NodePublishVolume calls. The CSI driver should parse and validate the following VolumeContext: "csi.storage.k8s.io/serviceAccount.tokens": {
             *   "<audience>": {
             *     "token": <token>,
             *     "expirationTimestamp": <expiration timestamp in RFC3339>,
             *   },
             *   ...
             * }
             *
             * Note: Audience in each TokenRequest should be different and at most one token is empty string. To receive a new token after expiry, RequiresRepublish can be used to trigger NodePublishVolume periodically.
             */
            tokenRequests?: pulumi.Input<pulumi.Input<inputs.storage.v1.TokenRequest>[]>;
            /**
             * volumeLifecycleModes defines what kind of volumes this CSI volume driver supports. The default if the list is empty is "Persistent", which is the usage defined by the CSI specification and implemented in Kubernetes via the usual PV/PVC mechanism.
             *
             * The other mode is "Ephemeral". In this mode, volumes are defined inline inside the pod spec with CSIVolumeSource and their lifecycle is tied to the lifecycle of that pod. A driver has to be aware of this because it is only going to get a NodePublishVolume call for such a volume.
             *
             * For more information about implementing this mode, see https://kubernetes-csi.github.io/docs/ephemeral-local-volumes.html A driver can support one or more of these modes and more modes may be added in the future.
             *
             * This field is beta. This field is immutable.
             */
            volumeLifecycleModes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * CSIDriverSpec is the specification of a CSIDriver.
         */
        interface CSIDriverSpecPatch {
            /**
             * attachRequired indicates this CSI volume driver requires an attach operation (because it implements the CSI ControllerPublishVolume() method), and that the Kubernetes attach detach controller should call the attach volume interface which checks the volumeattachment status and waits until the volume is attached before proceeding to mounting. The CSI external-attacher coordinates with CSI volume driver and updates the volumeattachment status when the attach operation is complete. If the CSIDriverRegistry feature gate is enabled and the value is specified to false, the attach operation will be skipped. Otherwise the attach operation will be called.
             *
             * This field is immutable.
             */
            attachRequired?: pulumi.Input<boolean>;
            /**
             * fsGroupPolicy defines if the underlying volume supports changing ownership and permission of the volume before being mounted. Refer to the specific FSGroupPolicy values for additional details.
             *
             * This field was immutable in Kubernetes < 1.29 and now is mutable.
             *
             * Defaults to ReadWriteOnceWithFSType, which will examine each volume to determine if Kubernetes should modify ownership and permissions of the volume. With the default policy the defined fsGroup will only be applied if a fstype is defined and the volume's access mode contains ReadWriteOnce.
             */
            fsGroupPolicy?: pulumi.Input<string>;
            /**
             * nodeAllocatableUpdatePeriodSeconds specifies the interval between periodic updates of the CSINode allocatable capacity for this driver. When set, both periodic updates and updates triggered by capacity-related failures are enabled. If not set, no updates occur (neither periodic nor upon detecting capacity-related failures), and the allocatable.count remains static. The minimum allowed value for this field is 10 seconds.
             *
             * This is an alpha feature and requires the MutableCSINodeAllocatableCount feature gate to be enabled.
             *
             * This field is mutable.
             */
            nodeAllocatableUpdatePeriodSeconds?: pulumi.Input<number>;
            /**
             * podInfoOnMount indicates this CSI volume driver requires additional pod information (like podName, podUID, etc.) during mount operations, if set to true. If set to false, pod information will not be passed on mount. Default is false.
             *
             * The CSI driver specifies podInfoOnMount as part of driver deployment. If true, Kubelet will pass pod information as VolumeContext in the CSI NodePublishVolume() calls. The CSI driver is responsible for parsing and validating the information passed in as VolumeContext.
             *
             * The following VolumeContext will be passed if podInfoOnMount is set to true. This list might grow, but the prefix will be used. "csi.storage.k8s.io/pod.name": pod.Name "csi.storage.k8s.io/pod.namespace": pod.Namespace "csi.storage.k8s.io/pod.uid": string(pod.UID) "csi.storage.k8s.io/ephemeral": "true" if the volume is an ephemeral inline volume
             *                                 defined by a CSIVolumeSource, otherwise "false"
             *
             * "csi.storage.k8s.io/ephemeral" is a new feature in Kubernetes 1.16. It is only required for drivers which support both the "Persistent" and "Ephemeral" VolumeLifecycleMode. Other drivers can leave pod info disabled and/or ignore this field. As Kubernetes 1.15 doesn't support this field, drivers can only support one mode when deployed on such a cluster and the deployment determines which mode that is, for example via a command line parameter of the driver.
             *
             * This field was immutable in Kubernetes < 1.29 and now is mutable.
             */
            podInfoOnMount?: pulumi.Input<boolean>;
            /**
             * requiresRepublish indicates the CSI driver wants `NodePublishVolume` being periodically called to reflect any possible change in the mounted volume. This field defaults to false.
             *
             * Note: After a successful initial NodePublishVolume call, subsequent calls to NodePublishVolume should only update the contents of the volume. New mount points will not be seen by a running container.
             */
            requiresRepublish?: pulumi.Input<boolean>;
            /**
             * seLinuxMount specifies if the CSI driver supports "-o context" mount option.
             *
             * When "true", the CSI driver must ensure that all volumes provided by this CSI driver can be mounted separately with different `-o context` options. This is typical for storage backends that provide volumes as filesystems on block devices or as independent shared volumes. Kubernetes will call NodeStage / NodePublish with "-o context=xyz" mount option when mounting a ReadWriteOncePod volume used in Pod that has explicitly set SELinux context. In the future, it may be expanded to other volume AccessModes. In any case, Kubernetes will ensure that the volume is mounted only with a single SELinux context.
             *
             * When "false", Kubernetes won't pass any special SELinux mount options to the driver. This is typical for volumes that represent subdirectories of a bigger shared filesystem.
             *
             * Default is "false".
             */
            seLinuxMount?: pulumi.Input<boolean>;
            /**
             * storageCapacity indicates that the CSI volume driver wants pod scheduling to consider the storage capacity that the driver deployment will report by creating CSIStorageCapacity objects with capacity information, if set to true.
             *
             * The check can be enabled immediately when deploying a driver. In that case, provisioning new volumes with late binding will pause until the driver deployment has published some suitable CSIStorageCapacity object.
             *
             * Alternatively, the driver can be deployed with the field unset or false and it can be flipped later when storage capacity information has been published.
             *
             * This field was immutable in Kubernetes <= 1.22 and now is mutable.
             */
            storageCapacity?: pulumi.Input<boolean>;
            /**
             * tokenRequests indicates the CSI driver needs pods' service account tokens it is mounting volume for to do necessary authentication. Kubelet will pass the tokens in VolumeContext in the CSI NodePublishVolume calls. The CSI driver should parse and validate the following VolumeContext: "csi.storage.k8s.io/serviceAccount.tokens": {
             *   "<audience>": {
             *     "token": <token>,
             *     "expirationTimestamp": <expiration timestamp in RFC3339>,
             *   },
             *   ...
             * }
             *
             * Note: Audience in each TokenRequest should be different and at most one token is empty string. To receive a new token after expiry, RequiresRepublish can be used to trigger NodePublishVolume periodically.
             */
            tokenRequests?: pulumi.Input<pulumi.Input<inputs.storage.v1.TokenRequestPatch>[]>;
            /**
             * volumeLifecycleModes defines what kind of volumes this CSI volume driver supports. The default if the list is empty is "Persistent", which is the usage defined by the CSI specification and implemented in Kubernetes via the usual PV/PVC mechanism.
             *
             * The other mode is "Ephemeral". In this mode, volumes are defined inline inside the pod spec with CSIVolumeSource and their lifecycle is tied to the lifecycle of that pod. A driver has to be aware of this because it is only going to get a NodePublishVolume call for such a volume.
             *
             * For more information about implementing this mode, see https://kubernetes-csi.github.io/docs/ephemeral-local-volumes.html A driver can support one or more of these modes and more modes may be added in the future.
             *
             * This field is beta. This field is immutable.
             */
            volumeLifecycleModes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * CSINode holds information about all CSI drivers installed on a node. CSI drivers do not need to create the CSINode object directly. As long as they use the node-driver-registrar sidecar container, the kubelet will automatically populate the CSINode object for the CSI driver as part of kubelet plugin registration. CSINode has the same name as a node. If the object is missing, it means either there are no CSI Drivers available on the node, or the Kubelet version is low enough that it doesn't create this object. CSINode has an OwnerReference that points to the corresponding node object.
         */
        interface CSINode {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"storage.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"CSINode">;
            /**
             * Standard object's metadata. metadata.name must be the Kubernetes node name.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec is the specification of CSINode
             */
            spec: pulumi.Input<inputs.storage.v1.CSINodeSpec>;
        }
        /**
         * CSINodeDriver holds information about the specification of one CSI driver installed on a node
         */
        interface CSINodeDriver {
            /**
             * allocatable represents the volume resources of a node that are available for scheduling. This field is beta.
             */
            allocatable?: pulumi.Input<inputs.storage.v1.VolumeNodeResources>;
            /**
             * name represents the name of the CSI driver that this object refers to. This MUST be the same name returned by the CSI GetPluginName() call for that driver.
             */
            name: pulumi.Input<string>;
            /**
             * nodeID of the node from the driver point of view. This field enables Kubernetes to communicate with storage systems that do not share the same nomenclature for nodes. For example, Kubernetes may refer to a given node as "node1", but the storage system may refer to the same node as "nodeA". When Kubernetes issues a command to the storage system to attach a volume to a specific node, it can use this field to refer to the node name using the ID that the storage system will understand, e.g. "nodeA" instead of "node1". This field is required.
             */
            nodeID: pulumi.Input<string>;
            /**
             * topologyKeys is the list of keys supported by the driver. When a driver is initialized on a cluster, it provides a set of topology keys that it understands (e.g. "company.com/zone", "company.com/region"). When a driver is initialized on a node, it provides the same topology keys along with values. Kubelet will expose these topology keys as labels on its own node object. When Kubernetes does topology aware provisioning, it can use this list to determine which labels it should retrieve from the node object and pass back to the driver. It is possible for different nodes to use different topology keys. This can be empty if driver does not support topology.
             */
            topologyKeys?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * CSINodeDriver holds information about the specification of one CSI driver installed on a node
         */
        interface CSINodeDriverPatch {
            /**
             * allocatable represents the volume resources of a node that are available for scheduling. This field is beta.
             */
            allocatable?: pulumi.Input<inputs.storage.v1.VolumeNodeResourcesPatch>;
            /**
             * name represents the name of the CSI driver that this object refers to. This MUST be the same name returned by the CSI GetPluginName() call for that driver.
             */
            name?: pulumi.Input<string>;
            /**
             * nodeID of the node from the driver point of view. This field enables Kubernetes to communicate with storage systems that do not share the same nomenclature for nodes. For example, Kubernetes may refer to a given node as "node1", but the storage system may refer to the same node as "nodeA". When Kubernetes issues a command to the storage system to attach a volume to a specific node, it can use this field to refer to the node name using the ID that the storage system will understand, e.g. "nodeA" instead of "node1". This field is required.
             */
            nodeID?: pulumi.Input<string>;
            /**
             * topologyKeys is the list of keys supported by the driver. When a driver is initialized on a cluster, it provides a set of topology keys that it understands (e.g. "company.com/zone", "company.com/region"). When a driver is initialized on a node, it provides the same topology keys along with values. Kubelet will expose these topology keys as labels on its own node object. When Kubernetes does topology aware provisioning, it can use this list to determine which labels it should retrieve from the node object and pass back to the driver. It is possible for different nodes to use different topology keys. This can be empty if driver does not support topology.
             */
            topologyKeys?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * CSINodeSpec holds information about the specification of all CSI drivers installed on a node
         */
        interface CSINodeSpec {
            /**
             * drivers is a list of information of all CSI Drivers existing on a node. If all drivers in the list are uninstalled, this can become empty.
             */
            drivers: pulumi.Input<pulumi.Input<inputs.storage.v1.CSINodeDriver>[]>;
        }
        /**
         * CSINodeSpec holds information about the specification of all CSI drivers installed on a node
         */
        interface CSINodeSpecPatch {
            /**
             * drivers is a list of information of all CSI Drivers existing on a node. If all drivers in the list are uninstalled, this can become empty.
             */
            drivers?: pulumi.Input<pulumi.Input<inputs.storage.v1.CSINodeDriverPatch>[]>;
        }
        /**
         * CSIStorageCapacity stores the result of one CSI GetCapacity call. For a given StorageClass, this describes the available capacity in a particular topology segment.  This can be used when considering where to instantiate new PersistentVolumes.
         *
         * For example this can express things like: - StorageClass "standard" has "1234 GiB" available in "topology.kubernetes.io/zone=us-east1" - StorageClass "localssd" has "10 GiB" available in "kubernetes.io/hostname=knode-abc123"
         *
         * The following three cases all imply that no capacity is available for a certain combination: - no object exists with suitable topology and storage class name - such an object exists, but the capacity is unset - such an object exists, but the capacity is zero
         *
         * The producer of these objects can decide which approach is more suitable.
         *
         * They are consumed by the kube-scheduler when a CSI driver opts into capacity-aware scheduling with CSIDriverSpec.StorageCapacity. The scheduler compares the MaximumVolumeSize against the requested size of pending volumes to filter out unsuitable nodes. If MaximumVolumeSize is unset, it falls back to a comparison against the less precise Capacity. If that is also unset, the scheduler assumes that capacity is insufficient and tries some other node.
         */
        interface CSIStorageCapacity {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"storage.k8s.io/v1">;
            /**
             * capacity is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields.
             *
             * The semantic is currently (CSI spec 1.2) defined as: The available capacity, in bytes, of the storage that can be used to provision volumes. If not set, that information is currently unavailable.
             */
            capacity?: pulumi.Input<string>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"CSIStorageCapacity">;
            /**
             * maximumVolumeSize is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields.
             *
             * This is defined since CSI spec 1.4.0 as the largest size that may be used in a CreateVolumeRequest.capacity_range.required_bytes field to create a volume with the same parameters as those in GetCapacityRequest. The corresponding value in the Kubernetes API is ResourceRequirements.Requests in a volume claim.
             */
            maximumVolumeSize?: pulumi.Input<string>;
            /**
             * Standard object's metadata. The name has no particular meaning. It must be a DNS subdomain (dots allowed, 253 characters). To ensure that there are no conflicts with other CSI drivers on the cluster, the recommendation is to use csisc-<uuid>, a generated name, or a reverse-domain name which ends with the unique CSI driver name.
             *
             * Objects are namespaced.
             *
             * More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * nodeTopology defines which nodes have access to the storage for which capacity was reported. If not set, the storage is not accessible from any node in the cluster. If empty, the storage is accessible from all nodes. This field is immutable.
             */
            nodeTopology?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * storageClassName represents the name of the StorageClass that the reported capacity applies to. It must meet the same requirements as the name of a StorageClass object (non-empty, DNS subdomain). If that object no longer exists, the CSIStorageCapacity object is obsolete and should be removed by its creator. This field is immutable.
             */
            storageClassName: pulumi.Input<string>;
        }
        /**
         * StorageClass describes the parameters for a class of storage for which PersistentVolumes can be dynamically provisioned.
         *
         * StorageClasses are non-namespaced; the name of the storage class according to etcd is in ObjectMeta.Name.
         */
        interface StorageClass {
            /**
             * allowVolumeExpansion shows whether the storage class allow volume expand.
             */
            allowVolumeExpansion?: pulumi.Input<boolean>;
            /**
             * allowedTopologies restrict the node topologies where volumes can be dynamically provisioned. Each volume plugin defines its own supported topology specifications. An empty TopologySelectorTerm list means there is no topology restriction. This field is only honored by servers that enable the VolumeScheduling feature.
             */
            allowedTopologies?: pulumi.Input<pulumi.Input<inputs.core.v1.TopologySelectorTerm>[]>;
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"storage.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"StorageClass">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * mountOptions controls the mountOptions for dynamically provisioned PersistentVolumes of this storage class. e.g. ["ro", "soft"]. Not validated - mount of the PVs will simply fail if one is invalid.
             */
            mountOptions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * parameters holds the parameters for the provisioner that should create volumes of this storage class.
             */
            parameters?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * provisioner indicates the type of the provisioner.
             */
            provisioner: pulumi.Input<string>;
            /**
             * reclaimPolicy controls the reclaimPolicy for dynamically provisioned PersistentVolumes of this storage class. Defaults to Delete.
             */
            reclaimPolicy?: pulumi.Input<string>;
            /**
             * volumeBindingMode indicates how PersistentVolumeClaims should be provisioned and bound.  When unset, VolumeBindingImmediate is used. This field is only honored by servers that enable the VolumeScheduling feature.
             */
            volumeBindingMode?: pulumi.Input<string>;
        }
        /**
         * TokenRequest contains parameters of a service account token.
         */
        interface TokenRequest {
            /**
             * audience is the intended audience of the token in "TokenRequestSpec". It will default to the audiences of kube apiserver.
             */
            audience: pulumi.Input<string>;
            /**
             * expirationSeconds is the duration of validity of the token in "TokenRequestSpec". It has the same default value of "ExpirationSeconds" in "TokenRequestSpec".
             */
            expirationSeconds?: pulumi.Input<number>;
        }
        /**
         * TokenRequest contains parameters of a service account token.
         */
        interface TokenRequestPatch {
            /**
             * audience is the intended audience of the token in "TokenRequestSpec". It will default to the audiences of kube apiserver.
             */
            audience?: pulumi.Input<string>;
            /**
             * expirationSeconds is the duration of validity of the token in "TokenRequestSpec". It has the same default value of "ExpirationSeconds" in "TokenRequestSpec".
             */
            expirationSeconds?: pulumi.Input<number>;
        }
        /**
         * VolumeAttachment captures the intent to attach or detach the specified volume to/from the specified node.
         *
         * VolumeAttachment objects are non-namespaced.
         */
        interface VolumeAttachment {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"storage.k8s.io/v1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"VolumeAttachment">;
            /**
             * Standard object metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec represents specification of the desired attach/detach volume behavior. Populated by the Kubernetes system.
             */
            spec: pulumi.Input<inputs.storage.v1.VolumeAttachmentSpec>;
            /**
             * status represents status of the VolumeAttachment request. Populated by the entity completing the attach or detach operation, i.e. the external-attacher.
             */
            status?: pulumi.Input<inputs.storage.v1.VolumeAttachmentStatus>;
        }
        /**
         * VolumeAttachmentSource represents a volume that should be attached. Right now only PersistentVolumes can be attached via external attacher, in the future we may allow also inline volumes in pods. Exactly one member can be set.
         */
        interface VolumeAttachmentSource {
            /**
             * inlineVolumeSpec contains all the information necessary to attach a persistent volume defined by a pod's inline VolumeSource. This field is populated only for the CSIMigration feature. It contains translated fields from a pod's inline VolumeSource to a PersistentVolumeSpec. This field is beta-level and is only honored by servers that enabled the CSIMigration feature.
             */
            inlineVolumeSpec?: pulumi.Input<inputs.core.v1.PersistentVolumeSpec>;
            /**
             * persistentVolumeName represents the name of the persistent volume to attach.
             */
            persistentVolumeName?: pulumi.Input<string>;
        }
        /**
         * VolumeAttachmentSource represents a volume that should be attached. Right now only PersistentVolumes can be attached via external attacher, in the future we may allow also inline volumes in pods. Exactly one member can be set.
         */
        interface VolumeAttachmentSourcePatch {
            /**
             * inlineVolumeSpec contains all the information necessary to attach a persistent volume defined by a pod's inline VolumeSource. This field is populated only for the CSIMigration feature. It contains translated fields from a pod's inline VolumeSource to a PersistentVolumeSpec. This field is beta-level and is only honored by servers that enabled the CSIMigration feature.
             */
            inlineVolumeSpec?: pulumi.Input<inputs.core.v1.PersistentVolumeSpecPatch>;
            /**
             * persistentVolumeName represents the name of the persistent volume to attach.
             */
            persistentVolumeName?: pulumi.Input<string>;
        }
        /**
         * VolumeAttachmentSpec is the specification of a VolumeAttachment request.
         */
        interface VolumeAttachmentSpec {
            /**
             * attacher indicates the name of the volume driver that MUST handle this request. This is the name returned by GetPluginName().
             */
            attacher: pulumi.Input<string>;
            /**
             * nodeName represents the node that the volume should be attached to.
             */
            nodeName: pulumi.Input<string>;
            /**
             * source represents the volume that should be attached.
             */
            source: pulumi.Input<inputs.storage.v1.VolumeAttachmentSource>;
        }
        /**
         * VolumeAttachmentSpec is the specification of a VolumeAttachment request.
         */
        interface VolumeAttachmentSpecPatch {
            /**
             * attacher indicates the name of the volume driver that MUST handle this request. This is the name returned by GetPluginName().
             */
            attacher?: pulumi.Input<string>;
            /**
             * nodeName represents the node that the volume should be attached to.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * source represents the volume that should be attached.
             */
            source?: pulumi.Input<inputs.storage.v1.VolumeAttachmentSourcePatch>;
        }
        /**
         * VolumeAttachmentStatus is the status of a VolumeAttachment request.
         */
        interface VolumeAttachmentStatus {
            /**
             * attachError represents the last error encountered during attach operation, if any. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.
             */
            attachError?: pulumi.Input<inputs.storage.v1.VolumeError>;
            /**
             * attached indicates the volume is successfully attached. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.
             */
            attached: pulumi.Input<boolean>;
            /**
             * attachmentMetadata is populated with any information returned by the attach operation, upon successful attach, that must be passed into subsequent WaitForAttach or Mount calls. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.
             */
            attachmentMetadata?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * detachError represents the last error encountered during detach operation, if any. This field must only be set by the entity completing the detach operation, i.e. the external-attacher.
             */
            detachError?: pulumi.Input<inputs.storage.v1.VolumeError>;
        }
        /**
         * VolumeError captures an error encountered during a volume operation.
         */
        interface VolumeError {
            /**
             * errorCode is a numeric gRPC code representing the error encountered during Attach or Detach operations.
             *
             * This is an optional, alpha field that requires the MutableCSINodeAllocatableCount feature gate being enabled to be set.
             */
            errorCode?: pulumi.Input<number>;
            /**
             * message represents the error encountered during Attach or Detach operation. This string may be logged, so it should not contain sensitive information.
             */
            message?: pulumi.Input<string>;
            /**
             * time represents the time the error was encountered.
             */
            time?: pulumi.Input<string>;
        }
        /**
         * VolumeNodeResources is a set of resource limits for scheduling of volumes.
         */
        interface VolumeNodeResources {
            /**
             * count indicates the maximum number of unique volumes managed by the CSI driver that can be used on a node. A volume that is both attached and mounted on a node is considered to be used once, not twice. The same rule applies for a unique volume that is shared among multiple pods on the same node. If this field is not specified, then the supported number of volumes on this node is unbounded.
             */
            count?: pulumi.Input<number>;
        }
        /**
         * VolumeNodeResources is a set of resource limits for scheduling of volumes.
         */
        interface VolumeNodeResourcesPatch {
            /**
             * count indicates the maximum number of unique volumes managed by the CSI driver that can be used on a node. A volume that is both attached and mounted on a node is considered to be used once, not twice. The same rule applies for a unique volume that is shared among multiple pods on the same node. If this field is not specified, then the supported number of volumes on this node is unbounded.
             */
            count?: pulumi.Input<number>;
        }
    }
    namespace v1alpha1 {
        /**
         * VolumeAttachment captures the intent to attach or detach the specified volume to/from the specified node.
         *
         * VolumeAttachment objects are non-namespaced.
         */
        interface VolumeAttachment {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"storage.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"VolumeAttachment">;
            /**
             * Standard object metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired attach/detach volume behavior. Populated by the Kubernetes system.
             */
            spec: pulumi.Input<inputs.storage.v1alpha1.VolumeAttachmentSpec>;
            /**
             * Status of the VolumeAttachment request. Populated by the entity completing the attach or detach operation, i.e. the external-attacher.
             */
            status?: pulumi.Input<inputs.storage.v1alpha1.VolumeAttachmentStatus>;
        }
        /**
         * VolumeAttachmentSource represents a volume that should be attached. Right now only PersistenVolumes can be attached via external attacher, in future we may allow also inline volumes in pods. Exactly one member can be set.
         */
        interface VolumeAttachmentSource {
            /**
             * inlineVolumeSpec contains all the information necessary to attach a persistent volume defined by a pod's inline VolumeSource. This field is populated only for the CSIMigration feature. It contains translated fields from a pod's inline VolumeSource to a PersistentVolumeSpec. This field is alpha-level and is only honored by servers that enabled the CSIMigration feature.
             */
            inlineVolumeSpec?: pulumi.Input<inputs.core.v1.PersistentVolumeSpec>;
            /**
             * Name of the persistent volume to attach.
             */
            persistentVolumeName?: pulumi.Input<string>;
        }
        /**
         * VolumeAttachmentSource represents a volume that should be attached. Right now only PersistenVolumes can be attached via external attacher, in future we may allow also inline volumes in pods. Exactly one member can be set.
         */
        interface VolumeAttachmentSourcePatch {
            /**
             * inlineVolumeSpec contains all the information necessary to attach a persistent volume defined by a pod's inline VolumeSource. This field is populated only for the CSIMigration feature. It contains translated fields from a pod's inline VolumeSource to a PersistentVolumeSpec. This field is alpha-level and is only honored by servers that enabled the CSIMigration feature.
             */
            inlineVolumeSpec?: pulumi.Input<inputs.core.v1.PersistentVolumeSpecPatch>;
            /**
             * Name of the persistent volume to attach.
             */
            persistentVolumeName?: pulumi.Input<string>;
        }
        /**
         * VolumeAttachmentSpec is the specification of a VolumeAttachment request.
         */
        interface VolumeAttachmentSpec {
            /**
             * Attacher indicates the name of the volume driver that MUST handle this request. This is the name returned by GetPluginName().
             */
            attacher: pulumi.Input<string>;
            /**
             * The node that the volume should be attached to.
             */
            nodeName: pulumi.Input<string>;
            /**
             * Source represents the volume that should be attached.
             */
            source: pulumi.Input<inputs.storage.v1alpha1.VolumeAttachmentSource>;
        }
        /**
         * VolumeAttachmentSpec is the specification of a VolumeAttachment request.
         */
        interface VolumeAttachmentSpecPatch {
            /**
             * Attacher indicates the name of the volume driver that MUST handle this request. This is the name returned by GetPluginName().
             */
            attacher?: pulumi.Input<string>;
            /**
             * The node that the volume should be attached to.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * Source represents the volume that should be attached.
             */
            source?: pulumi.Input<inputs.storage.v1alpha1.VolumeAttachmentSourcePatch>;
        }
        /**
         * VolumeAttachmentStatus is the status of a VolumeAttachment request.
         */
        interface VolumeAttachmentStatus {
            /**
             * The last error encountered during attach operation, if any. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.
             */
            attachError?: pulumi.Input<inputs.storage.v1alpha1.VolumeError>;
            /**
             * Indicates the volume is successfully attached. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.
             */
            attached: pulumi.Input<boolean>;
            /**
             * Upon successful attach, this field is populated with any information returned by the attach operation that must be passed into subsequent WaitForAttach or Mount calls. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.
             */
            attachmentMetadata?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * The last error encountered during detach operation, if any. This field must only be set by the entity completing the detach operation, i.e. the external-attacher.
             */
            detachError?: pulumi.Input<inputs.storage.v1alpha1.VolumeError>;
        }
        /**
         * VolumeAttributesClass represents a specification of mutable volume attributes defined by the CSI driver. The class can be specified during dynamic provisioning of PersistentVolumeClaims, and changed in the PersistentVolumeClaim spec after provisioning.
         */
        interface VolumeAttributesClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"storage.k8s.io/v1alpha1">;
            /**
             * Name of the CSI driver This field is immutable.
             */
            driverName: pulumi.Input<string>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"VolumeAttributesClass">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * parameters hold volume attributes defined by the CSI driver. These values are opaque to the Kubernetes and are passed directly to the CSI driver. The underlying storage provider supports changing these attributes on an existing volume, however the parameters field itself is immutable. To invoke a volume update, a new VolumeAttributesClass should be created with new parameters, and the PersistentVolumeClaim should be updated to reference the new VolumeAttributesClass.
             *
             * This field is required and must contain at least one key/value pair. The keys cannot be empty, and the maximum number of parameters is 512, with a cumulative max size of 256K. If the CSI driver rejects invalid parameters, the target PersistentVolumeClaim will be set to an "Infeasible" state in the modifyVolumeStatus field.
             */
            parameters?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * VolumeError captures an error encountered during a volume operation.
         */
        interface VolumeError {
            /**
             * String detailing the error encountered during Attach or Detach operation. This string maybe logged, so it should not contain sensitive information.
             */
            message?: pulumi.Input<string>;
            /**
             * Time the error was encountered.
             */
            time?: pulumi.Input<string>;
        }
    }
    namespace v1beta1 {
        /**
         * CSIDriver captures information about a Container Storage Interface (CSI) volume driver deployed on the cluster. CSI drivers do not need to create the CSIDriver object directly. Instead they may use the cluster-driver-registrar sidecar container. When deployed with a CSI driver it automatically creates a CSIDriver object representing the driver. Kubernetes attach detach controller uses this object to determine whether attach is required. Kubelet uses this object to determine whether pod information needs to be passed on mount. CSIDriver objects are non-namespaced.
         */
        interface CSIDriver {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"storage.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"CSIDriver">;
            /**
             * Standard object metadata. metadata.Name indicates the name of the CSI driver that this object refers to; it MUST be the same name returned by the CSI GetPluginName() call for that driver. The driver name must be 63 characters or less, beginning and ending with an alphanumeric character ([a-z0-9A-Z]) with dashes (-), dots (.), and alphanumerics between. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the CSI Driver.
             */
            spec: pulumi.Input<inputs.storage.v1beta1.CSIDriverSpec>;
        }
        /**
         * CSIDriverSpec is the specification of a CSIDriver.
         */
        interface CSIDriverSpec {
            /**
             * attachRequired indicates this CSI volume driver requires an attach operation (because it implements the CSI ControllerPublishVolume() method), and that the Kubernetes attach detach controller should call the attach volume interface which checks the volumeattachment status and waits until the volume is attached before proceeding to mounting. The CSI external-attacher coordinates with CSI volume driver and updates the volumeattachment status when the attach operation is complete. If the CSIDriverRegistry feature gate is enabled and the value is specified to false, the attach operation will be skipped. Otherwise the attach operation will be called.
             */
            attachRequired?: pulumi.Input<boolean>;
            /**
             * Defines if the underlying volume supports changing ownership and permission of the volume before being mounted. Refer to the specific FSGroupPolicy values for additional details. This field is alpha-level, and is only honored by servers that enable the CSIVolumeFSGroupPolicy feature gate.
             */
            fsGroupPolicy?: pulumi.Input<string>;
            /**
             * If set to true, podInfoOnMount indicates this CSI volume driver requires additional pod information (like podName, podUID, etc.) during mount operations. If set to false, pod information will not be passed on mount. Default is false. The CSI driver specifies podInfoOnMount as part of driver deployment. If true, Kubelet will pass pod information as VolumeContext in the CSI NodePublishVolume() calls. The CSI driver is responsible for parsing and validating the information passed in as VolumeContext. The following VolumeConext will be passed if podInfoOnMount is set to true. This list might grow, but the prefix will be used. "csi.storage.k8s.io/pod.name": pod.Name "csi.storage.k8s.io/pod.namespace": pod.Namespace "csi.storage.k8s.io/pod.uid": string(pod.UID) "csi.storage.k8s.io/ephemeral": "true" iff the volume is an ephemeral inline volume
             *                                 defined by a CSIVolumeSource, otherwise "false"
             *
             * "csi.storage.k8s.io/ephemeral" is a new feature in Kubernetes 1.16. It is only required for drivers which support both the "Persistent" and "Ephemeral" VolumeLifecycleMode. Other drivers can leave pod info disabled and/or ignore this field. As Kubernetes 1.15 doesn't support this field, drivers can only support one mode when deployed on such a cluster and the deployment determines which mode that is, for example via a command line parameter of the driver.
             */
            podInfoOnMount?: pulumi.Input<boolean>;
            /**
             * RequiresRepublish indicates the CSI driver wants `NodePublishVolume` being periodically called to reflect any possible change in the mounted volume. This field defaults to false.
             *
             * Note: After a successful initial NodePublishVolume call, subsequent calls to NodePublishVolume should only update the contents of the volume. New mount points will not be seen by a running container.
             *
             * This is an alpha feature and only available when the CSIServiceAccountToken feature is enabled.
             */
            requiresRepublish?: pulumi.Input<boolean>;
            /**
             * If set to true, storageCapacity indicates that the CSI volume driver wants pod scheduling to consider the storage capacity that the driver deployment will report by creating CSIStorageCapacity objects with capacity information.
             *
             * The check can be enabled immediately when deploying a driver. In that case, provisioning new volumes with late binding will pause until the driver deployment has published some suitable CSIStorageCapacity object.
             *
             * Alternatively, the driver can be deployed with the field unset or false and it can be flipped later when storage capacity information has been published.
             *
             * This is an alpha field and only available when the CSIStorageCapacity feature is enabled. The default is false.
             */
            storageCapacity?: pulumi.Input<boolean>;
            /**
             * TokenRequests indicates the CSI driver needs pods' service account tokens it is mounting volume for to do necessary authentication. Kubelet will pass the tokens in VolumeContext in the CSI NodePublishVolume calls. The CSI driver should parse and validate the following VolumeContext: "csi.storage.k8s.io/serviceAccount.tokens": {
             *   "<audience>": {
             *     "token": <token>,
             *     "expirationTimestamp": <expiration timestamp in RFC3339>,
             *   },
             *   ...
             * }
             *
             * Note: Audience in each TokenRequest should be different and at most one token is empty string. To receive a new token after expiry, RequiresRepublish can be used to trigger NodePublishVolume periodically.
             *
             * This is an alpha feature and only available when the CSIServiceAccountToken feature is enabled.
             */
            tokenRequests?: pulumi.Input<pulumi.Input<inputs.storage.v1beta1.TokenRequest>[]>;
            /**
             * VolumeLifecycleModes defines what kind of volumes this CSI volume driver supports. The default if the list is empty is "Persistent", which is the usage defined by the CSI specification and implemented in Kubernetes via the usual PV/PVC mechanism. The other mode is "Ephemeral". In this mode, volumes are defined inline inside the pod spec with CSIVolumeSource and their lifecycle is tied to the lifecycle of that pod. A driver has to be aware of this because it is only going to get a NodePublishVolume call for such a volume. For more information about implementing this mode, see https://kubernetes-csi.github.io/docs/ephemeral-local-volumes.html A driver can support one or more of these modes and more modes may be added in the future.
             */
            volumeLifecycleModes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * CSIDriverSpec is the specification of a CSIDriver.
         */
        interface CSIDriverSpecPatch {
            /**
             * attachRequired indicates this CSI volume driver requires an attach operation (because it implements the CSI ControllerPublishVolume() method), and that the Kubernetes attach detach controller should call the attach volume interface which checks the volumeattachment status and waits until the volume is attached before proceeding to mounting. The CSI external-attacher coordinates with CSI volume driver and updates the volumeattachment status when the attach operation is complete. If the CSIDriverRegistry feature gate is enabled and the value is specified to false, the attach operation will be skipped. Otherwise the attach operation will be called.
             */
            attachRequired?: pulumi.Input<boolean>;
            /**
             * Defines if the underlying volume supports changing ownership and permission of the volume before being mounted. Refer to the specific FSGroupPolicy values for additional details. This field is alpha-level, and is only honored by servers that enable the CSIVolumeFSGroupPolicy feature gate.
             */
            fsGroupPolicy?: pulumi.Input<string>;
            /**
             * If set to true, podInfoOnMount indicates this CSI volume driver requires additional pod information (like podName, podUID, etc.) during mount operations. If set to false, pod information will not be passed on mount. Default is false. The CSI driver specifies podInfoOnMount as part of driver deployment. If true, Kubelet will pass pod information as VolumeContext in the CSI NodePublishVolume() calls. The CSI driver is responsible for parsing and validating the information passed in as VolumeContext. The following VolumeConext will be passed if podInfoOnMount is set to true. This list might grow, but the prefix will be used. "csi.storage.k8s.io/pod.name": pod.Name "csi.storage.k8s.io/pod.namespace": pod.Namespace "csi.storage.k8s.io/pod.uid": string(pod.UID) "csi.storage.k8s.io/ephemeral": "true" iff the volume is an ephemeral inline volume
             *                                 defined by a CSIVolumeSource, otherwise "false"
             *
             * "csi.storage.k8s.io/ephemeral" is a new feature in Kubernetes 1.16. It is only required for drivers which support both the "Persistent" and "Ephemeral" VolumeLifecycleMode. Other drivers can leave pod info disabled and/or ignore this field. As Kubernetes 1.15 doesn't support this field, drivers can only support one mode when deployed on such a cluster and the deployment determines which mode that is, for example via a command line parameter of the driver.
             */
            podInfoOnMount?: pulumi.Input<boolean>;
            /**
             * RequiresRepublish indicates the CSI driver wants `NodePublishVolume` being periodically called to reflect any possible change in the mounted volume. This field defaults to false.
             *
             * Note: After a successful initial NodePublishVolume call, subsequent calls to NodePublishVolume should only update the contents of the volume. New mount points will not be seen by a running container.
             *
             * This is an alpha feature and only available when the CSIServiceAccountToken feature is enabled.
             */
            requiresRepublish?: pulumi.Input<boolean>;
            /**
             * If set to true, storageCapacity indicates that the CSI volume driver wants pod scheduling to consider the storage capacity that the driver deployment will report by creating CSIStorageCapacity objects with capacity information.
             *
             * The check can be enabled immediately when deploying a driver. In that case, provisioning new volumes with late binding will pause until the driver deployment has published some suitable CSIStorageCapacity object.
             *
             * Alternatively, the driver can be deployed with the field unset or false and it can be flipped later when storage capacity information has been published.
             *
             * This is an alpha field and only available when the CSIStorageCapacity feature is enabled. The default is false.
             */
            storageCapacity?: pulumi.Input<boolean>;
            /**
             * TokenRequests indicates the CSI driver needs pods' service account tokens it is mounting volume for to do necessary authentication. Kubelet will pass the tokens in VolumeContext in the CSI NodePublishVolume calls. The CSI driver should parse and validate the following VolumeContext: "csi.storage.k8s.io/serviceAccount.tokens": {
             *   "<audience>": {
             *     "token": <token>,
             *     "expirationTimestamp": <expiration timestamp in RFC3339>,
             *   },
             *   ...
             * }
             *
             * Note: Audience in each TokenRequest should be different and at most one token is empty string. To receive a new token after expiry, RequiresRepublish can be used to trigger NodePublishVolume periodically.
             *
             * This is an alpha feature and only available when the CSIServiceAccountToken feature is enabled.
             */
            tokenRequests?: pulumi.Input<pulumi.Input<inputs.storage.v1beta1.TokenRequestPatch>[]>;
            /**
             * VolumeLifecycleModes defines what kind of volumes this CSI volume driver supports. The default if the list is empty is "Persistent", which is the usage defined by the CSI specification and implemented in Kubernetes via the usual PV/PVC mechanism. The other mode is "Ephemeral". In this mode, volumes are defined inline inside the pod spec with CSIVolumeSource and their lifecycle is tied to the lifecycle of that pod. A driver has to be aware of this because it is only going to get a NodePublishVolume call for such a volume. For more information about implementing this mode, see https://kubernetes-csi.github.io/docs/ephemeral-local-volumes.html A driver can support one or more of these modes and more modes may be added in the future.
             */
            volumeLifecycleModes?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * CSINode holds information about all CSI drivers installed on a node. CSI drivers do not need to create the CSINode object directly. As long as they use the node-driver-registrar sidecar container, the kubelet will automatically populate the CSINode object for the CSI driver as part of kubelet plugin registration. CSINode has the same name as a node. If the object is missing, it means either there are no CSI Drivers available on the node, or the Kubelet version is low enough that it doesn't create this object. CSINode has an OwnerReference that points to the corresponding node object.
         */
        interface CSINode {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"storage.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"CSINode">;
            /**
             * metadata.name must be the Kubernetes node name.
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * spec is the specification of CSINode
             */
            spec: pulumi.Input<inputs.storage.v1beta1.CSINodeSpec>;
        }
        /**
         * CSINodeDriver holds information about the specification of one CSI driver installed on a node
         */
        interface CSINodeDriver {
            /**
             * allocatable represents the volume resources of a node that are available for scheduling.
             */
            allocatable?: pulumi.Input<inputs.storage.v1beta1.VolumeNodeResources>;
            /**
             * This is the name of the CSI driver that this object refers to. This MUST be the same name returned by the CSI GetPluginName() call for that driver.
             */
            name: pulumi.Input<string>;
            /**
             * nodeID of the node from the driver point of view. This field enables Kubernetes to communicate with storage systems that do not share the same nomenclature for nodes. For example, Kubernetes may refer to a given node as "node1", but the storage system may refer to the same node as "nodeA". When Kubernetes issues a command to the storage system to attach a volume to a specific node, it can use this field to refer to the node name using the ID that the storage system will understand, e.g. "nodeA" instead of "node1". This field is required.
             */
            nodeID: pulumi.Input<string>;
            /**
             * topologyKeys is the list of keys supported by the driver. When a driver is initialized on a cluster, it provides a set of topology keys that it understands (e.g. "company.com/zone", "company.com/region"). When a driver is initialized on a node, it provides the same topology keys along with values. Kubelet will expose these topology keys as labels on its own node object. When Kubernetes does topology aware provisioning, it can use this list to determine which labels it should retrieve from the node object and pass back to the driver. It is possible for different nodes to use different topology keys. This can be empty if driver does not support topology.
             */
            topologyKeys?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * CSINodeDriver holds information about the specification of one CSI driver installed on a node
         */
        interface CSINodeDriverPatch {
            /**
             * allocatable represents the volume resources of a node that are available for scheduling.
             */
            allocatable?: pulumi.Input<inputs.storage.v1beta1.VolumeNodeResourcesPatch>;
            /**
             * This is the name of the CSI driver that this object refers to. This MUST be the same name returned by the CSI GetPluginName() call for that driver.
             */
            name?: pulumi.Input<string>;
            /**
             * nodeID of the node from the driver point of view. This field enables Kubernetes to communicate with storage systems that do not share the same nomenclature for nodes. For example, Kubernetes may refer to a given node as "node1", but the storage system may refer to the same node as "nodeA". When Kubernetes issues a command to the storage system to attach a volume to a specific node, it can use this field to refer to the node name using the ID that the storage system will understand, e.g. "nodeA" instead of "node1". This field is required.
             */
            nodeID?: pulumi.Input<string>;
            /**
             * topologyKeys is the list of keys supported by the driver. When a driver is initialized on a cluster, it provides a set of topology keys that it understands (e.g. "company.com/zone", "company.com/region"). When a driver is initialized on a node, it provides the same topology keys along with values. Kubelet will expose these topology keys as labels on its own node object. When Kubernetes does topology aware provisioning, it can use this list to determine which labels it should retrieve from the node object and pass back to the driver. It is possible for different nodes to use different topology keys. This can be empty if driver does not support topology.
             */
            topologyKeys?: pulumi.Input<pulumi.Input<string>[]>;
        }
        /**
         * CSINodeSpec holds information about the specification of all CSI drivers installed on a node
         */
        interface CSINodeSpec {
            /**
             * drivers is a list of information of all CSI Drivers existing on a node. If all drivers in the list are uninstalled, this can become empty.
             */
            drivers: pulumi.Input<pulumi.Input<inputs.storage.v1beta1.CSINodeDriver>[]>;
        }
        /**
         * CSINodeSpec holds information about the specification of all CSI drivers installed on a node
         */
        interface CSINodeSpecPatch {
            /**
             * drivers is a list of information of all CSI Drivers existing on a node. If all drivers in the list are uninstalled, this can become empty.
             */
            drivers?: pulumi.Input<pulumi.Input<inputs.storage.v1beta1.CSINodeDriverPatch>[]>;
        }
        /**
         * CSIStorageCapacity stores the result of one CSI GetCapacity call. For a given StorageClass, this describes the available capacity in a particular topology segment.  This can be used when considering where to instantiate new PersistentVolumes.
         *
         * For example this can express things like: - StorageClass "standard" has "1234 GiB" available in "topology.kubernetes.io/zone=us-east1" - StorageClass "localssd" has "10 GiB" available in "kubernetes.io/hostname=knode-abc123"
         *
         * The following three cases all imply that no capacity is available for a certain combination: - no object exists with suitable topology and storage class name - such an object exists, but the capacity is unset - such an object exists, but the capacity is zero
         *
         * The producer of these objects can decide which approach is more suitable.
         *
         * They are consumed by the kube-scheduler when a CSI driver opts into capacity-aware scheduling with CSIDriverSpec.StorageCapacity. The scheduler compares the MaximumVolumeSize against the requested size of pending volumes to filter out unsuitable nodes. If MaximumVolumeSize is unset, it falls back to a comparison against the less precise Capacity. If that is also unset, the scheduler assumes that capacity is insufficient and tries some other node.
         */
        interface CSIStorageCapacity {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"storage.k8s.io/v1beta1">;
            /**
             * Capacity is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields.
             *
             * The semantic is currently (CSI spec 1.2) defined as: The available capacity, in bytes, of the storage that can be used to provision volumes. If not set, that information is currently unavailable.
             */
            capacity?: pulumi.Input<string>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"CSIStorageCapacity">;
            /**
             * MaximumVolumeSize is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields.
             *
             * This is defined since CSI spec 1.4.0 as the largest size that may be used in a CreateVolumeRequest.capacity_range.required_bytes field to create a volume with the same parameters as those in GetCapacityRequest. The corresponding value in the Kubernetes API is ResourceRequirements.Requests in a volume claim.
             */
            maximumVolumeSize?: pulumi.Input<string>;
            /**
             * Standard object's metadata. The name has no particular meaning. It must be be a DNS subdomain (dots allowed, 253 characters). To ensure that there are no conflicts with other CSI drivers on the cluster, the recommendation is to use csisc-<uuid>, a generated name, or a reverse-domain name which ends with the unique CSI driver name.
             *
             * Objects are namespaced.
             *
             * More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * NodeTopology defines which nodes have access to the storage for which capacity was reported. If not set, the storage is not accessible from any node in the cluster. If empty, the storage is accessible from all nodes. This field is immutable.
             */
            nodeTopology?: pulumi.Input<inputs.meta.v1.LabelSelector>;
            /**
             * The name of the StorageClass that the reported capacity applies to. It must meet the same requirements as the name of a StorageClass object (non-empty, DNS subdomain). If that object no longer exists, the CSIStorageCapacity object is obsolete and should be removed by its creator. This field is immutable.
             */
            storageClassName: pulumi.Input<string>;
        }
        /**
         * StorageClass describes the parameters for a class of storage for which PersistentVolumes can be dynamically provisioned.
         *
         * StorageClasses are non-namespaced; the name of the storage class according to etcd is in ObjectMeta.Name.
         */
        interface StorageClass {
            /**
             * AllowVolumeExpansion shows whether the storage class allow volume expand
             */
            allowVolumeExpansion?: pulumi.Input<boolean>;
            /**
             * Restrict the node topologies where volumes can be dynamically provisioned. Each volume plugin defines its own supported topology specifications. An empty TopologySelectorTerm list means there is no topology restriction. This field is only honored by servers that enable the VolumeScheduling feature.
             */
            allowedTopologies?: pulumi.Input<pulumi.Input<inputs.core.v1.TopologySelectorTerm>[]>;
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"storage.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"StorageClass">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Dynamically provisioned PersistentVolumes of this storage class are created with these mountOptions, e.g. ["ro", "soft"]. Not validated - mount of the PVs will simply fail if one is invalid.
             */
            mountOptions?: pulumi.Input<pulumi.Input<string>[]>;
            /**
             * Parameters holds the parameters for the provisioner that should create volumes of this storage class.
             */
            parameters?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * Provisioner indicates the type of the provisioner.
             */
            provisioner: pulumi.Input<string>;
            /**
             * Dynamically provisioned PersistentVolumes of this storage class are created with this reclaimPolicy. Defaults to Delete.
             */
            reclaimPolicy?: pulumi.Input<string>;
            /**
             * VolumeBindingMode indicates how PersistentVolumeClaims should be provisioned and bound.  When unset, VolumeBindingImmediate is used. This field is only honored by servers that enable the VolumeScheduling feature.
             */
            volumeBindingMode?: pulumi.Input<string>;
        }
        /**
         * TokenRequest contains parameters of a service account token.
         */
        interface TokenRequest {
            /**
             * Audience is the intended audience of the token in "TokenRequestSpec". It will default to the audiences of kube apiserver.
             */
            audience: pulumi.Input<string>;
            /**
             * ExpirationSeconds is the duration of validity of the token in "TokenRequestSpec". It has the same default value of "ExpirationSeconds" in "TokenRequestSpec"
             */
            expirationSeconds?: pulumi.Input<number>;
        }
        /**
         * TokenRequest contains parameters of a service account token.
         */
        interface TokenRequestPatch {
            /**
             * Audience is the intended audience of the token in "TokenRequestSpec". It will default to the audiences of kube apiserver.
             */
            audience?: pulumi.Input<string>;
            /**
             * ExpirationSeconds is the duration of validity of the token in "TokenRequestSpec". It has the same default value of "ExpirationSeconds" in "TokenRequestSpec"
             */
            expirationSeconds?: pulumi.Input<number>;
        }
        /**
         * VolumeAttachment captures the intent to attach or detach the specified volume to/from the specified node.
         *
         * VolumeAttachment objects are non-namespaced.
         */
        interface VolumeAttachment {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"storage.k8s.io/v1beta1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"VolumeAttachment">;
            /**
             * Standard object metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the desired attach/detach volume behavior. Populated by the Kubernetes system.
             */
            spec: pulumi.Input<inputs.storage.v1beta1.VolumeAttachmentSpec>;
            /**
             * Status of the VolumeAttachment request. Populated by the entity completing the attach or detach operation, i.e. the external-attacher.
             */
            status?: pulumi.Input<inputs.storage.v1beta1.VolumeAttachmentStatus>;
        }
        /**
         * VolumeAttachmentSource represents a volume that should be attached. Right now only PersistenVolumes can be attached via external attacher, in future we may allow also inline volumes in pods. Exactly one member can be set.
         */
        interface VolumeAttachmentSource {
            /**
             * inlineVolumeSpec contains all the information necessary to attach a persistent volume defined by a pod's inline VolumeSource. This field is populated only for the CSIMigration feature. It contains translated fields from a pod's inline VolumeSource to a PersistentVolumeSpec. This field is alpha-level and is only honored by servers that enabled the CSIMigration feature.
             */
            inlineVolumeSpec?: pulumi.Input<inputs.core.v1.PersistentVolumeSpec>;
            /**
             * Name of the persistent volume to attach.
             */
            persistentVolumeName?: pulumi.Input<string>;
        }
        /**
         * VolumeAttachmentSource represents a volume that should be attached. Right now only PersistenVolumes can be attached via external attacher, in future we may allow also inline volumes in pods. Exactly one member can be set.
         */
        interface VolumeAttachmentSourcePatch {
            /**
             * inlineVolumeSpec contains all the information necessary to attach a persistent volume defined by a pod's inline VolumeSource. This field is populated only for the CSIMigration feature. It contains translated fields from a pod's inline VolumeSource to a PersistentVolumeSpec. This field is alpha-level and is only honored by servers that enabled the CSIMigration feature.
             */
            inlineVolumeSpec?: pulumi.Input<inputs.core.v1.PersistentVolumeSpecPatch>;
            /**
             * Name of the persistent volume to attach.
             */
            persistentVolumeName?: pulumi.Input<string>;
        }
        /**
         * VolumeAttachmentSpec is the specification of a VolumeAttachment request.
         */
        interface VolumeAttachmentSpec {
            /**
             * Attacher indicates the name of the volume driver that MUST handle this request. This is the name returned by GetPluginName().
             */
            attacher: pulumi.Input<string>;
            /**
             * The node that the volume should be attached to.
             */
            nodeName: pulumi.Input<string>;
            /**
             * Source represents the volume that should be attached.
             */
            source: pulumi.Input<inputs.storage.v1beta1.VolumeAttachmentSource>;
        }
        /**
         * VolumeAttachmentSpec is the specification of a VolumeAttachment request.
         */
        interface VolumeAttachmentSpecPatch {
            /**
             * Attacher indicates the name of the volume driver that MUST handle this request. This is the name returned by GetPluginName().
             */
            attacher?: pulumi.Input<string>;
            /**
             * The node that the volume should be attached to.
             */
            nodeName?: pulumi.Input<string>;
            /**
             * Source represents the volume that should be attached.
             */
            source?: pulumi.Input<inputs.storage.v1beta1.VolumeAttachmentSourcePatch>;
        }
        /**
         * VolumeAttachmentStatus is the status of a VolumeAttachment request.
         */
        interface VolumeAttachmentStatus {
            /**
             * The last error encountered during attach operation, if any. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.
             */
            attachError?: pulumi.Input<inputs.storage.v1beta1.VolumeError>;
            /**
             * Indicates the volume is successfully attached. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.
             */
            attached: pulumi.Input<boolean>;
            /**
             * Upon successful attach, this field is populated with any information returned by the attach operation that must be passed into subsequent WaitForAttach or Mount calls. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.
             */
            attachmentMetadata?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
            /**
             * The last error encountered during detach operation, if any. This field must only be set by the entity completing the detach operation, i.e. the external-attacher.
             */
            detachError?: pulumi.Input<inputs.storage.v1beta1.VolumeError>;
        }
        /**
         * VolumeAttributesClass represents a specification of mutable volume attributes defined by the CSI driver. The class can be specified during dynamic provisioning of PersistentVolumeClaims, and changed in the PersistentVolumeClaim spec after provisioning.
         */
        interface VolumeAttributesClass {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"storage.k8s.io/v1beta1">;
            /**
             * Name of the CSI driver This field is immutable.
             */
            driverName: pulumi.Input<string>;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"VolumeAttributesClass">;
            /**
             * Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * parameters hold volume attributes defined by the CSI driver. These values are opaque to the Kubernetes and are passed directly to the CSI driver. The underlying storage provider supports changing these attributes on an existing volume, however the parameters field itself is immutable. To invoke a volume update, a new VolumeAttributesClass should be created with new parameters, and the PersistentVolumeClaim should be updated to reference the new VolumeAttributesClass.
             *
             * This field is required and must contain at least one key/value pair. The keys cannot be empty, and the maximum number of parameters is 512, with a cumulative max size of 256K. If the CSI driver rejects invalid parameters, the target PersistentVolumeClaim will be set to an "Infeasible" state in the modifyVolumeStatus field.
             */
            parameters?: pulumi.Input<{
                [key: string]: pulumi.Input<string>;
            }>;
        }
        /**
         * VolumeError captures an error encountered during a volume operation.
         */
        interface VolumeError {
            /**
             * String detailing the error encountered during Attach or Detach operation. This string may be logged, so it should not contain sensitive information.
             */
            message?: pulumi.Input<string>;
            /**
             * Time the error was encountered.
             */
            time?: pulumi.Input<string>;
        }
        /**
         * VolumeNodeResources is a set of resource limits for scheduling of volumes.
         */
        interface VolumeNodeResources {
            /**
             * Maximum number of unique volumes managed by the CSI driver that can be used on a node. A volume that is both attached and mounted on a node is considered to be used once, not twice. The same rule applies for a unique volume that is shared among multiple pods on the same node. If this field is nil, then the supported number of volumes on this node is unbounded.
             */
            count?: pulumi.Input<number>;
        }
        /**
         * VolumeNodeResources is a set of resource limits for scheduling of volumes.
         */
        interface VolumeNodeResourcesPatch {
            /**
             * Maximum number of unique volumes managed by the CSI driver that can be used on a node. A volume that is both attached and mounted on a node is considered to be used once, not twice. The same rule applies for a unique volume that is shared among multiple pods on the same node. If this field is nil, then the supported number of volumes on this node is unbounded.
             */
            count?: pulumi.Input<number>;
        }
    }
}
export declare namespace storagemigration {
    namespace v1alpha1 {
        /**
         * The names of the group, the version, and the resource.
         */
        interface GroupVersionResource {
            /**
             * The name of the group.
             */
            group?: pulumi.Input<string>;
            /**
             * The name of the resource.
             */
            resource?: pulumi.Input<string>;
            /**
             * The name of the version.
             */
            version?: pulumi.Input<string>;
        }
        /**
         * The names of the group, the version, and the resource.
         */
        interface GroupVersionResourcePatch {
            /**
             * The name of the group.
             */
            group?: pulumi.Input<string>;
            /**
             * The name of the resource.
             */
            resource?: pulumi.Input<string>;
            /**
             * The name of the version.
             */
            version?: pulumi.Input<string>;
        }
        /**
         * Describes the state of a migration at a certain point.
         */
        interface MigrationCondition {
            /**
             * The last time this condition was updated.
             */
            lastUpdateTime?: pulumi.Input<string>;
            /**
             * A human readable message indicating details about the transition.
             */
            message?: pulumi.Input<string>;
            /**
             * The reason for the condition's last transition.
             */
            reason?: pulumi.Input<string>;
            /**
             * Status of the condition, one of True, False, Unknown.
             */
            status: pulumi.Input<string>;
            /**
             * Type of the condition.
             */
            type: pulumi.Input<string>;
        }
        /**
         * StorageVersionMigration represents a migration of stored data to the latest storage version.
         */
        interface StorageVersionMigration {
            /**
             * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
             */
            apiVersion?: pulumi.Input<"storagemigration.k8s.io/v1alpha1">;
            /**
             * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
             */
            kind?: pulumi.Input<"StorageVersionMigration">;
            /**
             * Standard object metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
             */
            metadata?: pulumi.Input<inputs.meta.v1.ObjectMeta>;
            /**
             * Specification of the migration.
             */
            spec?: pulumi.Input<inputs.storagemigration.v1alpha1.StorageVersionMigrationSpec>;
            /**
             * Status of the migration.
             */
            status?: pulumi.Input<inputs.storagemigration.v1alpha1.StorageVersionMigrationStatus>;
        }
        /**
         * Spec of the storage version migration.
         */
        interface StorageVersionMigrationSpec {
            /**
             * The token used in the list options to get the next chunk of objects to migrate. When the .status.conditions indicates the migration is "Running", users can use this token to check the progress of the migration.
             */
            continueToken?: pulumi.Input<string>;
            /**
             * The resource that is being migrated. The migrator sends requests to the endpoint serving the resource. Immutable.
             */
            resource: pulumi.Input<inputs.storagemigration.v1alpha1.GroupVersionResource>;
        }
        /**
         * Spec of the storage version migration.
         */
        interface StorageVersionMigrationSpecPatch {
            /**
             * The token used in the list options to get the next chunk of objects to migrate. When the .status.conditions indicates the migration is "Running", users can use this token to check the progress of the migration.
             */
            continueToken?: pulumi.Input<string>;
            /**
             * The resource that is being migrated. The migrator sends requests to the endpoint serving the resource. Immutable.
             */
            resource?: pulumi.Input<inputs.storagemigration.v1alpha1.GroupVersionResourcePatch>;
        }
        /**
         * Status of the storage version migration.
         */
        interface StorageVersionMigrationStatus {
            /**
             * The latest available observations of the migration's current state.
             */
            conditions?: pulumi.Input<pulumi.Input<inputs.storagemigration.v1alpha1.MigrationCondition>[]>;
            /**
             * ResourceVersion to compare with the GC cache for performing the migration. This is the current resource version of given group, version and resource when kube-controller-manager first observes this StorageVersionMigration resource.
             */
            resourceVersion?: pulumi.Input<string>;
        }
    }
}
